
static void L1();
static void L3();
static void L5();
static void L7();
#define VC1
static object LI2();
#define VMB2 register object *base=vs_top;
#define VMS2  register object *sup=vs_top+0;vs_top=sup;
#define VMV2
#define VMR2(VMT2) return(VMT2);
#define VC3
static object LI4();
#define VMB4 register object *base=vs_top;
#define VMS4  register object *sup=vs_top+0;vs_top=sup;
#define VMV4
#define VMR4(VMT4) return(VMT4);
#define VC5
static object LI6();
#define VMB6 register object *base=vs_top;
#define VMS6  register object *sup=vs_top+0;vs_top=sup;
#define VMV6
#define VMR6(VMT6) return(VMT6);
#define VC7
static object LI8();
#define VMB8 register object *base=vs_top;
#define VMS8  register object *sup=vs_top+0;vs_top=sup;
#define VMV8
#define VMR8(VMT8) return(VMT8);
static object LI9();
#define VMB9 register object *base=vs_top;
#define VMS9  register object *sup=vs_top+1;vs_top=sup;
#define VMV9 vs_reserve(1);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static void LC13();
#define VC10
static void LC14();
#define VC11 object  V16;
static void LC12();
#define VC12
static void LC15();
#define VC13 object  V34;
static void LC11();
#define VC14
static void LC16();
#define VC15 object  V52;
static void LC10();
#define VC16
static void LC17();
#define VC17 object  V66;
static void LC17();
static void LC16();
static void LC15();
static void LC14();
static void LC13();
static void LC12();
static void LC11();
static void LC10();
#define VM17 4
#define VM16 3
#define VM15 4
#define VM14 3
#define VM13 4
#define VM12 3
#define VM11 4
#define VM10 3
#define VM9 1
#define VM8 0
#define VM7 4
#define VM6 0
#define VM5 4
#define VM4 0
#define VM3 4
#define VM2 0
#define VM1 4
static char * VVi[30]={
#define Cdata VV[29]
(char *)(L1),
(char *)(LI2),
(char *)(L3),
(char *)(LI4),
(char *)(L5),
(char *)(LI6),
(char *)(L7),
(char *)(LI8),
(char *)(LI9),
(char *)(&LC10),
(char *)(&LC11),
(char *)(&LC12),
(char *)(&LC13)
};
#define VV ((object *)VVi)
static void LnkT28();
static void (*Lnk28)() = LnkT28;
static void LnkT27();
static void (*Lnk27)() = LnkT27;
static void LnkT26();
static void (*Lnk26)() = LnkT26;
static void LnkT25();
static void (*Lnk25)() = LnkT25;
static void LnkT23();
static void (*Lnk23)() = LnkT23;
static void LnkT21();
static void (*Lnk21)() = LnkT21;
static void LnkT19();
static void (*Lnk19)() = LnkT19;
static void LnkT18();
static void (*Lnk18)() = LnkT18;
