;;; Tests of symbols
(compile-and-load "cl-symbols-aux.lsp")
;; (load "cl-symbol-names.lsp")  ;; moved to gclload1.lsp
(load "cl-symbols.lsp")
(load "symbolp.lsp")
(load "boundp.lsp")
(load "copy-symbol.lsp")
(load "gensym.lsp")
(load "gentemp.lsp")
(load "keywordp.lsp")
(load "make-symbol.lsp")
(load "symbol-name.lsp")
(load "special-operator-p.lsp")
(load "set.lsp")
