/* config.h.  Generated automatically by configure.  */
/* config.in.  Generated automatically from configure.in by autoheader.  */
/* Templates for defines setup by configure.

Copyright 2000, 2001 Free Software Foundation, Inc.

This file is part of the GNU MP Library.

The GNU MP Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or (at your
option) any later version.

The GNU MP Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
License for more details.

You should have received a copy of the GNU Lesser General Public License
along with the GNU MP Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. */



/* Define one (and only one) of these for the CPU host.
   Only hosts that are going to be tested for need to be in this list,
   not everything that can possibly be selected.
 */
/* #undef HAVE_HOST_CPU_alpha */
/* #undef HAVE_HOST_CPU_alphaev5 */
/* #undef HAVE_HOST_CPU_alphaev6 */
/* #undef HAVE_HOST_CPU_alphaev67 */

/* #undef HAVE_HOST_CPU_sparc */
/* #undef HAVE_HOST_CPU_sparcv8 */
/* #undef HAVE_HOST_CPU_supersparc */
/* #undef HAVE_HOST_CPU_sparclite */
/* #undef HAVE_HOST_CPU_microsparc */
/* #undef HAVE_HOST_CPU_ultrasparc1 */
/* #undef HAVE_HOST_CPU_ultrasparc2 */
/* #undef HAVE_HOST_CPU_sparc64 */

/* #undef HAVE_HOST_CPU_hppa1_0 */
/* #undef HAVE_HOST_CPU_hppa1_1 */
/* #undef HAVE_HOST_CPU_hppa2_0n */
/* #undef HAVE_HOST_CPU_hppa2_0w */

/* #undef HAVE_HOST_CPU_i386 */
/* #undef HAVE_HOST_CPU_i486 */
/* #undef HAVE_HOST_CPU_i586 */
#define HAVE_HOST_CPU_i686 1
/* #undef HAVE_HOST_CPU_pentium */
/* #undef HAVE_HOST_CPU_pentiummmx */
/* #undef HAVE_HOST_CPU_pentiumpro */
/* #undef HAVE_HOST_CPU_pentium2 */
/* #undef HAVE_HOST_CPU_pentium3 */
/* #undef HAVE_HOST_CPU_k5 */
/* #undef HAVE_HOST_CPU_k6 */
/* #undef HAVE_HOST_CPU_k62 */
/* #undef HAVE_HOST_CPU_k63 */
/* #undef HAVE_HOST_CPU_athlon */

/* a dummy to make autoheader happy */
/* #undef HAVE_HOST_CPU_ */


/* Define one (and only one) of these for the CPU host family.
   Only hosts that are going to be tested for need to be in this list,
   not everything that can possibly be selected.
 */
/* #undef HAVE_HOST_CPU_FAMILY_power */
/* #undef HAVE_HOST_CPU_FAMILY_powerpc */
#define HAVE_HOST_CPU_FAMILY_x86 1


/* Define if we have native implementation of function. */
/* #undef HAVE_NATIVE_mpn_add */
/* #undef HAVE_NATIVE_mpn_add_1 */
#define HAVE_NATIVE_mpn_add_n 1
#define HAVE_NATIVE_mpn_add_nc 1
#define HAVE_NATIVE_mpn_addmul_1 1
#define HAVE_NATIVE_mpn_addmul_1c 1
/* #undef HAVE_NATIVE_mpn_addsub_n */
/* #undef HAVE_NATIVE_mpn_addsub_nc */
/* #undef HAVE_NATIVE_mpn_and_n */
/* #undef HAVE_NATIVE_mpn_andn_n */
/* #undef HAVE_NATIVE_mpn_bdivmod */
/* #undef HAVE_NATIVE_mpn_cmp */
/* #undef HAVE_NATIVE_mpn_com_n */
#define HAVE_NATIVE_mpn_copyd 1
#define HAVE_NATIVE_mpn_copyi 1
#define HAVE_NATIVE_mpn_divexact_1 1
#define HAVE_NATIVE_mpn_divexact_by3c 1
/* #undef HAVE_NATIVE_mpn_divrem */
#define HAVE_NATIVE_mpn_divrem_1 1
#define HAVE_NATIVE_mpn_divrem_1c 1
/* #undef HAVE_NATIVE_mpn_divrem_2 */
/* #undef HAVE_NATIVE_mpn_divrem_newton */
/* #undef HAVE_NATIVE_mpn_divrem_classic */
/* #undef HAVE_NATIVE_mpn_dump */
/* #undef HAVE_NATIVE_mpn_gcd */
/* #undef HAVE_NATIVE_mpn_gcd_1 */
/* #undef HAVE_NATIVE_mpn_gcd_finda */
/* #undef HAVE_NATIVE_mpn_gcdext */
/* #undef HAVE_NATIVE_mpn_get_str */
/* #undef HAVE_NATIVE_mpn_hamdist */
/* #undef HAVE_NATIVE_mpn_invert_limb */
/* #undef HAVE_NATIVE_mpn_ior_n */
/* #undef HAVE_NATIVE_mpn_iorn_n */
#define HAVE_NATIVE_mpn_lshift 1
#define HAVE_NATIVE_mpn_mod_1 1
#define HAVE_NATIVE_mpn_mod_1c 1
#define HAVE_NATIVE_mpn_modexact_1_odd 1
#define HAVE_NATIVE_mpn_modexact_1c_odd 1
/* #undef HAVE_NATIVE_mpn_mul */
#define HAVE_NATIVE_mpn_mul_1 1
/* #undef HAVE_NATIVE_mpn_mul_1c */
/* #undef HAVE_NATIVE_mpn_mul_2 */
#define HAVE_NATIVE_mpn_mul_basecase 1
/* #undef HAVE_NATIVE_mpn_mul_n */
/* #undef HAVE_NATIVE_mpn_nand_n */
/* #undef HAVE_NATIVE_mpn_nior_n */
/* #undef HAVE_NATIVE_mpn_perfect_square_p */
/* #undef HAVE_NATIVE_mpn_popcount */
#define HAVE_NATIVE_mpn_preinv_mod_1 1
/* #undef HAVE_NATIVE_mpn_random2 */
/* #undef HAVE_NATIVE_mpn_random */
/* #undef HAVE_NATIVE_mpn_rawrandom */
#define HAVE_NATIVE_mpn_rshift 1
/* #undef HAVE_NATIVE_mpn_scan0 */
/* #undef HAVE_NATIVE_mpn_scan1 */
/* #undef HAVE_NATIVE_mpn_set_str */
/* #undef HAVE_NATIVE_mpn_sqrtrem */
#define HAVE_NATIVE_mpn_sqr_basecase 1
/* #undef HAVE_NATIVE_mpn_sqr_diagonal */
/* #undef HAVE_NATIVE_mpn_sub */
/* #undef HAVE_NATIVE_mpn_sub_1 */
#define HAVE_NATIVE_mpn_sub_n 1
#define HAVE_NATIVE_mpn_sub_nc 1
#define HAVE_NATIVE_mpn_submul_1 1
#define HAVE_NATIVE_mpn_submul_1c 1
/* #undef HAVE_NATIVE_mpn_udiv_w_sdiv */
#define HAVE_NATIVE_mpn_umul_ppmm 1
#define HAVE_NATIVE_mpn_udiv_qrnnd 1
/* #undef HAVE_NATIVE_mpn_xor_n */
/* #undef HAVE_NATIVE_mpn_xnor_n */

/* a dummy to make autoheader happy */
/* #undef HAVE_NATIVE_ */

/* bits per unsigned long, if not in gmp-mparam.h */
#define BITS_PER_ULONG BITS_PER_MP_LIMB

/* bytes per mp_limb_t, if not in gmp-mparam.h */
/* #undef BYTES_PER_MP_LIMB */

/* Define if you have the `alarm' function. */
#define HAVE_ALARM 1

/* Define if alloca() works (via gmp-impl.h). */
#define HAVE_ALLOCA 1

/* Define if you have <alloca.h> and it should be used (not on Ultrix). */
#define HAVE_ALLOCA_H 1

/* Define if the compiler accepts gcc style __attribute__ ((const)) */
#define HAVE_ATTRIBUTE_CONST 1

/* Define if the compiler accepts gcc style __attribute__ ((malloc)) */
#define HAVE_ATTRIBUTE_MALLOC 1

/* Define if the compiler accepts gcc style __attribute__ ((mode (XX))) */
#define HAVE_ATTRIBUTE_MODE 1

/* Define if the compiler accepts gcc style __attribute__ ((noreturn)) */
#define HAVE_ATTRIBUTE_NORETURN 1

/* Define if tests/libtests has calling conventions checking for the CPU */
#define HAVE_CALLING_CONVENTIONS 1

/* Define to 1 if you have the declaration of `fgetc', and to 0 if you don't.
   */
#define HAVE_DECL_FGETC 1

/* Define to 1 if you have the declaration of `fscanf', and to 0 if you don't.
   */
#define HAVE_DECL_FSCANF 1

/* Define to 1 if you have the declaration of `optarg', and to 0 if you don't.
   */
#define HAVE_DECL_OPTARG 1

/* Define to 1 if you have the declaration of `ungetc', and to 0 if you don't.
   */
#define HAVE_DECL_UNGETC 1

/* Define to 1 if you have the declaration of `vfprintf', and to 0 if you
   don't. */
#define HAVE_DECL_VFPRINTF 1

/* Define if you have the <dlfcn.h> header file. */
#define HAVE_DLFCN_H 1

/* Define if you have the `getpagesize' function. */
#define HAVE_GETPAGESIZE 1

/* Define if you have the `getrusage' function. */
#define HAVE_GETRUSAGE 1

/* Define if you have the `gettimeofday' function. */
#define HAVE_GETTIMEOFDAY 1

/* Define if the system has the type `intmax_t'. */
#define HAVE_INTMAX_T 1

/* Define if you have the <inttypes.h> header file. */
#define HAVE_INTTYPES_H 1

/* Define if you have the `localeconv' function. */
#define HAVE_LOCALECONV 1

/* Define if you have the <locale.h> header file. */
#define HAVE_LOCALE_H 1

/* Define if the system has the type `long double'. */
#define HAVE_LONG_DOUBLE 1

/* Define if the system has the type `long long'. */
#define HAVE_LONG_LONG 1

/* Define if you have the <memory.h> header file. */
#define HAVE_MEMORY_H 1

/* Define if you have the `memset' function. */
#define HAVE_MEMSET 1

/* Define if you have the `mmap' function. */
#define HAVE_MMAP 1

/* Define if you have the `mprotect' function. */
#define HAVE_MPROTECT 1

/* Define if you have the `obstack_vprintf' function. */
#define HAVE_OBSTACK_VPRINTF 1

/* Define if you have the `popen' function. */
#define HAVE_POPEN 1

/* Define if you have the `processor_info' function. */
/* #undef HAVE_PROCESSOR_INFO */

/* Define if the system has the type `ptrdiff_t'. */
#define HAVE_PTRDIFF_T 1

/* Define if the system has the type `quad_t'. */
#define HAVE_QUAD_T 1

/* Define if you have the `read_real_time' function. */
/* #undef HAVE_READ_REAL_TIME */

/* Tune directory speed_cyclecounter, undef=none, 1=32bits, 2=64bits) */
#define HAVE_SPEED_CYCLECOUNTER 2

/* Define if <stdarg.h> exists and works */
#define HAVE_STDARG 1

/* Define if you have the <stdint.h> header file. */
#define HAVE_STDINT_H 1

/* Define if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H 1

/* Define if you have the `strchr' function. */
#define HAVE_STRCHR 1

/* Define if cpp supports the ANSI # stringizing operator. */
#define HAVE_STRINGIZE 1

/* Define if you have the <strings.h> header file. */
#define HAVE_STRINGS_H 1

/* Define if you have the <string.h> header file. */
#define HAVE_STRING_H 1

/* Define if you have the `strnlen' function. */
#define HAVE_STRNLEN 1

/* Define if you have the `strtoul' function. */
#define HAVE_STRTOUL 1

/* Define if you have the `sysconf' function. */
#define HAVE_SYSCONF 1

/* Define if you have the `sysctl' function. */
#define HAVE_SYSCTL 1

/* Define if you have the `sysctlbyname' function. */
/* #undef HAVE_SYSCTLBYNAME */

/* Define if you have the <sys/mman.h> header file. */
#define HAVE_SYS_MMAN_H 1

/* Define if you have the <sys/param.h> header file. */
#define HAVE_SYS_PARAM_H 1

/* Define if you have the <sys/processor.h> header file. */
/* #undef HAVE_SYS_PROCESSOR_H */

/* Define if you have the <sys/resource.h> header file. */
#define HAVE_SYS_RESOURCE_H 1

/* Define if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define if you have the <sys/sysctl.h> header file. */
#define HAVE_SYS_SYSCTL_H 1

/* Define if you have the <sys/systemcfg.h> header file. */
/* #undef HAVE_SYS_SYSTEMCFG_H */

/* Define if you have the <sys/times.h> header file. */
#define HAVE_SYS_TIMES_H 1

/* Define if you have the <sys/time.h> header file. */
#define HAVE_SYS_TIME_H 1

/* Define if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define if you have the `times' function. */
#define HAVE_TIMES 1

/* Define if you have the <unistd.h> header file. */
#define HAVE_UNISTD_H 1

/* Define if you have vsnprintf and it works properly. */
#define HAVE_VSNPRINTF 1

/* Assembler local label prefix */
#define LSYM_PREFIX ".L"

/* Name of package */
#define PACKAGE "gmp"

/* Define if compiler has function prototypes */
#define PROTOTYPES 1

/* Define as the return type of signal handlers (`int' or `void'). */
#define RETSIGTYPE void

/* The size of a `mp_limb_t', as computed by sizeof. */
/* #undef SIZEOF_MP_LIMB_T */

/* The size of a `unsigned long', as computed by sizeof. */
/* #undef SIZEOF_UNSIGNED_LONG */

/* Define if sscanf requires writable inputs */
/* #undef SSCANF_WRITABLE_INPUT */

/* Define if you have the ANSI C header files. */
#define STDC_HEADERS 1

/* Define if you can safely include both <sys/time.h> and <time.h>. */
#define TIME_WITH_SYS_TIME 1

/* Maximum size the tune program can test for KARATSUBA_SQR_THRESHOLD */
#define TUNE_KARATSUBA_SQR_MAX 67

/* Version number of package */
#define VERSION "4.0.1"

/* ./configure --enable-assert option, to enable some ASSERT()s */
/* #undef WANT_ASSERT */

/* ./configure --enable-fft option, to enable FFTs for multiplication */
#define WANT_FFT 1

/* --enable-alloca=yes */
#define WANT_TMP_ALLOCA 1

/* --enable-alloca=debug */
/* #undef WANT_TMP_DEBUG */

/* --enable-alloca=malloc-notreentrant */
/* #undef WANT_TMP_NOTREENTRANT */

/* --enable-alloca=malloc-reentrant */
/* #undef WANT_TMP_REENTRANT */

/* Define as `__inline' if that's what the C compiler calls it, or to nothing
   if it is not supported. */
/* #undef inline */
