
static void L1();
#define VC1
static void LC2();
#define VC2 object  V13 ,V10;
static void LC2();
#define VM2 11
#define VM3 1
#define VM1 4
static char * VVi[2]={
#define Cdata VV[1]
(char *)(L1)
};
#define VV ((object *)VVi)
