;-*- Mode:     Lisp -*-
;;;; Author:   Paul Dietz
;;;; Created:  Mon Mar 24 03:39:09 2003
;;;; Contains: Loader for CLOS-related test files

(compile-and-load "defclass-aux.lsp")
(load "defclass.lsp")
(load "defclass-01.lsp")
(load "defclass-02.lsp")
(load "defclass-03.lsp")
(load "defclass-errors.lsp")
(load "defclass-forward-reference.lsp")
(load "ensure-generic-function.lsp")
(load "allocate-instance.lsp")
(load "reinitialize-instance.lsp")
(load "shared-initialize.lsp")
(load "change-class.lsp")
(load "update-instance-for-different-class.lsp")
(load "slot-boundp.lsp")
(load "slot-exists-p.lsp")
(load "slot-makunbound.lsp")
(load "slot-missing.lsp")
(load "slot-unbound.lsp")
(load "slot-value.lsp")
(load "method-qualifiers.lsp")
(load "no-applicable-method.lsp")
(load "no-next-method.lsp")
(load "remove-method.lsp")
(load "make-instance.lsp")
(load "make-instances-obsolete.lsp")
(load "make-load-form.lsp")
(load "make-load-form-saving-slots.lsp")
(load "with-accessors.lsp")
(load "with-slots.lsp")
(load "defgeneric.lsp")
(load "defgeneric-method-combination-aux.lsp")
(load "defgeneric-method-combination-plus.lsp")
(load "defgeneric-method-combination-append.lsp")
(load "defgeneric-method-combination-nconc.lsp")
(load "defgeneric-method-combination-list.lsp")
(load "defgeneric-method-combination-max.lsp")
(load "defgeneric-method-combination-min.lsp")
(load "defgeneric-method-combination-and.lsp")
(load "defgeneric-method-combination-or.lsp")
(load "defgeneric-method-combination-progn.lsp")
;; (load "defgeneric-method-combination-standard.lsp")
(load "find-class.lsp")
(load "next-method-p.lsp")
(load "call-next-method.lsp")
(load "compute-applicable-methods.lsp")
(load "define-method-combination.lsp")
(load "find-method.lsp")
(load "add-method.lsp")
(load "class-name.lsp")
(load "class-of.lsp")
(load "unbound-slot.lsp")
