
static void L1();
static void L2();
static void L3();
static void L6();
static void L7();
static void L8();
static void L9();
static void L10();
static void L11();
static void L12();
static void L13();
static void L15();
static void L16();
static void L19();
static void L23();
static void L28();
static void L31();
static void L32();
static void L44();
#define VC1 object  V2;
#define VC2 object  V4;
#define VC3
static object LI4(object,...);
static struct { short n,allow_other_keys;object *defaults;
	 KEYTYPE keys[2];} LI4key={2,0,Cstd_key_defaults,{(void *)71,(void *)72}};
#define VMB4 register object *base=vs_top; object Vcs[4];
#define VMS4  register object *sup=vs_top+3;vs_top=sup;
#define VMV4 vs_check;
#define VMR4(VMT4) vs_top=base ; return(VMT4);
static object LI5();
#define VMB5 register object *base=vs_top;
#define VMS5  register object *sup=vs_top+3;vs_top=sup;
#define VMV5 vs_check;
#define VMR5(VMT5) vs_top=base ; return(VMT5);
#define VC6
#define VC7
#define VC8
#define VC9
#define VC10 object  V19 ,V18 ,V17;
#define VC11 object  V23 ,V22 ,V21;
#define VC12 object  V27 ,V26 ,V25;
#define VC13 object  V31 ,V30 ,V29;
static object LI14();
#define VMB14 register object *base=vs_top; object  V41 ,V40 ,V39;
#define VMS14  register object *sup=vs_top+4;vs_top=sup;
#define VMV14 vs_check;
#define VMR14(VMT14) vs_top=base ; return(VMT14);
#define VC15
#define VC16
static object LI17();
#define VMB17
#define VMS17
#define VMV17
#define VMR17(VMT17) return(VMT17);
static object LI18();
#define VMB18
#define VMS18
#define VMV18
#define VMR18(VMT18) return(VMT18);
#define VC19
static object LI20();
#define VMB20
#define VMS20
#define VMV20
#define VMR20(VMT20) return(VMT20);
static object LI21();
#define VMB21 register object *base=vs_top;
#define VMS21  register object *sup=vs_top+8;vs_top=sup;
#define VMV21 vs_check;
#define VMR21(VMT21) vs_top=base ; return(VMT21);
static object LI22();
#define VMB22
#define VMS22
#define VMV22
#define VMR22(VMT22) return(VMT22);
#define VC23
static object LI25();
#define VMB24 register object *base=vs_top;
#define VMS24 vs_top += 1;
#define VMV24 vs_check;
#define VMR24(VMT24) vs_top=base ; return(VMT24);
static object LI27();
#define VMB25 register object *base=vs_top;
#define VMS25  register object *sup=vs_top+5;vs_top=sup;
#define VMV25 vs_check;
#define VMR25(VMT25) vs_top=base ; return(VMT25);
#define VC26 object  V79 ,V78;
static object LI29(object,object,object,...);
#define VMB27 object  V85; object Vcs[3];
#define VMS27
#define VMV27
#define VMR27(VMT27) return(VMT27);
static object LI30();
#define VMB28
#define VMS28
#define VMV28
#define VMR28(VMT28) return(VMT28);
#define VC29 object  V112 ,V111 ,V107 ,V106 ,V105 ,V104 ,V103 ,V102 ,V101;
#define VC30 object  V117 ,V116 ,V115 ,V114;
static object LI33();
#define VMB31 register object *base=vs_top;
#define VMS31  register object *sup=vs_top+4;vs_top=sup;
#define VMV31 vs_check;
#define VMR31(VMT31) vs_top=base ; return(VMT31);
static object LI34();
#define VMB32 register object *base=vs_top; object  V130;
#define VMS32  register object *sup=vs_top+1;vs_top=sup;
#define VMV32 vs_check;
#define VMR32(VMT32) vs_top=base ; return(VMT32);
static object LI35();
#define VMB33 register object *base=vs_top;
#define VMS33  register object *sup=vs_top+1;vs_top=sup;
#define VMV33 vs_check;
#define VMR33(VMT33) vs_top=base ; return(VMT33);
static object LI36();
#define VMB34 register object *base=vs_top;
#define VMS34  register object *sup=vs_top+1;vs_top=sup;
#define VMV34 vs_check;
#define VMR34(VMT34) vs_top=base ; return(VMT34);
static object LI37();
#define VMB35 register object *base=vs_top; object  V142;
#define VMS35  register object *sup=vs_top+2;vs_top=sup;
#define VMV35 vs_check;
#define VMR35(VMT35) vs_top=base ; return(VMT35);
static object LI38();
#define VMB36 register object *base=vs_top; object  V146;
#define VMS36  register object *sup=vs_top+2;vs_top=sup;
#define VMV36 vs_check;
#define VMR36(VMT36) vs_top=base ; return(VMT36);
static object LI39();
#define VMB37 register object *base=vs_top; object  V150;
#define VMS37  register object *sup=vs_top+2;vs_top=sup;
#define VMV37 vs_check;
#define VMR37(VMT37) vs_top=base ; return(VMT37);
static object LI40();
#define VMB38
#define VMS38
#define VMV38
#define VMR38(VMT38) return(VMT38);
static object LI41();
#define VMB39
#define VMS39
#define VMV39
#define VMR39(VMT39) return(VMT39);
static object LI42();
#define VMB40
#define VMS40
#define VMV40
#define VMR40(VMT40) return(VMT40);
static object LI43();
#define VMB41
#define VMS41
#define VMV41
#define VMR41(VMT41) return(VMT41);
#define VC42
static void LC46();
#define VC43
static void LC45();
#define VC44
static void LC46();
static void LC45();
#define VM44 4
#define VM43 3
#define VM42 2
#define VM41 0
#define VM40 0
#define VM39 0
#define VM38 0
#define VM37 2
#define VM36 2
#define VM35 2
#define VM34 1
#define VM33 1
#define VM32 1
#define VM31 4
#define VM30 4
#define VM29 5
#define VM28 0
#define VM27 0
#define VM26 4
#define VM25 5
#define VM24 1
#define VM23 4
#define VM22 0
#define VM21 8
#define VM20 0
#define VM19 6
#define VM18 0
#define VM17 0
#define VM16 4
#define VM15 4
#define VM14 4
#define VM13 4
#define VM12 4
#define VM11 4
#define VM10 4
#define VM9 4
#define VM8 4
#define VM7 5
#define VM6 5
#define VM5 3
#define VM4 3
#define VM3 4
#define VM2 6
#define VM1 5
static char * VVi[89]={
#define Cdata VV[88]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(LI4),
(char *)(&LI4key),
(char *)(LI5),
(char *)(L6),
(char *)(L7),
(char *)(L8),
(char *)(L9),
(char *)(L10),
(char *)(L11),
(char *)(L12),
(char *)(L13),
(char *)(LI14),
(char *)(L15),
(char *)(L16),
(char *)(LI17),
(char *)(LI18),
(char *)(L19),
(char *)(LI20),
(char *)(LI21),
(char *)(LI22),
(char *)(L23),
(char *)(LI25),
(char *)(LI27),
(char *)(L28),
(char *)(LI29),
(char *)(LI30),
(char *)(L31),
(char *)(L32),
(char *)(LI33),
(char *)(LI34),
(char *)(LI35),
(char *)(LI36),
(char *)(LI37),
(char *)(LI38),
(char *)(LI39),
(char *)(LI40),
(char *)(LI41),
(char *)(LI42),
(char *)(LI43),
(char *)(L44)
};
#define VV ((object *)VVi)
static void LnkT87();
static void (*Lnk87)() = LnkT87;
static object  LnkTLI86(object,...);
static object  (*LnkLI86)() = (object (*)()) LnkTLI86;
static object  LnkTLI85();
static object  (*LnkLI85)() = LnkTLI85;
static void LnkT84();
static void (*Lnk84)() = LnkT84;
static void LnkT83();
static void (*Lnk83)() = LnkT83;
static object  LnkTLI82(object,...);
static object  (*LnkLI82)() = (object (*)()) LnkTLI82;
static object  LnkTLI81();
static object  (*LnkLI81)() = LnkTLI81;
static object  LnkTLI80(object,...);
static object  (*LnkLI80)() = (object (*)()) LnkTLI80;
static void LnkT79();
static void (*Lnk79)() = LnkT79;
static object  LnkTLI76(object,...);
static object  (*LnkLI76)() = (object (*)()) LnkTLI76;
static object  LnkTLI75(object,...);
static object  (*LnkLI75)() = (object (*)()) LnkTLI75;
static object  LnkTLI74(object,...);
static object  (*LnkLI74)() = (object (*)()) LnkTLI74;
static object  LnkTLI73(object,...);
static object  (*LnkLI73)() = (object (*)()) LnkTLI73;
