
static void L1();
static void L3();
static void L4();
static void L5();
static void L9();
static void L10();
#define VC1 object  V5 ,V4 ,V3;
static object LI2();
#define VMB2 register object *base=vs_top; object  V10;
#define VMS2  register object *sup=vs_top+3;vs_top=sup;
#define VMV2 vs_reserve(3);
#define VMR2(VMT2) vs_top=base ; return(VMT2);
#define VC3 object  V47 ,V46 ,V45 ,V44 ,V43 ,V42 ,V41 ,V40 ,V39 ,V38 ,V37 ,V36 ,V35 ,V34 ,V33 ,V32 ,V31 ,V30 ,V29 ,V28 ,V27;
#define VC4 object  V66 ,V65 ,V64 ,V63 ,V62 ,V61 ,V60 ,V59 ,V58 ,V57 ,V56;
#define VC5 object  V70 ,V69;
static object LI6();
#define VMB6 register object *base=vs_top; object  V79 ,V78;
#define VMS6  register object *sup=vs_top+6;vs_top=sup;
#define VMV6 vs_reserve(6);
#define VMR6(VMT6) vs_top=base ; return(VMT6);
static object LI7();
#define VMB7 register object *base=vs_top; object  V84;
#define VMS7  register object *sup=vs_top+1;vs_top=sup;
#define VMV7 vs_reserve(1);
#define VMR7(VMT7) vs_top=base ; return(VMT7);
static object LI8(object,object,...);
#define VMB8 register object *base=vs_top; object  V134 ,V133 ,V132 ,V131 ,V130 ,V129 ,V128 ,V123 ,V114 ,V106 ,V105 ,V104 ,V103 ,V102 ,V101 ,V96; object Vcs[2];
#define VMS8  register object *sup=vs_top+8;vs_top=sup;
#define VMV8 vs_reserve(8);
#define VMR8(VMT8) vs_top=base ; return(VMT8);
#define VC9
#define VC10 object  V200 ,V199 ,V198 ,V197 ,V196 ,V195 ,V194 ,V193 ,V192 ,V191 ,V190 ,V189 ,V188 ,V187 ,V186 ,V185 ,V184 ,V183 ,V182 ,V181 ,V180 ,V179 ,V178 ,V177 ,V176 ,V175 ,V174 ,V173 ,V172 ,V171 ,V170 ,V169 ,V168 ,V167 ,V166 ,V165 ,V164 ,V163 ,V162 ,V161 ,V160 ,V159 ,V158 ,V157 ,V156 ,V155 ,V154 ,V153 ,V152 ,V151;
#define VM10 8
#define VM9 4
#define VM8 8
#define VM7 1
#define VM6 6
#define VM5 6
#define VM4 7
#define VM3 7
#define VM2 3
#define VM1 4
static char * VVi[70]={
#define Cdata VV[69]
(char *)(L1),
(char *)(LI2),
(char *)(L3),
(char *)(L4),
(char *)(L5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(L9),
(char *)(L10)
};
#define VV ((object *)VVi)
static void LnkT68();
static void (*Lnk68)() = LnkT68;
static object  LnkTLI67(object,...);
static object  (*LnkLI67)() = (object (*)()) LnkTLI67;
static object  LnkTLI66(object,...);
static object  (*LnkLI66)() = (object (*)()) LnkTLI66;
static void LnkT65();
static void (*Lnk65)() = LnkT65;
static object  LnkTLI63(object,...);
static object  (*LnkLI63)() = (object (*)()) LnkTLI63;
static object  LnkTLI62(object,...);
static object  (*LnkLI62)() = (object (*)()) LnkTLI62;
static void LnkT15();
static void (*Lnk15)() = LnkT15;
static void LnkT61();
static void (*Lnk61)() = LnkT61;
