
static void L25();
static void L26();
static void L27();
static void L54();
static void L56();
static object LI1();
#define VMB1 register object *base=vs_top;
#define VMS1  register object *sup=vs_top+1;vs_top=sup;
#define VMV1 vs_reserve(1);
#define VMR1(VMT1) vs_top=base ; return(VMT1);
static object LI2();
#define VMB2 register object *base=vs_top;
#define VMS2  register object *sup=vs_top+1;vs_top=sup;
#define VMV2 vs_reserve(1);
#define VMR2(VMT2) vs_top=base ; return(VMT2);
static object LI3();
#define VMB3
#define VMS3
#define VMV3
#define VMR3(VMT3) return(VMT3);
static object LI4();
#define VMB4 register object *base=vs_top;
#define VMS4  register object *sup=vs_top+1;vs_top=sup;
#define VMV4 vs_reserve(1);
#define VMR4(VMT4) vs_top=base ; return(VMT4);
static object LI5();
#define VMB5 register object *base=vs_top;
#define VMS5  register object *sup=vs_top+1;vs_top=sup;
#define VMV5 vs_reserve(1);
#define VMR5(VMT5) vs_top=base ; return(VMT5);
static object LI6();
#define VMB6
#define VMS6
#define VMV6
#define VMR6(VMT6) return(VMT6);
static object LI7();
#define VMB7 register object *base=vs_top;
#define VMS7  register object *sup=vs_top+1;vs_top=sup;
#define VMV7 vs_reserve(1);
#define VMR7(VMT7) vs_top=base ; return(VMT7);
static object LI8();
#define VMB8 register object *base=vs_top;
#define VMS8  register object *sup=vs_top+1;vs_top=sup;
#define VMV8 vs_reserve(1);
#define VMR8(VMT8) vs_top=base ; return(VMT8);
static object LI9();
#define VMB9
#define VMS9
#define VMV9
#define VMR9(VMT9) return(VMT9);
static object LI10();
#define VMB10 register object *base=vs_top;
#define VMS10  register object *sup=vs_top+1;vs_top=sup;
#define VMV10 vs_reserve(1);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI11();
#define VMB11 register object *base=vs_top;
#define VMS11  register object *sup=vs_top+1;vs_top=sup;
#define VMV11 vs_reserve(1);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI12();
#define VMB12
#define VMS12
#define VMV12
#define VMR12(VMT12) return(VMT12);
static object LI13();
#define VMB13 register object *base=vs_top;
#define VMS13  register object *sup=vs_top+1;vs_top=sup;
#define VMV13 vs_reserve(1);
#define VMR13(VMT13) vs_top=base ; return(VMT13);
static object LI14();
#define VMB14 register object *base=vs_top;
#define VMS14  register object *sup=vs_top+1;vs_top=sup;
#define VMV14 vs_reserve(1);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI15();
#define VMB15
#define VMS15
#define VMV15
#define VMR15(VMT15) return(VMT15);
static object LI16();
#define VMB16 register object *base=vs_top;
#define VMS16  register object *sup=vs_top+1;vs_top=sup;
#define VMV16 vs_reserve(1);
#define VMR16(VMT16) vs_top=base ; return(VMT16);
static object LI17();
#define VMB17 register object *base=vs_top;
#define VMS17  register object *sup=vs_top+1;vs_top=sup;
#define VMV17 vs_reserve(1);
#define VMR17(VMT17) vs_top=base ; return(VMT17);
static object LI18();
#define VMB18
#define VMS18
#define VMV18
#define VMR18(VMT18) return(VMT18);
static object LI19();
#define VMB19 register object *base=vs_top;
#define VMS19  register object *sup=vs_top+1;vs_top=sup;
#define VMV19 vs_reserve(1);
#define VMR19(VMT19) vs_top=base ; return(VMT19);
static object LI20();
#define VMB20 register object *base=vs_top;
#define VMS20  register object *sup=vs_top+1;vs_top=sup;
#define VMV20 vs_reserve(1);
#define VMR20(VMT20) vs_top=base ; return(VMT20);
static object LI21();
#define VMB21
#define VMS21
#define VMV21
#define VMR21(VMT21) return(VMT21);
static object LI22();
#define VMB22 register object *base=vs_top;
#define VMS22  register object *sup=vs_top+1;vs_top=sup;
#define VMV22 vs_reserve(1);
#define VMR22(VMT22) vs_top=base ; return(VMT22);
static object LI23();
#define VMB23 register object *base=vs_top;
#define VMS23  register object *sup=vs_top+1;vs_top=sup;
#define VMV23 vs_reserve(1);
#define VMR23(VMT23) vs_top=base ; return(VMT23);
static object LI24();
#define VMB24
#define VMS24
#define VMV24
#define VMR24(VMT24) return(VMT24);
#define VC25
#define VC26
#define VC27 object  V32 ,V31 ,V30 ,V29 ,V28;
static object LI28();
#define VMB28 register object *base=vs_top; object  V39;
#define VMS28  register object *sup=vs_top+4;vs_top=sup;
#define VMV28 vs_reserve(4);
#define VMR28(VMT28) vs_top=base ; return(VMT28);
static object LI29();
#define VMB29 object  V41;
#define VMS29
#define VMV29
#define VMR29(VMT29) return(VMT29);
static object LI30();
#define VMB30
#define VMS30
#define VMV30
#define VMR30(VMT30) return(VMT30);
static object LI31();
#define VMB31
#define VMS31
#define VMV31
#define VMR31(VMT31) return(VMT31);
static object LI32();
#define VMB32 object  V45;
#define VMS32
#define VMV32
#define VMR32(VMT32) return(VMT32);
static object LI33();
#define VMB33
#define VMS33
#define VMV33
#define VMR33(VMT33) return(VMT33);
static object LI34();
#define VMB34
#define VMS34
#define VMV34
#define VMR34(VMT34) return(VMT34);
static object LI35();
#define VMB35 object  V49;
#define VMS35
#define VMV35
#define VMR35(VMT35) return(VMT35);
static object LI36();
#define VMB36
#define VMS36
#define VMV36
#define VMR36(VMT36) return(VMT36);
static object LI37();
#define VMB37
#define VMS37
#define VMV37
#define VMR37(VMT37) return(VMT37);
static object LI38();
#define VMB38 object  V53;
#define VMS38
#define VMV38
#define VMR38(VMT38) return(VMT38);
static object LI39();
#define VMB39
#define VMS39
#define VMV39
#define VMR39(VMT39) return(VMT39);
static object LI40();
#define VMB40
#define VMS40
#define VMV40
#define VMR40(VMT40) return(VMT40);
static object LI41();
#define VMB41 object  V57;
#define VMS41
#define VMV41
#define VMR41(VMT41) return(VMT41);
static object LI42();
#define VMB42
#define VMS42
#define VMV42
#define VMR42(VMT42) return(VMT42);
static object LI43();
#define VMB43
#define VMS43
#define VMV43
#define VMR43(VMT43) return(VMT43);
static object LI44();
#define VMB44 register object *base=vs_top;
#define VMS44  register object *sup=vs_top+1;vs_top=sup;
#define VMV44 vs_reserve(1);
#define VMR44(VMT44) vs_top=base ; return(VMT44);
static object LI45();
#define VMB45 register object *base=vs_top;
#define VMS45  register object *sup=vs_top+1;vs_top=sup;
#define VMV45 vs_reserve(1);
#define VMR45(VMT45) vs_top=base ; return(VMT45);
static object LI46();
#define VMB46
#define VMS46
#define VMV46
#define VMR46(VMT46) return(VMT46);
static object LI47(object,...);
#define VMB47 register object *base=vs_top; object  V75; object Vcs[3];
#define VMS47  register object *sup=vs_top+7;vs_top=sup;
#define VMV47 vs_reserve(7);
#define VMR47(VMT47) vs_top=base ; return(VMT47);
static object LI48();
#define VMB48 register object *base=vs_top;
#define VMS48  register object *sup=vs_top+1;vs_top=sup;
#define VMV48 vs_reserve(1);
#define VMR48(VMT48) vs_top=base ; return(VMT48);
static object LI49();
#define VMB49 register object *base=vs_top;
#define VMS49  register object *sup=vs_top+1;vs_top=sup;
#define VMV49 vs_reserve(1);
#define VMR49(VMT49) vs_top=base ; return(VMT49);
static object LI50();
#define VMB50
#define VMS50
#define VMV50
#define VMR50(VMT50) return(VMT50);
static object LI51();
#define VMB51 register object *base=vs_top;
#define VMS51  register object *sup=vs_top+1;vs_top=sup;
#define VMV51 vs_reserve(1);
#define VMR51(VMT51) vs_top=base ; return(VMT51);
static object LI52();
#define VMB52 register object *base=vs_top;
#define VMS52  register object *sup=vs_top+1;vs_top=sup;
#define VMV52 vs_reserve(1);
#define VMR52(VMT52) vs_top=base ; return(VMT52);
static object LI53();
#define VMB53
#define VMS53
#define VMV53
#define VMR53(VMT53) return(VMT53);
#define VC54 object  V87;
static object LI55();
#define VMB55 register object *base=vs_top;
#define VMS55  register object *sup=vs_top+9;vs_top=sup;
#define VMV55 vs_reserve(9);
#define VMR55(VMT55) vs_top=base ; return(VMT55);
#define VC56 object  V111 ,V110 ,V109 ,V108 ,V103 ,V101 ,V99 ,V98 ,V97 ,V96;
static void LC64();
#define VC57
static void LC63();
#define VC58
static void LC62();
#define VC59
static void LC61();
#define VC60
static void LC60();
#define VC61
static void LC59();
#define VC62
static void LC58();
#define VC63
static void LC57();
#define VC64
static void LC64();
static void LC63();
static void LC62();
static void LC61();
static void LC60();
static void LC59();
static void LC58();
static void LC57();
#define VM64 4
#define VM63 4
#define VM62 2
#define VM61 2
#define VM60 3
#define VM59 2
#define VM58 1
#define VM57 4
#define VM56 11
#define VM55 9
#define VM54 6
#define VM53 0
#define VM52 1
#define VM51 1
#define VM50 0
#define VM49 1
#define VM48 1
#define VM47 7
#define VM46 0
#define VM45 1
#define VM44 1
#define VM43 0
#define VM42 0
#define VM41 0
#define VM40 0
#define VM39 0
#define VM38 0
#define VM37 0
#define VM36 0
#define VM35 0
#define VM34 0
#define VM33 0
#define VM32 0
#define VM31 0
#define VM30 0
#define VM29 0
#define VM28 4
#define VM27 6
#define VM26 4
#define VM25 4
#define VM24 0
#define VM23 1
#define VM22 1
#define VM21 0
#define VM20 1
#define VM19 1
#define VM18 0
#define VM17 1
#define VM16 1
#define VM15 0
#define VM14 1
#define VM13 1
#define VM12 0
#define VM11 1
#define VM10 1
#define VM9 0
#define VM8 1
#define VM7 1
#define VM6 0
#define VM5 1
#define VM4 1
#define VM3 0
#define VM2 1
#define VM1 1
static char * VVi[85]={
#define Cdata VV[84]
(char *)(LI1),
(char *)(LI2),
(char *)(LI3),
(char *)(LI4),
(char *)(LI5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(LI16),
(char *)(LI17),
(char *)(LI18),
(char *)(LI19),
(char *)(LI20),
(char *)(LI21),
(char *)(LI22),
(char *)(LI23),
(char *)(LI24),
(char *)(L25),
(char *)(L26),
(char *)(L27),
(char *)(LI28),
(char *)(LI29),
(char *)(LI30),
(char *)(LI31),
(char *)(LI32),
(char *)(LI33),
(char *)(LI34),
(char *)(LI35),
(char *)(LI36),
(char *)(LI37),
(char *)(LI38),
(char *)(LI39),
(char *)(LI40),
(char *)(LI41),
(char *)(LI42),
(char *)(LI43),
(char *)(LI44),
(char *)(LI45),
(char *)(LI46),
(char *)(LI47),
(char *)(LI48),
(char *)(LI49),
(char *)(LI50),
(char *)(LI51),
(char *)(LI52),
(char *)(LI53),
(char *)(L54),
(char *)(LI55),
(char *)(L56),
(char *)(&LC57),
(char *)(&LC58),
(char *)(&LC59),
(char *)(&LC60),
(char *)(&LC61),
(char *)(&LC62)
};
#define VV ((object *)VVi)
static void LnkT83();
static void (*Lnk83)() = LnkT83;
static void LnkT82();
static void (*Lnk82)() = LnkT82;
static object  LnkTLI81(object,...);
static object  (*LnkLI81)() = (object (*)()) LnkTLI81;
static void LnkT80();
static void (*Lnk80)() = LnkT80;
static object  LnkTLI79();
static object  (*LnkLI79)() = LnkTLI79;
static object  LnkTLI78(object,...);
static object  (*LnkLI78)() = (object (*)()) LnkTLI78;
static object  LnkTLI77(object,...);
static object  (*LnkLI77)() = (object (*)()) LnkTLI77;
static object  LnkTLI76(object,...);
static object  (*LnkLI76)() = (object (*)()) LnkTLI76;
static void LnkT75();
static void (*Lnk75)() = LnkT75;
static void LnkT74();
static void (*Lnk74)() = LnkT74;
static void LnkT73();
static void (*Lnk73)() = LnkT73;
static void LnkT67();
static void (*Lnk67)() = LnkT67;
static void LnkT65();
static void (*Lnk65)() = LnkT65;
