
(IN-PACKAGE "CONDITIONS") 
(PROCLAIM '(FTYPE (FUNCTION (*) (*)) SYSTEM::CLCS-BREAK-QUIT)) 
(PROCLAIM '(FTYPE (FUNCTION (T) (*)) CONDITION-BACKTRACE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) *) COERCE-TO-CONDITION
            |(PCL::FAST-METHOD PRINT-OBJECT (SIMPLE-CONDITION T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (TYPE-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (CASE-FAILURE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (END-OF-FILE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (PACKAGE-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (UNBOUND-VARIABLE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (UNDEFINED-FUNCTION T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (ABORT-FAILURE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (INTERNAL-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (INTERNAL-SIMPLE-ERROR T))|)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T *) *) CLCS-UNIVERSAL-ERROR-HANDLER)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) *) RESTART-PRINT
            EXECUTE-DEBUGGER-COMMAND)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T) T) ACCUMULATE-CASES)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) SET-INTERNAL-ERROR)) 
(PROCLAIM '(FTYPE (FUNCTION (T T *) T) CERROR)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) T)
            |(PCL::FAST-METHOD PRINT-OBJECT (CONDITION T))|)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL *) SYSTEM::BREAK-RESUME ABORT CONTINUE
            MUFFLE-WARNING SYSTEM::BREAK-HELP)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL T) INSTALL-CLCS-SYMBOLS REVERT-CLCS-SYMBOLS
            KCL-TOP-RESTARTS READ-DEBUG-COMMAND
            INITIALIZE-INTERNAL-ERROR-TABLE READ-EVALUATED-FORM)) 
(PROCLAIM '(FTYPE (FUNCTION (*) *) CLCS-COMPILE INVOKE-DEBUGGER)) 
(PROCLAIM
    '(FTYPE (FUNCTION (*) T) MAKE-RESTART BREAK COMPUTE-RESTARTS
            SHOW-RESTARTS)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) *) SYSTEM::CLCS-BREAK-LEVEL-INVOKE-RESTART
            COMPILER::CMP-TOPLEVEL-EVAL INVOKE-RESTART-INTERACTIVELY
            STORE-VALUE USE-VALUE CLCS-ERROR-SET
            SIMPLE-ASSERTION-FAILURE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) T) SYSTEM::CLCS-TERMINAL-INTERRUPT
            RESTART-FUNCTION RESTART-REPORT-FUNCTION
            RESTART-INTERACTIVE-FUNCTION RESTART-P REVERT-SYMBOL
            CONDITIONP CONDITION-CLASS-P UNIQUE-ID MAKE-KCL-TOP-RESTART
            FIND-KCL-TOP-RESTART RESTART-NAME STANDARD-DEBUGGER
            SIMPLE-CONDITION-CLASS-P RESET-FUNCTION
            ESCAPE-SPECIAL-CASES-REPLACE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) *) CLCS-COMPILE-FILE CLCS-LOAD CLCS-OPEN
            ERROR MAKE-CONDITION INVOKE-RESTART)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) T) WARN SIGNAL FIND-RESTART
            SYSTEM::CLCS-BREAK-LEVEL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) *) PARSE-KEYWORD-PAIRS RESTART-REPORT
            ASSERT-PROMPT)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) T) INSTALL-SYMBOL SIMPLE-CONDITION-PRINTER
            INTERNAL-SIMPLE-ERROR-PRINTER ASSERT-REPORT)) 