
static void L1();
static void L3();
static void L5();
static void L6();
static void L9();
static void L11();
static void L12();
static void L13();
static void L15();
#define VC1
static object LI2();
#define VMB2 register object *base=vs_top;
#define VMS2  register object *sup=vs_top+1;vs_top=sup;
#define VMV2 vs_check;
#define VMR2(VMT2) vs_top=base ; return(VMT2);
#define VC3 object  V15;
static object LI4();
#define VMB4 register object *base=vs_top; object  V26 ,V25 ,V24 ,V23 ,V22;
#define VMS4  register object *sup=vs_top+7;vs_top=sup;
#define VMV4 vs_check;
#define VMR4(VMT4) vs_top=base ; return(VMT4);
#define VC5 object  V34 ,V33 ,V32;
#define VC6
static object LI7();
#define VMB7 register object *base=vs_top; object  V74 ,V73 ,V72 ,V71 ,V68 ,V64;
#define VMS7  register object *sup=vs_top+4;vs_top=sup;
#define VMV7 vs_check;
#define VMR7(VMT7) vs_top=base ; return(VMT7);
#define VC8 object  V76;
static object LI10();
#define VMB9 register object *base=vs_top; object  V94 ,V93 ,V92 ,V91 ,V87 ,V85;
#define VMS9  register object *sup=vs_top+6;vs_top=sup;
#define VMV9 vs_check;
#define VMR9(VMT9) vs_top=base ; return(VMT9);
#define VC10 object  V105 ,V104 ,V103 ,V102 ,V101;
#define VC11
#define VC12
static object LI14();
#define VMB13 register object *base=vs_top; object  V181 ,V180 ,V179 ,V178 ,V177 ,V176 ,V173 ,V172 ,V171 ,V169 ,V168 ,V167 ,V166 ,V165 ,V164 ,V162 ,V161 ,V159 ,V158;
#define VMS13  register object *sup=vs_top+5;vs_top=sup;
#define VMV13 vs_check;
#define VMR13(VMT13) vs_top=base ; return(VMT13);
#define VC14 object  V196 ,V195;
static object LI16();
#define VMB15 register object *base=vs_top;
#define VMS15  register object *sup=vs_top+3;vs_top=sup;
#define VMV15 vs_check;
#define VMR15(VMT15) vs_top=base ; return(VMT15);
static object LI17();
#define VMB16
#define VMS16
#define VMV16
#define VMR16(VMT16) return(VMT16);
static object LI18();
#define VMB17 register object *base=vs_top; object  V217;
#define VMS17  register object *sup=vs_top+5;vs_top=sup;
#define VMV17 vs_check;
#define VMR17(VMT17) vs_top=base ; return(VMT17);
static object LI19();
#define VMB18 register object *base=vs_top; object  V259 ,V258 ,V257 ,V256 ,V248 ,V247 ,V236 ,V235 ,V233 ,V232;
#define VMS18  register object *sup=vs_top+3;vs_top=sup;
#define VMV18 vs_check;
#define VMR18(VMT18) vs_top=base ; return(VMT18);
static void LC21();
#define VC19
static void L8();
#define VC20
static void LC20();
#define VC21
static void LC21();
static void LC20();
#define VM21 9
#define VM20 8
#define VM19 10
#define VM18 3
#define VM17 5
#define VM16 0
#define VM15 3
#define VM14 11
#define VM13 5
#define VM12 8
#define VM11 9
#define VM10 17
#define VM9 6
#define VM8 6
#define VM7 4
#define VM6 19
#define VM5 19
#define VM4 7
#define VM3 6
#define VM2 1
#define VM1 4
static char * VVi[143]={
#define Cdata VV[142]
(char *)(L1),
(char *)(LI2),
(char *)(L3),
(char *)(LI4),
(char *)(L5),
(char *)(L6),
(char *)(LI7),
(char *)(L9),
(char *)(LI10),
(char *)(L11),
(char *)(L12),
(char *)(L13),
(char *)(LI14),
(char *)(L15),
(char *)(LI16),
(char *)(LI17),
(char *)(LI18),
(char *)(LI19)
};
#define VV ((object *)VVi)
static void LnkT141();
static void (*Lnk141)() = LnkT141;
static void LnkT140();
static void (*Lnk140)() = LnkT140;
static object  LnkTLI139(object,...);
static object  (*LnkLI139)() = (object (*)()) LnkTLI139;
static object  LnkTLI138(object,...);
static object  (*LnkLI138)() = (object (*)()) LnkTLI138;
static void LnkT137();
static void (*Lnk137)() = LnkT137;
static object  LnkTLI136(object,...);
static object  (*LnkLI136)() = (object (*)()) LnkTLI136;
static object  LnkTLI135(object,...);
static object  (*LnkLI135)() = (object (*)()) LnkTLI135;
static void LnkT134();
static void (*Lnk134)() = LnkT134;
static void LnkT133();
static void (*Lnk133)() = LnkT133;
static object *Lclptr132;
static void LnkT132();
static void (*Lnk132)() = LnkT132;
static object *Lclptr131;
static void LnkT131();
static void (*Lnk131)() = LnkT131;
static object *Lclptr130;
static void LnkT130();
static void (*Lnk130)() = LnkT130;
static object *Lclptr129;
static void LnkT129();
static void (*Lnk129)() = LnkT129;
static object *Lclptr126;
static void LnkT126();
static void (*Lnk126)() = LnkT126;
static object  LnkTLI124(object,...);
static object  (*LnkLI124)() = (object (*)()) LnkTLI124;
static object  LnkTLI123(object,...);
static object  (*LnkLI123)() = (object (*)()) LnkTLI123;
static object  LnkTLI122(object,...);
static object  (*LnkLI122)() = (object (*)()) LnkTLI122;
static void LnkT121();
static void (*Lnk121)() = LnkT121;
static object  LnkTLI120(object,...);
static object  (*LnkLI120)() = (object (*)()) LnkTLI120;
static void LnkT118();
static void (*Lnk118)() = LnkT118;
static object  LnkTLI117(object,...);
static object  (*LnkLI117)() = (object (*)()) LnkTLI117;
static object  LnkTLI116(object,...);
static object  (*LnkLI116)() = (object (*)()) LnkTLI116;
