
static void L1();
static void L2();
static void L3();
static void L4();
static void L5();
static void L6();
static void L7();
static void L8();
static void L9();
#define VC1
#define VC2
#define VC3
#define VC4
#define VC5
#define VC6
#define VC7
#define VC8
#define VC9
#define VM9 4
#define VM8 4
#define VM7 4
#define VM6 4
#define VM5 4
#define VM4 4
#define VM3 4
#define VM2 4
#define VM1 4
static char * VVi[12]={
#define Cdata VV[11]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(L4),
(char *)(L5),
(char *)(L6),
(char *)(L7),
(char *)(L8),
(char *)(L9)
};
#define VV ((object *)VVi)
static void LnkT10();
static void (*Lnk10)() = LnkT10;
