
static void L1();
static void L2();
static void L3();
static void L4();
static void L5();
static void L6();
static void L7();
static void L8();
#define VC1 object  V9 ,V8 ,V7 ,V6 ,V5;
#define VC2 object  V22 ,V21 ,V20 ,V19 ,V18 ,V17;
#define VC3 object  V29 ,V28 ,V27 ,V26 ,V25;
#define VC4
#define VC5
#define VC6
#define VC7
#define VC8 object  V63 ,V62 ,V61 ,V60 ,V59;
static object LI9(object,...);
#define VMB9 register object *base=vs_top; object  V66; object Vcs[2];
#define VMS9  register object *sup=vs_top+4;vs_top=sup;
#define VMV9 vs_reserve(4);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10(object,...);
#define VMB10 register object *base=vs_top; object  V72; object Vcs[2];
#define VMS10  register object *sup=vs_top+4;vs_top=sup;
#define VMV10 vs_reserve(4);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI11();
#define VMB11 register object *base=vs_top; object  V89 ,V87;
#define VMS11  register object *sup=vs_top+4;vs_top=sup;
#define VMV11 vs_reserve(4);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI12(object,...);
#define VMB12 register object *base=vs_top; object Vcs[2];
#define VMS12  register object *sup=vs_top+11;vs_top=sup;
#define VMV12 vs_reserve(11);
#define VMR12(VMT12) vs_top=base ; return(VMT12);
#define VM12 11
#define VM11 4
#define VM10 4
#define VM9 4
#define VM8 6
#define VM7 3
#define VM6 3
#define VM5 26
#define VM4 13
#define VM3 6
#define VM2 9
#define VM1 6
static char * VVi[60]={
#define Cdata VV[59]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(L4),
(char *)(L5),
(char *)(L6),
(char *)(L7),
(char *)(L8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12)
};
#define VV ((object *)VVi)
static void LnkT58();
static void (*Lnk58)() = LnkT58;
static void LnkT11();
static void (*Lnk11)() = LnkT11;
static object  LnkTLI57(object,...);
static object  (*LnkLI57)() = (object (*)()) LnkTLI57;
static object  LnkTLI56(object,...);
static object  (*LnkLI56)() = (object (*)()) LnkTLI56;
static void LnkT9();
static void (*Lnk9)() = LnkT9;
static void LnkT55();
static void (*Lnk55)() = LnkT55;
static void LnkT6();
static void (*Lnk6)() = LnkT6;
static void LnkT44();
static void (*Lnk44)() = LnkT44;
static void LnkT4();
static void (*Lnk4)() = LnkT4;
static void LnkT39();
static void (*Lnk39)() = LnkT39;
