
static void L1();
static void L2();
static void L3();
static void L5();
static void L6();
static void L9();
#define VC1
#define VC2
#define VC3 object  V16 ,V12;
static object LI4();
#define VMB4
#define VMS4
#define VMV4
#define VMR4(VMT4) return(VMT4);
#define VC5
#define VC6 object  V26 ,V24;
static object LI8();
#define VMB7 register object *base=vs_top;
#define VMS7 vs_top += 2;
#define VMV7 vs_check;
#define VMR7(VMT7) vs_top=base ; return(VMT7);
#define VC8
static void LC28();
#define VC9
static void LC29();
#define VC10
static void LC27();
#define VC11
static void LC30();
#define VC12 object  V58;
static void LC26();
#define VC13
static void LC31();
#define VC14
static void LC25();
#define VC15
static void LC32();
#define VC16 object  V89;
static void LC24();
#define VC17
static void LC33();
#define VC18 object  V105;
static void LC23();
#define VC19
static void LC34();
#define VC20 long  V133; object  V125;
static void LC22();
#define VC21
static void LC35();
#define VC22 long  V154; object  V146;
static void LC21();
#define VC23
static void LC36();
#define VC24 object  V168;
static void LC20();
#define VC25
static void LC37();
#define VC26 object  V184;
static void LC19();
#define VC27
static void LC38();
#define VC28 long  V210; object  V202;
static void LC18();
#define VC29
static void LC39();
#define VC30 long  V231; object  V223;
static void LC17();
#define VC31
static void LC40();
#define VC32 object  V240;
static void LC16();
#define VC33
static void LC41();
#define VC34 object  V246;
static void LC15();
#define VC35
static void LC42();
#define VC36 object  V255;
static void LC14();
#define VC37
static void LC43();
#define VC38 object  V261;
static void LC13();
#define VC39
static void LC44();
#define VC40 object  V270;
static void LC12();
#define VC41
static void LC45();
#define VC42 object  V277;
static void LC11();
#define VC43
static void LC46();
#define VC44 object  V285;
static void LC10();
#define VC45
static void LC47();
#define VC46 object  V292;
static void LC47();
static void LC46();
static void LC45();
static void LC44();
static void LC43();
static void LC42();
static void LC41();
static void LC40();
static void LC39();
static void LC38();
static void LC37();
static void LC36();
static void LC35();
static void LC34();
static void LC33();
static void LC32();
static void LC31();
static void LC30();
static void LC29();
static void LC28();
static void LC27();
static void LC26();
static void LC25();
static void LC24();
static void LC23();
static void LC22();
static void LC21();
static void LC20();
static void LC19();
static void LC18();
static void LC17();
static void LC16();
static void LC15();
static void LC14();
static void LC13();
static void LC12();
static void LC11();
static void LC10();
#define VM46 4
#define VM45 4
#define VM44 4
#define VM43 4
#define VM42 4
#define VM41 5
#define VM40 4
#define VM39 5
#define VM38 5
#define VM37 4
#define VM36 5
#define VM35 4
#define VM34 5
#define VM33 5
#define VM32 5
#define VM31 5
#define VM30 3
#define VM29 3
#define VM28 3
#define VM27 3
#define VM26 3
#define VM25 4
#define VM24 3
#define VM23 4
#define VM22 4
#define VM21 3
#define VM20 4
#define VM19 3
#define VM18 4
#define VM17 4
#define VM16 4
#define VM15 4
#define VM14 3
#define VM13 3
#define VM12 3
#define VM11 4
#define VM10 3
#define VM9 2
#define VM8 4
#define VM7 2
#define VM6 6
#define VM5 3
#define VM4 0
#define VM3 4
#define VM2 5
#define VM1 5
static char * VVi[58]={
#define Cdata VV[57]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(LI4),
(char *)(L5),
(char *)(L6),
(char *)(LI8),
(char *)(L9),
(char *)(&LC10),
(char *)(&LC11),
(char *)(&LC12),
(char *)(&LC13),
(char *)(&LC14),
(char *)(&LC15),
(char *)(&LC16),
(char *)(&LC17),
(char *)(&LC18),
(char *)(&LC19),
(char *)(&LC20),
(char *)(&LC21),
(char *)(&LC22),
(char *)(&LC23),
(char *)(&LC24),
(char *)(&LC25),
(char *)(&LC28)
};
#define VV ((object *)VVi)
static object  LnkTLI56(object,...);
static object  (*LnkLI56)() = (object (*)()) LnkTLI56;
static void LnkT55();
static void (*Lnk55)() = LnkT55;
static object  LnkTLI54(object,...);
static object  (*LnkLI54)() = (object (*)()) LnkTLI54;
static object  LnkTLI53(object,...);
static object  (*LnkLI53)() = (object (*)()) LnkTLI53;
static object  LnkTLI52(object,...);
static object  (*LnkLI52)() = (object (*)()) LnkTLI52;
static void LnkT51();
static void (*Lnk51)() = LnkT51;
static object  LnkTLI49(object,...);
static object  (*LnkLI49)() = (object (*)()) LnkTLI49;
