
static void L1();
#define VC1
static void LC2();
#define VC2 object  V25 ,V10;
static void LC2();
#define VM2 11
#define VM3 5
#define VM1 4
static char * VVi[10]={
#define Cdata VV[9]
(char *)(L1)
};
#define VV ((object *)VVi)
static void LnkT8();
static void (*Lnk8)() = LnkT8;
static void LnkT7();
static void (*Lnk7)() = LnkT7;
