
static void L1();
static void L2();
static void L5();
static void L17();
static void L18();
static void L19();
static void L22();
#define VC1
#define VC2
static object LI3();
#define VMB3 register object *base=vs_top; object  V13;
#define VMS3  register object *sup=vs_top+2;vs_top=sup;
#define VMV3 vs_check;
#define VMR3(VMT3) vs_top=base ; return(VMT3);
static object LI4();
#define VMB4
#define VMS4
#define VMV4
#define VMR4(VMT4) return(VMT4);
#define VC5
static object LI6();
#define VMB6 register object *base=vs_top; object  V23;
#define VMS6  register object *sup=vs_top+1;vs_top=sup;
#define VMV6 vs_check;
#define VMR6(VMT6) vs_top=base ; return(VMT6);
static object LI7();
#define VMB7 object  V35 ,V31 ,V30 ,V29;
#define VMS7
#define VMV7
#define VMR7(VMT7) return(VMT7);
static object LI8();
#define VMB8 register object *base=vs_top;
#define VMS8  register object *sup=vs_top+6;vs_top=sup;
#define VMV8 vs_check;
#define VMR8(VMT8) vs_top=base ; return(VMT8);
static object LI9();
#define VMB9 register object *base=vs_top;
#define VMS9  register object *sup=vs_top+1;vs_top=sup;
#define VMV9 vs_check;
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10();
#define VMB10
#define VMS10
#define VMV10
#define VMR10(VMT10) return(VMT10);
static object LI11();
#define VMB11
#define VMS11
#define VMV11
#define VMR11(VMT11) return(VMT11);
static object LI12();
#define VMB12
#define VMS12
#define VMV12
#define VMR12(VMT12) return(VMT12);
static object LI13();
#define VMB13
#define VMS13
#define VMV13
#define VMR13(VMT13) return(VMT13);
static object LI14();
#define VMB14
#define VMS14
#define VMV14
#define VMR14(VMT14) return(VMT14);
static object LI15();
#define VMB15 register object *base=vs_top;
#define VMS15  register object *sup=vs_top+4;vs_top=sup;
#define VMV15 vs_check;
#define VMR15(VMT15) vs_top=base ; return(VMT15);
static object LI16();
#define VMB16 register object *base=vs_top;
#define VMS16  register object *sup=vs_top+3;vs_top=sup;
#define VMV16 vs_check;
#define VMR16(VMT16) vs_top=base ; return(VMT16);
#define VC17
#define VC18
#define VC19
static object LI21();
#define VMB20 register object *base=vs_top;
#define VMS20  register object *sup=vs_top+6;vs_top=sup;
#define VMV20 vs_check;
#define VMR20(VMT20) vs_top=base ; return(VMT20);
#define VC21 object  V115 ,V114 ,V113 ,V112 ,V111 ,V110 ,V109 ,V108 ,V106 ,V101;
static object LI23();
#define VMB22 object  V126;
#define VMS22
#define VMV22
#define VMR22(VMT22) return(VMT22);
static void LC26();
#define VC23
static void LC25();
#define VC24
static void LC24();
#define VC25
static void LC26();
static void LC25();
static void LC24();
#define VM25 5
#define VM24 5
#define VM23 5
#define VM22 0
#define VM21 4
#define VM20 6
#define VM19 8
#define VM18 6
#define VM17 4
#define VM16 3
#define VM15 4
#define VM14 0
#define VM13 0
#define VM12 0
#define VM11 0
#define VM10 0
#define VM9 1
#define VM8 6
#define VM7 0
#define VM6 1
#define VM5 3
#define VM4 0
#define VM3 2
#define VM2 6
#define VM1 5
static char * VVi[40]={
#define Cdata VV[39]
(char *)(L1),
(char *)(L2),
(char *)(LI3),
(char *)(LI4),
(char *)(L5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(LI16),
(char *)(L17),
(char *)(L18),
(char *)(L19),
(char *)(LI21),
(char *)(L22),
(char *)(LI23)
};
#define VV ((object *)VVi)
static object  LnkTLI38(object,...);
static object  (*LnkLI38)() = (object (*)()) LnkTLI38;
static object  LnkTLI37(object,...);
static object  (*LnkLI37)() = (object (*)()) LnkTLI37;
static object  LnkTLI36(object,...);
static object  (*LnkLI36)() = (object (*)()) LnkTLI36;
static void LnkT35();
static void (*Lnk35)() = LnkT35;
static void LnkT34();
static void (*Lnk34)() = LnkT34;
static object  LnkTLI33(object,...);
static object  (*LnkLI33)() = (object (*)()) LnkTLI33;
static object  LnkTLI32(object,...);
static object  (*LnkLI32)() = (object (*)()) LnkTLI32;
static void LnkT31();
static void (*Lnk31)() = LnkT31;
static void LnkT30();
static void (*Lnk30)() = LnkT30;
static object  LnkTLI29(object,...);
static object  (*LnkLI29)() = (object (*)()) LnkTLI29;
static void LnkT28();
static void (*Lnk28)() = LnkT28;
static void LnkT27();
static void (*Lnk27)() = LnkT27;
static void LnkT26();
static void (*Lnk26)() = LnkT26;
static object  LnkTLI24(object,...);
static object  (*LnkLI24)() = (object (*)()) LnkTLI24;
static object  LnkTLI23(object,...);
static object  (*LnkLI23)() = (object (*)()) LnkTLI23;
static object  LnkTLI22(object,...);
static object  (*LnkLI22)() = (object (*)()) LnkTLI22;
static object  LnkTLI21(object,...);
static object  (*LnkLI21)() = (object (*)()) LnkTLI21;
static object  LnkTLI20(object,...);
static object  (*LnkLI20)() = (object (*)()) LnkTLI20;
static void LnkT19();
static void (*Lnk19)() = LnkT19;
static object  LnkTLI18(object,...);
static object  (*LnkLI18)() = (object (*)()) LnkTLI18;
static object  LnkTLI17(object,...);
static object  (*LnkLI17)() = (object (*)()) LnkTLI17;
