
static void L1();
#define VC1 object  V140 ,V139 ,V138 ,V137 ,V136 ,V135 ,V134 ,V133 ,V129 ,V128 ,V127 ,V124 ,V123 ,V122 ,V121 ,V117 ,V116 ,V115 ,V114 ,V113 ,V112 ,V111 ,V110 ,V109 ,V108 ,V107 ,V106 ,V105 ,V104 ,V103 ,V102 ,V101 ,V60 ,V53 ,V52 ,V41 ,V40 ,V33 ,V30 ,V27 ,V24 ,V23 ,V22 ,V10 ,V9;
static void L2();
#define VC2 object  V169 ,V168 ,V166 ,V165 ,V164 ,V161 ,V156 ,V154 ,V153;
static void LC3();
#define VC3
static void L5();
#define VC4
static void L4();
#define VC5
static void LC3();
#define VM5 6
#define VM4 6
#define VM3 3
#define VM2 5
#define VM1 12
static char * VVi[77]={
#define Cdata VV[76]
(char *)(L1)
};
#define VV ((object *)VVi)
static object  LnkTLI75();
static object  (*LnkLI75)() = LnkTLI75;
static object  LnkTLI73(object,...);
static object  (*LnkLI73)() = (object (*)()) LnkTLI73;
static void LnkT72();
static void (*Lnk72)() = LnkT72;
static object  LnkTLI70(object,...);
static object  (*LnkLI70)() = (object (*)()) LnkTLI70;
