
static void L1();
#define VC1
static void LC2();
#define VC2 object  V18 ,V9;
static void LC2();
#define VM2 9
#define VM3 5
#define VM1 4
static char * VVi[9]={
#define Cdata VV[8]
(char *)(L1)
};
#define VV ((object *)VVi)
static void LnkT7();
static void (*Lnk7)() = LnkT7;
static void LnkT6();
static void (*Lnk6)() = LnkT6;
