
#include "cmpinclude.h"
#include "clcs_debugger.h"
void init_clcs_debugger(){do_init(VV);}
/*	local entry for function progn 'compile2181	*/

static object LI1()

{	 VMB1 VMS1 VMV1
	goto TTL;
TTL:;
	base[0]= VV[0];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V1 = Cnil;
	VMR1(V1)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2193	*/

static object LI2()

{	 VMB2 VMS2 VMV2
	goto TTL;
TTL:;
	base[0]= VV[0];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4;}
	goto T3;
	goto T4;
T4:;
	setq(VV[0],small_fixnum(0));
	goto T3;
T3:;
	{object V2 = Cnil;
	VMR2(V2)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2206	*/

static object LI3()

{	 VMB3 VMS3 VMV3
	goto TTL;
TTL:;
	{object V3 = Cnil;
	VMR3(V3)}
	return Cnil;
}
/*	local entry for function progn 'compile2222	*/

static object LI4()

{	 VMB4 VMS4 VMV4
	goto TTL;
TTL:;
	base[0]= VV[1];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V4 = Cnil;
	VMR4(V4)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2234	*/

static object LI5()

{	 VMB5 VMS5 VMV5
	goto TTL;
TTL:;
	base[0]= VV[1];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T12;}
	goto T11;
	goto T12;
T12:;
	setq(VV[1],Cnil);
	goto T11;
T11:;
	{object V5 = Cnil;
	VMR5(V5)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2247	*/

static object LI6()

{	 VMB6 VMS6 VMV6
	goto TTL;
TTL:;
	{object V6 = Cnil;
	VMR6(V6)}
	return Cnil;
}
/*	local entry for function progn 'compile2263	*/

static object LI7()

{	 VMB7 VMS7 VMV7
	goto TTL;
TTL:;
	base[0]= VV[2];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V7 = Cnil;
	VMR7(V7)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2275	*/

static object LI8()

{	 VMB8 VMS8 VMV8
	goto TTL;
TTL:;
	base[0]= VV[2];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T20;}
	goto T19;
	goto T20;
T20:;
	setq(VV[2],Cnil);
	goto T19;
T19:;
	{object V8 = Cnil;
	VMR8(V8)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2288	*/

static object LI9()

{	 VMB9 VMS9 VMV9
	goto TTL;
TTL:;
	{object V9 = Cnil;
	VMR9(V9)}
	return Cnil;
}
/*	local entry for function progn 'compile2304	*/

static object LI10()

{	 VMB10 VMS10 VMV10
	goto TTL;
TTL:;
	base[0]= VV[3];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V10 = Cnil;
	VMR10(V10)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2316	*/

static object LI11()

{	 VMB11 VMS11 VMV11
	goto TTL;
TTL:;
	base[0]= VV[3];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T28;}
	goto T27;
	goto T28;
T28:;
	setq(VV[3],Cnil);
	goto T27;
T27:;
	{object V11 = Cnil;
	VMR11(V11)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2329	*/

static object LI12()

{	 VMB12 VMS12 VMV12
	goto TTL;
TTL:;
	{object V12 = Cnil;
	VMR12(V12)}
	return Cnil;
}
/*	local entry for function progn 'compile2345	*/

static object LI13()

{	 VMB13 VMS13 VMV13
	goto TTL;
TTL:;
	base[0]= VV[4];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V13 = Cnil;
	VMR13(V13)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2357	*/

static object LI14()

{	 VMB14 VMS14 VMV14
	goto TTL;
TTL:;
	base[0]= VV[4];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T36;}
	goto T35;
	goto T36;
T36:;
	setq(VV[4],Cnil);
	goto T35;
T35:;
	{object V14 = Cnil;
	VMR14(V14)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2370	*/

static object LI15()

{	 VMB15 VMS15 VMV15
	goto TTL;
TTL:;
	{object V15 = Cnil;
	VMR15(V15)}
	return Cnil;
}
/*	local entry for function progn 'compile2386	*/

static object LI16()

{	 VMB16 VMS16 VMV16
	goto TTL;
TTL:;
	base[0]= VV[5];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V16 = Cnil;
	VMR16(V16)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2398	*/

static object LI17()

{	 VMB17 VMS17 VMV17
	goto TTL;
TTL:;
	base[0]= VV[5];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T44;}
	goto T43;
	goto T44;
T44:;
	setq(VV[5],small_fixnum(0));
	goto T43;
T43:;
	{object V17 = Cnil;
	VMR17(V17)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2411	*/

static object LI18()

{	 VMB18 VMS18 VMV18
	goto TTL;
TTL:;
	{object V18 = Cnil;
	VMR18(V18)}
	return Cnil;
}
/*	local entry for function progn 'compile2427	*/

static object LI19()

{	 VMB19 VMS19 VMV19
	goto TTL;
TTL:;
	base[0]= VV[6];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V19 = Cnil;
	VMR19(V19)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2439	*/

static object LI20()

{	 VMB20 VMS20 VMV20
	goto TTL;
TTL:;
	base[0]= VV[6];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T52;}
	goto T51;
	goto T52;
T52:;
	setq(VV[6],VV[7]);
	goto T51;
T51:;
	{object V20 = Cnil;
	VMR20(V20)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2452	*/

static object LI21()

{	 VMB21 VMS21 VMV21
	goto TTL;
TTL:;
	{object V21 = Cnil;
	VMR21(V21)}
	return Cnil;
}
/*	local entry for function progn 'compile2468	*/

static object LI22()

{	 VMB22 VMS22 VMV22
	goto TTL;
TTL:;
	base[0]= VV[8];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V22 = Cnil;
	VMR22(V22)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2480	*/

static object LI23()

{	 VMB23 VMS23 VMV23
	goto TTL;
TTL:;
	base[0]= VV[8];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T60;}
	goto T59;
	goto T60;
T60:;
	setq(VV[8],VV[66]);
	goto T59;
T59:;
	{object V23 = Cnil;
	VMR23(V23)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2497	*/

static object LI24()

{	 VMB24 VMS24 VMV24
	goto TTL;
TTL:;
	{object V24 = Cnil;
	VMR24(V24)}
	return Cnil;
}
/*	macro definition for DEBUG-COMMAND	*/

static void L25()
{register object *base=vs_base;
	register object *sup=base+VM25; VC25
	vs_reserve(VM25);
	check_arg(2);
	vs_top=sup;
	{object V25=base[0]->c.c_cdr;
	if(endp(V25))invalid_macro_call();
	base[2]= (V25->c.c_car);
	V25=V25->c.c_cdr;
	if(!endp(V25))invalid_macro_call();}
	base[3]= list(3,VV[10],base[2],VV[11]);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	macro definition for DEBUG-COMMAND-ARGUMENT-COUNT	*/

static void L26()
{register object *base=vs_base;
	register object *sup=base+VM26; VC26
	vs_reserve(VM26);
	check_arg(2);
	vs_top=sup;
	{object V26=base[0]->c.c_cdr;
	if(endp(V26))invalid_macro_call();
	base[2]= (V26->c.c_car);
	V26=V26->c.c_cdr;
	if(!endp(V26))invalid_macro_call();}
	base[3]= list(3,VV[10],base[2],VV[12]);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	macro definition for DEFINE-DEBUG-COMMAND	*/

static void L27()
{register object *base=vs_base;
	register object *sup=base+VM27; VC27
	vs_reserve(VM27);
	check_arg(2);
	vs_top=sup;
	{object V27=base[0]->c.c_cdr;
	if(endp(V27))invalid_macro_call();
	base[2]= (V27->c.c_car);
	V27=V27->c.c_cdr;
	if(endp(V27))invalid_macro_call();
	base[3]= (V27->c.c_car);
	V27=V27->c.c_cdr;
	base[4]= V27;}
	V28= list(2,VV[15],list(2,VV[16],base[2]));
	V29= list(3,VV[14],/* INLINE-ARGS */V28,list(2,VV[17],listA(3,VV[18],base[3],base[4])));
	V30= list(2,VV[19],list(2,VV[16],base[2]));
	V31 = make_fixnum((long)length(base[3]));
	V32= list(3,VV[14],/* INLINE-ARGS */V30,V31);
	base[5]= list(4,VV[13],/* INLINE-ARGS */V29,/* INLINE-ARGS */V32,list(2,VV[16],base[2]));
	vs_top=(vs_base=base+5)+1;
	return;
}
/*	local entry for function READ-DEBUG-COMMAND	*/

static object LI28()

{	 VMB28 VMS28 VMV28
	bds_check;
	goto TTL;
TTL:;
	base[0]= Ct;
	base[1]= VV[20];
	base[2]= symbol_value(VV[0]);
	vs_top=(vs_base=base+0)+3;
	Lformat();
	vs_top=sup;
	base[1]= Ct;
	vs_top=(vs_base=base+1)+1;
	Lpeek_char();
	vs_top=sup;
	base[0]= vs_base[0];
	base[1]= VV[21];
	vs_top=(vs_base=base+0)+2;
	Lchar_eq();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T70;}
	vs_base=vs_top;
	Lread_char();
	vs_top=sup;
	{register object V33;
	vs_base=vs_top;
	Lread_line();
	vs_top=sup;
	base[0]= vs_base[0];
	base[1]= Cnil;
	base[2]= Cnil;
	vs_top=(vs_base=base+0)+3;
	(void) (*Lnk67)();
	vs_top=sup;
	V33= vs_base[0];
	{register object V34;
	V34= make_cons(Cnil,Cnil);
	{register object V35;
	register object V36;
	base[1]= VV[23];
	vs_top=(vs_base=base+1)+1;
	Lfind_package();
	vs_top=sup;
	base[0]= vs_base[0];
	bds_bind(VV[22],base[0]);
	base[1]= (V33);
	base[2]= Cnil;
	base[3]= (V34);
	vs_top=(vs_base=base+1)+3;
	Lread();
	vs_top=sup;
	bds_unwind1;
	V35= vs_base[0];
	V36= Cnil;
	goto T88;
T88:;
	if(!(((V35))==((V34)))){
	goto T89;}
	{object V37 = nreverse((V36));
	VMR28(V37)}
	goto T89;
T89:;
	{object V38;
	base[0]= (V33);
	base[1]= Cnil;
	base[2]= (V34);
	vs_top=(vs_base=base+0)+3;
	Lread();
	vs_top=sup;
	V38= vs_base[0];
	V36= make_cons((V35),(V36));
	V35= (V38);}
	goto T88;}}}
	goto T70;
T70:;
	vs_base=vs_top;
	Lread();
	vs_top=sup;
	V39= vs_base[0];
	{object V40 = list(2,VV[24],V39);
	VMR28(V40)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2593	*/

static object LI29()

{	 VMB29 VMS29 VMV29
	goto TTL;
TTL:;
	V41= VV[68];
	(void)(sputprop(VV[24],VV[15],V41));
	{object V42 = Cnil;
	VMR29(V42)}
	return Cnil;
}
/*	local entry for function progn 'compile2621	*/

static object LI30()

{	 VMB30 VMS30 VMV30
	goto TTL;
TTL:;
	(void)(sputprop(VV[24],VV[19],small_fixnum(1)));
	{object V43 = Cnil;
	VMR30(V43)}
	return Cnil;
}
/*	local entry for function progn 'compile2633	*/

static object LI31()

{	 VMB31 VMS31 VMV31
	goto TTL;
TTL:;
	{object V44 = Cnil;
	VMR31(V44)}
	return Cnil;
}
/*	local entry for function progn 'compile2657	*/

static object LI32()

{	 VMB32 VMS32 VMV32
	goto TTL;
TTL:;
	V45= VV[69];
	(void)(sputprop(VV[25],VV[15],V45));
	{object V46 = Cnil;
	VMR32(V46)}
	return Cnil;
}
/*	local entry for function progn 'compile2681	*/

static object LI33()

{	 VMB33 VMS33 VMV33
	goto TTL;
TTL:;
	(void)(sputprop(VV[25],VV[19],small_fixnum(0)));
	{object V47 = Cnil;
	VMR33(V47)}
	return Cnil;
}
/*	local entry for function progn 'compile2693	*/

static object LI34()

{	 VMB34 VMS34 VMV34
	goto TTL;
TTL:;
	{object V48 = Cnil;
	VMR34(V48)}
	return Cnil;
}
/*	local entry for function progn 'compile2717	*/

static object LI35()

{	 VMB35 VMS35 VMV35
	goto TTL;
TTL:;
	V49= VV[70];
	(void)(sputprop(VV[27],VV[15],V49));
	{object V50 = Cnil;
	VMR35(V50)}
	return Cnil;
}
/*	local entry for function progn 'compile2741	*/

static object LI36()

{	 VMB36 VMS36 VMV36
	goto TTL;
TTL:;
	(void)(sputprop(VV[27],VV[19],small_fixnum(0)));
	{object V51 = Cnil;
	VMR36(V51)}
	return Cnil;
}
/*	local entry for function progn 'compile2753	*/

static object LI37()

{	 VMB37 VMS37 VMV37
	goto TTL;
TTL:;
	{object V52 = Cnil;
	VMR37(V52)}
	return Cnil;
}
/*	local entry for function progn 'compile2777	*/

static object LI38()

{	 VMB38 VMS38 VMV38
	goto TTL;
TTL:;
	V53= VV[71];
	(void)(sputprop(VV[29],VV[15],V53));
	{object V54 = Cnil;
	VMR38(V54)}
	return Cnil;
}
/*	local entry for function progn 'compile2801	*/

static object LI39()

{	 VMB39 VMS39 VMV39
	goto TTL;
TTL:;
	(void)(sputprop(VV[29],VV[19],small_fixnum(0)));
	{object V55 = Cnil;
	VMR39(V55)}
	return Cnil;
}
/*	local entry for function progn 'compile2813	*/

static object LI40()

{	 VMB40 VMS40 VMV40
	goto TTL;
TTL:;
	{object V56 = Cnil;
	VMR40(V56)}
	return Cnil;
}
/*	local entry for function progn 'compile2837	*/

static object LI41()

{	 VMB41 VMS41 VMV41
	goto TTL;
TTL:;
	V57= VV[72];
	(void)(sputprop(VV[31],VV[15],V57));
	{object V58 = Cnil;
	VMR41(V58)}
	return Cnil;
}
/*	local entry for function progn 'compile2861	*/

static object LI42()

{	 VMB42 VMS42 VMV42
	goto TTL;
TTL:;
	(void)(sputprop(VV[31],VV[19],small_fixnum(0)));
	{object V59 = Cnil;
	VMR42(V59)}
	return Cnil;
}
/*	local entry for function progn 'compile2873	*/

static object LI43()

{	 VMB43 VMS43 VMV43
	goto TTL;
TTL:;
	{object V60 = Cnil;
	VMR43(V60)}
	return Cnil;
}
/*	local entry for function progn 'compile2889	*/

static object LI44()

{	 VMB44 VMS44 VMV44
	goto TTL;
TTL:;
	base[0]= VV[37];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V61 = Cnil;
	VMR44(V61)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2901	*/

static object LI45()

{	 VMB45 VMS45 VMV45
	goto TTL;
TTL:;
	base[0]= VV[37];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T124;}
	goto T123;
	goto T124;
T124:;
	setq(VV[37],VV[38]);
	goto T123;
T123:;
	{object V62 = Cnil;
	VMR45(V62)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile2914	*/

static object LI46()

{	 VMB46 VMS46 VMV46
	goto TTL;
TTL:;
	{object V63 = Cnil;
	VMR46(V63)}
	return Cnil;
}
/*	local entry for function SHOW-RESTARTS	*/

static object LI47(object first,...)
{	
	va_list ap;
	int narg = VFUN_NARGS; VMB47 VMS47 VMV47
	{object V64;
	object V65;
	object V66;
	Vcs[0]=Vcs[0];
	va_start(ap,first);
	narg = narg - 0;
	if (narg <= 0) goto T129;
	else {
	V64= first;}
	if (--narg <= 0) goto T130;
	else {
	V65= va_arg(ap,object);}
	if (--narg <= 0) goto T131;
	else {
	V66= va_arg(ap,object);}
	--narg; goto T132;
	goto T129;
T129:;
	V64= symbol_value(VV[4]);
	goto T130;
T130:;
	V65= symbol_value(VV[5]);
	goto T131;
T131:;
	V66= Cnil;
	goto T132;
T132:;
	if(((V65))!=Cnil){
	goto T136;}
	V65= make_fixnum((long)length((V64)));
	goto T136;
T136:;
	if(((V64))==Cnil){
	goto T141;}
	{object V67;
	register object V68;
	register object V69;
	if(((V66))==Cnil){
	goto T145;}
	V67= number_minus((V66),small_fixnum(3));
	goto T143;
	goto T145;
T145:;
	base[1]= (V65);
	base[2]= small_fixnum(10);
	vs_top=(vs_base=base+1)+2;
	Llog();
	vs_top=sup;
	base[0]= vs_base[0];
	vs_top=(vs_base=base+0)+1;
	Lceiling();
	vs_top=sup;
	V67= vs_base[0];
	goto T143;
T143:;
	V68= (V64);
	V69= small_fixnum(0);
	goto T151;
T151:;
	if(((V68))==Cnil){
	goto T153;}
	if(!(number_compare((V69),(V65))==0)){
	goto T152;}
	goto T153;
T153:;
	{object V70 = Cnil;
	VMR47(V70)}
	goto T152;
T152:;
	base[0]= Ct;
	base[1]= VV[39];
	base[2]= symbol_value(VV[37]);
	{register object V71;
	base[4]= Cnil;
	base[5]= VV[40];
	base[6]= number_plus((V69),small_fixnum(1));
	vs_top=(vs_base=base+4)+3;
	Lformat();
	vs_top=sup;
	V71= vs_base[0];
	{register object V72;
	vs_base=vs_top;
	(void) (*Lnk73)();
	vs_top=sup;
	V72= vs_base[0];
	base[4]= (V72);
	base[5]= VV[41];
	base[6]= (V71);
	vs_top=(vs_base=base+4)+3;
	Lformat();
	vs_top=sup;
	{register object V73;
	register object V74;
	V75 = make_fixnum((long)length((V71)));
	V73= number_minus((V67),V75);
	V74= small_fixnum(0);
	goto T176;
T176:;
	if(!(number_compare((V74),(V73))>=0)){
	goto T177;}
	goto T172;
	goto T177;
T177:;
	base[5]= VV[42];
	base[6]= (V72);
	vs_top=(vs_base=base+5)+2;
	Lwrite_char();
	vs_top=sup;
	V74= one_plus((V74));
	goto T176;}
	goto T172;
T172:;
	base[4]= (V72);
	vs_top=(vs_base=base+4)+1;
	(void) (*Lnk74)();
	vs_top=sup;
	base[3]= vs_base[0];}}
	vs_top=(vs_base=base+0)+4;
	Lformat();
	vs_top=sup;
	if(!((car((V68)))==(symbol_value(VV[1])))){
	goto T188;}
	base[0]= Ct;
	base[1]= VV[43];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	vs_top=sup;
	goto T188;
T188:;
	if(!((car((V68)))==(symbol_value(VV[2])))){
	goto T193;}
	base[0]= Ct;
	base[1]= VV[44];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	vs_top=sup;
	goto T193;
T193:;
	base[0]= Ct;
	base[1]= VV[45];
	base[2]= car((V68));
	vs_top=(vs_base=base+0)+3;
	Lformat();
	vs_top=sup;
	base[0]= Ct;
	base[1]= VV[46];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	vs_top=sup;
	V68= cdr((V68));
	V69= one_plus((V69));
	goto T151;}
	goto T141;
T141:;
	{object V76 = Cnil;
	VMR47(V76)}
	va_end(ap);
	base[0]=base[0];
	return Cnil;}
	}
/*	local entry for function progn 'compile2997	*/

static object LI48()

{	 VMB48 VMS48 VMV48
	goto TTL;
TTL:;
	base[0]= VV[47];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V77 = Cnil;
	VMR48(V77)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile3009	*/

static object LI49()

{	 VMB49 VMS49 VMV49
	goto TTL;
TTL:;
	base[0]= VV[47];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T212;}
	goto T211;
	goto T212;
T212:;
	setq(VV[47],Cnil);
	goto T211;
T211:;
	{object V78 = Cnil;
	VMR49(V78)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile3022	*/

static object LI50()

{	 VMB50 VMS50 VMV50
	goto TTL;
TTL:;
	{object V79 = Cnil;
	VMR50(V79)}
	return Cnil;
}
/*	local entry for function progn 'compile3038	*/

static object LI51()

{	 VMB51 VMS51 VMV51
	goto TTL;
TTL:;
	base[0]= VV[48];
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk65)();
	vs_top=sup;
	{object V80 = Cnil;
	VMR51(V80)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile3050	*/

static object LI52()

{	 VMB52 VMS52 VMV52
	goto TTL;
TTL:;
	base[0]= VV[48];
	vs_top=(vs_base=base+0)+1;
	Lboundp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T220;}
	goto T219;
	goto T220;
T220:;
	setq(VV[48],VV[49]);
	goto T219;
T219:;
	{object V81 = Cnil;
	VMR52(V81)}
	base[0]=base[0];
	return Cnil;
}
/*	local entry for function progn 'compile3063	*/

static object LI53()

{	 VMB53 VMS53 VMV53
	goto TTL;
TTL:;
	{object V82 = Cnil;
	VMR53(V82)}
	return Cnil;
}
/*	function definition for INVOKE-DEBUGGER	*/

static void L54()
{register object *base=vs_base;
	register object *sup=base+VM54; VC54
	vs_reserve(VM54);
	bds_check;
	{object V83;
	object V84;
	vs_top[0]=Cnil;
	{object *p=vs_top, *q=vs_base+1;
	 for(;p>q;p--)p[-1]=MMcons(p[-1],p[0]);}
	if(vs_base>=vs_top){vs_top=sup;goto T225;}
	V83=(base[0]);
	V84=(base[1]);
	vs_top=sup;
	goto T226;
	goto T225;
T225:;
	V83= VV[50];
	V84= Cnil;
	goto T226;
T226:;
	{object V85;
	base[2]= (V83);
	base[3]= (V84);
	base[4]= VV[51];
	base[5]= VV[52];
	vs_top=(vs_base=base+2)+4;
	(void) (*Lnk75)();
	vs_top=sup;
	V85= vs_base[0];
	if((symbol_value(VV[47]))==Cnil){
	goto T233;}
	{object V86;
	V86= symbol_value(VV[47]);
	bds_bind(VV[47],Cnil);
	V87= (
	(type_of((V86)) == t_sfun ?(*(((V86))->sfn.sfn_self)):
	(fcall.fun=((V86)),fcall.argd=2,fcalln))((V85),(V86)));
	bds_unwind1;}
	goto T233;
T233:;
	base[2]= (V85);
	vs_top=(vs_base=base+2)+1;
	{object _funobj = symbol_value(VV[48]);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	}
}
/*	local entry for function STANDARD-DEBUGGER	*/

static object LI55(V89)

object V89;
{	 VMB55 VMS55 VMV55
	bds_check;
	goto TTL;
TTL:;
	bds_bind(VV[0],one_plus(symbol_value(VV[0])));
	bds_bind(VV[4],(VFUN_NARGS=0,(*(LnkLI76))()));
	bds_bind(VV[5],make_fixnum((long)length((VV[4]->s.s_dbind))));
	bds_bind(VV[1],(VFUN_NARGS=1,(*(LnkLI77))(VV[53])));{object V90;
	{object V91;
	V91= (VFUN_NARGS=1,(*(LnkLI77))(VV[54]));
	if((symbol_value(VV[2]))==Cnil){
	goto T245;}
	if((symbol_value(VV[2]))==((V91))){
	goto T246;}
	goto T245;
T245:;
	V90= (V91);
	goto T243;
	goto T246;
T246:;
	V90= Cnil;}
	goto T243;
T243:;
	if(V90==Cnil)goto T242;
	bds_bind(VV[2],V90);
	goto T241;
	goto T242;
T242:;}
	{object V92;
	if(((VV[4]->s.s_dbind))==Cnil){
	goto T252;}
	V92= car((VV[4]->s.s_dbind));
	goto T250;
	goto T252;
T252:;
	V92= Cnil;
	goto T250;
T250:;
	if(((V92))==((VV[1]->s.s_dbind))){
	goto T255;}
	bds_bind(VV[2],(V92));
	goto T241;
	goto T255;
T255:;
	bds_bind(VV[2],Cnil);}
	goto T241;
T241:;
	bds_bind(VV[3],(V89));
	base[6]= Ct;
	base[7]= VV[55];
	base[8]= (V89);
	vs_top=(vs_base=base+6)+3;
	Lformat();
	vs_top=sup;
	(void)((VFUN_NARGS=0,(*(LnkLI78))()));
	{register object V93;
	V93= (*(LnkLI79))();
	goto T264;
T264:;
	base[6]= car((V93));
	base[7]= cdr((V93));
	base[8]= (VV[0]->s.s_dbind);
	vs_top=(vs_base=base+6)+3;
	(void) (*Lnk80)();
	vs_top=sup;
	V93= (*(LnkLI79))();
	goto T264;}
	base[0]=base[0];
	return Cnil;
}
/*	function definition for EXECUTE-DEBUGGER-COMMAND	*/

static void L56()
{register object *VOL base=vs_base;
	register object *VOL sup=base+VM56; VC56
	vs_reserve(VM56);
	bds_check;
	{VOL object V94;
	VOL object V95;
	check_arg(3);
	V94=(base[0]);
	V95=(base[1]);
	base[2]=MMcons(base[2],Cnil);
	vs_top=sup;
	base[3]=MMcons(Cnil,base[2]);
	base[4]=alloc_frame_id();
	base[4]=MMcons(base[4],base[3]);
	frs_push(FRS_CATCH,(base[4]->c.c_car));
	if(nlj_active){
	nlj_active=FALSE;
	if(eql(nlj_tag,VV[64]))goto T275;
	FEerror("The GO tag ~s is not established.",1,nlj_tag);
	}
	V96= 
	make_cclosure_new(LC63,Cnil,base[4],Cdata);
	V97= 
	make_cclosure_new(LC64,Cnil,base[4],Cdata);
	V98= (VFUN_NARGS=6,(*(LnkLI81))(VV[57],VV[53],VV[58],V96,VV[59],V97));
	V99= make_cons(/* INLINE-ARGS */V98,Cnil);
	base[5]= make_cons(/* INLINE-ARGS */V99,symbol_value(VV[56]));
	bds_bind(VV[56],base[5]);
	{object V100;
	V100= (((V94))==Cnil?Ct:Cnil);
	if(((V100))==Cnil){
	goto T281;}
	frs_pop();
	base[6]= (V100);
	vs_top=(vs_base=base+6)+1;
	bds_unwind1;
	return;
	goto T281;
T281:;
	if(!(type_of((V94))==t_fixnum||type_of((V94))==t_bignum)){
	goto T284;}
	if(!(number_compare(small_fixnum(0),(V94))<0)){
	goto T287;}
	V101= number_plus(symbol_value(VV[5]),small_fixnum(1));
	if(!(number_compare((V94),/* INLINE-ARGS */V101)<0)){
	goto T287;}
	{object V102;
	V103= number_minus((V94),small_fixnum(1));
	V102= nth(fixint(/* INLINE-ARGS */V103),symbol_value(VV[4]));
	if(((V95))==Cnil){
	goto T293;}
	base[6]=symbol_function(VV[82]);
	base[7]= (V102);
	{object V104;
	base[9]= symbol_value(VV[6]);
	{object V105;
	object V106= (V95);
	if(endp(V106)){
	V104= Cnil;
	goto T296;}
	base[8]=V105=MMcons(Cnil,Cnil);
	goto T297;
T297:;
	base[10]= (V106->c.c_car);
	vs_top=(vs_base=base+10)+1;
	{object _funobj = base[9];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	vs_top=sup;
	(V105->c.c_car)= vs_base[0];
	V106=MMcdr(V106);
	if(endp(V106)){
	V104= base[8];
	goto T296;}
	V105=MMcdr(V105)=MMcons(Cnil,Cnil);
	goto T297;}
	goto T296;
T296:;
	 vs_top=base+8;
	 while(!endp(V104))
	 {vs_push(car(V104));V104=cdr(V104);}
	vs_base=base+7;}
	(void) (*Lnk82)();
	frs_pop();
	bds_unwind1;
	return;
	goto T293;
T293:;
	base[6]= (V102);
	vs_top=(vs_base=base+6)+1;
	(void) (*Lnk83)();
	frs_pop();
	bds_unwind1;
	return;}
	goto T287;
T287:;
	base[6]= Ct;
	base[7]= VV[61];
	vs_top=(vs_base=base+6)+2;
	Lformat();
	frs_pop();
	bds_unwind1;
	return;
	goto T284;
T284:;
	{object V107;
	V107= get((V94),VV[15],Cnil);
	if(((V107))==Cnil){
	goto T306;}
	V108 = make_fixnum((long)length((V95)));
	V109= get((V94),VV[19],Cnil);
	if(number_compare(V108,V109)==0){
	goto T309;}
	base[6]= Ct;
	base[7]= VV[62];
	V110 = make_fixnum((long)length((V95)));
	V111= get((V94),VV[19],Cnil);
	base[8]= (number_compare(V110,V111)>0?Ct:Cnil);
	base[9]= (V94);
	vs_top=(vs_base=base+6)+4;
	Lformat();
	frs_pop();
	bds_unwind1;
	return;
	goto T309;
T309:;
	base[6]= (V107);
	{object V112;
	V112= (V95);
	 vs_top=base+7;
	 while(!endp(V112))
	 {vs_push(car(V112));V112=cdr(V112);}
	vs_base=base+7;}
	{object _funobj = base[6];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	frs_pop();
	bds_unwind1;
	return;
	goto T306;
T306:;
	base[6]= Ct;
	base[7]= VV[63];
	base[8]= (V94);
	vs_top=(vs_base=base+6)+3;
	Lformat();
	frs_pop();
	bds_unwind1;
	return;}}
	goto T275;
T275:;
	{object V113;
	V113= (base[3]->c.c_car);
	ck_larg_exactly(0,(V113));
	base[5]= Cnil;
	base[6]= Ct;
	vs_top=(vs_base=base+5)+2;
	frs_pop();
	return;}
	frs_pop();
	base[5]= Cnil;
	vs_top=(vs_base=base+5)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC64(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM57; VC57
	vs_reserve(VM57);
	{object V114;
	check_arg(1);
	V114=(base[0]);
	vs_top=sup;
	base[1]= (V114);
	base[2]= VV[60];
	base[3]= (base0[2]->c.c_car);
	vs_top=(vs_base=base+1)+3;
	Lformat();
	return;
	}
}
/*	local function CLOSURE	*/

static void LC63(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM58; VC58
	vs_reserve(VM58);
	{object V115;
	vs_top[0]=Cnil;
	{object *p=vs_top;
	 for(;p>vs_base;p--)p[-1]=MMcons(p[-1],p[0]);}
	V115=(base[0]);
	vs_top=sup;
	(base0[1]->c.c_car)= (V115);
	{frame_ptr fr;
	fr=frs_sch((base0[0]->c.c_car));
	if(fr==NULL)FEerror("The GO tag ~s is missing.",1,VV[64]);
	vs_base=vs_top;
	unwind(fr,VV[64]);}
	}
}
/*	local function CLOSURE	*/

static void LC62(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM59; VC59
	vs_reserve(VM59);
	check_arg(0);
	vs_top=sup;
	base[0]= Ct;
	base[1]= VV[32];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	vs_top=sup;
	(void)((VFUN_NARGS=3,(*(LnkLI78))(symbol_value(VV[4]),symbol_value(VV[5]),small_fixnum(16))));
	base[0]= Ct;
	base[1]= VV[33];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	vs_top=sup;
	if((symbol_value(VV[1]))==Cnil){
	goto T337;}
	base[0]= Ct;
	base[1]= VV[34];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	vs_top=sup;
	goto T337;
T337:;
	if((symbol_value(VV[2]))==Cnil){
	goto T342;}
	base[0]= Ct;
	base[1]= VV[35];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	vs_top=sup;
	goto T342;
T342:;
	base[0]= Ct;
	base[1]= VV[36];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	return;
}
/*	local function CLOSURE	*/

static void LC61(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM60; VC60
	vs_reserve(VM60);
	check_arg(0);
	vs_top=sup;
	base[0]= Ct;
	base[1]= VV[30];
	base[2]= symbol_value(VV[3]);
	vs_top=(vs_base=base+0)+3;
	Lformat();
	return;
}
/*	local function CLOSURE	*/

static void LC60(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM61; VC61
	vs_reserve(VM61);
	check_arg(0);
	vs_top=sup;
	if((symbol_value(VV[2]))==Cnil){
	goto T353;}
	base[0]= symbol_value(VV[2]);
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk83)();
	return;
	goto T353;
T353:;
	base[0]= Ct;
	base[1]= VV[28];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	return;
}
/*	local function CLOSURE	*/

static void LC59(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM62; VC62
	vs_reserve(VM62);
	check_arg(0);
	vs_top=sup;
	if((symbol_value(VV[1]))==Cnil){
	goto T359;}
	base[0]= symbol_value(VV[1]);
	vs_top=(vs_base=base+0)+1;
	(void) (*Lnk83)();
	return;
	goto T359;
T359:;
	base[0]= Ct;
	base[1]= VV[26];
	vs_top=(vs_base=base+0)+2;
	Lformat();
	return;
}
/*	local function CLOSURE	*/

static void LC58(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM63; VC63
	vs_reserve(VM63);
	{object V116;
	check_arg(1);
	V116=(base[0]);
	vs_top=sup;
	base[1]= symbol_value(VV[8]);
	base[3]= (V116);
	vs_top=(vs_base=base+3)+1;
	{object _funobj = symbol_value(VV[6]);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	Llist();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	}
}
/*	local function CLOSURE	*/

static void LC57(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM64; VC64
	vs_reserve(VM64);
	{object V117;
	check_arg(1);
	V117=(base[0]);
	vs_top=sup;
	base[1]= Ct;
	base[2]= VV[9];
	base[3]= (V117);
	vs_top=(vs_base=base+1)+3;
	Lformat();
	return;
	}
}
static void LnkT83(){ call_or_link(VV[83],(void **)(void *)&Lnk83);} /* INVOKE-RESTART-INTERACTIVELY */
static void LnkT82(){ call_or_link(VV[82],(void **)(void *)&Lnk82);} /* INVOKE-RESTART */
static object  LnkTLI81(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_vproc_new(VV[81],(void **)(void *)&LnkLI81,first,ap);va_end(ap);return V1;} /* MAKE-RESTART */
static void LnkT80(){ call_or_link(VV[80],(void **)(void *)&Lnk80);} /* EXECUTE-DEBUGGER-COMMAND */
static object  LnkTLI79(){return call_proc0(VV[79],(void **)(void *)&LnkLI79);} /* READ-DEBUG-COMMAND */
static object  LnkTLI78(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_vproc_new(VV[78],(void **)(void *)&LnkLI78,first,ap);va_end(ap);return V1;} /* SHOW-RESTARTS */
static object  LnkTLI77(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_vproc_new(VV[77],(void **)(void *)&LnkLI77,first,ap);va_end(ap);return V1;} /* FIND-RESTART */
static object  LnkTLI76(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_vproc_new(VV[76],(void **)(void *)&LnkLI76,first,ap);va_end(ap);return V1;} /* COMPUTE-RESTARTS */
static void LnkT75(){ call_or_link(VV[75],(void **)(void *)&Lnk75);} /* COERCE-TO-CONDITION */
static void LnkT74(){ call_or_link(VV[74],(void **)(void *)&Lnk74);} /* GET-OUTPUT-STREAM-STRING */
static void LnkT73(){ call_or_link(VV[73],(void **)(void *)&Lnk73);} /* MAKE-STRING-OUTPUT-STREAM */
static void LnkT67(){ call_or_link(VV[67],(void **)(void *)&Lnk67);} /* MAKE-STRING-INPUT-STREAM */
static void LnkT65(){ call_or_link(VV[65],(void **)(void *)&Lnk65);} /* *MAKE-SPECIAL */

#ifdef SYSTEM_SPECIAL_INIT
SYSTEM_SPECIAL_INIT
#endif

