
static void L1();
static void L3();
static void L4();
static void L6();
static void L7();
static void L8();
static void L10();
#define VC1
static object LI2();
#define VMB2 register object *base=vs_top;
#define VMS2  register object *sup=vs_top+6;vs_top=sup;
#define VMV2 vs_check;
#define VMR2(VMT2) vs_top=base ; return(VMT2);
#define VC3 object  V34 ,V33 ,V32;
#define VC4
static object LI5();
#define VMB5 register object *base=vs_top;
#define VMS5  register object *sup=vs_top+7;vs_top=sup;
#define VMV5 vs_check;
#define VMR5(VMT5) vs_top=base ; return(VMT5);
#define VC6 object  V79 ,V78 ,V77 ,V75 ,V74 ,V70;
#define VC7 object  V92 ,V91 ,V90;
#define VC8 object  V123 ,V116 ,V115 ,V114 ,V113 ,V112 ,V111 ,V108 ,V107 ,V106 ,V105 ,V104 ,V103;
static object LI9(object,object,object,object,...);
#define VMB9 register object *base=vs_top; object Vcs[5];
#define VMS9  register object *sup=vs_top+2;vs_top=sup;
#define VMV9 vs_check;
#define VMR9(VMT9) vs_top=base ; return(VMT9);
#define VC10 object  V165;
static object LI11(object,object,object,object,...);
#define VMB11 register object *base=vs_top; object Vcs[4];
#define VMS11  register object *sup=vs_top+4;vs_top=sup;
#define VMV11 vs_check;
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI12(object,object,object,object,...);
#define VMB12 register object *base=vs_top; object Vcs[4];
#define VMS12  register object *sup=vs_top+5;vs_top=sup;
#define VMV12 vs_check;
#define VMR12(VMT12) vs_top=base ; return(VMT12);
#define VM12 5
#define VM11 4
#define VM10 6
#define VM9 2
#define VM8 13
#define VM7 10
#define VM6 8
#define VM5 7
#define VM4 7
#define VM3 6
#define VM2 6
#define VM1 6
static char * VVi[50]={
#define Cdata VV[49]
(char *)(L1),
(char *)(LI2),
(char *)(L3),
(char *)(L4),
(char *)(LI5),
(char *)(L6),
(char *)(L7),
(char *)(L8),
(char *)(LI9),
(char *)(L10),
(char *)(LI11),
(char *)(LI12)
};
#define VV ((object *)VVi)
static void LnkT48();
static void (*Lnk48)() = LnkT48;
static object *Lclptr47;
static void LnkT47();
static void (*Lnk47)() = LnkT47;
static object  LnkTLI46(object,...);
static object  (*LnkLI46)() = (object (*)()) LnkTLI46;
static object *Lclptr45;
static void LnkT45();
static void (*Lnk45)() = LnkT45;
static object  LnkTLI44(object,...);
static object  (*LnkLI44)() = (object (*)()) LnkTLI44;
static object  LnkTLI43(object,...);
static object  (*LnkLI43)() = (object (*)()) LnkTLI43;
static object  LnkTLI42(object,...);
static object  (*LnkLI42)() = (object (*)()) LnkTLI42;
static void LnkT41();
static void (*Lnk41)() = LnkT41;
static object *Lclptr40;
static void LnkT40();
static void (*Lnk40)() = LnkT40;
static object *Lclptr39;
static void LnkT39();
static void (*Lnk39)() = LnkT39;
static object *Lclptr38;
static void LnkT38();
static void (*Lnk38)() = LnkT38;
static object *Lclptr37;
static void LnkT37();
static void (*Lnk37)() = LnkT37;
static void LnkT36();
static void (*Lnk36)() = LnkT36;
static object  LnkTLI35(object,...);
static object  (*LnkLI35)() = (object (*)()) LnkTLI35;
static object *Lclptr34;
static void LnkT34();
static void (*Lnk34)() = LnkT34;
static object *Lclptr33;
static void LnkT33();
static void (*Lnk33)() = LnkT33;
static object *Lclptr32;
static void LnkT32();
static void (*Lnk32)() = LnkT32;
static object  LnkTLI31(object,...);
static object  (*LnkLI31)() = (object (*)()) LnkTLI31;
static object *Lclptr11;
static void LnkT11();
static void (*Lnk11)() = LnkT11;
static object  LnkTLI30(object,...);
static object  (*LnkLI30)() = (object (*)()) LnkTLI30;
static object *Lclptr29;
static void LnkT29();
static void (*Lnk29)() = LnkT29;
static object *Lclptr28;
static void LnkT28();
static void (*Lnk28)() = LnkT28;
static object *Lclptr27;
static void LnkT27();
static void (*Lnk27)() = LnkT27;
static object  LnkTLI26(object,...);
static object  (*LnkLI26)() = (object (*)()) LnkTLI26;
static object  LnkTLI0(object,...);
static object  (*LnkLI0)() = (object (*)()) LnkTLI0;
static object *Lclptr25;
static void LnkT25();
static void (*Lnk25)() = LnkT25;
static object *Lclptr24;
static void LnkT24();
static void (*Lnk24)() = LnkT24;
static object *Lclptr23;
static void LnkT23();
static void (*Lnk23)() = LnkT23;
static object *Lclptr21;
static void LnkT21();
static void (*Lnk21)() = LnkT21;
static object  LnkTLI22(object,...);
static object  (*LnkLI22)() = (object (*)()) LnkTLI22;
