
static void L1();
static void L2();
static void L4();
static void L6();
static void L7();
static void L12();
static void L19();
static void L20();
static void L21();
static void L22();
static void L23();
static void L24();
static void L25();
static void L26();
static void L27();
static void L28();
static void L29();
static void L31();
static void L32();
static void L33();
static void L34();
static void L37();
static void L43();
static void L50();
static void L59();
static void L61();
static void L63();
static void L85();
#define VC1 object  V2;
#define VC2
static object LI3();
#define VMB3 register object *base=vs_top;
#define VMS3  register object *sup=vs_top+3;vs_top=sup;
#define VMV3 vs_check;
#define VMR3(VMT3) vs_top=base ; return(VMT3);
#define VC4
static object LI5();
#define VMB5 register object *base=vs_top;
#define VMS5  register object *sup=vs_top+2;vs_top=sup;
#define VMV5 vs_check;
#define VMR5(VMT5) vs_top=base ; return(VMT5);
#define VC6 object  V14 ,V13 ,V12;
#define VC7
static object LI8();
#define VMB8 register object *base=vs_top; object  V17;
#define VMS8  register object *sup=vs_top+3;vs_top=sup;
#define VMV8 vs_check;
#define VMR8(VMT8) vs_top=base ; return(VMT8);
static object LI9(object,...);
static object VK9defaults[12]={(void *)-2,(void *)164,(void *)-2,(void *)170,(void *)170,(void *)-1,(void *)170,(void *)170,(void *)164,(void *)170,(void *)17,(void *)-2};
static struct { short n,allow_other_keys;object *defaults;
	 KEYTYPE keys[12];} LI9key={12,0,VK9defaults,{(void *)171,(void *)172,(void *)173,(void *)174,(void *)175,(void *)176,(void *)177,(void *)178,(void *)179,(void *)180,(void *)181,(void *)182}};
#define VMB9 register object *base=vs_top; object Vcs[24];
#define VMS9  register object *sup=vs_top+13;vs_top=sup;
#define VMV9 vs_check;
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10();
#define VMB10 register object *base=vs_top;
#define VMS10  register object *sup=vs_top+14;vs_top=sup;
#define VMV10 vs_check;
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI11();
#define VMB11 register object *base=vs_top;
#define VMS11  register object *sup=vs_top+5;vs_top=sup;
#define VMV11 vs_check;
#define VMR11(VMT11) vs_top=base ; return(VMT11);
#define VC12
static object LI13();
#define VMB13 register object *base=vs_top; object  V61;
#define VMS13  register object *sup=vs_top+4;vs_top=sup;
#define VMV13 vs_check;
#define VMR13(VMT13) vs_top=base ; return(VMT13);
static object LI14();
#define VMB14 register object *base=vs_top;
#define VMS14  register object *sup=vs_top+3;vs_top=sup;
#define VMV14 vs_check;
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI15();
#define VMB15 register object *base=vs_top; object  V83;
#define VMS15  register object *sup=vs_top+16;vs_top=sup;
#define VMV15 vs_check;
#define VMR15(VMT15) vs_top=base ; return(VMT15);
static object LI16();
#define VMB16 register object *base=vs_top;
#define VMS16  register object *sup=vs_top+4;vs_top=sup;
#define VMV16 vs_check;
#define VMR16(VMT16) vs_top=base ; return(VMT16);
static object LI17();
#define VMB17 register object *base=vs_top;
#define VMS17  register object *sup=vs_top+4;vs_top=sup;
#define VMV17 vs_check;
#define VMR17(VMT17) vs_top=base ; return(VMT17);
static object LI18();
#define VMB18 register object *base=vs_top;
#define VMS18  register object *sup=vs_top+4;vs_top=sup;
#define VMV18 vs_check;
#define VMR18(VMT18) vs_top=base ; return(VMT18);
#define VC19
#define VC20
#define VC21
#define VC22
#define VC23
#define VC24
#define VC25
#define VC26
#define VC27
#define VC28
#define VC29 object  V118 ,V117 ,V106 ,V105 ,V104 ,V103;
static object LI30(object,object,...);
#define VMB30 register object *base=vs_top; object  V132 ,V131 ,V130 ,V129 ,V128 ,V127 ,V126 ,V125; object Vcs[2];
#define VMS30  register object *sup=vs_top+3;vs_top=sup;
#define VMV30 vs_check;
#define VMR30(VMT30) vs_top=base ; return(VMT30);
#define VC31
#define VC32
#define VC33
#define VC34
static object LI35();
#define VMB35 register object *base=vs_top; object  V161;
#define VMS35  register object *sup=vs_top+4;vs_top=sup;
#define VMV35 vs_check;
#define VMR35(VMT35) vs_top=base ; return(VMT35);
static object LI36();
#define VMB36 register object *base=vs_top; object  V177;
#define VMS36  register object *sup=vs_top+3;vs_top=sup;
#define VMV36 vs_check;
#define VMR36(VMT36) vs_top=base ; return(VMT36);
#define VC37 object  V187 ,V186 ,V185 ,V184 ,V183 ,V182 ,V181;
static object LI38();
#define VMB38 register object *base=vs_top; object  V218 ,V217 ,V216 ,V215 ,V214; long  V212; object  V211 ,V210 ,V209 ,V208 ,V207 ,V205 ,V204 ,V203;
#define VMS38  register object *sup=vs_top+3;vs_top=sup;
#define VMV38 vs_check;
#define VMR38(VMT38) vs_top=base ; return(VMT38);
static object LI39(object,object,object,...);
#define VMB39 register object *base=vs_top; object  V249 ,V248 ,V247 ,V246 ,V245; long  V243; object  V242 ,V241 ,V240 ,V239 ,V238 ,V237 ,V236 ,V235 ,V234; object Vcs[3];
#define VMS39  register object *sup=vs_top+4;vs_top=sup;
#define VMV39 vs_check;
#define VMR39(VMT39) vs_top=base ; return(VMT39);
static object LI40();
#define VMB40 register object *base=vs_top; object  V259;
#define VMS40  register object *sup=vs_top+5;vs_top=sup;
#define VMV40 vs_check;
#define VMR40(VMT40) vs_top=base ; return(VMT40);
static object LI41();
#define VMB41 object  V264 ,V263;
#define VMS41
#define VMV41
#define VMR41(VMT41) return(VMT41);
static object LI42();
#define VMB42
#define VMS42
#define VMV42
#define VMR42(VMT42) return(VMT42);
#define VC43 object  V281 ,V279; long  V278;
static object LI44();
#define VMB44 register object *base=vs_top;
#define VMS44 vs_top += 1;
#define VMV44 vs_check;
#define VMR44(VMT44) vs_top=base ; return(VMT44);
static object LI45(object,object,object,...);
#define VMB45 register object *base=vs_top; object Vcs[3];
#define VMS45 vs_top += 1;
#define VMV45 vs_check;
#define VMR45(VMT45) vs_top=base ; return(VMT45);
static object LI48();
#define VMB46 register object *base=vs_top;
#define VMS46  register object *sup=vs_top+7;vs_top=sup;
#define VMV46 vs_check;
#define VMR46(VMT46) vs_top=base ; return(VMT46);
#define VC47 object  V343 ,V342 ,V341 ,V340 ,V339 ,V338 ,V337 ,V336 ,V335 ,V334 ,V333 ,V332 ,V331 ,V330 ,V329 ,V328 ,V327 ,V326 ,V325 ,V324;
static object LI51();
#define VMB48 register object *base=vs_top;
#define VMS48  register object *sup=vs_top+4;vs_top=sup;
#define VMV48 vs_check;
#define VMR48(VMT48) vs_top=base ; return(VMT48);
static object LI52();
#define VMB49 register object *base=vs_top;
#define VMS49  register object *sup=vs_top+4;vs_top=sup;
#define VMV49 vs_check;
#define VMR49(VMT49) vs_top=base ; return(VMT49);
static object LI53();
#define VMB50 object  V374 ,V373 ,V371 ,V370 ,V368 ,V367;
#define VMS50
#define VMV50
#define VMR50(VMT50) return(VMT50);
static object LI54();
#define VMB51 object  V393 ,V392 ,V390 ,V389;
#define VMS51
#define VMV51
#define VMR51(VMT51) return(VMT51);
static object LI55(object,object,object,object,...);
#define VMB52 object  V415 ,V414 ,V413 ,V412; object Vcs[4];
#define VMS52
#define VMV52
#define VMR52(VMT52) return(VMT52);
static object LI56();
#define VMB53 object  V434 ,V433;
#define VMS53
#define VMV53
#define VMR53(VMT53) return(VMT53);
static object LI57();
#define VMB54 object  V453 ,V452 ,V451;
#define VMS54
#define VMV54
#define VMR54(VMT54) return(VMT54);
static object LI58();
#define VMB55 object  V479 ,V478 ,V476 ,V475 ,V467 ,V466 ,V464 ,V463;
#define VMS55
#define VMV55
#define VMR55(VMT55) return(VMT55);
#define VC56
static object LI60();
#define VMB57 object  V491 ,V490;
#define VMS57
#define VMV57
#define VMR57(VMT57) return(VMT57);
#define VC58 object  V507 ,V503 ,V502 ,V501 ,V497 ,V496 ,V495;
static object LI62(object,object,object,object,...);
#define VMB59 register object *base=vs_top; object  V520 ,V519 ,V518; object Vcs[4];
#define VMS59  register object *sup=vs_top+1;vs_top=sup;
#define VMV59 vs_check;
#define VMR59(VMT59) vs_top=base ; return(VMT59);
#define VC60
static object LI64();
#define VMB61 register object *base=vs_top; long  V569 ,V568 ,V567 ,V565 ,V563 ,V559 ,V558 ,V557 ,V556 ,V554 ,V548 ,V547 ,V546 ,V545 ,V542; object  V541; long  V540 ,V537; object  V532 ,V531 ,V530; long  V529;
#define VMS61  register object *sup=vs_top+8;vs_top=sup;
#define VMV61 vs_check;
#define VMR61(VMT61) vs_top=base ; return(VMT61);
static object LI65(object,object,object,...);
#define VMB62 register object *base=vs_top; object  V614; long  V611 ,V610 ,V609 ,V606; object  V605 ,V601 ,V599; long  V596 ,V590 ,V589 ,V588 ,V586; object  V584 ,V583 ,V581; long  V580 ,V579; object Vcs[4];
#define VMS62  register object *sup=vs_top+2;vs_top=sup;
#define VMV62 vs_check;
#define VMR62(VMT62) vs_top=base ; return(VMT62);
static object LI66(object,object,object,...);
#define VMB63 register object *base=vs_top; object  V690; long  V689 ,V688 ,V687 ,V686; object  V683 ,V682; long  V681; object  V680; long  V679 ,V678 ,V677 ,V676 ,V672; object  V669 ,V661; long  V660 ,V659 ,V658 ,V657 ,V656 ,V652; object  V649 ,V646; long  V640 ,V639 ,V638 ,V637 ,V632 ,V628; object Vcs[3];
#define VMS63  register object *sup=vs_top+2;vs_top=sup;
#define VMV63 vs_check;
#define VMR63(VMT63) vs_top=base ; return(VMT63);
static object LI67();
#define VMB64 register object *base=vs_top; long  V717 ,V716 ,V715 ,V714 ,V711; object  V710; long  V709 ,V706;
#define VMS64  register object *sup=vs_top+1;vs_top=sup;
#define VMV64 vs_check;
#define VMR64(VMT64) vs_top=base ; return(VMT64);
static object LI68();
#define VMB65 register object *base=vs_top; object  V742; long  V741 ,V740 ,V739 ,V738 ,V737 ,V733; object  V730; long  V729;
#define VMS65  register object *sup=vs_top+1;vs_top=sup;
#define VMV65 vs_check;
#define VMR65(VMT65) vs_top=base ; return(VMT65);
static object LI69();
#define VMB66 register object *base=vs_top; long  V820 ,V816 ,V815 ,V814 ,V813 ,V812 ,V807; object  V804; long  V803; object  V802; long  V801 ,V800 ,V799 ,V798 ,V794; object  V791 ,V783; long  V782 ,V781 ,V780 ,V779 ,V778 ,V774; object  V771; long  V765 ,V763 ,V762;
#define VMS66  register object *sup=vs_top+3;vs_top=sup;
#define VMV66 vs_check;
#define VMR66(VMT66) vs_top=base ; return(VMT66);
static object LI70();
#define VMB67 register object *base=vs_top; object  V905; long  V899 ,V898 ,V897 ,V896 ,V893 ,V892 ,V891 ,V890 ,V885; object  V880; long  V879; object  V878; long  V877 ,V876 ,V875 ,V874 ,V870; object  V867 ,V859; long  V858 ,V857 ,V856 ,V855 ,V854 ,V850; object  V847; long  V841 ,V840 ,V839 ,V838 ,V837; object  V834;
#define VMS67  register object *sup=vs_top+3;vs_top=sup;
#define VMV67 vs_check;
#define VMR67(VMT67) vs_top=base ; return(VMT67);
static object LI74();
#define VMB69 register object *base=vs_top; object  V944; long  V938 ,V937 ,V936 ,V935 ,V930 ,V926; object  V922 ,V918 ,V917;
#define VMS69  register object *sup=vs_top+6;vs_top=sup;
#define VMV69 vs_check;
#define VMR69(VMT69) vs_top=base ; return(VMT69);
static object LI81();
#define VMB70 register object *base=vs_top; object  V980; long  V974 ,V973 ,V972 ,V971 ,V966 ,V962; object  V958 ,V957;
#define VMS70  register object *sup=vs_top+7;vs_top=sup;
#define VMV70 vs_check;
#define VMR70(VMT70) vs_top=base ; return(VMT70);
#define VC71 object  V1100; long  V1094 ,V1093 ,V1092 ,V1091 ,V1088 ,V1087 ,V1086 ,V1085 ,V1076 ,V1074 ,V1072 ,V1070 ,V1068 ,V1066 ,V1065 ,V1064 ,V1063 ,V1062; object  V1059 ,V1058; long  V1054; object  V1053 ,V1052 ,V1051 ,V1050; long  V1049 ,V1047 ,V1045 ,V1044 ,V1043 ,V1042 ,V1041; object  V1038 ,V1037 ,V1028; long  V1022 ,V1021 ,V1020 ,V1019 ,V1014 ,V1010 ,V1008; object  V1002 ,V1001 ,V1000; long  V994 ,V992 ,V990;
static object LI86();
#define VMB73
#define VMS73
#define VMV73
#define VMR73(VMT73) return(VMT73);
static object LI87();
#define VMB74 register object *base=vs_top;
#define VMS74  register object *sup=vs_top+4;vs_top=sup;
#define VMV74 vs_check;
#define VMR74(VMT74) vs_top=base ; return(VMT74);
static void LC89();
#define VC75
static void L84();
#define VC76
static void L83();
#define VC77
static void L82();
#define VC78 long  V1147; object  V1146; long  V1145 ,V1144 ,V1143 ,V1142 ,V1138; object  V1128; long  V1127 ,V1126 ,V1125 ,V1124 ,V1123 ,V1119;
static void L76();
#define VC79
static void L75();
#define VC80
static void L49();
#define VC81 object  V1153;
static void LC88();
#define VC82
static void LC89();
static void LC88();
#define VM82 4
#define VM81 4
#define VM80 2
#define VM79 3
#define VM78 4
#define VM77 3
#define VM76 3
#define VM75 4
#define VM74 4
#define VM73 0
#define VM71 5
#define VM72 0
#define VM70 7
#define VM69 6
#define VM67 3
#define VM68 0
#define VM66 3
#define VM65 1
#define VM64 1
#define VM63 2
#define VM62 2
#define VM61 8
#define VM60 4
#define VM59 1
#define VM58 6
#define VM57 0
#define VM56 5
#define VM55 0
#define VM54 0
#define VM53 0
#define VM52 0
#define VM51 0
#define VM50 0
#define VM49 4
#define VM48 4
#define VM47 12
#define VM46 7
#define VM45 1
#define VM44 1
#define VM43 7
#define VM42 0
#define VM41 0
#define VM40 5
#define VM39 4
#define VM38 3
#define VM37 4
#define VM36 3
#define VM35 4
#define VM34 4
#define VM33 4
#define VM32 4
#define VM31 5
#define VM30 3
#define VM29 13
#define VM28 4
#define VM27 4
#define VM26 4
#define VM25 4
#define VM24 4
#define VM23 5
#define VM22 5
#define VM21 3
#define VM20 4
#define VM19 3
#define VM18 4
#define VM17 4
#define VM16 4
#define VM15 16
#define VM14 3
#define VM13 4
#define VM12 4
#define VM11 5
#define VM10 14
#define VM9 13
#define VM8 3
#define VM7 1
#define VM6 5
#define VM5 2
#define VM4 4
#define VM3 3
#define VM2 4
#define VM1 5
static char * VVi[222]={
#define Cdata VV[221]
(char *)(L1),
(char *)(L2),
(char *)(LI3),
(char *)(L4),
(char *)(LI5),
(char *)(L6),
(char *)(L7),
(char *)(LI8),
(char *)(LI9),
(char *)(&LI9key),
(char *)(LI10),
(char *)(LI11),
(char *)(L12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(LI16),
(char *)(LI17),
(char *)(LI18),
(char *)(L19),
(char *)(L20),
(char *)(L21),
(char *)(L22),
(char *)(L23),
(char *)(L24),
(char *)(L25),
(char *)(L26),
(char *)(L27),
(char *)(L28),
(char *)(L29),
(char *)(LI30),
(char *)(L31),
(char *)(L32),
(char *)(L33),
(char *)(L34),
(char *)(LI35),
(char *)(LI36),
(char *)(L37),
(char *)(LI38),
(char *)(LI39),
(char *)(LI40),
(char *)(LI41),
(char *)(LI42),
(char *)(L43),
(char *)(LI44),
(char *)(LI45),
(char *)(LI48),
(char *)(L50),
(char *)(LI51),
(char *)(LI52),
(char *)(LI53),
(char *)(LI54),
(char *)(LI55),
(char *)(LI56),
(char *)(LI57),
(char *)(LI58),
(char *)(L59),
(char *)(LI60),
(char *)(L61),
(char *)(LI62),
(char *)(L63),
(char *)(LI64),
(char *)(LI65),
(char *)(LI66),
(char *)(LI67),
(char *)(LI68),
(char *)(LI69),
(char *)(LI70),
(char *)(LI74),
(char *)(LI81),
(char *)(L85),
(char *)(LI86),
(char *)(LI87)
};
#define VV ((object *)VVi)
static void LnkT220();
static void (*Lnk220)() = LnkT220;
static object *Lclptr219;
static void LnkT219();
static void (*Lnk219)() = LnkT219;
static object  LnkTLI218(object,...);
static object  (*LnkLI218)() = (object (*)()) LnkTLI218;
static object  LnkTLI217(object,...);
static object  (*LnkLI217)() = (object (*)()) LnkTLI217;
static object  LnkTLI36(object,...);
static object  (*LnkLI36)() = (object (*)()) LnkTLI36;
static object  LnkTLI214(object,...);
static object  (*LnkLI214)() = (object (*)()) LnkTLI214;
static object  LnkTLI213(object,...);
static object  (*LnkLI213)() = (object (*)()) LnkTLI213;
static object  LnkTLI154(object,...);
static object  (*LnkLI154)() = (object (*)()) LnkTLI154;
static void LnkT212();
static void (*Lnk212)() = LnkT212;
static object  LnkTLI211(object,...);
static object  (*LnkLI211)() = (object (*)()) LnkTLI211;
static object  LnkTLI210(object,...);
static object  (*LnkLI210)() = (object (*)()) LnkTLI210;
static object  LnkTLI209(object,...);
static object  (*LnkLI209)() = (object (*)()) LnkTLI209;
static object  LnkTLI208(object,...);
static object  (*LnkLI208)() = (object (*)()) LnkTLI208;
static object  LnkTLI207(object,...);
static object  (*LnkLI207)() = (object (*)()) LnkTLI207;
static object  LnkTLI206(object,...);
static object  (*LnkLI206)() = (object (*)()) LnkTLI206;
static object  LnkTLI205(object,...);
static object  (*LnkLI205)() = (object (*)()) LnkTLI205;
static object  LnkTLI204(object,...);
static object  (*LnkLI204)() = (object (*)()) LnkTLI204;
static object  LnkTLI203(object,...);
static object  (*LnkLI203)() = (object (*)()) LnkTLI203;
static object  LnkTLI202(object,...);
static object  (*LnkLI202)() = (object (*)()) LnkTLI202;
static object  LnkTLI201(object,...);
static object  (*LnkLI201)() = (object (*)()) LnkTLI201;
static object  LnkTLI200(object,...);
static object  (*LnkLI200)() = (object (*)()) LnkTLI200;
static void LnkT199();
static void (*Lnk199)() = LnkT199;
static object  LnkTLI198(object,...);
static object  (*LnkLI198)() = (object (*)()) LnkTLI198;
static void LnkT197();
static void (*Lnk197)() = LnkT197;
static object  LnkTLI196();
static object  (*LnkLI196)() = LnkTLI196;
static object  LnkTLI195(object,...);
static object  (*LnkLI195)() = (object (*)()) LnkTLI195;
static object  LnkTLI194(object,...);
static object  (*LnkLI194)() = (object (*)()) LnkTLI194;
static object  LnkTLI71(object,...);
static object  (*LnkLI71)() = (object (*)()) LnkTLI71;
static object  LnkTLI192(object,...);
static object  (*LnkLI192)() = (object (*)()) LnkTLI192;
static object  LnkTLI191(object,...);
static object  (*LnkLI191)() = (object (*)()) LnkTLI191;
static void LnkT190();
static void (*Lnk190)() = LnkT190;
static void LnkT189();
static void (*Lnk189)() = LnkT189;
static object  LnkTLI186(object,...);
static object  (*LnkLI186)() = (object (*)()) LnkTLI186;
static object  LnkTLI185(object,...);
static object  (*LnkLI185)() = (object (*)()) LnkTLI185;
static object  LnkTLI184(object,...);
static object  (*LnkLI184)() = (object (*)()) LnkTLI184;
static void LnkT169();
static void (*Lnk169)() = LnkT169;
static void LnkT44();
static void (*Lnk44)() = LnkT44;
