
static void L1();
static void L2();
static void L3();
static void L4();
static void L5();
static void L6();
static void L7();
static void L8();
static void L9();
static void L10();
static void L11();
static void L12();
static void L13();
#define VC1
#define VC2 object  V27 ,V26 ,V25 ,V24 ,V23 ,V22;
#define VC3
#define VC4
#define VC5
#define VC6
#define VC7
#define VC8 object  V106 ,V105 ,V104 ,V103 ,V102 ,V101 ,V97 ,V96 ,V95 ,V94 ,V93 ,V92 ,V91 ,V90 ,V89 ,V87 ,V86 ,V85 ,V84 ,V83;
#define VC9 object  V120 ,V119 ,V118 ,V117 ,V116 ,V115;
#define VC10
#define VC11
#define VC12
#define VC13 object  V152 ,V151 ,V150;
#define VM13 15
#define VM12 6
#define VM11 14
#define VM10 6
#define VM9 8
#define VM8 20
#define VM7 3
#define VM6 3
#define VM5 5
#define VM4 7
#define VM3 4
#define VM2 27
#define VM1 13
static char * VVi[97]={
#define Cdata VV[96]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(L4),
(char *)(L5),
(char *)(L6),
(char *)(L7),
(char *)(L8),
(char *)(L9),
(char *)(L10),
(char *)(L11),
(char *)(L12),
(char *)(L13)
};
#define VV ((object *)VVi)
static void LnkT95();
static void (*Lnk95)() = LnkT95;
static void LnkT94();
static void (*Lnk94)() = LnkT94;
static void LnkT93();
static void (*Lnk93)() = LnkT93;
static void LnkT92();
static void (*Lnk92)() = LnkT92;
static void LnkT91();
static void (*Lnk91)() = LnkT91;
static void LnkT90();
static void (*Lnk90)() = LnkT90;
static void LnkT49();
static void (*Lnk49)() = LnkT49;
static void LnkT89();
static void (*Lnk89)() = LnkT89;
static void LnkT88();
static void (*Lnk88)() = LnkT88;
static void LnkT30();
static void (*Lnk30)() = LnkT30;
