
static void L1();
#define VC1 object  V35 ,V34 ,V33 ,V32 ,V31 ,V30 ,V25 ,V18 ,V17 ,V16 ,V15 ,V14 ,V13 ,V8;
#define VM1 6
static char * VVi[8]={
#define Cdata VV[7]
(char *)(L1)
};
#define VV ((object *)VVi)
static void LnkT0();
static void (*Lnk0)() = LnkT0;
static void LnkT6();
static void (*Lnk6)() = LnkT6;
