
static void L1();
static void L4();
static void L6();
static void L7();
static void L8();
static void L9();
#define VC1
static object LI2();
#define VMB2 register object *base=vs_top; object  V8 ,V6 ,V4;
#define VMS2  register object *sup=vs_top+2;vs_top=sup;
#define VMV2 vs_reserve(2);
#define VMR2(VMT2) vs_top=base ; return(VMT2);
static object LI3();
#define VMB3 register object *base=vs_top; object  V14 ,V13;
#define VMS3  register object *sup=vs_top+6;vs_top=sup;
#define VMV3 vs_reserve(6);
#define VMR3(VMT3) vs_top=base ; return(VMT3);
#define VC4 object  V31 ,V29 ,V28 ,V26 ,V25;
static object LI5(object,object,object,object,object,object,object,...);
#define VMB5 register object *base=vs_top; object  V58 ,V57 ,V56 ,V55 ,V54; object Vcs[7];
#define VMS5  register object *sup=vs_top+5;vs_top=sup;
#define VMV5 vs_reserve(5);
#define VMR5(VMT5) vs_top=base ; return(VMT5);
#define VC6
#define VC7
#define VC8
#define VC9
static void LC11();
#define VC10 object  V64;
static void LC10();
#define VC11
static void LC11();
static void LC10();
#define VM11 2
#define VM10 2
#define VM9 2
#define VM8 2
#define VM7 5
#define VM6 5
#define VM5 5
#define VM4 11
#define VM3 6
#define VM2 2
#define VM1 4
static char * VVi[21]={
#define Cdata VV[20]
(char *)(L1),
(char *)(LI2),
(char *)(LI3),
(char *)(L4),
(char *)(LI5),
(char *)(L6),
(char *)(L7),
(char *)(L8),
(char *)(L9)
};
#define VV ((object *)VVi)
static void LnkT19();
static void (*Lnk19)() = LnkT19;
static object  LnkTLI18(object,...);
static object  (*LnkLI18)() = (object (*)()) LnkTLI18;
static object  LnkTLI17(object,...);
static object  (*LnkLI17)() = (object (*)()) LnkTLI17;
