
static void L1();
#define VC1
static void LC2();
#define VC2 object  V8;
static void LC2();
#define VM2 7
#define VM1 3
static char * VVi[11]={
#define Cdata VV[10]
(char *)(L1)
};
#define VV ((object *)VVi)
static void LnkT9();
static void (*Lnk9)() = LnkT9;
static object  LnkTLI8(object,...);
static object  (*LnkLI8)() = (object (*)()) LnkTLI8;
static void LnkT7();
static void (*Lnk7)() = LnkT7;
static void LnkT6();
static void (*Lnk6)() = LnkT6;
