;;; Tests of evaluation and compilation
(load "eval.lsp")
(load "eval-and-compile.lsp")
(load "compile.lsp")
(load "compiler-macros.lsp")
(load "constantp.lsp")
(load "lambda.lsp")
(load "eval-when.lsp")
(load "define-compiler-macro.lsp")
(load "define-symbol-macro.lsp")
(load "defmacro.lsp")
(load "the.lsp")

