
static void L1();
static void L2();
static void L3();
static void L4();
static void L6();
static void L7();
static void L9();
static void L10();
static void L12();
static void L24();
static void L34();
#define VC1
#define VC2
#define VC3
#define VC4 object  V19 ,V18 ,V17 ,V16 ,V15 ,V14 ,V13 ,V12 ,V11;
static object LI5();
#define VMB5 register object *base=vs_top;
#define VMS5  register object *sup=vs_top+4;vs_top=sup;
#define VMV5 vs_check;
#define VMR5(VMT5) vs_top=base ; return(VMT5);
#define VC6 object  V26;
#define VC7
static object LI8();
#define VMB8
#define VMS8
#define VMV8
#define VMR8(VMT8) return(VMT8);
static object LI11();
#define VMB9 register object *base=vs_top; object  V43 ,V42 ,V41 ,V40 ,V39 ,V37 ,V36;
#define VMS9  register object *sup=vs_top+4;vs_top=sup;
#define VMV9 vs_check;
#define VMR9(VMT9) vs_top=base ; return(VMT9);
#define VC10 object  V69 ,V68 ,V67 ,V66 ,V65 ,V59 ,V58 ,V56 ,V55 ,V46;
static object LI13();
#define VMB11
#define VMS11
#define VMV11
#define VMR11(VMT11) return(VMT11);
static object LI14();
#define VMB12
#define VMS12
#define VMV12
#define VMR12(VMT12) return(VMT12);
static object LI15();
#define VMB13
#define VMS13
#define VMV13
#define VMR13(VMT13) return(VMT13);
static object LI16();
#define VMB14
#define VMS14
#define VMV14
#define VMR14(VMT14) return(VMT14);
static object LI17();
#define VMB15
#define VMS15
#define VMV15
#define VMR15(VMT15) return(VMT15);
static object LI18();
#define VMB16
#define VMS16
#define VMV16
#define VMR16(VMT16) return(VMT16);
static object LI19();
#define VMB17
#define VMS17
#define VMV17
#define VMR17(VMT17) return(VMT17);
static object LI20();
#define VMB18
#define VMS18
#define VMV18
#define VMR18(VMT18) return(VMT18);
static object LI21();
#define VMB19
#define VMS19
#define VMV19
#define VMR19(VMT19) return(VMT19);
static object LI22();
#define VMB20
#define VMS20
#define VMV20
#define VMR20(VMT20) return(VMT20);
static object LI23();
#define VMB21 register object *base=vs_top;
#define VMS21  register object *sup=vs_top+1;vs_top=sup;
#define VMV21 vs_check;
#define VMR21(VMT21) vs_top=base ; return(VMT21);
static object LI25();
#define VMB22
#define VMS22
#define VMV22
#define VMR22(VMT22) return(VMT22);
static object LI26();
#define VMB23
#define VMS23
#define VMV23
#define VMR23(VMT23) return(VMT23);
static object LI27();
#define VMB24 register object *base=vs_top; object  V126;
#define VMS24  register object *sup=vs_top+2;vs_top=sup;
#define VMV24 vs_check;
#define VMR24(VMT24) vs_top=base ; return(VMT24);
static object LI28();
#define VMB25 register object *base=vs_top; object  V139 ,V136;
#define VMS25  register object *sup=vs_top+2;vs_top=sup;
#define VMV25 vs_check;
#define VMR25(VMT25) vs_top=base ; return(VMT25);
static object LI29();
#define VMB26 object  V145;
#define VMS26
#define VMV26
#define VMR26(VMT26) return(VMT26);
static object LI31();
#define VMB27 register object *base=vs_top; object  V169 ,V168 ,V159 ,V158 ,V155 ,V151;
#define VMS27  register object *sup=vs_top+13;vs_top=sup;
#define VMV27 vs_check;
#define VMR27(VMT27) vs_top=base ; return(VMT27);
static object LI32();
#define VMB28
#define VMS28
#define VMV28
#define VMR28(VMT28) return(VMT28);
static object LI33();
#define VMB29
#define VMS29
#define VMV29
#define VMR29(VMT29) return(VMT29);
#define VC30
static object LI35();
#define VMB31
#define VMS31
#define VMV31
#define VMR31(VMT31) return(VMT31);
static object LI36();
#define VMB32 register object *VOL base=vs_top; object  V203 ,V199 ,V198 ,V197 ,V196 ,V195 ,V190 ,V181;
#define VMS32  register object *VOL sup=vs_top+8;vs_top=sup;
#define VMV32 vs_check;
#define VMR32(VMT32) vs_top=base ; return(VMT32);
static void LC39();
#define VC33
static void LC38();
#define VC34
static void LC37();
#define VC35
static void LC39();
static void LC38();
static void LC37();
#define VM35 2
#define VM34 3
#define VM33 6
#define VM32 8
#define VM31 0
#define VM30 2
#define VM29 0
#define VM28 0
#define VM27 13
#define VM26 0
#define VM25 2
#define VM24 2
#define VM23 0
#define VM22 0
#define VM21 1
#define VM20 0
#define VM19 0
#define VM18 0
#define VM17 0
#define VM16 0
#define VM15 0
#define VM14 0
#define VM13 0
#define VM12 0
#define VM11 0
#define VM10 8
#define VM9 4
#define VM8 0
#define VM7 7
#define VM6 5
#define VM5 4
#define VM4 8
#define VM3 5
#define VM2 5
#define VM1 5
static char * VVi[78]={
#define Cdata VV[77]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(L4),
(char *)(LI5),
(char *)(L6),
(char *)(L7),
(char *)(LI8),
(char *)(L9),
(char *)(L10),
(char *)(LI11),
(char *)(L12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(LI16),
(char *)(LI17),
(char *)(LI18),
(char *)(LI19),
(char *)(LI20),
(char *)(LI21),
(char *)(LI22),
(char *)(LI23),
(char *)(L24),
(char *)(LI25),
(char *)(LI26),
(char *)(LI27),
(char *)(LI28),
(char *)(LI29),
(char *)(LI31),
(char *)(LI32),
(char *)(LI33),
(char *)(L34),
(char *)(LI35),
(char *)(LI36),
(char *)(&LC37)
};
#define VV ((object *)VVi)
static void LnkT76();
static void (*Lnk76)() = LnkT76;
static void LnkT75();
static void (*Lnk75)() = LnkT75;
static void LnkT74();
static void (*Lnk74)() = LnkT74;
static void LnkT73();
static void (*Lnk73)() = LnkT73;
static void LnkT72();
static void (*Lnk72)() = LnkT72;
static object  LnkTLI71(object,...);
static object  (*LnkLI71)() = (object (*)()) LnkTLI71;
static object  LnkTLI70(object,...);
static object  (*LnkLI70)() = (object (*)()) LnkTLI70;
static object  LnkTLI69(object,...);
static object  (*LnkLI69)() = (object (*)()) LnkTLI69;
static object  LnkTLI68(object,...);
static object  (*LnkLI68)() = (object (*)()) LnkTLI68;
static object  LnkTLI67(object,...);
static object  (*LnkLI67)() = (object (*)()) LnkTLI67;
static object  LnkTLI66(object,...);
static object  (*LnkLI66)() = (object (*)()) LnkTLI66;
static object  LnkTLI65(object,...);
static object  (*LnkLI65)() = (object (*)()) LnkTLI65;
static void LnkT64();
static void (*Lnk64)() = LnkT64;
static void LnkT63();
static void (*Lnk63)() = LnkT63;
static void LnkT61();
static void (*Lnk61)() = LnkT61;
static void LnkT60();
static void (*Lnk60)() = LnkT60;
static void LnkT59();
static void (*Lnk59)() = LnkT59;
