
static void L1();
#define VC1
static void LC2();
#define VC2
static void LC2();
#define VM2 9
#define VM1 5
static char * VVi[8]={
#define Cdata VV[7]
(char *)(L1)
};
#define VV ((object *)VVi)
static void LnkT6();
static void (*Lnk6)() = LnkT6;
static void LnkT5();
static void (*Lnk5)() = LnkT5;
static void LnkT4();
static void (*Lnk4)() = LnkT4;
