
(IN-PACKAGE "COMPILER") 
(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) F-TYPE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) FIXNUM) ANALYZE-REGS PROCLAIMED-ARGD
            ANALYZE-REGS1)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) *) WT-INLINE C2IF C2FLET C2LABELS
            C2COMPILER-LET)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) *) C1DM-VL C1DM-V C2DM C2RETURN-FROM
            C2APPLY-OPTIMIZE)) 
(PROCLAIM '(FTYPE (FUNCTION (T T *) *) T3DEFUN-AUX)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) T) C2CALL-GLOBAL WT-GLOBAL-ENTRY
            C2CALL-UNKNOWN-GLOBAL SYSTEM::RECORD-FN C1MAKE-VAR C2SWITCH
            C2STRUCTURE-REF T3DEFUN-VARARG T3DEFUN-NORMAL MY-CALL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T) T) T3LOCAL-DCFUN T3LOCAL-FUN T2DEFUN
            T2DEFENTRY T3DEFENTRY C1APPLY-OPTIMIZE C2STRUCTURE-SET
            T3DEFUN-LOCAL-ENTRY T3DEFUN)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) T) ADD-FAST-LINK INLINE-TYPE-MATCHES
            C2FUNCALL-SFUN WT-IF-PROCLAIMED C2LET WT-INLINE-COND
            FIX-DOWN-ARGS WT-INLINE-FIXNUM WT-INLINE-CHARACTER
            ASSIGN-DOWN-VARS WT-INLINE-LONG-FLOAT WT-INLINE-SHORT-FLOAT
            SUBLIS1-INLINE C1DM C1STRUCTURE-REF1 C2CASE GET-INLINE-INFO
            CJT C2LET* CJF T3DEFCFUN CAN-BE-REPLACED* TOO-MANY-ARGS
            TOO-FEW-ARGS C2TAGBODY C2PROGV C2GO CMP-EXPAND-MACRO
            AND-FORM-TYPE C2MAPCAR ADD-FUNCTION-PROCLAMATION
            CHECK-FORM-TYPE ADD-FUNCTION-DECLARATION C2MAPC C2MAPCAN
            C1MAP-FUNCTIONS CHECK-VDECL C2MULTIPLE-VALUE-BIND C2PRINC
            SET-VAR)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T *) T) C2FUNCALL C2LAMBDA-EXPR INLINE-ARGS)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T T) T) DEFSYSFUN T2DEFMACRO T3DEFMACRO)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) WT-SIMPLE-CALL)) 
(PROCLAIM '(FTYPE (FUNCTION NIL *) WT-DATA-FILE WT-FASD-DATA-FILE)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL T) TAIL-RECURSION-POSSIBLE
            CLOSE-INLINE-BLOCKS C1T CVS-PUSH WT-CVARS
            ADD-LOAD-TIME-SHARP-COMMA WT-C-PUSH RESET-TOP 
            INIT-ENV VS-PUSH BABOON PRINT-CURRENT-FORM
            NO-MAKE-PROCLAIMS-HACK WT-NEXT-VAR-ARG INIT-FN C1NIL
            LIST-UNDEFINED-FUNCTIONS WT-DATA-BEGIN
            LIST-UNCALLED-FUNCTIONS WT-DATA-END CCB-VS-PUSH WFS-ERROR
            CURRENT-FN CLEAR-CALL-TABLE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (*) *) INLINE-BOOLE3 DUMP-FN-DATA 
            MAKE-ALL-PROCLAIMS)) 
(PROCLAIM
    '(FTYPE (FUNCTION (*) T) MAKE-INFO FCALLN-INLINE MAKE-FUN MAKE-VAR
            MAKE-FN MAKE-PROCLAIMS MAKE-TAG WT-CLINK LIST-INLINE CS-PUSH
            LIST*-INLINE MAKE-BLK)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) *) T1EXPR C2AND C2OR T1EVAL-WHEN WT-LOC
            WT-FIXNUM-LOC WT-CHARACTER-LOC WT-LONG-FLOAT-LOC
            WT-SHORT-FLOAT-LOC C2EXPR CMP-EVAL CMP-TOPLEVEL-EVAL
            WT-TO-STRING SET-LOC C2PROGN)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) T) C1NTHCDR-CONDITION C1NTHCDR C1LOCAL-FUN
            C1DOWNWARD-FUNCTION C1RPLACA-NTHCDR CMP-MACRO-FUNCTION
            WT-DATA-PACKAGE-OPERATION C2DOWNWARD-FUNCTION C1LIST-NTH
            TYPE-FILTER T1ORDINARY C1BOOLE-CONDITION
            FUNCTION-RETURN-TYPE C1BOOLE3 T1PROGN C1ASH-CONDITION
            CHECK-DOWNWARD VOLATILE C1ASH PUSH-ARGS C1LENGTH
            PUSH-ARGS-LISPCALL NEED-TO-SET-VS-POINTERS FASD-INDEX
            INFO-P FASD-PACKAGE FASD-DIRECTION VARARG-P FASD-EOF
            MAXARGS NAME-TO-SD FASD-TABLE UNWIND-NO-EXIT FASD-STREAM
            WT-DOWNWARD-CLOSURE-MACRO THE-PARAMETER REPLACE-CONSTANT
            ADD-OBJECT FASD-MACRO FASD-TABLE_LENGTH
            ARGS-CAUSE-SIDE-EFFECT C1IF C2FUNCALL-AUX FASD-FILEPOS
            WT-LIST SET-UP-VAR-CVS INFO-CHANGED-VARS C1AND C1FUNOB
            C1DM-BAD-KEY INFO-REFERRED-VARS INFO-TYPE C1OR
            WT-FUNCTION-LINK PARSE-CVSPECS C2DM-RESERVE-VL
            INFO-SP-CHANGE NAME-SD1 WT-FUNCALL-C C1VAR C2DM-RESERVE-V
            INFO-VOLATILE T1DEFUN SAVE-FUNOB T1DEFMACRO REP-TYPE
            AET-C-TYPE C1CATCH WT1 T1CLINES C1ECASE WT-H1 T1DEFCFUN
            C1UNWIND-PROTECT T1DEFENTRY CHECK-VREF T1DEFLA C1THROW
            RECORD-ARG-INFO C1ADD-GLOBALS T1DEFVAR INLINE-POSSIBLE
            C1FLET C2VAR-KIND C1FMLA-CONSTANT SET-PUSH-CATCH-FRAME
            T2ORDINARY C1LET C1LABELS T2DECLARE C1LET* C1MACROLET
            VAR-KIND  FUN-P
            C1LOCAL-CLOSURE T3CLINES C1STACK-LET FUN-NAME FUN-REF
            C2EXPR* FUN-REF-CCB PROCLAIM CTOP-WRITE FUN-CFUN
            PROCLAMATION FUN-LEVEL T1DEFINE-STRUCTURE FIXNUM-LOC-P
            WRITE-BLOCK-OPEN CHARACTER-LOC-P  LONG-FLOAT-LOC-P
            WT-VV INLINE-TYPE C2VAR SHORT-FLOAT-LOC-P WT-CAR C2LOCATION
            WT-CDR C1SETQ WT-CADR C1TAGBODY GET-VAR-TYPES C1PROGV
            WT-VS-BASE GET-VALUE-TYPE1 UNDEFINED-VARIABLE C1GO
            GET-VALUE-TYPE C1PSETQ WT-DOWN C1PROGN ADD-CALLEE C1SWITCH
            RESULT-TYPE-FROM-LOC CMP-MACROEXPAND REGISTER SET-RETURN
            ADD-SYMBOL WT-VS* CMP-MACROEXPAND-1 SET-TOP PUSH-DATA-INCF
            VAR-P ADD-REG1 WT-DATA1 VAR-NAME ADD-LOOP-REGISTERS
            ADD-MACRO-CALLEE VAR-REF C2TAGBODY-LOCAL C1EXPR WT-CCB-VS
            VAR-REF-CCB OBJECT-TYPE C2TAGBODY-BODY FUNCTION-ARG-TYPES
            VAR-LOC C2TAGBODY-CLB C1MAPCAR SCH-LOCAL-FUN VAR-TYPE
            RESET-INFO-TYPE C2TAGBODY-CCB C1MAPLIST EMIT-FN FN-P
            VAR-REGISTER C2GO-LOCAL SCH-GLOBAL C2GO-CLB C1MAPC
            DEFAULT-INIT C2GO-CCB C1MAPL WT-SWITCH-CASE C1MAPCAN
            ADD-CONSTANT VERIFY-DATA-VECTOR C1MAPCON BLK-P BLK-NAME
            GET-ARG-TYPES BLK-REF GET-RETURN-TYPE BLK-REF-CLB FN-NAME
            TAG-P GET-LOCAL-ARG-TYPES BLK-REF-CCB FN-DEF TAG-NAME
            C1MULTIPLE-VALUE-CALL GET-LOCAL-RETURN-TYPE BLK-EXIT C2BIND
            FN-VALUE-TYPE TAG-REF INLINE-BOOLE3-STRING BLK-VALUE-TO-GO
            FN-FUN-VALUES TAG-REF-CLB C1MULTIPLE-VALUE-PROG1
            RESULT-TYPE BLK-VAR FN-CALLEES WT-VS TAG-REF-CCB
            FN-RETURN-TYPE TAG-LABEL C1VALUES GET-INCLUDED FN-ARG-TYPES
            CLINK TAG-UNWIND-EXIT C2VALUES CONS-TO-LISTA FN-NO-EMIT
            TAG-VAR C1MULTIPLE-VALUE-SETQ FN-MACROS TAG-SWITCH
            SYSTEM:UNDEF-COMPILER-MACRO ADD-FN-DATA
            C1MULTIPLE-VALUE-BIND CONSTANT-FOLD-P C1BLOCK C1PRINC
            C1STRUCTURE-REF C1TERPRI C1RETURN-FROM C1VREF C1APPLY
            C1STRUCTURE-SET C1FUNCALL C1RPLACA C2RPLACA C1SHARP-COMMA
            C1RPLACD C1DEFINE-STRUCTURE C1QUOTE C2RPLACD C1FUNCTION
            C1MEMQ C2FUNCTION C1MEMBER C1THE C1EVAL-WHEN C1ASSOC
            C1DECLARE C1COMPILER-LET C1GET C2GET WT-SYMBOL-FUNCTION
            C1NTH-CONDITION C1NTH)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) *) WT-INLINE-LOC C1SYMBOL-FUN
            C2RETURN-LOCAL C1BODY C2DECL-BODY C2BLOCK C2BLOCK-LOCAL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) T) C1LAMBDA-EXPR WT-COMMENT C1CASE CMPERR
            FAST-LINK-PROCLAIMED-TYPE-P CMPWARN CMPNOTE UNWIND-EXIT
            ADD-INIT WT-CVAR)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) T) TYPE>= MAYBE-EVAL C2LIST-NTH-IMMEDIATE
	    COMPILER-CLEAR-COMPILER-PROPERTIES
	    compiler-def-hook
            WT-MAKE-DCLOSURE C2CALL-LOCAL C2CALL-LAMBDA CMPFIX-ARGS
            MAKE-INLINE-STRING CO1EQL CO1TYPEP CO1SCHAR ADD-INFO
            CO1CONS C2PSETQ ARGS-INFO-REFERRED-VARS CO1READ-BYTE
            CO1READ-CHAR CO1WRITE-BYTE C1EXPR* CHECK-FNAME-ARGS
            ADD-DEBUG-INFO CO1WRITE-CHAR INLINE-PROC CO1VECTOR-PUSH
            WT-REQUIREDS CO1SPECIAL-FIX-DECL C2LAMBDA-EXPR-WITHOUT-KEY
            CO1SUBLIS C1LAMBDA-FUN WT-V*-MACROS C2LAMBDA-EXPR-WITH-KEY
            C2EXPR-TOP C2EXPR-TOP* C1PROGN* C1ARGS
            CO1STRUCTURE-PREDICATE C1CONSTANT-VALUE COERCE-LOC
            SET-JUMP-TRUE C2DM-BIND-VL ARGS-INFO-CHANGED-VARS
            SET-JUMP-FALSE C2DM-BIND-LOC C2DM-BIND-INIT C2CATCH WT-VAR
            C2UNWIND-PROTECT C2THROW GET-INLINE-LOC NEED-TO-PROTECT
            C1FMLA T2SHARP-COMMA CONVERT-CASE-TO-SWITCH C2STACK-LET
            CAN-BE-REPLACED COERCE-LOC-STRUCTURE-REF SYSTEM::ADD-DEBUG
            UNWIND-BDS SET-DBIND C2BLOCK-CCB TYPE-OR C2SETQ
            C2RETURN-CLB WT-FIXNUM-VALUE C2RETURN-CCB
            WT-CHARACTER-VALUE SHIFT>> WT-LONG-FLOAT-VALUE SHIFT<<
            WT-SHORT-FLOAT-VALUE C1SETQ1 ADD-VALUE-TYPE JUMPS-TO-P
            TYPE-AND PROCLAIM-VAR SET-VS SMALL-ALL-T-P SET-BDS-BIND
            CO1CONSTANT-FOLD PUSH-CHANGED-VARS C2MULTIPLE-VALUE-CALL
            C2BIND-LOC C2BIND-INIT C2MULTIPLE-VALUE-PROG1
            STRUCT-TYPE-OPT C1DECL-BODY FAST-READ C2MULTIPLE-VALUE-SETQ
            CFAST-WRITE MULTIPLE-VALUE-CHECK C2APPLY ADD-ADDRESS
            RECORD-CALL-INFO C2MEMBER!2 C2ASSOC!2 WT-MAKE-CCLOSURE
            C2BLOCK-CLB)) 