
static void L1();
#define VC1 object  V58 ,V57 ,V53 ,V52 ,V48 ,V45 ,V44 ,V43 ,V42 ,V41 ,V39 ,V38 ,V37 ,V36 ,V35 ,V34 ,V33 ,V28;
#define VM1 15
static char * VVi[14]={
#define Cdata VV[13]
(char *)(L1)
};
#define VV ((object *)VVi)
static object  LnkTLI12(object,...);
static object  (*LnkLI12)() = (object (*)()) LnkTLI12;
static object  LnkTLI11(object,...);
static object  (*LnkLI11)() = (object (*)()) LnkTLI11;
static object  LnkTLI10(object,...);
static object  (*LnkLI10)() = (object (*)()) LnkTLI10;
static void LnkT9();
static void (*Lnk9)() = LnkT9;
static void LnkT8();
static void (*Lnk8)() = LnkT8;
