
static void L1();
static void L12();
static void L19();
static void L20();
static void L22();
static void L39();
static void L40();
static void L41();
static void L44();
static void L45();
static void L46();
static void L47();
static void L48();
static void L49();
static void L50();
static void L51();
static void L52();
static void L53();
static void L59();
static void L60();
static void L61();
static void L62();
#define VC1 object  V2;
static object LI2();
#define VMB2
#define VMS2
#define VMV2
#define VMR2(VMT2) return(VMT2);
static object LI3(object,...);
static object VK3defaults[4]={(void *)-2,(void *)153,(void *)-2,(void *)-2};
static struct { short n,allow_other_keys;object *defaults;
	 KEYTYPE keys[4];} LI3key={4,0,VK3defaults,{(void *)18,(void *)17,(void *)154,(void *)155}};
#define VMB3 register object *base=vs_top; object Vcs[8];
#define VMS3  register object *sup=vs_top+5;vs_top=sup;
#define VMV3 vs_check;
#define VMR3(VMT3) vs_top=base ; return(VMT3);
static object LI4();
#define VMB4 register object *base=vs_top;
#define VMS4  register object *sup=vs_top+5;vs_top=sup;
#define VMV4 vs_check;
#define VMR4(VMT4) vs_top=base ; return(VMT4);
static object LI5(object,...);
static struct { short n,allow_other_keys;object *defaults;
	 KEYTYPE keys[2];} LI5key={2,0,Cstd_key_defaults,{(void *)18,(void *)17}};
#define VMB5 object Vcs[4];
#define VMS5
#define VMV5
#define VMR5(VMT5) return(VMT5);
static object LI6();
#define VMB6
#define VMS6
#define VMV6
#define VMR6(VMT6) return(VMT6);
static object LI7(object,...);
static struct { short n,allow_other_keys;object *defaults;
	 KEYTYPE keys[2];} LI7key={2,0,Cstd_key_defaults,{(void *)18,(void *)17}};
#define VMB7 register object *base=vs_top; object  V41 ,V40 ,V37 ,V31; object Vcs[4];
#define VMS7  register object *sup=vs_top+4;vs_top=sup;
#define VMV7 vs_check;
#define VMR7(VMT7) vs_top=base ; return(VMT7);
static object LI10();
#define VMB8 register object *base=vs_top;
#define VMS8  register object *sup=vs_top+6;vs_top=sup;
#define VMV8 vs_check;
#define VMR8(VMT8) vs_top=base ; return(VMT8);
static object LI11();
#define VMB9 register object *base=vs_top;
#define VMS9  register object *sup=vs_top+2;vs_top=sup;
#define VMV9 vs_check;
#define VMR9(VMT9) vs_top=base ; return(VMT9);
#define VC10
static object LI13();
#define VMB11 register object *base=vs_top;
#define VMS11  register object *sup=vs_top+7;vs_top=sup;
#define VMV11 vs_check;
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI14();
#define VMB12 register object *base=vs_top; object  V152 ,V145 ,V144 ,V143;
#define VMS12  register object *sup=vs_top+7;vs_top=sup;
#define VMV12 vs_check;
#define VMR12(VMT12) vs_top=base ; return(VMT12);
static object LI15();
#define VMB13
#define VMS13
#define VMV13
#define VMR13(VMT13) return(VMT13);
static object LI16();
#define VMB14 register object *base=vs_top;
#define VMS14  register object *sup=vs_top+3;vs_top=sup;
#define VMV14 vs_check;
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI17();
#define VMB15 register object *base=vs_top; object  V182 ,V175 ,V174 ,V173 ,V172 ,V171 ,V170;
#define VMS15  register object *sup=vs_top+7;vs_top=sup;
#define VMV15 vs_check;
#define VMR15(VMT15) vs_top=base ; return(VMT15);
static object LI18();
#define VMB16
#define VMS16
#define VMV16
#define VMR16(VMT16) return(VMT16);
#define VC17
#define VC18
static object LI21();
#define VMB19
#define VMS19
#define VMV19
#define VMR19(VMT19) return(VMT19);
#define VC20
static object LI23();
#define VMB21 register object *base=vs_top;
#define VMS21  register object *sup=vs_top+4;vs_top=sup;
#define VMV21 vs_check;
#define VMR21(VMT21) vs_top=base ; return(VMT21);
static object LI24();
#define VMB22 register object *base=vs_top; object  V233 ,V232 ,V231 ,V217 ,V214;
#define VMS22  register object *sup=vs_top+13;vs_top=sup;
#define VMV22 vs_check;
#define VMR22(VMT22) vs_top=base ; return(VMT22);
static object LI25();
#define VMB23 register object *base=vs_top; object  V263 ,V262 ,V260 ,V253;
#define VMS23  register object *sup=vs_top+7;vs_top=sup;
#define VMV23 vs_check;
#define VMR23(VMT23) vs_top=base ; return(VMT23);
static object LI26();
#define VMB24 register object *base=vs_top;
#define VMS24  register object *sup=vs_top+9;vs_top=sup;
#define VMV24 vs_check;
#define VMR24(VMT24) vs_top=base ; return(VMT24);
static object LI27();
#define VMB25
#define VMS25
#define VMV25
#define VMR25(VMT25) return(VMT25);
static object LI28();
#define VMB26 register object *base=vs_top;
#define VMS26  register object *sup=vs_top+1;vs_top=sup;
#define VMV26 vs_check;
#define VMR26(VMT26) vs_top=base ; return(VMT26);
static object LI29(object,object,object,object,...);
#define VMB27 register object *base=vs_top; object  V343 ,V342 ,V339 ,V336 ,V334 ,V333; object Vcs[5];
#define VMS27  register object *sup=vs_top+7;vs_top=sup;
#define VMV27 vs_check;
#define VMR27(VMT27) vs_top=base ; return(VMT27);
static object LI30();
#define VMB28 register object *base=vs_top;
#define VMS28  register object *sup=vs_top+1;vs_top=sup;
#define VMV28 vs_check;
#define VMR28(VMT28) vs_top=base ; return(VMT28);
static object LI31();
#define VMB29 register object *base=vs_top;
#define VMS29  register object *sup=vs_top+1;vs_top=sup;
#define VMV29 vs_check;
#define VMR29(VMT29) vs_top=base ; return(VMT29);
static object LI32();
#define VMB30 register object *base=vs_top;
#define VMS30  register object *sup=vs_top+1;vs_top=sup;
#define VMV30 vs_check;
#define VMR30(VMT30) vs_top=base ; return(VMT30);
static object LI33();
#define VMB31
#define VMS31
#define VMV31
#define VMR31(VMT31) return(VMT31);
static object LI34();
#define VMB32
#define VMS32
#define VMV32
#define VMR32(VMT32) return(VMT32);
static object LI35();
#define VMB33 register object *base=vs_top; object  V450 ,V448 ,V447 ,V446 ,V444 ,V427 ,V425 ,V422;
#define VMS33  register object *sup=vs_top+8;vs_top=sup;
#define VMV33 vs_check;
#define VMR33(VMT33) vs_top=base ; return(VMT33);
static object LI36();
#define VMB34 register object *base=vs_top; object  V482 ,V481;
#define VMS34  register object *sup=vs_top+11;vs_top=sup;
#define VMV34 vs_check;
#define VMR34(VMT34) vs_top=base ; return(VMT34);
static object LI37();
#define VMB35 register object *base=vs_top; object  V499 ,V497 ,V495 ,V494;
#define VMS35  register object *sup=vs_top+7;vs_top=sup;
#define VMV35 vs_check;
#define VMR35(VMT35) vs_top=base ; return(VMT35);
static object LI38();
#define VMB36 register object *base=vs_top; object  V543 ,V542 ,V541 ,V540 ,V528 ,V525 ,V524;
#define VMS36  register object *sup=vs_top+11;vs_top=sup;
#define VMV36 vs_check;
#define VMR36(VMT36) vs_top=base ; return(VMT36);
#define VC37
#define VC38
#define VC39
static object LI42();
#define VMB40 register object *base=vs_top;
#define VMS40  register object *sup=vs_top+1;vs_top=sup;
#define VMV40 vs_check;
#define VMR40(VMT40) vs_top=base ; return(VMT40);
static object LI43();
#define VMB41 register object *base=vs_top; object  V576;
#define VMS41  register object *sup=vs_top+2;vs_top=sup;
#define VMV41 vs_check;
#define VMR41(VMT41) vs_top=base ; return(VMT41);
#define VC42 object  V588 ,V587 ,V586 ,V585 ,V584 ,V583 ,V582;
#define VC43 object  V592 ,V591 ,V590;
#define VC44 object  V594;
#define VC45 object  V603 ,V602 ,V601 ,V600 ,V599 ,V598;
#define VC46 object  V607 ,V606 ,V605;
#define VC47 object  V610 ,V609;
#define VC48 object  V621 ,V620 ,V619 ,V618 ,V617 ,V616 ,V615 ,V614;
#define VC49 object  V625 ,V624 ,V623;
#define VC50 object  V659 ,V658 ,V635;
#define VC51
static object LI54();
#define VMB52 register object *base=vs_top;
#define VMS52  register object *sup=vs_top+1;vs_top=sup;
#define VMV52 vs_check;
#define VMR52(VMT52) vs_top=base ; return(VMT52);
static object LI55();
#define VMB53 register object *base=vs_top; object  V692 ,V691;
#define VMS53  register object *sup=vs_top+2;vs_top=sup;
#define VMV53 vs_check;
#define VMR53(VMT53) vs_top=base ; return(VMT53);
static object LI56();
#define VMB54 register object *base=vs_top;
#define VMS54  register object *sup=vs_top+4;vs_top=sup;
#define VMV54 vs_check;
#define VMR54(VMT54) vs_top=base ; return(VMT54);
static object LI57();
#define VMB55 register object *base=vs_top; object  V715 ,V714;
#define VMS55  register object *sup=vs_top+5;vs_top=sup;
#define VMV55 vs_check;
#define VMR55(VMT55) vs_top=base ; return(VMT55);
static object LI58();
#define VMB56 register object *base=vs_top;
#define VMS56  register object *sup=vs_top+4;vs_top=sup;
#define VMV56 vs_check;
#define VMR56(VMT56) vs_top=base ; return(VMT56);
#define VC57 object  V742 ,V741 ,V739 ,V738;
#define VC58 object  V746 ,V745;
#define VC59 object  V761 ,V760 ,V759 ,V758 ,V757 ,V756 ,V755 ,V754;
#define VC60 object  V784 ,V782 ,V779;
static object LI63();
#define VMB61 register object *base=vs_top; object  V802 ,V801;
#define VMS61  register object *sup=vs_top+6;vs_top=sup;
#define VMV61 vs_check;
#define VMR61(VMT61) vs_top=base ; return(VMT61);
static object LI64();
#define VMB62 register object *base=vs_top; object  V837 ,V836 ,V835 ,V834 ,V833;
#define VMS62  register object *sup=vs_top+2;vs_top=sup;
#define VMV62 vs_check;
#define VMR62(VMT62) vs_top=base ; return(VMT62);
static object LI66();
#define VMB63 register object *base=vs_top; object  V848 ,V847 ,V844;
#define VMS63  register object *sup=vs_top+12;vs_top=sup;
#define VMV63 vs_check;
#define VMR63(VMT63) vs_top=base ; return(VMT63);
static object LI67(object,object,object,...);
#define VMB64 object Vcs[3];
#define VMS64
#define VMV64
#define VMR64(VMT64) return(VMT64);
static object LI68(object,object,...);
#define VMB65 object  V867 ,V866; object Vcs[2];
#define VMS65
#define VMV65
#define VMR65(VMT65) return(VMT65);
static object LI69(object,...);
#define VMB66 register object *base=vs_top; object  V879 ,V870; object Vcs[1];
#define VMS66  register object *sup=vs_top+4;vs_top=sup;
#define VMV66 vs_check;
#define VMR66(VMT66) vs_top=base ; return(VMT66);
static object LI70();
#define VMB67 register object *base=vs_top;
#define VMS67  register object *sup=vs_top+5;vs_top=sup;
#define VMV67 vs_check;
#define VMR67(VMT67) vs_top=base ; return(VMT67);
static object LI71();
#define VMB68 register object *base=vs_top;
#define VMS68  register object *sup=vs_top+3;vs_top=sup;
#define VMV68 vs_check;
#define VMR68(VMT68) vs_top=base ; return(VMT68);
static void LC74();
#define VC69 object  V928 ,V924 ,V922;
static void LC73();
#define VC70
static void LC72();
#define VC71
static void L9();
#define VC72
static void L8();
#define VC73
static void LC74();
static void LC73();
static void LC72();
#define VM73 5
#define VM72 5
#define VM71 4
#define VM70 4
#define VM69 11
#define VM68 3
#define VM67 5
#define VM66 4
#define VM65 0
#define VM64 0
#define VM63 12
#define VM62 2
#define VM61 6
#define VM60 11
#define VM59 10
#define VM58 9
#define VM57 8
#define VM56 4
#define VM55 5
#define VM54 4
#define VM53 2
#define VM52 1
#define VM51 7
#define VM50 8
#define VM49 9
#define VM48 11
#define VM47 9
#define VM46 10
#define VM45 12
#define VM44 8
#define VM43 9
#define VM42 11
#define VM41 2
#define VM40 1
#define VM39 4
#define VM38 3
#define VM37 3
#define VM36 11
#define VM35 7
#define VM34 11
#define VM33 8
#define VM32 0
#define VM31 0
#define VM30 1
#define VM29 1
#define VM28 1
#define VM27 7
#define VM26 1
#define VM25 0
#define VM24 9
#define VM23 7
#define VM22 13
#define VM21 4
#define VM20 5
#define VM19 0
#define VM18 4
#define VM17 5
#define VM16 0
#define VM15 7
#define VM14 3
#define VM13 0
#define VM12 7
#define VM11 7
#define VM10 5
#define VM9 2
#define VM8 6
#define VM7 4
#define VM6 0
#define VM5 0
#define VM4 5
#define VM3 5
#define VM2 0
#define VM1 5
static char * VVi[246]={
#define Cdata VV[245]
(char *)(L1),
(char *)(LI2),
(char *)(LI3),
(char *)(&LI3key),
(char *)(LI4),
(char *)(LI5),
(char *)(&LI5key),
(char *)(LI6),
(char *)(LI7),
(char *)(&LI7key),
(char *)(LI10),
(char *)(LI11),
(char *)(L12),
(char *)(LI13),
(char *)(LI14),
(char *)(LI15),
(char *)(LI16),
(char *)(LI17),
(char *)(LI18),
(char *)(L19),
(char *)(L20),
(char *)(LI21),
(char *)(L22),
(char *)(LI23),
(char *)(LI24),
(char *)(LI25),
(char *)(LI26),
(char *)(LI27),
(char *)(LI28),
(char *)(LI29),
(char *)(LI30),
(char *)(LI31),
(char *)(LI32),
(char *)(LI33),
(char *)(LI34),
(char *)(LI35),
(char *)(LI36),
(char *)(LI37),
(char *)(LI38),
(char *)(L39),
(char *)(L40),
(char *)(L41),
(char *)(LI42),
(char *)(LI43),
(char *)(L44),
(char *)(L45),
(char *)(L46),
(char *)(L47),
(char *)(L48),
(char *)(L49),
(char *)(L50),
(char *)(L51),
(char *)(L52),
(char *)(L53),
(char *)(LI54),
(char *)(LI55),
(char *)(LI56),
(char *)(LI57),
(char *)(LI58),
(char *)(L59),
(char *)(L60),
(char *)(L61),
(char *)(L62),
(char *)(LI63),
(char *)(LI64),
(char *)(LI66),
(char *)(LI67),
(char *)(LI68),
(char *)(LI69),
(char *)(LI70),
(char *)(LI71)
};
#define VV ((object *)VVi)
static object  LnkTLI244(object,...);
static object  (*LnkLI244)() = (object (*)()) LnkTLI244;
static object  LnkTLI243(object,...);
static object  (*LnkLI243)() = (object (*)()) LnkTLI243;
static object *Lclptr242;
static void LnkT242();
static void (*Lnk242)() = LnkT242;
static object  LnkTLI241(object,...);
static object  (*LnkLI241)() = (object (*)()) LnkTLI241;
static object  LnkTLI240(object,...);
static object  (*LnkLI240)() = (object (*)()) LnkTLI240;
static object  LnkTLI239(object,...);
static object  (*LnkLI239)() = (object (*)()) LnkTLI239;
static object  LnkTLI238(object,...);
static object  (*LnkLI238)() = (object (*)()) LnkTLI238;
static object  LnkTLI237(object,...);
static object  (*LnkLI237)() = (object (*)()) LnkTLI237;
static object  LnkTLI236(object,...);
static object  (*LnkLI236)() = (object (*)()) LnkTLI236;
static object  LnkTLI235(object,...);
static object  (*LnkLI235)() = (object (*)()) LnkTLI235;
static void LnkT234();
static void (*Lnk234)() = LnkT234;
static object  LnkTLI233(object,...);
static object  (*LnkLI233)() = (object (*)()) LnkTLI233;
static object  LnkTLI232(object,...);
static object  (*LnkLI232)() = (object (*)()) LnkTLI232;
static object  LnkTLI231(object,...);
static object  (*LnkLI231)() = (object (*)()) LnkTLI231;
static object  LnkTLI230(object,...);
static object  (*LnkLI230)() = (object (*)()) LnkTLI230;
static object  LnkTLI229(object,...);
static object  (*LnkLI229)() = (object (*)()) LnkTLI229;
static void LnkT228();
static void (*Lnk228)() = LnkT228;
static object  LnkTLI227(object,...);
static object  (*LnkLI227)() = (object (*)()) LnkTLI227;
static void LnkT121();
static void (*Lnk121)() = LnkT121;
static object  LnkTLI226(object,...);
static object  (*LnkLI226)() = (object (*)()) LnkTLI226;
static void LnkT225();
static void (*Lnk225)() = LnkT225;
static object  LnkTLI224(object,...);
static object  (*LnkLI224)() = (object (*)()) LnkTLI224;
static object  LnkTLI223(object,...);
static object  (*LnkLI223)() = (object (*)()) LnkTLI223;
static void LnkT222();
static void (*Lnk222)() = LnkT222;
static void LnkT220();
static void (*Lnk220)() = LnkT220;
static object  LnkTLI219(object,...);
static object  (*LnkLI219)() = (object (*)()) LnkTLI219;
static object  LnkTLI218(object,...);
static object  (*LnkLI218)() = (object (*)()) LnkTLI218;
static object  LnkTLI217(object,...);
static object  (*LnkLI217)() = (object (*)()) LnkTLI217;
static object  LnkTLI216(object,...);
static object  (*LnkLI216)() = (object (*)()) LnkTLI216;
static void LnkT215();
static void (*Lnk215)() = LnkT215;
static void LnkT214();
static void (*Lnk214)() = LnkT214;
static object  LnkTLI213(object,...);
static object  (*LnkLI213)() = (object (*)()) LnkTLI213;
static void LnkT212();
static void (*Lnk212)() = LnkT212;
static object  LnkTLI211(object,...);
static object  (*LnkLI211)() = (object (*)()) LnkTLI211;
static object  LnkTLI210(object,...);
static object  (*LnkLI210)() = (object (*)()) LnkTLI210;
static object  LnkTLI209(object,...);
static object  (*LnkLI209)() = (object (*)()) LnkTLI209;
static object *Lclptr208;
static void LnkT208();
static void (*Lnk208)() = LnkT208;
static object *Lclptr207;
static void LnkT207();
static void (*Lnk207)() = LnkT207;
static object  LnkTLI205(object,...);
static object  (*LnkLI205)() = (object (*)()) LnkTLI205;
static void LnkT203();
static void (*Lnk203)() = LnkT203;
static object *Lclptr202;
static void LnkT202();
static void (*Lnk202)() = LnkT202;
static object *Lclptr201;
static void LnkT201();
static void (*Lnk201)() = LnkT201;
static object  LnkTLI200(object,...);
static object  (*LnkLI200)() = (object (*)()) LnkTLI200;
static object  LnkTLI199(object,...);
static object  (*LnkLI199)() = (object (*)()) LnkTLI199;
static object *Lclptr198;
static void LnkT198();
static void (*Lnk198)() = LnkT198;
static object *Lclptr197;
static void LnkT197();
static void (*Lnk197)() = LnkT197;
static object  LnkTLI196(object,...);
static object  (*LnkLI196)() = (object (*)()) LnkTLI196;
static object  LnkTLI195(object,...);
static object  (*LnkLI195)() = (object (*)()) LnkTLI195;
static object  LnkTLI191(object,...);
static object  (*LnkLI191)() = (object (*)()) LnkTLI191;
static object  LnkTLI190(object,...);
static object  (*LnkLI190)() = (object (*)()) LnkTLI190;
static object  LnkTLI188(object,...);
static object  (*LnkLI188)() = (object (*)()) LnkTLI188;
static object  LnkTLI187(object,...);
static object  (*LnkLI187)() = (object (*)()) LnkTLI187;
static void LnkT186();
static void (*Lnk186)() = LnkT186;
static object  LnkTLI184(object,...);
static object  (*LnkLI184)() = (object (*)()) LnkTLI184;
static object *Lclptr183;
static void LnkT183();
static void (*Lnk183)() = LnkT183;
static object *Lclptr182;
static void LnkT182();
static void (*Lnk182)() = LnkT182;
static object *Lclptr181;
static void LnkT181();
static void (*Lnk181)() = LnkT181;
static object *Lclptr180;
static void LnkT180();
static void (*Lnk180)() = LnkT180;
static object  LnkTLI179(object,...);
static object  (*LnkLI179)() = (object (*)()) LnkTLI179;
static void LnkT178();
static void (*Lnk178)() = LnkT178;
static object  LnkTLI177(object,...);
static object  (*LnkLI177)() = (object (*)()) LnkTLI177;
static object  LnkTLI176(object,...);
static object  (*LnkLI176)() = (object (*)()) LnkTLI176;
static object *Lclptr175;
static void LnkT175();
static void (*Lnk175)() = LnkT175;
static object  LnkTLI174(object,...);
static object  (*LnkLI174)() = (object (*)()) LnkTLI174;
static object  LnkTLI173(object,...);
static object  (*LnkLI173)() = (object (*)()) LnkTLI173;
static object  LnkTLI172(object,...);
static object  (*LnkLI172)() = (object (*)()) LnkTLI172;
static object  LnkTLI171(object,...);
static object  (*LnkLI171)() = (object (*)()) LnkTLI171;
static object  LnkTLI170(object,...);
static object  (*LnkLI170)() = (object (*)()) LnkTLI170;
static object  LnkTLI169(object,...);
static object  (*LnkLI169)() = (object (*)()) LnkTLI169;
static void LnkT167();
static void (*Lnk167)() = LnkT167;
static object  LnkTLI166(object,...);
static object  (*LnkLI166)() = (object (*)()) LnkTLI166;
static void LnkT165();
static void (*Lnk165)() = LnkT165;
static object  LnkTLI164(object,...);
static object  (*LnkLI164)() = (object (*)()) LnkTLI164;
static object  LnkTLI163(object,...);
static object  (*LnkLI163)() = (object (*)()) LnkTLI163;
static void LnkT162();
static void (*Lnk162)() = LnkT162;
static object  LnkTLI161(object,...);
static object  (*LnkLI161)() = (object (*)()) LnkTLI161;
static void LnkT160();
static void (*Lnk160)() = LnkT160;
static object *Lclptr159;
static void LnkT159();
static void (*Lnk159)() = LnkT159;
static object  LnkTLI158(object,...);
static object  (*LnkLI158)() = (object (*)()) LnkTLI158;
static object  LnkTLI157(object,...);
static object  (*LnkLI157)() = (object (*)()) LnkTLI157;
static object  LnkTLI156(object,...);
static object  (*LnkLI156)() = (object (*)()) LnkTLI156;
static object  LnkTLI152(object,...);
static object  (*LnkLI152)() = (object (*)()) LnkTLI152;
