
(lisp::defun compiler::cmp-anon (pcl::effective-method-gensym-0 pcl::effective-method-gensym-1 pcl::effective-method-gensym-2) (lisp::function (lisp::lambda (pcl::.pv-cell. pcl::.next-method-call. pcl::.arg0. pcl::.dfun-rest-arg.) (lisp::declare (lisp::ignore pcl::.pv-cell. pcl::.next-method-call.)) (lisp::multiple-value-prog1 (lisp::progn (lisp::dolist (pcl::emf pcl::effective-method-gensym-0 lisp::nil) (pcl::invoke-effective-method-function-fast pcl::emf lisp::t pcl::.arg0. . #0=(pcl::.dfun-rest-arg.))) (pcl::invoke-effective-method-function pcl::effective-method-gensym-1 lisp::t pcl::.arg0. . #0#)) (lisp::dolist (pcl::emf pcl::effective-method-gensym-2 lisp::nil) (pcl::invoke-effective-method-function pcl::emf lisp::t pcl::.arg0. . #0#))))))