
static void L1();
#define VC1
static void LC2();
#define VC2 object  V7;
static void LC2();
#define VM2 5
#define VM1 3
static char * VVi[13]={
#define Cdata VV[12]
(char *)(L1)
};
#define VV ((object *)VVi)
static void LnkT11();
static void (*Lnk11)() = LnkT11;
static void LnkT10();
static void (*Lnk10)() = LnkT10;
static object  LnkTLI9(object,...);
static object  (*LnkLI9)() = (object (*)()) LnkTLI9;
static void LnkT8();
static void (*Lnk8)() = LnkT8;
static void LnkT7();
static void (*Lnk7)() = LnkT7;
