
static void L1();
static void L2();
static void L3();
static void L4();
static void L7();
static void L8();
static void L9();
static void L12();
static void L13();
static void L14();
static void L15();
static void L16();
static void L18();
static void L21();
#define VC1
#define VC2
#define VC3
#define VC4 object  V24 ,V20;
#define VC5
#define VC6 object  V48;
#define VC7 object  V75 ,V70 ,V69 ,V66 ,V63 ,V60;
static object LI11();
#define VMB8 register object *base=vs_top; object  V110 ,V109 ,V108 ,V107 ,V106 ,V101 ,V86;
#define VMS8  register object *sup=vs_top+6;vs_top=sup;
#define VMV8 vs_check;
#define VMR8(VMT8) vs_top=base ; return(VMT8);
#define VC9 object  V121 ,V120 ,V119;
#define VC10 object  V131;
#define VC11 object  V144;
#define VC12 object  V157;
#define VC13 object  V170;
static object LI17(object,object,...);
#define VMB14 register object *base=vs_top; object  V183 ,V177; object Vcs[2];
#define VMS14  register object *sup=vs_top+7;vs_top=sup;
#define VMV14 vs_check;
#define VMR14(VMT14) vs_top=base ; return(VMT14);
#define VC15
static object LI20();
#define VMB16 register object *base=vs_top;
#define VMS16  register object *sup=vs_top+2;vs_top=sup;
#define VMV16 vs_check;
#define VMR16(VMT16) vs_top=base ; return(VMT16);
#define VC17
static object LI22();
#define VMB18 register object *base=vs_top;
#define VMS18  register object *sup=vs_top+2;vs_top=sup;
#define VMV18 vs_check;
#define VMR18(VMT18) vs_top=base ; return(VMT18);
static void L19();
#define VC19
static void L10();
#define VC20
static void L6();
#define VC21
static void L5();
#define VC22 object  V216;
#define VM22 2
#define VM21 10
#define VM20 2
#define VM19 5
#define VM18 2
#define VM17 4
#define VM16 2
#define VM15 3
#define VM14 7
#define VM13 5
#define VM12 5
#define VM11 5
#define VM10 5
#define VM9 15
#define VM8 6
#define VM7 11
#define VM6 10
#define VM5 5
#define VM4 14
#define VM3 6
#define VM2 3
#define VM1 2
static char * VVi[111]={
#define Cdata VV[110]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(L4),
(char *)(L7),
(char *)(L8),
(char *)(L9),
(char *)(LI11),
(char *)(L12),
(char *)(L13),
(char *)(L14),
(char *)(L15),
(char *)(L16),
(char *)(LI17),
(char *)(L18),
(char *)(LI20),
(char *)(L21),
(char *)(LI22)
};
#define VV ((object *)VVi)
static void LnkT109();
static void (*Lnk109)() = LnkT109;
static object  LnkTLI108(object,...);
static object  (*LnkLI108)() = (object (*)()) LnkTLI108;
static object  LnkTLI107(object,...);
static object  (*LnkLI107)() = (object (*)()) LnkTLI107;
static object *Lclptr106;
static void LnkT106();
static void (*Lnk106)() = LnkT106;
static object *Lclptr103;
static void LnkT103();
static void (*Lnk103)() = LnkT103;
static object  LnkTLI102(object,...);
static object  (*LnkLI102)() = (object (*)()) LnkTLI102;
static void LnkT101();
static void (*Lnk101)() = LnkT101;
static object *Lclptr100;
static void LnkT100();
static void (*Lnk100)() = LnkT100;
static object *Lclptr99;
static void LnkT99();
static void (*Lnk99)() = LnkT99;
static object *Lclptr98;
static void LnkT98();
static void (*Lnk98)() = LnkT98;
static void LnkT64();
static void (*Lnk64)() = LnkT64;
static void LnkT95();
static void (*Lnk95)() = LnkT95;
static object *Lclptr94;
static void LnkT94();
static void (*Lnk94)() = LnkT94;
static object *Lclptr93;
static void LnkT93();
static void (*Lnk93)() = LnkT93;
static object *Lclptr92;
static void LnkT92();
static void (*Lnk92)() = LnkT92;
static object *Lclptr91;
static void LnkT91();
static void (*Lnk91)() = LnkT91;
static object  LnkTLI90(object,...);
static object  (*LnkLI90)() = (object (*)()) LnkTLI90;
static object *Lclptr89;
static void LnkT89();
static void (*Lnk89)() = LnkT89;
static void LnkT88();
static void (*Lnk88)() = LnkT88;
static object  LnkTLI87(object,...);
static object  (*LnkLI87)() = (object (*)()) LnkTLI87;
static void LnkT86();
static void (*Lnk86)() = LnkT86;
static void LnkT85();
static void (*Lnk85)() = LnkT85;
static object *Lclptr84;
static void LnkT84();
static void (*Lnk84)() = LnkT84;
static object *Lclptr83;
static void LnkT83();
static void (*Lnk83)() = LnkT83;
static object  LnkTLI82(object,...);
static object  (*LnkLI82)() = (object (*)()) LnkTLI82;
static object *Lclptr81;
static void LnkT81();
static void (*Lnk81)() = LnkT81;
static object *Lclptr80;
static void LnkT80();
static void (*Lnk80)() = LnkT80;
static object *Lclptr79;
static void LnkT79();
static void (*Lnk79)() = LnkT79;
static object *Lclptr78;
static void LnkT78();
static void (*Lnk78)() = LnkT78;
static void LnkT77();
static void (*Lnk77)() = LnkT77;
static object *Lclptr74;
static void LnkT74();
static void (*Lnk74)() = LnkT74;
static object *Lclptr73;
static void LnkT73();
static void (*Lnk73)() = LnkT73;
static object *Lclptr72;
static void LnkT72();
static void (*Lnk72)() = LnkT72;
static object  LnkTLI71(object,...);
static object  (*LnkLI71)() = (object (*)()) LnkTLI71;
static object  LnkTLI70(object,...);
static object  (*LnkLI70)() = (object (*)()) LnkTLI70;
static object *Lclptr0;
static void LnkT0();
static void (*Lnk0)() = LnkT0;
static void LnkT69();
static void (*Lnk69)() = LnkT69;
