;;; Tests of conses

(compile-and-load "cons-aux.lsp")

(load "cons.lsp")
(load "consp.lsp")
(load "atom.lsp")
(load "cxr.lsp")
(load "rplaca.lsp")
(load "rplacd.lsp")
(load "copy-tree.lsp")
(load "sublis.lsp")
(load "nsublis.lsp")
(load "subst.lsp")
(load "subst-if.lsp")
(load "subst-if-not.lsp")
(load "nsubst.lsp")
(load "nsubst-if.lsp")
(load "nsubst-if-not.lsp")
(load "tree-equal.lsp")
(load "copy-list.lsp")
(load "list.lsp")
(load "list-length.lsp")
(load "listp.lsp")
(load "make-list.lsp")
(load "push.lsp")
(load "pop.lsp")
(load "pushnew.lsp")
(load "adjoin.lsp")
(load "nth.lsp")
(load "endp.lsp")
(load "nconc.lsp")
(load "append.lsp")
(load "revappend.lsp")
(load "nreconc.lsp")
(load "butlast.lsp")
(load "nbutlast.lsp")
(load "last.lsp")
(load "ldiff.lsp")
(load "tailp.lsp")
(load "nthcdr.lsp")
(load "rest.lsp")
(load "member.lsp")
(load "member-if.lsp")
(load "member-if-not.lsp")

(load "mapc.lsp")
(load "mapcar.lsp")
(load "mapcan.lsp")
(load "mapl.lsp")
(load "maplist.lsp")
(load "mapcon.lsp")

(load "acons.lsp")
(load "assoc.lsp")
(load "assoc-if.lsp")
(load "assoc-if-not.lsp")
(load "rassoc.lsp")
(load "rassoc-if.lsp")
(load "rassoc-if-not.lsp")
(load "copy-alist.lsp")
(load "pairlis.lsp")

(load "get-properties.lsp")
(load "getf.lsp")
(load "remf.lsp")

(load "intersection.lsp")
(load "nintersection.lsp")
(load "union.lsp")
(load "nunion.lsp")
(load "set-difference.lsp")
(load "nset-difference.lsp")
(load "set-exclusive-or.lsp")
(load "nset-exclusive-or.lsp")
(load "subsetp.lsp")

;;; Misc. stuff that should be moved elsewhere
(load "cons-test-01.lsp")
(load "cons-test-03.lsp")
(load "cons-test-05.lsp")

