
#include "cmpinclude.h"
#include "pcl_precom2.h"
void init_pcl_precom2(){do_init(VV);}
/*	function definition for (PRECOMPILE-FUNCTION-GENERATORS PCL 0)9381	*/

static void L1()
{register object *base=vs_base;
	register object *sup=base+VM1; VC1
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V1= VV[199];
	base[0]= (*(LnkLI198))(VV[0],VV[1],V1,VV[3],VV[4]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-FUNCTION-GENERATORS PCL 1)9381	*/

static void L2()
{register object *base=vs_base;
	register object *sup=base+VM2; VC2
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V2= VV[200];
	base[0]= (*(LnkLI198))(VV[5],VV[6],V2,VV[7],VV[4]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-FUNCTION-GENERATORS PCL 2)9381	*/

static void L3()
{register object *base=vs_base;
	register object *sup=base+VM3; VC3
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V3= VV[201];
	base[0]= (*(LnkLI198))(VV[8],VV[9],V3,VV[16],VV[4]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-FUNCTION-GENERATORS PCL 3)9381	*/

static void L4()
{register object *base=vs_base;
	register object *sup=base+VM4; VC4
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V4= VV[202];
	base[0]= (*(LnkLI198))(VV[17],VV[18],V4,VV[21],VV[4]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-FUNCTION-GENERATORS PCL 4)9381	*/

static void L5()
{register object *base=vs_base;
	register object *sup=base+VM5; VC5
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V5= VV[203];
	base[0]= (*(LnkLI198))(VV[22],VV[23],V5,VV[25],VV[4]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-FUNCTION-GENERATORS PCL 5)9381	*/

static void L6()
{register object *base=vs_base;
	register object *sup=base+VM6; VC6
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V6= VV[204];
	base[0]= (*(LnkLI198))(VV[26],VV[27],V6,VV[32],VV[4]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-FUNCTION-GENERATORS PCL 6)9381	*/

static void L7()
{register object *base=vs_base;
	register object *sup=base+VM7; VC7
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V7= VV[205];
	base[0]= (*(LnkLI198))(VV[33],VV[34],V7,VV[35],VV[4]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-FUNCTION-GENERATORS PCL 7)9381	*/

static void L8()
{register object *base=vs_base;
	register object *sup=base+VM8; VC8
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V8= VV[206];
	base[0]= (*(LnkLI198))(VV[36],VV[37],V8,VV[39],VV[4]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L9()
{register object *base=vs_base;
	register object *sup=base+VM9; VC9
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V9= VV[208];
	base[0]= (*(LnkLI207))(VV[40],VV[41],VV[4],V9);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L10()
{register object *base=vs_base;
	register object *sup=base+VM10; VC10
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V10= VV[209];
	base[0]= (*(LnkLI207))(VV[40],VV[49],VV[4],V10);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L11()
{register object *base=vs_base;
	register object *sup=base+VM11; VC11
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V11= VV[210];
	base[0]= (*(LnkLI207))(VV[40],VV[53],VV[4],V11);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L12()
{register object *base=vs_base;
	register object *sup=base+VM12; VC12
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V12= VV[211];
	base[0]= (*(LnkLI207))(VV[40],VV[57],VV[4],V12);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L13()
{register object *base=vs_base;
	register object *sup=base+VM13; VC13
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V13= VV[212];
	base[0]= (*(LnkLI207))(VV[40],VV[61],VV[4],V13);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L14()
{register object *base=vs_base;
	register object *sup=base+VM14; VC14
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V14= VV[213];
	base[0]= (*(LnkLI207))(VV[40],VV[64],VV[4],V14);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L15()
{register object *base=vs_base;
	register object *sup=base+VM15; VC15
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V15= VV[214];
	base[0]= (*(LnkLI207))(VV[40],VV[69],VV[4],V15);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L16()
{register object *base=vs_base;
	register object *sup=base+VM16; VC16
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V16= VV[215];
	base[0]= (*(LnkLI207))(VV[40],VV[72],VV[4],V16);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L17()
{register object *base=vs_base;
	register object *sup=base+VM17; VC17
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V17= VV[216];
	base[0]= (*(LnkLI207))(VV[40],VV[76],VV[4],V17);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L18()
{register object *base=vs_base;
	register object *sup=base+VM18; VC18
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V18= VV[217];
	base[0]= (*(LnkLI207))(VV[40],VV[79],VV[4],V18);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L19()
{register object *base=vs_base;
	register object *sup=base+VM19; VC19
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V19= VV[218];
	base[0]= (*(LnkLI207))(VV[40],VV[82],VV[4],V19);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L20()
{register object *base=vs_base;
	register object *sup=base+VM20; VC20
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V20= VV[219];
	base[0]= (*(LnkLI207))(VV[40],VV[85],VV[4],V20);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L21()
{register object *base=vs_base;
	register object *sup=base+VM21; VC21
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V21= VV[220];
	base[0]= (*(LnkLI207))(VV[40],VV[90],VV[4],V21);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L22()
{register object *base=vs_base;
	register object *sup=base+VM22; VC22
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V22= VV[221];
	base[0]= (*(LnkLI207))(VV[40],VV[94],VV[4],V22);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L23()
{register object *base=vs_base;
	register object *sup=base+VM23; VC23
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V23= VV[222];
	base[0]= (*(LnkLI207))(VV[40],VV[97],VV[4],V23);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CACHING)9406	*/

static void L24()
{register object *base=vs_base;
	register object *sup=base+VM24; VC24
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V24= VV[223];
	base[0]= (*(LnkLI207))(VV[40],VV[101],VV[4],V24);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CONSTANT-VALUE)9406	*/

static void L25()
{register object *base=vs_base;
	register object *sup=base+VM25; VC25
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V25= VV[224];
	base[0]= (*(LnkLI207))(VV[104],VV[105],VV[4],V25);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CONSTANT-VALUE)9406	*/

static void L26()
{register object *base=vs_base;
	register object *sup=base+VM26; VC26
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V26= VV[225];
	base[0]= (*(LnkLI207))(VV[104],VV[107],VV[4],V26);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CHECKING)9406	*/

static void L27()
{register object *base=vs_base;
	register object *sup=base+VM27; VC27
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V27= VV[226];
	base[0]= (*(LnkLI207))(VV[109],VV[110],VV[4],V27);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CHECKING)9406	*/

static void L28()
{register object *base=vs_base;
	register object *sup=base+VM28; VC28
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V28= VV[227];
	base[0]= (*(LnkLI207))(VV[109],VV[113],VV[4],V28);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CHECKING)9406	*/

static void L29()
{register object *base=vs_base;
	register object *sup=base+VM29; VC29
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V29= VV[228];
	base[0]= (*(LnkLI207))(VV[109],VV[118],VV[4],V29);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CHECKING)9406	*/

static void L30()
{register object *base=vs_base;
	register object *sup=base+VM30; VC30
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V30= VV[229];
	base[0]= (*(LnkLI207))(VV[109],VV[122],VV[4],V30);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-DFUN-CONSTRUCTOR EMIT-CHECKING)9406	*/

static void L31()
{register object *base=vs_base;
	register object *sup=base+VM31; VC31
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V31= VV[230];
	base[0]= (*(LnkLI207))(VV[109],VV[125],VV[4],V31);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 0)9549	*/

static void L32()
{register object *base=vs_base;
	register object *sup=base+VM32; VC32
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V32= VV[232];
	base[0]= (*(LnkLI231))(VV[129],V32,VV[4],VV[134]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 1)9549	*/

static void L33()
{register object *base=vs_base;
	register object *sup=base+VM33; VC33
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V33= VV[233];
	base[0]= (*(LnkLI231))(VV[135],V33,VV[4],VV[137]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 2)9549	*/

static void L34()
{register object *base=vs_base;
	register object *sup=base+VM34; VC34
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V34= VV[234];
	base[0]= (*(LnkLI231))(VV[138],V34,VV[4],VV[140]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 3)9549	*/

static void L35()
{register object *base=vs_base;
	register object *sup=base+VM35; VC35
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V35= VV[235];
	base[0]= (*(LnkLI231))(VV[141],V35,VV[4],VV[143]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 4)9549	*/

static void L36()
{register object *base=vs_base;
	register object *sup=base+VM36; VC36
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V36= VV[236];
	base[0]= (*(LnkLI231))(VV[144],V36,VV[4],VV[146]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 5)9549	*/

static void L37()
{register object *base=vs_base;
	register object *sup=base+VM37; VC37
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V37= VV[237];
	base[0]= (*(LnkLI231))(VV[147],V37,VV[4],VV[149]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 6)9549	*/

static void L38()
{register object *base=vs_base;
	register object *sup=base+VM38; VC38
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V38= VV[238];
	base[0]= (*(LnkLI231))(VV[150],V38,VV[4],VV[154]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 7)9549	*/

static void L39()
{register object *base=vs_base;
	register object *sup=base+VM39; VC39
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V39= VV[239];
	base[0]= (*(LnkLI231))(VV[155],V39,VV[4],VV[157]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 8)9549	*/

static void L40()
{register object *base=vs_base;
	register object *sup=base+VM40; VC40
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V40= VV[240];
	base[0]= (*(LnkLI231))(VV[158],V40,VV[4],VV[160]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 9)9549	*/

static void L41()
{register object *base=vs_base;
	register object *sup=base+VM41; VC41
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V41= VV[241];
	base[0]= (*(LnkLI231))(VV[161],V41,VV[4],VV[163]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 10)9549	*/

static void L42()
{register object *base=vs_base;
	register object *sup=base+VM42; VC42
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V42= VV[242];
	base[0]= (*(LnkLI231))(VV[164],V42,VV[4],VV[166]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 11)9549	*/

static void L43()
{register object *base=vs_base;
	register object *sup=base+VM43; VC43
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V43= VV[243];
	base[0]= (*(LnkLI231))(VV[167],V43,VV[4],VV[169]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 12)9549	*/

static void L44()
{register object *base=vs_base;
	register object *sup=base+VM44; VC44
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V44= VV[244];
	base[0]= (*(LnkLI231))(VV[170],V44,VV[4],VV[172]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 13)9549	*/

static void L45()
{register object *base=vs_base;
	register object *sup=base+VM45; VC45
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V45= VV[245];
	base[0]= (*(LnkLI231))(VV[173],V45,VV[4],VV[175]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 14)9549	*/

static void L46()
{register object *base=vs_base;
	register object *sup=base+VM46; VC46
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V46= VV[246];
	base[0]= (*(LnkLI231))(VV[176],V46,VV[4],VV[178]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 15)9549	*/

static void L47()
{register object *base=vs_base;
	register object *sup=base+VM47; VC47
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V47= VV[247];
	base[0]= (*(LnkLI231))(VV[179],V47,VV[4],VV[181]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 16)9549	*/

static void L48()
{register object *base=vs_base;
	register object *sup=base+VM48; VC48
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V48= VV[248];
	base[0]= (*(LnkLI231))(VV[182],V48,VV[4],VV[185]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 17)9549	*/

static void L49()
{register object *base=vs_base;
	register object *sup=base+VM49; VC49
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V49= VV[249];
	base[0]= (*(LnkLI231))(VV[186],V49,VV[4],VV[188]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 18)9549	*/

static void L50()
{register object *base=vs_base;
	register object *sup=base+VM50; VC50
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V50= VV[250];
	base[0]= (*(LnkLI231))(VV[189],V50,VV[4],VV[191]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 19)9549	*/

static void L51()
{register object *base=vs_base;
	register object *sup=base+VM51; VC51
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V51= VV[251];
	base[0]= (*(LnkLI231))(VV[192],V51,VV[4],VV[194]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	function definition for (PRECOMPILE-INITIALIZE-INSTANCE-SIMPLE PCL 20)9549	*/

static void L52()
{register object *base=vs_base;
	register object *sup=base+VM52; VC52
	vs_check;
	check_arg(0);
	vs_top=sup;
	goto TTL;
TTL:;
	V52= VV[252];
	base[0]= (*(LnkLI231))(VV[195],V52,VV[4],VV[197]);
	vs_top=(vs_base=base+0)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC104(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM53; VC53
	vs_check;
	{object V53;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V53=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC105,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC105(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM54; VC54
	vs_check;
	{register object V54;
	object V55;
	check_arg(2);
	V54=(base[0]);
	V55=(base[1]);
	vs_top=sup;
	{register object V56;
	object V57;
	register object V58;
	register object V59;
	object V60;
	register object V61;
	V57= CMPcar((base0[0]->c.c_car));
	V56= (V55);
	V58= Cnil;
	V59= Cnil;
	V60= Cnil;
	V61= Cnil;
	if(type_of(V54)==t_structure){
	goto T65;}
	goto T63;
	goto T65;
T65:;
	if(!(((V54)->str.str_def)==(VV[196]))){
	goto T63;}
	V58= STREF(object,(V54),4);
	V59= STREF(object,(V54),0);
	goto T61;
	goto T63;
T63:;{object V63;
	V63= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V54);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V64= vs_base[0];
	if(!((V63)==(CMPcar(V64)))){
	goto T71;}}
	V58= CMPcar(((V54))->cc.cc_turbo[12]);
	V59= CMPcar(((V54))->cc.cc_turbo[13]);
	goto T61;
	goto T71;
T71:;
	V59= (*(LnkLI255))((V54));
	goto T61;
T61:;
	V60= ((V59))->v.v_self[11];
	V56= CMPcdr((V56));
	{object V65;
	V65= CMPcar((V56));
	V56= CMPcdr((V56));
	V61= (V65);}
	(void)(((V58))->v.v_self[1]= ((V61)));
	if(!((((V58))->v.v_self[0])==(VV[31]))){
	goto T53;}
	V61= Cnil;
	(void)(((V58))->v.v_self[0]= ((V61)));}
	goto T53;
T53:;
	base[2]= (V55);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC103(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM55; VC55
	vs_check;
	{object V66;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V66=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC106,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC106(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM56; VC56
	vs_check;
	{register object V67;
	object V68;
	check_arg(2);
	V67=(base[0]);
	V68=(base[1]);
	vs_top=sup;
	{register object V69;
	object V70;
	register object V71;
	register object V72;
	object V73;
	object V74;
	V70= CMPcar((base0[0]->c.c_car));
	V69= (V68);
	V71= Cnil;
	V72= Cnil;
	V73= Cnil;
	V74= Cnil;
	if(type_of(V67)==t_structure){
	goto T106;}
	goto T104;
	goto T106;
T106:;
	if(!(((V67)->str.str_def)==(VV[193]))){
	goto T104;}
	V71= STREF(object,(V67),4);
	V72= STREF(object,(V67),0);
	goto T102;
	goto T104;
T104:;{object V76;
	V76= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V67);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V77= vs_base[0];
	if(!((V76)==(CMPcar(V77)))){
	goto T112;}}
	V71= CMPcar(((V67))->cc.cc_turbo[12]);
	V72= CMPcar(((V67))->cc.cc_turbo[13]);
	goto T102;
	goto T112;
T112:;
	V72= (*(LnkLI255))((V67));
	goto T102;
T102:;
	V73= ((V72))->v.v_self[11];
	V69= (V68);
	V69= CMPcdr((V69));
	{object V78;
	V78= CMPcar((V69));
	V69= CMPcdr((V69));
	V74= (V78);}
	(void)(((V71))->v.v_self[1]= ((V74)));}
	base[2]= (V68);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC102(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM57; VC57
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC107,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC107(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM58; VC58
	vs_check;
	{register object V79;
	object V80;
	check_arg(2);
	V79=(base[0]);
	V80=(base[1]);
	vs_top=sup;
	{register object V81;
	object V82;
	register object V83;
	register object V84;
	object V85;
	register object V86;
	V82= CMPcar((base0[1]->c.c_car));
	V81= (V80);
	V83= Cnil;
	V84= Cnil;
	V85= Cnil;
	V86= Cnil;
	if(type_of(V79)==t_structure){
	goto T144;}
	goto T142;
	goto T144;
T144:;
	if(!(((V79)->str.str_def)==(VV[190]))){
	goto T142;}
	V83= STREF(object,(V79),4);
	V84= STREF(object,(V79),0);
	goto T140;
	goto T142;
T142:;{object V88;
	V88= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V79);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V89= vs_base[0];
	if(!((V88)==(CMPcar(V89)))){
	goto T150;}}
	V83= CMPcar(((V79))->cc.cc_turbo[12]);
	V84= CMPcar(((V79))->cc.cc_turbo[13]);
	goto T140;
	goto T150;
T150:;
	V84= (*(LnkLI255))((V79));
	goto T140;
T140:;
	V85= ((V84))->v.v_self[11];
	V81= CMPcdr((V81));
	{object V90;
	V90= CMPcar((V81));
	V81= CMPcdr((V81));
	V86= (V90);}
	(void)(((V83))->v.v_self[8]= ((V86)));
	V81= CMPcdr((V81));
	{object V91;
	V91= CMPcar((V81));
	V81= CMPcdr((V81));
	V86= (V91);}
	(void)(((V83))->v.v_self[2]= ((V86)));
	V81= CMPcdr((V81));
	{object V92;
	V92= CMPcar((V81));
	V81= CMPcdr((V81));
	V86= (V92);}
	(void)(((V83))->v.v_self[0]= ((V86)));
	V81= CMPcdr((V81));
	{object V93;
	V93= CMPcar((V81));
	V81= CMPcdr((V81));
	V86= (V93);}
	(void)(((V83))->v.v_self[3]= ((V86)));
	V81= CMPcdr((V81));
	{object V94;
	V94= CMPcar((V81));
	V81= CMPcdr((V81));
	V86= (V94);}
	(void)(((V83))->v.v_self[4]= ((V86)));
	V81= CMPcdr((V81));
	{object V95;
	V95= CMPcar((V81));
	V81= CMPcdr((V81));
	V86= (V95);}
	(void)(((V83))->v.v_self[5]= ((V86)));
	V81= CMPcdr((V81));
	{object V96;
	V96= CMPcar((V81));
	V81= CMPcdr((V81));
	V86= (V96);}
	(void)(((V83))->v.v_self[1]= ((V86)));
	if(!((((V83))->v.v_self[6])==(VV[31]))){
	goto T217;}
	V86= Ct;
	(void)(((V83))->v.v_self[6]= ((V86)));
	goto T217;
T217:;
	if(!((((V83))->v.v_self[7])==(VV[31]))){
	goto T222;}
	V86= ((base0[0]->c.c_car))->v.v_self[9];
	(void)(((V83))->v.v_self[7]= ((V86)));
	goto T222;
T222:;
	if(!((((V83))->v.v_self[9])==(VV[31]))){
	goto T132;}
	V86= VV[184];
	(void)(((V83))->v.v_self[9]= ((V86)));}
	goto T132;
T132:;
	base[2]= (V80);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC101(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM59; VC59
	vs_check;
	{object V97;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V97=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC108,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC108(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM60; VC60
	vs_check;
	{register object V98;
	object V99;
	check_arg(2);
	V98=(base[0]);
	V99=(base[1]);
	vs_top=sup;
	{register object V100;
	object V101;
	register object V102;
	register object V103;
	object V104;
	register object V105;
	V101= CMPcar((base0[0]->c.c_car));
	V100= (V99);
	V102= Cnil;
	V103= Cnil;
	V104= Cnil;
	V105= Cnil;
	if(type_of(V98)==t_structure){
	goto T243;}
	goto T241;
	goto T243;
T243:;
	if(!(((V98)->str.str_def)==(VV[187]))){
	goto T241;}
	V102= STREF(object,(V98),4);
	V103= STREF(object,(V98),0);
	goto T239;
	goto T241;
T241:;{object V107;
	V107= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V98);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V108= vs_base[0];
	if(!((V107)==(CMPcar(V108)))){
	goto T249;}}
	V102= CMPcar(((V98))->cc.cc_turbo[12]);
	V103= CMPcar(((V98))->cc.cc_turbo[13]);
	goto T239;
	goto T249;
T249:;
	V103= (*(LnkLI255))((V98));
	goto T239;
T239:;
	V104= ((V103))->v.v_self[11];
	V100= (V99);
	V100= CMPcdr((V100));
	{object V109;
	V109= CMPcar((V100));
	V100= CMPcdr((V100));
	V105= (V109);}
	(void)(((V102))->v.v_self[8]= ((V105)));
	V100= CMPcdr((V100));
	{object V110;
	V110= CMPcar((V100));
	V100= CMPcdr((V100));
	V105= (V110);}
	(void)(((V102))->v.v_self[2]= ((V105)));
	V100= CMPcdr((V100));
	{object V111;
	V111= CMPcar((V100));
	V100= CMPcdr((V100));
	V105= (V111);}
	(void)(((V102))->v.v_self[0]= ((V105)));
	V100= CMPcdr((V100));
	{object V112;
	V112= CMPcar((V100));
	V100= CMPcdr((V100));
	V105= (V112);}
	(void)(((V102))->v.v_self[3]= ((V105)));
	V100= CMPcdr((V100));
	{object V113;
	V113= CMPcar((V100));
	V100= CMPcdr((V100));
	V105= (V113);}
	(void)(((V102))->v.v_self[4]= ((V105)));
	V100= CMPcdr((V100));
	{object V114;
	V114= CMPcar((V100));
	V100= CMPcdr((V100));
	V105= (V114);}
	(void)(((V102))->v.v_self[5]= ((V105)));
	V100= CMPcdr((V100));
	{object V115;
	V115= CMPcar((V100));
	V100= CMPcdr((V100));
	V105= (V115);}
	(void)(((V102))->v.v_self[1]= ((V105)));}
	base[2]= (V99);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC100(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM61; VC61
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC109,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC109(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM62; VC62
	vs_check;
	{register object V116;
	object V117;
	check_arg(2);
	V116=(base[0]);
	V117=(base[1]);
	vs_top=sup;
	{register object V118;
	object V119;
	register object V120;
	register object V121;
	object V122;
	register object V123;
	V119= CMPcar((base0[1]->c.c_car));
	V118= (V117);
	V120= Cnil;
	V121= Cnil;
	V122= Cnil;
	V123= Cnil;
	if(type_of(V116)==t_structure){
	goto T329;}
	goto T327;
	goto T329;
T329:;
	if(!(((V116)->str.str_def)==(VV[183]))){
	goto T327;}
	V120= STREF(object,(V116),4);
	V121= STREF(object,(V116),0);
	goto T325;
	goto T327;
T327:;{object V125;
	V125= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V116);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V126= vs_base[0];
	if(!((V125)==(CMPcar(V126)))){
	goto T335;}}
	V120= CMPcar(((V116))->cc.cc_turbo[12]);
	V121= CMPcar(((V116))->cc.cc_turbo[13]);
	goto T325;
	goto T335;
T335:;
	V121= (*(LnkLI255))((V116));
	goto T325;
T325:;
	V122= ((V121))->v.v_self[11];
	V118= CMPcdr((V118));
	{object V127;
	V127= CMPcar((V118));
	V118= CMPcdr((V118));
	V123= (V127);}
	(void)(((V120))->v.v_self[8]= ((V123)));
	V118= CMPcdr((V118));
	{object V128;
	V128= CMPcar((V118));
	V118= CMPcdr((V118));
	V123= (V128);}
	(void)(((V120))->v.v_self[0]= ((V123)));
	V118= CMPcdr((V118));
	{object V129;
	V129= CMPcar((V118));
	V118= CMPcdr((V118));
	V123= (V129);}
	(void)(((V120))->v.v_self[3]= ((V123)));
	V118= CMPcdr((V118));
	{object V130;
	V130= CMPcar((V118));
	V118= CMPcdr((V118));
	V123= (V130);}
	(void)(((V120))->v.v_self[4]= ((V123)));
	V118= CMPcdr((V118));
	{object V131;
	V131= CMPcar((V118));
	V118= CMPcdr((V118));
	V123= (V131);}
	(void)(((V120))->v.v_self[5]= ((V123)));
	if(!((((V120))->v.v_self[1])==(VV[31]))){
	goto T386;}
	V123= Cnil;
	(void)(((V120))->v.v_self[1]= ((V123)));
	goto T386;
T386:;
	if(!((((V120))->v.v_self[2])==(VV[31]))){
	goto T391;}
	V123= Cnil;
	(void)(((V120))->v.v_self[2]= ((V123)));
	goto T391;
T391:;
	if(!((((V120))->v.v_self[6])==(VV[31]))){
	goto T396;}
	V123= Ct;
	(void)(((V120))->v.v_self[6]= ((V123)));
	goto T396;
T396:;
	if(!((((V120))->v.v_self[7])==(VV[31]))){
	goto T401;}
	V123= ((base0[0]->c.c_car))->v.v_self[9];
	(void)(((V120))->v.v_self[7]= ((V123)));
	goto T401;
T401:;
	if(!((((V120))->v.v_self[9])==(VV[31]))){
	goto T317;}
	V123= VV[184];
	(void)(((V120))->v.v_self[9]= ((V123)));}
	goto T317;
T317:;
	base[2]= (V117);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC99(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM63; VC63
	vs_check;
	{object V132;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V132=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC110,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC110(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM64; VC64
	vs_check;
	{register object V133;
	object V134;
	check_arg(2);
	V133=(base[0]);
	V134=(base[1]);
	vs_top=sup;
	{register object V135;
	object V136;
	register object V137;
	register object V138;
	object V139;
	register object V140;
	V136= CMPcar((base0[0]->c.c_car));
	V135= (V134);
	V137= Cnil;
	V138= Cnil;
	V139= Cnil;
	V140= Cnil;
	if(type_of(V133)==t_structure){
	goto T422;}
	goto T420;
	goto T422;
T422:;
	if(!(((V133)->str.str_def)==(VV[180]))){
	goto T420;}
	V137= STREF(object,(V133),4);
	V138= STREF(object,(V133),0);
	goto T418;
	goto T420;
T420:;{object V142;
	V142= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V133);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V143= vs_base[0];
	if(!((V142)==(CMPcar(V143)))){
	goto T428;}}
	V137= CMPcar(((V133))->cc.cc_turbo[12]);
	V138= CMPcar(((V133))->cc.cc_turbo[13]);
	goto T418;
	goto T428;
T428:;
	V138= (*(LnkLI255))((V133));
	goto T418;
T418:;
	V139= ((V138))->v.v_self[11];
	V135= (V134);
	V135= CMPcdr((V135));
	{object V144;
	V144= CMPcar((V135));
	V135= CMPcdr((V135));
	V140= (V144);}
	(void)(((V137))->v.v_self[8]= ((V140)));
	V135= CMPcdr((V135));
	{object V145;
	V145= CMPcar((V135));
	V135= CMPcdr((V135));
	V140= (V145);}
	(void)(((V137))->v.v_self[0]= ((V140)));
	V135= CMPcdr((V135));
	{object V146;
	V146= CMPcar((V135));
	V135= CMPcdr((V135));
	V140= (V146);}
	(void)(((V137))->v.v_self[3]= ((V140)));
	V135= CMPcdr((V135));
	{object V147;
	V147= CMPcar((V135));
	V135= CMPcdr((V135));
	V140= (V147);}
	(void)(((V137))->v.v_self[4]= ((V140)));
	V135= CMPcdr((V135));
	{object V148;
	V148= CMPcar((V135));
	V135= CMPcdr((V135));
	V140= (V148);}
	(void)(((V137))->v.v_self[5]= ((V140)));}
	base[2]= (V134);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC98(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM65; VC65
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC111,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC111(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM66; VC66
	vs_check;
	{register object V149;
	object V150;
	check_arg(2);
	V149=(base[0]);
	V150=(base[1]);
	vs_top=sup;
	{register object V151;
	object V152;
	register object V153;
	register object V154;
	object V155;
	register object V156;
	V152= CMPcar((base0[1]->c.c_car));
	V151= (V150);
	V153= Cnil;
	V154= Cnil;
	V155= Cnil;
	V156= Cnil;
	if(type_of(V149)==t_structure){
	goto T492;}
	goto T490;
	goto T492;
T492:;
	if(!(((V149)->str.str_def)==(VV[177]))){
	goto T490;}
	V153= STREF(object,(V149),4);
	V154= STREF(object,(V149),0);
	goto T488;
	goto T490;
T490:;{object V158;
	V158= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V149);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V159= vs_base[0];
	if(!((V158)==(CMPcar(V159)))){
	goto T498;}}
	V153= CMPcar(((V149))->cc.cc_turbo[12]);
	V154= CMPcar(((V149))->cc.cc_turbo[13]);
	goto T488;
	goto T498;
T498:;
	V154= (*(LnkLI255))((V149));
	goto T488;
T488:;
	V155= ((V154))->v.v_self[11];
	V151= CMPcdr((V151));
	{object V160;
	V160= CMPcar((V151));
	V151= CMPcdr((V151));
	V156= (V160);}
	(void)(((V153))->v.v_self[0]= ((V156)));
	V151= CMPcdr((V151));
	{object V161;
	V161= CMPcar((V151));
	V151= CMPcdr((V151));
	V156= (V161);}
	(void)(((V153))->v.v_self[1]= ((V156)));
	V151= CMPcdr((V151));
	{object V162;
	V162= CMPcar((V151));
	V151= CMPcdr((V151));
	V156= (V162);}
	(void)(((V153))->v.v_self[2]= ((V156)));
	V151= CMPcdr((V151));
	{object V163;
	V163= CMPcar((V151));
	V151= CMPcdr((V151));
	V156= (V163);}
	(void)(((V153))->v.v_self[5]= ((V156)));
	V151= CMPcdr((V151));
	{object V164;
	V164= CMPcar((V151));
	V151= CMPcdr((V151));
	V156= (V164);}
	(void)(((V153))->v.v_self[13]= ((V156)));
	V151= CMPcdr((V151));
	{object V165;
	V165= CMPcar((V151));
	V151= CMPcdr((V151));
	V156= (V165);}
	(void)(((V153))->v.v_self[6]= ((V156)));
	V151= CMPcdr((V151));
	{object V166;
	V166= CMPcar((V151));
	V151= CMPcdr((V151));
	V156= (V166);}
	(void)(((V153))->v.v_self[8]= ((V156)));
	if(!((((V153))->v.v_self[3])==(VV[31]))){
	goto T565;}
	V156= Cnil;
	(void)(((V153))->v.v_self[3]= ((V156)));
	goto T565;
T565:;
	if(!((((V153))->v.v_self[4])==(VV[31]))){
	goto T570;}
	V156= Cnil;
	(void)(((V153))->v.v_self[4]= ((V156)));
	goto T570;
T570:;
	if(!((((V153))->v.v_self[7])==(VV[31]))){
	goto T575;}
	V156= ((base0[0]->c.c_car))->v.v_self[10];
	(void)(((V153))->v.v_self[7]= ((V156)));
	goto T575;
T575:;
	if(!((((V153))->v.v_self[12])==(VV[31]))){
	goto T580;}
	V156= small_fixnum(0);
	(void)(((V153))->v.v_self[12]= ((V156)));
	goto T580;
T580:;
	if(!((((V153))->v.v_self[14])==(VV[31]))){
	goto T480;}
	V156= Cnil;
	(void)(((V153))->v.v_self[14]= ((V156)));}
	goto T480;
T480:;
	base[2]= (V150);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC97(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM67; VC67
	vs_check;
	{object V167;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V167=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC112,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC112(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM68; VC68
	vs_check;
	{register object V168;
	object V169;
	check_arg(2);
	V168=(base[0]);
	V169=(base[1]);
	vs_top=sup;
	{register object V170;
	object V171;
	register object V172;
	register object V173;
	object V174;
	register object V175;
	V171= CMPcar((base0[0]->c.c_car));
	V170= (V169);
	V172= Cnil;
	V173= Cnil;
	V174= Cnil;
	V175= Cnil;
	if(type_of(V168)==t_structure){
	goto T601;}
	goto T599;
	goto T601;
T601:;
	if(!(((V168)->str.str_def)==(VV[174]))){
	goto T599;}
	V172= STREF(object,(V168),4);
	V173= STREF(object,(V168),0);
	goto T597;
	goto T599;
T599:;{object V177;
	V177= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V168);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V178= vs_base[0];
	if(!((V177)==(CMPcar(V178)))){
	goto T607;}}
	V172= CMPcar(((V168))->cc.cc_turbo[12]);
	V173= CMPcar(((V168))->cc.cc_turbo[13]);
	goto T597;
	goto T607;
T607:;
	V173= (*(LnkLI255))((V168));
	goto T597;
T597:;
	V174= ((V173))->v.v_self[11];
	V170= (V169);
	V170= CMPcdr((V170));
	{object V179;
	V179= CMPcar((V170));
	V170= CMPcdr((V170));
	V175= (V179);}
	(void)(((V172))->v.v_self[0]= ((V175)));
	V170= CMPcdr((V170));
	{object V180;
	V180= CMPcar((V170));
	V170= CMPcdr((V170));
	V175= (V180);}
	(void)(((V172))->v.v_self[1]= ((V175)));
	V170= CMPcdr((V170));
	{object V181;
	V181= CMPcar((V170));
	V170= CMPcdr((V170));
	V175= (V181);}
	(void)(((V172))->v.v_self[2]= ((V175)));
	V170= CMPcdr((V170));
	{object V182;
	V182= CMPcar((V170));
	V170= CMPcdr((V170));
	V175= (V182);}
	(void)(((V172))->v.v_self[5]= ((V175)));
	V170= CMPcdr((V170));
	{object V183;
	V183= CMPcar((V170));
	V170= CMPcdr((V170));
	V175= (V183);}
	(void)(((V172))->v.v_self[13]= ((V175)));
	V170= CMPcdr((V170));
	{object V184;
	V184= CMPcar((V170));
	V170= CMPcdr((V170));
	V175= (V184);}
	(void)(((V172))->v.v_self[6]= ((V175)));
	V170= CMPcdr((V170));
	{object V185;
	V185= CMPcar((V170));
	V170= CMPcdr((V170));
	V175= (V185);}
	(void)(((V172))->v.v_self[8]= ((V175)));}
	base[2]= (V169);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC96(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM69; VC69
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC113,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC113(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM70; VC70
	vs_check;
	{register object V186;
	object V187;
	check_arg(2);
	V186=(base[0]);
	V187=(base[1]);
	vs_top=sup;
	{register object V188;
	object V189;
	register object V190;
	register object V191;
	object V192;
	register object V193;
	V189= CMPcar((base0[1]->c.c_car));
	V188= (V187);
	V190= Cnil;
	V191= Cnil;
	V192= Cnil;
	V193= Cnil;
	if(type_of(V186)==t_structure){
	goto T687;}
	goto T685;
	goto T687;
T687:;
	if(!(((V186)->str.str_def)==(VV[171]))){
	goto T685;}
	V190= STREF(object,(V186),4);
	V191= STREF(object,(V186),0);
	goto T683;
	goto T685;
T685:;{object V195;
	V195= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V186);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V196= vs_base[0];
	if(!((V195)==(CMPcar(V196)))){
	goto T693;}}
	V190= CMPcar(((V186))->cc.cc_turbo[12]);
	V191= CMPcar(((V186))->cc.cc_turbo[13]);
	goto T683;
	goto T693;
T693:;
	V191= (*(LnkLI255))((V186));
	goto T683;
T683:;
	V192= ((V191))->v.v_self[11];
	V188= CMPcdr((V188));
	{object V197;
	V197= CMPcar((V188));
	V188= CMPcdr((V188));
	V193= (V197);}
	(void)(((V190))->v.v_self[3]= ((V193)));
	V188= CMPcdr(CMPcddddr((V188)));
	{object V198;
	V198= CMPcar((V188));
	V188= CMPcdr((V188));
	V193= (V198);}
	(void)(((V190))->v.v_self[1]= ((V193)));
	if(!((((V190))->v.v_self[0])==(VV[31]))){
	goto T720;}
	V193= Cnil;
	(void)(((V190))->v.v_self[0]= ((V193)));
	goto T720;
T720:;
	if(!((((V190))->v.v_self[2])==(VV[31]))){
	goto T725;}
	V193= Cnil;
	(void)(((V190))->v.v_self[2]= ((V193)));
	goto T725;
T725:;
	if(!((((V190))->v.v_self[4])==(VV[31]))){
	goto T730;}
	V193= Cnil;
	(void)(((V190))->v.v_self[4]= ((V193)));
	goto T730;
T730:;
	if(!((((V190))->v.v_self[5])==(VV[31]))){
	goto T735;}
	V193= Cnil;
	(void)(((V190))->v.v_self[5]= ((V193)));
	goto T735;
T735:;
	if(!((((V190))->v.v_self[6])==(VV[31]))){
	goto T740;}
	V193= Cnil;
	(void)(((V190))->v.v_self[6]= ((V193)));
	goto T740;
T740:;
	if(!((((V190))->v.v_self[7])==(VV[31]))){
	goto T745;}
	V193= (
	V199 = ((base0[0]->c.c_car))->v.v_self[8],
	(type_of(V199) == t_sfun ?(*((V199)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V199)==t_vfun) ?
	(*((V199)->sfn.sfn_self)):
	(fcall.fun=(V199),fcalln))());
	(void)(((V190))->v.v_self[7]= ((V193)));
	goto T745;
T745:;
	if(!((((V190))->v.v_self[8])==(VV[31]))){
	goto T750;}
	V193= Cnil;
	(void)(((V190))->v.v_self[8]= ((V193)));
	goto T750;
T750:;
	if(!((((V190))->v.v_self[10])==(VV[31]))){
	goto T755;}
	V193= Cnil;
	(void)(((V190))->v.v_self[10]= ((V193)));
	goto T755;
T755:;
	if(!((((V190))->v.v_self[11])==(VV[31]))){
	goto T760;}
	V193= Cnil;
	(void)(((V190))->v.v_self[11]= ((V193)));
	goto T760;
T760:;
	if(!((((V190))->v.v_self[12])==(VV[31]))){
	goto T765;}
	V193= Cnil;
	(void)(((V190))->v.v_self[12]= ((V193)));
	goto T765;
T765:;
	if(!((((V190))->v.v_self[13])==(VV[31]))){
	goto T770;}
	V193= Cnil;
	(void)(((V190))->v.v_self[13]= ((V193)));
	goto T770;
T770:;
	if(!((((V190))->v.v_self[14])==(VV[31]))){
	goto T775;}
	V193= Cnil;
	(void)(((V190))->v.v_self[14]= ((V193)));
	goto T775;
T775:;
	if(!((((V190))->v.v_self[15])==(VV[31]))){
	goto T780;}
	V193= Cnil;
	(void)(((V190))->v.v_self[15]= ((V193)));
	goto T780;
T780:;
	if(!((((V190))->v.v_self[16])==(VV[31]))){
	goto T675;}
	V193= Cnil;
	(void)(((V190))->v.v_self[16]= ((V193)));}
	goto T675;
T675:;
	base[2]= (V187);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC95(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM71; VC71
	vs_check;
	{object V200;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V200=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC114,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC114(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM72; VC72
	vs_check;
	{register object V201;
	object V202;
	check_arg(2);
	V201=(base[0]);
	V202=(base[1]);
	vs_top=sup;
	{register object V203;
	object V204;
	register object V205;
	register object V206;
	object V207;
	object V208;
	V204= CMPcar((base0[0]->c.c_car));
	V203= (V202);
	V205= Cnil;
	V206= Cnil;
	V207= Cnil;
	V208= Cnil;
	if(type_of(V201)==t_structure){
	goto T801;}
	goto T799;
	goto T801;
T801:;
	if(!(((V201)->str.str_def)==(VV[168]))){
	goto T799;}
	V205= STREF(object,(V201),4);
	V206= STREF(object,(V201),0);
	goto T797;
	goto T799;
T799:;{object V210;
	V210= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V201);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V211= vs_base[0];
	if(!((V210)==(CMPcar(V211)))){
	goto T807;}}
	V205= CMPcar(((V201))->cc.cc_turbo[12]);
	V206= CMPcar(((V201))->cc.cc_turbo[13]);
	goto T797;
	goto T807;
T807:;
	V206= (*(LnkLI255))((V201));
	goto T797;
T797:;
	V207= ((V206))->v.v_self[11];
	V203= CMPcdddr((V203));
	{object V212;
	V212= CMPcar((V203));
	V203= CMPcdr((V203));
	V208= (V212);}
	(void)(((V205))->v.v_self[1]= ((V208)));}
	base[2]= (V202);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC94(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM73; VC73
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC115,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC115(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM74; VC74
	vs_check;
	{register object V213;
	object V214;
	check_arg(2);
	V213=(base[0]);
	V214=(base[1]);
	vs_top=sup;
	{register object V215;
	object V216;
	register object V217;
	register object V218;
	object V219;
	register object V220;
	V216= CMPcar((base0[1]->c.c_car));
	V215= (V214);
	V217= Cnil;
	V218= Cnil;
	V219= Cnil;
	V220= Cnil;
	if(type_of(V213)==t_structure){
	goto T837;}
	goto T835;
	goto T837;
T837:;
	if(!(((V213)->str.str_def)==(VV[165]))){
	goto T835;}
	V217= STREF(object,(V213),4);
	V218= STREF(object,(V213),0);
	goto T833;
	goto T835;
T835:;{object V222;
	V222= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V213);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V223= vs_base[0];
	if(!((V222)==(CMPcar(V223)))){
	goto T843;}}
	V217= CMPcar(((V213))->cc.cc_turbo[12]);
	V218= CMPcar(((V213))->cc.cc_turbo[13]);
	goto T833;
	goto T843;
T843:;
	V218= (*(LnkLI255))((V213));
	goto T833;
T833:;
	V219= ((V218))->v.v_self[11];
	V215= CMPcdr((V215));
	{object V224;
	V224= CMPcar((V215));
	V215= CMPcdr((V215));
	V220= (V224);}
	(void)(((V217))->v.v_self[5]= ((V220)));
	V215= CMPcdr((V215));
	{object V225;
	V225= CMPcar((V215));
	V215= CMPcdr((V215));
	V220= (V225);}
	(void)(((V217))->v.v_self[4]= ((V220)));
	V215= CMPcdddr((V215));
	{object V226;
	V226= CMPcar((V215));
	V215= CMPcdr((V215));
	V220= (V226);}
	(void)(((V217))->v.v_self[1]= ((V220)));
	if(!((((V217))->v.v_self[0])==(VV[31]))){
	goto T878;}
	V220= Cnil;
	(void)(((V217))->v.v_self[0]= ((V220)));
	goto T878;
T878:;
	if(!((((V217))->v.v_self[2])==(VV[31]))){
	goto T883;}
	V220= Cnil;
	(void)(((V217))->v.v_self[2]= ((V220)));
	goto T883;
T883:;
	if(!((((V217))->v.v_self[3])==(VV[31]))){
	goto T888;}
	V220= Cnil;
	(void)(((V217))->v.v_self[3]= ((V220)));
	goto T888;
T888:;
	if(!((((V217))->v.v_self[6])==(VV[31]))){
	goto T893;}
	V220= (
	V227 = ((base0[0]->c.c_car))->v.v_self[7],
	(type_of(V227) == t_sfun ?(*((V227)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V227)==t_vfun) ?
	(*((V227)->sfn.sfn_self)):
	(fcall.fun=(V227),fcalln))());
	(void)(((V217))->v.v_self[6]= ((V220)));
	goto T893;
T893:;
	if(!((((V217))->v.v_self[7])==(VV[31]))){
	goto T898;}
	V220= Cnil;
	(void)(((V217))->v.v_self[7]= ((V220)));
	goto T898;
T898:;
	if(!((((V217))->v.v_self[8])==(VV[31]))){
	goto T825;}
	V220= Cnil;
	(void)(((V217))->v.v_self[8]= ((V220)));}
	goto T825;
T825:;
	base[2]= (V214);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC93(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM75; VC75
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC116,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC116(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM76; VC76
	vs_check;
	{register object V228;
	object V229;
	check_arg(2);
	V228=(base[0]);
	V229=(base[1]);
	vs_top=sup;
	{register object V230;
	object V231;
	register object V232;
	register object V233;
	object V234;
	register object V235;
	V231= CMPcar((base0[1]->c.c_car));
	V230= (V229);
	V232= Cnil;
	V233= Cnil;
	V234= Cnil;
	V235= Cnil;
	if(type_of(V228)==t_structure){
	goto T919;}
	goto T917;
	goto T919;
T919:;
	if(!(((V228)->str.str_def)==(VV[162]))){
	goto T917;}
	V232= STREF(object,(V228),4);
	V233= STREF(object,(V228),0);
	goto T915;
	goto T917;
T917:;{object V237;
	V237= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V228);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V238= vs_base[0];
	if(!((V237)==(CMPcar(V238)))){
	goto T925;}}
	V232= CMPcar(((V228))->cc.cc_turbo[12]);
	V233= CMPcar(((V228))->cc.cc_turbo[13]);
	goto T915;
	goto T925;
T925:;
	V233= (*(LnkLI255))((V228));
	goto T915;
T915:;
	V234= ((V233))->v.v_self[11];
	V230= CMPcdr((V230));
	{object V239;
	V239= CMPcar((V230));
	V230= CMPcdr((V230));
	V235= (V239);}
	(void)(((V232))->v.v_self[5]= ((V235)));
	V230= CMPcdr((V230));
	{object V240;
	V240= CMPcar((V230));
	V230= CMPcdr((V230));
	V235= (V240);}
	(void)(((V232))->v.v_self[4]= ((V235)));
	V230= CMPcdr((V230));
	{object V241;
	V241= CMPcar((V230));
	V230= CMPcdr((V230));
	V235= (V241);}
	(void)(((V232))->v.v_self[2]= ((V235)));
	if(!((((V232))->v.v_self[0])==(VV[31]))){
	goto T960;}
	V235= Cnil;
	(void)(((V232))->v.v_self[0]= ((V235)));
	goto T960;
T960:;
	if(!((((V232))->v.v_self[1])==(VV[31]))){
	goto T965;}
	V235= (
	V242 = ((base0[0]->c.c_car))->v.v_self[5],
	(type_of(V242) == t_sfun ?(*((V242)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V242)==t_vfun) ?
	(*((V242)->sfn.sfn_self)):
	(fcall.fun=(V242),fcalln))());
	(void)(((V232))->v.v_self[1]= ((V235)));
	goto T965;
T965:;
	if(!((((V232))->v.v_self[3])==(VV[31]))){
	goto T970;}
	V235= Cnil;
	(void)(((V232))->v.v_self[3]= ((V235)));
	goto T970;
T970:;
	if(!((((V232))->v.v_self[6])==(VV[31]))){
	goto T975;}
	V235= (
	V243 = ((base0[0]->c.c_car))->v.v_self[8],
	(type_of(V243) == t_sfun ?(*((V243)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V243)==t_vfun) ?
	(*((V243)->sfn.sfn_self)):
	(fcall.fun=(V243),fcalln))());
	(void)(((V232))->v.v_self[6]= ((V235)));
	goto T975;
T975:;
	if(!((((V232))->v.v_self[7])==(VV[31]))){
	goto T980;}
	V235= Cnil;
	(void)(((V232))->v.v_self[7]= ((V235)));
	goto T980;
T980:;
	if(!((((V232))->v.v_self[8])==(VV[31]))){
	goto T907;}
	V235= Cnil;
	(void)(((V232))->v.v_self[8]= ((V235)));}
	goto T907;
T907:;
	base[2]= (V229);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC92(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM77; VC77
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC117,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC117(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM78; VC78
	vs_check;
	{register object V244;
	object V245;
	check_arg(2);
	V244=(base[0]);
	V245=(base[1]);
	vs_top=sup;
	{register object V246;
	object V247;
	register object V248;
	register object V249;
	object V250;
	register object V251;
	V247= CMPcar((base0[1]->c.c_car));
	V246= (V245);
	V248= Cnil;
	V249= Cnil;
	V250= Cnil;
	V251= Cnil;
	if(type_of(V244)==t_structure){
	goto T1001;}
	goto T999;
	goto T1001;
T1001:;
	if(!(((V244)->str.str_def)==(VV[159]))){
	goto T999;}
	V248= STREF(object,(V244),4);
	V249= STREF(object,(V244),0);
	goto T997;
	goto T999;
T999:;{object V253;
	V253= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V244);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V254= vs_base[0];
	if(!((V253)==(CMPcar(V254)))){
	goto T1007;}}
	V248= CMPcar(((V244))->cc.cc_turbo[12]);
	V249= CMPcar(((V244))->cc.cc_turbo[13]);
	goto T997;
	goto T1007;
T1007:;
	V249= (*(LnkLI255))((V244));
	goto T997;
T997:;
	V250= ((V249))->v.v_self[11];
	V246= CMPcdr((V246));
	{object V255;
	V255= CMPcar((V246));
	V246= CMPcdr((V246));
	V251= (V255);}
	(void)(((V248))->v.v_self[5]= ((V251)));
	V246= CMPcdr((V246));
	{object V256;
	V256= CMPcar((V246));
	V246= CMPcdr((V246));
	V251= (V256);}
	(void)(((V248))->v.v_self[4]= ((V251)));
	if(!((((V248))->v.v_self[0])==(VV[31]))){
	goto T1034;}
	V251= Cnil;
	(void)(((V248))->v.v_self[0]= ((V251)));
	goto T1034;
T1034:;
	if(!((((V248))->v.v_self[1])==(VV[31]))){
	goto T1039;}
	V251= (
	V257 = ((base0[0]->c.c_car))->v.v_self[4],
	(type_of(V257) == t_sfun ?(*((V257)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V257)==t_vfun) ?
	(*((V257)->sfn.sfn_self)):
	(fcall.fun=(V257),fcalln))());
	(void)(((V248))->v.v_self[1]= ((V251)));
	goto T1039;
T1039:;
	if(!((((V248))->v.v_self[2])==(VV[31]))){
	goto T1044;}
	V251= Cnil;
	(void)(((V248))->v.v_self[2]= ((V251)));
	goto T1044;
T1044:;
	if(!((((V248))->v.v_self[3])==(VV[31]))){
	goto T1049;}
	V251= Cnil;
	(void)(((V248))->v.v_self[3]= ((V251)));
	goto T1049;
T1049:;
	if(!((((V248))->v.v_self[6])==(VV[31]))){
	goto T1054;}
	V251= (
	V258 = ((base0[0]->c.c_car))->v.v_self[8],
	(type_of(V258) == t_sfun ?(*((V258)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V258)==t_vfun) ?
	(*((V258)->sfn.sfn_self)):
	(fcall.fun=(V258),fcalln))());
	(void)(((V248))->v.v_self[6]= ((V251)));
	goto T1054;
T1054:;
	if(!((((V248))->v.v_self[7])==(VV[31]))){
	goto T1059;}
	V251= Cnil;
	(void)(((V248))->v.v_self[7]= ((V251)));
	goto T1059;
T1059:;
	if(!((((V248))->v.v_self[8])==(VV[31]))){
	goto T989;}
	V251= Cnil;
	(void)(((V248))->v.v_self[8]= ((V251)));}
	goto T989;
T989:;
	base[2]= (V245);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC91(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM79; VC79
	vs_check;
	{object V259;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V259=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC118,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC118(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM80; VC80
	vs_check;
	{register object V260;
	object V261;
	check_arg(2);
	V260=(base[0]);
	V261=(base[1]);
	vs_top=sup;
	{object V263;
	object V264;
	register object V265;
	object V266;
	V263= CMPcar((base0[0]->c.c_car));
	V264= Cnil;
	V265= Cnil;
	V266= Cnil;
	if(type_of(V260)==t_structure){
	goto T1080;}
	goto T1078;
	goto T1080;
T1080:;
	if(!(((V260)->str.str_def)==(VV[156]))){
	goto T1078;}
	V264= STREF(object,(V260),4);
	V265= STREF(object,(V260),0);
	goto T1076;
	goto T1078;
T1078:;{object V269;
	V269= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V260);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V270= vs_base[0];
	if(!((V269)==(CMPcar(V270)))){
	goto T1086;}}
	V264= CMPcar(((V260))->cc.cc_turbo[12]);
	V265= CMPcar(((V260))->cc.cc_turbo[13]);
	goto T1076;
	goto T1086;
T1086:;
	V265= (*(LnkLI255))((V260));
	goto T1076;
T1076:;
	V266= ((V265))->v.v_self[11];}
	base[2]= (V261);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC90(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM81; VC81
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC119,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC119(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM82; VC82
	vs_check;
	{register object V271;
	register object V272;
	check_arg(2);
	V271=(base[0]);
	V272=(base[1]);
	vs_top=sup;
	{object V273;
	object V274;
	object V275;
	register object V276;
	object V277;
	register object V278;
	V274= CMPcar((base0[1]->c.c_car));
	V273= (V272);
	V275= Cnil;
	V276= Cnil;
	V277= Cnil;
	V278= Cnil;
	if(type_of(V271)==t_structure){
	goto T1108;}
	goto T1106;
	goto T1108;
T1108:;
	if(!(((V271)->str.str_def)==(VV[151]))){
	goto T1106;}
	V275= STREF(object,(V271),4);
	V276= STREF(object,(V271),0);
	goto T1104;
	goto T1106;
T1106:;{object V280;
	V280= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V271);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V281= vs_base[0];
	if(!((V280)==(CMPcar(V281)))){
	goto T1114;}}
	V275= CMPcar(((V271))->cc.cc_turbo[12]);
	V276= CMPcar(((V271))->cc.cc_turbo[13]);
	goto T1104;
	goto T1114;
T1114:;
	V276= (*(LnkLI255))((V271));
	goto T1104;
T1104:;
	V277= ((V276))->v.v_self[11];
	V278= (
	V282 = ((base0[0]->c.c_car))->v.v_self[0],
	(type_of(V282) == t_sfun ?(*((V282)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V282)==t_vfun) ?
	(*((V282)->sfn.sfn_self)):
	(fcall.fun=(V282),fcalln))());
	V272= make_cons(V278,(V272));
	V272= make_cons(VV[152],(V272));
	V278= (
	V285 = ((base0[0]->c.c_car))->v.v_self[1],
	(type_of(V285) == t_sfun ?(*((V285)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V285)==t_vfun) ?
	(*((V285)->sfn.sfn_self)):
	(fcall.fun=(V285),fcalln))());
	V272= make_cons(V278,(V272));
	V272= make_cons(VV[153],(V272));
	if(!(type_of((V272))==t_cons)){
	goto T1137;}
	V272= make_cons(CMPcar((V272)),CMPcdr((V272)));
	goto T1137;
T1137:;
	(VV[131]->s.s_dbind)= ((base0[0]->c.c_car))->v.v_self[2];
	(VV[132]->s.s_dbind)= (V272);
	(VV[133]->s.s_dbind)= ((base0[0]->c.c_car))->v.v_self[3];
	V273= (V272);}
	base[2]= (V272);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC89(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM83; VC83
	vs_check;
	{object V288;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V288=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC120,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC120(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM84; VC84
	vs_check;
	{register object V289;
	object V290;
	check_arg(2);
	V289=(base[0]);
	V290=(base[1]);
	vs_top=sup;
	{register object V291;
	object V292;
	register object V293;
	register object V294;
	object V295;
	register object V296;
	V292= CMPcar((base0[0]->c.c_car));
	V291= (V290);
	V293= Cnil;
	V294= Cnil;
	V295= Cnil;
	V296= Cnil;
	if(type_of(V289)==t_structure){
	goto T1160;}
	goto T1158;
	goto T1160;
T1160:;
	if(!(((V289)->str.str_def)==(VV[148]))){
	goto T1158;}
	V293= STREF(object,(V289),4);
	V294= STREF(object,(V289),0);
	goto T1156;
	goto T1158;
T1158:;{object V298;
	V298= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V289);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V299= vs_base[0];
	if(!((V298)==(CMPcar(V299)))){
	goto T1166;}}
	V293= CMPcar(((V289))->cc.cc_turbo[12]);
	V294= CMPcar(((V289))->cc.cc_turbo[13]);
	goto T1156;
	goto T1166;
T1166:;
	V294= (*(LnkLI255))((V289));
	goto T1156;
T1156:;
	V295= ((V294))->v.v_self[11];
	V291= CMPcdddr((V291));
	{object V300;
	V300= CMPcar((V291));
	V291= CMPcdr((V291));
	V296= (V300);}
	(void)(((V293))->v.v_self[3]= ((V296)));
	V291= CMPcdr((V291));
	{object V301;
	V301= CMPcar((V291));
	V291= CMPcdr((V291));
	V296= (V301);}
	(void)(((V293))->v.v_self[4]= ((V296)));
	V291= CMPcdr((V291));
	{object V302;
	V302= CMPcar((V291));
	V291= CMPcdr((V291));
	V296= (V302);}
	(void)(((V293))->v.v_self[5]= ((V296)));
	V291= CMPcdr((V291));
	{object V303;
	V303= CMPcar((V291));
	V291= CMPcdr((V291));
	V296= (V303);}
	(void)(((V293))->v.v_self[1]= ((V296)));
	if(!((((V293))->v.v_self[0])==(VV[31]))){
	goto T1209;}
	V296= Cnil;
	(void)(((V293))->v.v_self[0]= ((V296)));
	goto T1209;
T1209:;
	if(!((((V293))->v.v_self[2])==(VV[31]))){
	goto T1214;}
	V296= Cnil;
	(void)(((V293))->v.v_self[2]= ((V296)));
	goto T1214;
T1214:;
	if(!((((V293))->v.v_self[6])==(VV[31]))){
	goto T1148;}
	V296= Cnil;
	(void)(((V293))->v.v_self[6]= ((V296)));}
	goto T1148;
T1148:;
	base[2]= (V290);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC88(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM85; VC85
	vs_check;
	{object V304;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V304=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC121,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC121(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM86; VC86
	vs_check;
	{register object V305;
	object V306;
	check_arg(2);
	V305=(base[0]);
	V306=(base[1]);
	vs_top=sup;
	{register object V307;
	object V308;
	register object V309;
	register object V310;
	object V311;
	register object V312;
	V308= CMPcar((base0[0]->c.c_car));
	V307= (V306);
	V309= Cnil;
	V310= Cnil;
	V311= Cnil;
	V312= Cnil;
	if(type_of(V305)==t_structure){
	goto T1235;}
	goto T1233;
	goto T1235;
T1235:;
	if(!(((V305)->str.str_def)==(VV[145]))){
	goto T1233;}
	V309= STREF(object,(V305),4);
	V310= STREF(object,(V305),0);
	goto T1231;
	goto T1233;
T1233:;{object V314;
	V314= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V305);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V315= vs_base[0];
	if(!((V314)==(CMPcar(V315)))){
	goto T1241;}}
	V309= CMPcar(((V305))->cc.cc_turbo[12]);
	V310= CMPcar(((V305))->cc.cc_turbo[13]);
	goto T1231;
	goto T1241;
T1241:;
	V310= (*(LnkLI255))((V305));
	goto T1231;
T1231:;
	V311= ((V310))->v.v_self[11];
	V307= CMPcdddr((V307));
	{object V316;
	V316= CMPcar((V307));
	V307= CMPcdr((V307));
	V312= (V316);}
	(void)(((V309))->v.v_self[3]= ((V312)));
	V307= CMPcdr((V307));
	{object V317;
	V317= CMPcar((V307));
	V307= CMPcdr((V307));
	V312= (V317);}
	(void)(((V309))->v.v_self[4]= ((V312)));
	V307= CMPcdr((V307));
	{object V318;
	V318= CMPcar((V307));
	V307= CMPcdr((V307));
	V312= (V318);}
	(void)(((V309))->v.v_self[1]= ((V312)));
	V307= CMPcdddr((V307));
	{object V319;
	V319= CMPcar((V307));
	V307= CMPcdr((V307));
	V312= (V319);}
	(void)(((V309))->v.v_self[6]= ((V312)));
	if(!((((V309))->v.v_self[0])==(VV[31]))){
	goto T1284;}
	V312= Cnil;
	(void)(((V309))->v.v_self[0]= ((V312)));
	goto T1284;
T1284:;
	if(!((((V309))->v.v_self[2])==(VV[31]))){
	goto T1289;}
	V312= Cnil;
	(void)(((V309))->v.v_self[2]= ((V312)));
	goto T1289;
T1289:;
	if(!((((V309))->v.v_self[5])==(VV[31]))){
	goto T1223;}
	V312= Cnil;
	(void)(((V309))->v.v_self[5]= ((V312)));}
	goto T1223;
T1223:;
	base[2]= (V306);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC87(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM87; VC87
	vs_check;
	{object V320;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	V320=(base[1]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC122,Cnil,base[0],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC122(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM88; VC88
	vs_check;
	{register object V321;
	object V322;
	check_arg(2);
	V321=(base[0]);
	V322=(base[1]);
	vs_top=sup;
	{register object V323;
	object V324;
	register object V325;
	register object V326;
	object V327;
	register object V328;
	V324= CMPcar((base0[0]->c.c_car));
	V323= (V322);
	V325= Cnil;
	V326= Cnil;
	V327= Cnil;
	V328= Cnil;
	if(type_of(V321)==t_structure){
	goto T1310;}
	goto T1308;
	goto T1310;
T1310:;
	if(!(((V321)->str.str_def)==(VV[142]))){
	goto T1308;}
	V325= STREF(object,(V321),4);
	V326= STREF(object,(V321),0);
	goto T1306;
	goto T1308;
T1308:;{object V330;
	V330= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V321);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V331= vs_base[0];
	if(!((V330)==(CMPcar(V331)))){
	goto T1316;}}
	V325= CMPcar(((V321))->cc.cc_turbo[12]);
	V326= CMPcar(((V321))->cc.cc_turbo[13]);
	goto T1306;
	goto T1316;
T1316:;
	V326= (*(LnkLI255))((V321));
	goto T1306;
T1306:;
	V327= ((V326))->v.v_self[11];
	V323= CMPcdddr((V323));
	{object V332;
	V332= CMPcar((V323));
	V323= CMPcdr((V323));
	V328= (V332);}
	(void)(((V325))->v.v_self[4]= ((V328)));
	V323= CMPcdr((V323));
	{object V333;
	V333= CMPcar((V323));
	V323= CMPcdr((V323));
	V328= (V333);}
	(void)(((V325))->v.v_self[3]= ((V328)));
	V323= CMPcdddr(CMPcddddr((V323)));
	{object V334;
	V334= CMPcar((V323));
	V323= CMPcdr((V323));
	V328= (V334);}
	(void)(((V325))->v.v_self[1]= ((V328)));
	V323= CMPcdddr((V323));
	{object V335;
	V335= CMPcar((V323));
	V323= CMPcdr((V323));
	V328= (V335);}
	(void)(((V325))->v.v_self[6]= ((V328)));
	if(!((((V325))->v.v_self[0])==(VV[31]))){
	goto T1359;}
	V328= Cnil;
	(void)(((V325))->v.v_self[0]= ((V328)));
	goto T1359;
T1359:;
	if(!((((V325))->v.v_self[2])==(VV[31]))){
	goto T1364;}
	V328= Cnil;
	(void)(((V325))->v.v_self[2]= ((V328)));
	goto T1364;
T1364:;
	if(!((((V325))->v.v_self[5])==(VV[31]))){
	goto T1298;}
	V328= Cnil;
	(void)(((V325))->v.v_self[5]= ((V328)));}
	goto T1298;
T1298:;
	base[2]= (V322);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC86(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM89; VC89
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC123,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC123(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM90; VC90
	vs_check;
	{register object V336;
	object V337;
	check_arg(2);
	V336=(base[0]);
	V337=(base[1]);
	vs_top=sup;
	{register object V338;
	object V339;
	register object V340;
	register object V341;
	object V342;
	register object V343;
	V339= CMPcar((base0[1]->c.c_car));
	V338= (V337);
	V340= Cnil;
	V341= Cnil;
	V342= Cnil;
	V343= Cnil;
	if(type_of(V336)==t_structure){
	goto T1385;}
	goto T1383;
	goto T1385;
T1385:;
	if(!(((V336)->str.str_def)==(VV[139]))){
	goto T1383;}
	V340= STREF(object,(V336),4);
	V341= STREF(object,(V336),0);
	goto T1381;
	goto T1383;
T1383:;{object V345;
	V345= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V336);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V346= vs_base[0];
	if(!((V345)==(CMPcar(V346)))){
	goto T1391;}}
	V340= CMPcar(((V336))->cc.cc_turbo[12]);
	V341= CMPcar(((V336))->cc.cc_turbo[13]);
	goto T1381;
	goto T1391;
T1391:;
	V341= (*(LnkLI255))((V336));
	goto T1381;
T1381:;
	V342= ((V341))->v.v_self[11];
	V338= CMPcdddr((V338));
	{object V347;
	V347= CMPcar((V338));
	V338= CMPcdr((V338));
	V343= (V347);}
	(void)(((V340))->v.v_self[4]= ((V343)));
	V338= CMPcdr((V338));
	{object V348;
	V348= CMPcar((V338));
	V338= CMPcdr((V338));
	V343= (V348);}
	(void)(((V340))->v.v_self[3]= ((V343)));
	V338= CMPcdddr(CMPcddddr((V338)));
	{object V349;
	V349= CMPcar((V338));
	V338= CMPcdr((V338));
	V343= (V349);}
	(void)(((V340))->v.v_self[5]= ((V343)));
	if(!((((V340))->v.v_self[0])==(VV[31]))){
	goto T1426;}
	V343= Cnil;
	(void)(((V340))->v.v_self[0]= ((V343)));
	goto T1426;
T1426:;
	if(!((((V340))->v.v_self[1])==(VV[31]))){
	goto T1431;}
	V343= (
	V350 = ((base0[0]->c.c_car))->v.v_self[5],
	(type_of(V350) == t_sfun ?(*((V350)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V350)==t_vfun) ?
	(*((V350)->sfn.sfn_self)):
	(fcall.fun=(V350),fcalln))());
	(void)(((V340))->v.v_self[1]= ((V343)));
	goto T1431;
T1431:;
	if(!((((V340))->v.v_self[2])==(VV[31]))){
	goto T1436;}
	V343= Cnil;
	(void)(((V340))->v.v_self[2]= ((V343)));
	goto T1436;
T1436:;
	if(!((((V340))->v.v_self[6])==(VV[31]))){
	goto T1373;}
	V343= Cnil;
	(void)(((V340))->v.v_self[6]= ((V343)));}
	goto T1373;
T1373:;
	base[2]= (V337);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC85(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM91; VC91
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC124,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC124(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM92; VC92
	vs_check;
	{register object V351;
	object V352;
	check_arg(2);
	V351=(base[0]);
	V352=(base[1]);
	vs_top=sup;
	{register object V353;
	object V354;
	register object V355;
	register object V356;
	object V357;
	register object V358;
	V354= CMPcar((base0[1]->c.c_car));
	V353= (V352);
	V355= Cnil;
	V356= Cnil;
	V357= Cnil;
	V358= Cnil;
	if(type_of(V351)==t_structure){
	goto T1457;}
	goto T1455;
	goto T1457;
T1457:;
	if(!(((V351)->str.str_def)==(VV[136]))){
	goto T1455;}
	V355= STREF(object,(V351),4);
	V356= STREF(object,(V351),0);
	goto T1453;
	goto T1455;
T1455:;{object V360;
	V360= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V351);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V361= vs_base[0];
	if(!((V360)==(CMPcar(V361)))){
	goto T1463;}}
	V355= CMPcar(((V351))->cc.cc_turbo[12]);
	V356= CMPcar(((V351))->cc.cc_turbo[13]);
	goto T1453;
	goto T1463;
T1463:;
	V356= (*(LnkLI255))((V351));
	goto T1453;
T1453:;
	V357= ((V356))->v.v_self[11];
	V353= CMPcdddr((V353));
	{object V362;
	V362= CMPcar((V353));
	V353= CMPcdr((V353));
	V358= (V362);}
	(void)(((V355))->v.v_self[4]= ((V358)));
	V353= CMPcdr((V353));
	{object V363;
	V363= CMPcar((V353));
	V353= CMPcdr((V353));
	V358= (V363);}
	(void)(((V355))->v.v_self[3]= ((V358)));
	V353= CMPcdddr((V353));
	{object V364;
	V364= CMPcar((V353));
	V353= CMPcdr((V353));
	V358= (V364);}
	(void)(((V355))->v.v_self[7]= ((V358)));
	V353= CMPcdr(CMPcddddr((V353)));
	{object V365;
	V365= CMPcar((V353));
	V353= CMPcdr((V353));
	V358= (V365);}
	(void)(((V355))->v.v_self[6]= ((V358)));
	if(!((((V355))->v.v_self[0])==(VV[31]))){
	goto T1506;}
	V358= Cnil;
	(void)(((V355))->v.v_self[0]= ((V358)));
	goto T1506;
T1506:;
	if(!((((V355))->v.v_self[1])==(VV[31]))){
	goto T1511;}
	V358= (
	V366 = ((base0[0]->c.c_car))->v.v_self[6],
	(type_of(V366) == t_sfun ?(*((V366)->sfn.sfn_self)):
	(fcall.argd=0,type_of(V366)==t_vfun) ?
	(*((V366)->sfn.sfn_self)):
	(fcall.fun=(V366),fcalln))());
	(void)(((V355))->v.v_self[1]= ((V358)));
	goto T1511;
T1511:;
	if(!((((V355))->v.v_self[2])==(VV[31]))){
	goto T1516;}
	V358= Cnil;
	(void)(((V355))->v.v_self[2]= ((V358)));
	goto T1516;
T1516:;
	if(!((((V355))->v.v_self[5])==(VV[31]))){
	goto T1521;}
	V358= Cnil;
	(void)(((V355))->v.v_self[5]= ((V358)));
	goto T1521;
T1521:;
	if(!((((V355))->v.v_self[8])==(VV[31]))){
	goto T1445;}
	V358= Cnil;
	(void)(((V355))->v.v_self[8]= ((V358)));}
	goto T1445;
T1445:;
	base[2]= (V352);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC84(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM93; VC93
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC125,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC125(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM94; VC94
	vs_check;
	{register object V367;
	register object V368;
	check_arg(2);
	V367=(base[0]);
	V368=(base[1]);
	vs_top=sup;
	{object V369;
	object V370;
	object V371;
	register object V372;
	object V373;
	V370= CMPcar((base0[1]->c.c_car));
	V369= (V368);
	V371= Cnil;
	V372= Cnil;
	V373= Cnil;
	if(type_of(V367)==t_structure){
	goto T1542;}
	goto T1540;
	goto T1542;
T1542:;
	if(!(((V367)->str.str_def)==(VV[130]))){
	goto T1540;}
	V371= STREF(object,(V367),4);
	V372= STREF(object,(V367),0);
	goto T1538;
	goto T1540;
T1540:;{object V376;
	V376= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V367);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V377= vs_base[0];
	if(!((V376)==(CMPcar(V377)))){
	goto T1548;}}
	V371= CMPcar(((V367))->cc.cc_turbo[12]);
	V372= CMPcar(((V367))->cc.cc_turbo[13]);
	goto T1538;
	goto T1548;
T1548:;
	V372= (*(LnkLI255))((V367));
	goto T1538;
T1538:;
	V373= ((V372))->v.v_self[11];
	if(!(type_of((V368))==t_cons)){
	goto T1559;}
	V368= make_cons(CMPcar((V368)),CMPcdr((V368)));
	goto T1559;
T1559:;
	(VV[131]->s.s_dbind)= ((base0[0]->c.c_car))->v.v_self[0];
	(VV[132]->s.s_dbind)= (V368);
	(VV[133]->s.s_dbind)= ((base0[0]->c.c_car))->v.v_self[1];
	V369= (V368);}
	base[2]= (V368);
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC83(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM95; VC95
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC126,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC126(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM96; VC96
	vs_check;
	{register object V378;
	check_arg(1);
	V378=(base[0]);
	vs_top=sup;
	{long V379;
	object V380;
	long V381;
	long V382;
	object V383;
	register object V384;
	V379= (long)STREF(unsigned char,(base0[2]->c.c_car),16);
	V380= STREF(object,(base0[2]->c.c_car),40);
	V381= (long)STREF(fixnum,(base0[2]->c.c_car),24);
	V382= (long)STREF(fixnum,(base0[2]->c.c_car),28);
	V383= STREF(object,(base0[2]->c.c_car),44);
	if(type_of(V378)==t_structure){
	goto T1581;}
	goto T1579;
	goto T1581;
T1581:;
	if(!(((V378)->str.str_def)==(VV[126]))){
	goto T1579;}
	V384= STREF(object,(V378),0);
	goto T1577;
	goto T1579;
T1579:;{object V386;
	V386= (VV[30]->s.s_dbind);
	base[1]= small_fixnum(14);
	base[2]= (V378);
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V387= vs_base[0];
	if(!((V386)==(CMPcar(V387)))){
	goto T1584;}}
	V384= CMPcar(((V378))->cc.cc_turbo[13]);
	goto T1577;
	goto T1584;
T1584:;
	if(!(type_of((V378))==t_structure)){
	goto T1590;}
	V384= (*(LnkLI256))((V378));
	goto T1577;
	goto T1590;
T1590:;
	if(!(type_of((V378))==t_symbol)){
	goto T1593;}
	if(((V378))==Cnil){
	goto T1596;}
	V384= (VV[44]->s.s_dbind);
	goto T1577;
	goto T1596;
T1596:;
	V384= (VV[45]->s.s_dbind);
	goto T1577;
	goto T1593;
T1593:;
	V384= (*(LnkLI257))((V378));
	goto T1577;
T1577:;
	{register long V388;
	register long V389;
	{long V390;
	V390= fix(((V384))->v.v_self[V379]);
	if(!((V390)==0)){
	goto T1601;}
	goto T1571;
	goto T1601;
T1601:;
	V388= (long)((V381) & (V390));}
	V389= V388;
	goto T1606;
T1606:;
	if(!(((V384))==(((V380))->v.v_self[V389]))){
	goto T1608;}
	goto T1598;
	goto T1608;
T1608:;
	V389= (long)(V389)+(1);
	if(!((V389)==(V382))){
	goto T1613;}
	V389= 0;
	goto T1613;
T1613:;
	if(!((V389)==(V388))){
	goto T1607;}
	{register object V391;
	register object V392;
	V391= (V383);
	V392= CMPcar((V391));
	goto T1623;
T1623:;
	if(!(((V391))==Cnil)){
	goto T1624;}
	goto T1619;
	goto T1624;
T1624:;
	if(!((CMPcar((V392)))==((V384)))){
	goto T1628;}
	goto T1598;
	goto T1628;
T1628:;
	V391= CMPcdr((V391));
	V392= CMPcar((V391));
	goto T1623;}
	goto T1619;
T1619:;
	goto T1571;
	goto T1607;
T1607:;
	goto T1606;}
	goto T1598;
T1598:;
	base[1]= (base0[1]->c.c_car);
	base[2]= VV[2];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1639;}
	base[1]= STREF(object,(base0[1]->c.c_car),0);
	base[2]= STREF(object,(base0[1]->c.c_car),4);
	base[3]= STREF(object,(base0[1]->c.c_car),8);
	base[4]= (V378);
	vs_top=(vs_base=base+2)+3;
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1639;
T1639:;
	if(!(type_of((base0[1]->c.c_car))==t_fixnum)){
	goto T1648;}
	{object V393;
	object V394;
	if(type_of(V378)==t_structure){
	goto T1654;}
	goto T1652;
	goto T1654;
T1654:;
	if(!(((V378)->str.str_def)==(VV[127]))){
	goto T1652;}
	V393= STREF(object,(V378),4);
	goto T1650;
	goto T1652;
T1652:;{object V396;
	V396= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V378);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V397= vs_base[0];
	if(!((V396)==(CMPcar(V397)))){
	goto T1657;}}
	V393= CMPcar(((V378))->cc.cc_turbo[12]);
	goto T1650;
	goto T1657;
T1657:;
	V393= Cnil;
	goto T1650;
T1650:;
	if(((V393))==Cnil){
	goto T1664;}
	V394= ((V393))->v.v_self[fix((base0[1]->c.c_car))];
	goto T1662;
	goto T1664;
T1664:;
	V394= Cnil;
	goto T1662;
T1662:;
	if(!(((V394))==(VV[31]))){
	goto T1667;}
	base[3]= (V378);
	base[4]= (base0[1]->c.c_car);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk259)();
	return;
	goto T1667;
T1667:;
	base[3]= (V394);
	vs_top=(vs_base=base+3)+1;
	return;}
	goto T1648;
T1648:;
	{object V398;
	V398= (base0[1]->c.c_car);
	base[1]= (V398);
	base[2]= VV[10];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1672;}
	{object V399;
	object V400;
	object V401;
	V399= STREF(object,(base0[1]->c.c_car),0);
	V400= make_cons((V378),Cnil);
	V401= STREF(object,(base0[1]->c.c_car),4);
	if(((V401))==Cnil){
	goto T1680;}
	if((CMPcdr((V401)))!=Cnil){
	goto T1680;}
	base[1]= (V400);
	base[2]= CMPcar((V401));
	vs_top=(vs_base=base+1)+2;
	{object _funobj = (V399);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1680;
T1680:;
	base[1]= (V399);
	base[2]= (V400);
	{object V402;
	V402= (V401);
	 vs_top=base+3;
	 while(V402!=Cnil)
	 {vs_push((V402)->c.c_car);V402=(V402)->c.c_cdr;}
	vs_base=base+2;}
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T1672;
T1672:;
	base[1]= (V398);
	vs_top=(vs_base=base+1)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1690;}
	base[1]= (V378);
	vs_top=(vs_base=base+1)+1;
	{object _funobj = (base0[1]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1690;
T1690:;
	base[2]= VV[11];
	base[3]= (V398);
	base[4]= VV[128];
	vs_top=(vs_base=base+2)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[1]= vs_base[0];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	return;}}
	goto T1571;
T1571:;
	base[1]= (V378);
	vs_top=(vs_base=base+1)+1;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[1]= Cnil;
	vs_top=(vs_base=base+1)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC82(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM97; VC97
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC127,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC127(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM98; VC98
	vs_check;
	{register object V403;
	register object V404;
	if(vs_top-vs_base<1) too_few_arguments();
	V403=(base[0]);
	vs_base=vs_base+1;
	vs_top[0]=Cnil;
	{object *p=vs_top;
	 for(;p>vs_base;p--)p[-1]=MMcons(p[-1],p[0]);}
	V404=(base[1]);
	vs_top=sup;
	{long V405;
	object V406;
	long V407;
	long V408;
	object V409;
	register object V410;
	V405= (long)STREF(unsigned char,(base0[2]->c.c_car),16);
	V406= STREF(object,(base0[2]->c.c_car),40);
	V407= (long)STREF(fixnum,(base0[2]->c.c_car),24);
	V408= (long)STREF(fixnum,(base0[2]->c.c_car),28);
	V409= STREF(object,(base0[2]->c.c_car),44);
	if(type_of(V403)==t_structure){
	goto T1711;}
	goto T1709;
	goto T1711;
T1711:;
	if(!(((V403)->str.str_def)==(VV[123]))){
	goto T1709;}
	V410= STREF(object,(V403),0);
	goto T1707;
	goto T1709;
T1709:;{object V412;
	V412= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V403);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V413= vs_base[0];
	if(!((V412)==(CMPcar(V413)))){
	goto T1714;}}
	V410= CMPcar(((V403))->cc.cc_turbo[13]);
	goto T1707;
	goto T1714;
T1714:;
	if(!(type_of((V403))==t_structure)){
	goto T1720;}
	V410= (*(LnkLI256))((V403));
	goto T1707;
	goto T1720;
T1720:;
	if(!(type_of((V403))==t_symbol)){
	goto T1723;}
	if(((V403))==Cnil){
	goto T1726;}
	V410= (VV[44]->s.s_dbind);
	goto T1707;
	goto T1726;
T1726:;
	V410= (VV[45]->s.s_dbind);
	goto T1707;
	goto T1723;
T1723:;
	V410= (*(LnkLI257))((V403));
	goto T1707;
T1707:;
	{long V414;
	register long V415;
	{long V416;
	V416= fix(((V410))->v.v_self[V405]);
	if(!((V416)==0)){
	goto T1731;}
	goto T1701;
	goto T1731;
T1731:;
	V414= (long)((V407) & (V416));}
	V415= V414;
	goto T1736;
T1736:;
	if(!(((V410))==(((V406))->v.v_self[V415]))){
	goto T1738;}
	goto T1728;
	goto T1738;
T1738:;
	V415= (long)(V415)+(1);
	if(!((V415)==(V408))){
	goto T1743;}
	V415= 0;
	goto T1743;
T1743:;
	if(!((V415)==(V414))){
	goto T1737;}
	{register object V417;
	register object V418;
	V417= (V409);
	V418= CMPcar((V417));
	goto T1753;
T1753:;
	if(!(((V417))==Cnil)){
	goto T1754;}
	goto T1749;
	goto T1754;
T1754:;
	if(!((CMPcar((V418)))==((V410)))){
	goto T1758;}
	goto T1728;
	goto T1758;
T1758:;
	V417= CMPcdr((V417));
	V418= CMPcar((V417));
	goto T1753;}
	goto T1749;
T1749:;
	goto T1701;
	goto T1737;
T1737:;
	goto T1736;}
	goto T1728;
T1728:;
	base[2]= (base0[1]->c.c_car);
	base[3]= VV[2];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1769;}
	base[2]= STREF(object,(base0[1]->c.c_car),0);
	base[3]= STREF(object,(base0[1]->c.c_car),4);
	base[4]= STREF(object,(base0[1]->c.c_car),8);
	base[5]= (V403);
	base[6]= (V404);
	vs_top=(vs_base=base+3)+4;
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1769;
T1769:;
	{object V419;
	V419= (base0[1]->c.c_car);
	base[2]= (V419);
	base[3]= VV[10];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1779;}
	{object V420;
	object V421;
	object V422;
	V420= STREF(object,(base0[1]->c.c_car),0);
	V421= make_cons((V403),(V404));
	V422= STREF(object,(base0[1]->c.c_car),4);
	if(((V422))==Cnil){
	goto T1787;}
	if((CMPcdr((V422)))!=Cnil){
	goto T1787;}
	base[2]= (V421);
	base[3]= CMPcar((V422));
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V420);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1787;
T1787:;
	base[2]= (V420);
	base[3]= (V421);
	{object V423;
	V423= (V422);
	 vs_top=base+4;
	 while(V423!=Cnil)
	 {vs_push((V423)->c.c_car);V423=(V423)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T1779;
T1779:;
	base[2]= (V419);
	vs_top=(vs_base=base+2)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1797;}
	base[2]= (base0[1]->c.c_car);
	base[3]= (V403);
	{object V424;
	V424= (V404);
	 vs_top=base+4;
	 while(V424!=Cnil)
	 {vs_push((V424)->c.c_car);V424=(V424)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1797;
T1797:;
	base[3]= VV[11];
	base[4]= (V419);
	base[5]= VV[124];
	vs_top=(vs_base=base+3)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	return;}}
	goto T1701;
T1701:;
	base[2]= (base0[0]->c.c_car);
	base[3]= (V403);
	{object V425;
	V425= (V404);
	 vs_top=base+4;
	 while(V425!=Cnil)
	 {vs_push((V425)->c.c_car);V425=(V425)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC81(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM99; VC99
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC128,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC128(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM100; VC100
	vs_check;
	{register object V426;
	register object V427;
	check_arg(2);
	V426=(base[0]);
	V427=(base[1]);
	vs_top=sup;
	{long V428;
	object V429;
	long V430;
	long V431;
	object V432;
	register object V433;
	V428= (long)STREF(unsigned char,(base0[2]->c.c_car),16);
	V429= STREF(object,(base0[2]->c.c_car),40);
	V430= (long)STREF(fixnum,(base0[2]->c.c_car),24);
	V431= (long)STREF(fixnum,(base0[2]->c.c_car),28);
	V432= STREF(object,(base0[2]->c.c_car),44);
	if(type_of(V426)==t_structure){
	goto T1822;}
	goto T1820;
	goto T1822;
T1822:;
	if(!(((V426)->str.str_def)==(VV[119]))){
	goto T1820;}
	V433= STREF(object,(V426),0);
	goto T1818;
	goto T1820;
T1820:;{object V435;
	V435= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V426);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V436= vs_base[0];
	if(!((V435)==(CMPcar(V436)))){
	goto T1825;}}
	V433= CMPcar(((V426))->cc.cc_turbo[13]);
	goto T1818;
	goto T1825;
T1825:;
	if(!(type_of((V426))==t_structure)){
	goto T1831;}
	V433= (*(LnkLI256))((V426));
	goto T1818;
	goto T1831;
T1831:;
	if(!(type_of((V426))==t_symbol)){
	goto T1834;}
	if(((V426))==Cnil){
	goto T1837;}
	V433= (VV[44]->s.s_dbind);
	goto T1818;
	goto T1837;
T1837:;
	V433= (VV[45]->s.s_dbind);
	goto T1818;
	goto T1834;
T1834:;
	V433= (*(LnkLI257))((V426));
	goto T1818;
T1818:;
	{long V437;
	register long V438;
	{long V439;
	V439= fix(((V433))->v.v_self[V428]);
	if(!((V439)==0)){
	goto T1842;}
	goto T1812;
	goto T1842;
T1842:;
	V437= (long)((V430) & (V439));}
	V438= V437;
	goto T1847;
T1847:;
	if(!(((V433))==(((V429))->v.v_self[V438]))){
	goto T1849;}
	goto T1839;
	goto T1849;
T1849:;
	V438= (long)(V438)+(1);
	if(!((V438)==(V431))){
	goto T1854;}
	V438= 0;
	goto T1854;
T1854:;
	if(!((V438)==(V437))){
	goto T1848;}
	{register object V440;
	register object V441;
	V440= (V432);
	V441= CMPcar((V440));
	goto T1864;
T1864:;
	if(!(((V440))==Cnil)){
	goto T1865;}
	goto T1860;
	goto T1865;
T1865:;
	if(!((CMPcar((V441)))==((V433)))){
	goto T1869;}
	goto T1839;
	goto T1869;
T1869:;
	V440= CMPcdr((V440));
	V441= CMPcar((V440));
	goto T1864;}
	goto T1860;
T1860:;
	goto T1812;
	goto T1848;
T1848:;
	goto T1847;}
	goto T1839;
T1839:;
	base[2]= (base0[1]->c.c_car);
	base[3]= VV[2];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1880;}
	base[2]= STREF(object,(base0[1]->c.c_car),0);
	base[3]= STREF(object,(base0[1]->c.c_car),4);
	base[4]= STREF(object,(base0[1]->c.c_car),8);
	base[5]= (V426);
	base[6]= (V427);
	vs_top=(vs_base=base+3)+4;
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1880;
T1880:;
	if(!(type_of((base0[1]->c.c_car))==t_fixnum)){
	goto T1890;}
	{object V443;
	if(type_of(V426)==t_structure){
	goto T1896;}
	goto T1894;
	goto T1896;
T1896:;
	if(!(((V426)->str.str_def)==(VV[120]))){
	goto T1894;}
	V443= STREF(object,(V426),4);
	goto T1892;
	goto T1894;
T1894:;{object V445;
	V445= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V426);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V446= vs_base[0];
	if(!((V445)==(CMPcar(V446)))){
	goto T1899;}}
	V443= CMPcar(((V426))->cc.cc_turbo[12]);
	goto T1892;
	goto T1899;
T1899:;
	V443= Cnil;
	goto T1892;
T1892:;
	if(((V443))==Cnil){
	goto T1905;}
	base[2]= ((V443))->v.v_self[fix((base0[1]->c.c_car))]= (V426);
	vs_top=(vs_base=base+2)+1;
	return;
	goto T1905;
T1905:;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	goto T1890;
T1890:;
	{object V447;
	V447= (base0[1]->c.c_car);
	base[2]= (V447);
	base[3]= VV[10];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1908;}
	{object V448;
	object V449;
	object V450;
	V448= STREF(object,(base0[1]->c.c_car),0);
	V449= list(2,(V426),(V427));
	V450= STREF(object,(base0[1]->c.c_car),4);
	if(((V450))==Cnil){
	goto T1916;}
	if((CMPcdr((V450)))!=Cnil){
	goto T1916;}
	base[2]= (V449);
	base[3]= CMPcar((V450));
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V448);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1916;
T1916:;
	base[2]= (V448);
	base[3]= (V449);
	{object V451;
	V451= (V450);
	 vs_top=base+4;
	 while(V451!=Cnil)
	 {vs_push((V451)->c.c_car);V451=(V451)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T1908;
T1908:;
	base[2]= (V447);
	vs_top=(vs_base=base+2)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T1926;}
	base[2]= (V426);
	base[3]= (V427);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (base0[1]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T1926;
T1926:;
	base[3]= VV[11];
	base[4]= (V447);
	base[5]= VV[121];
	vs_top=(vs_base=base+3)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	return;}}
	goto T1812;
T1812:;
	base[2]= (V426);
	base[3]= (V427);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC80(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM101; VC101
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC129,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC129(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM102; VC102
	vs_check;
	{object V452;
	object V453;
	check_arg(2);
	V452=(base[0]);
	V453=(base[1]);
	vs_top=sup;
	{long V454;
	object V455;
	long V456;
	long V457;
	object V458;
	object V459;
	object V460;
	V454= (long)STREF(unsigned char,(base0[2]->c.c_car),16);
	V455= STREF(object,(base0[2]->c.c_car),40);
	V456= (long)STREF(fixnum,(base0[2]->c.c_car),24);
	V457= (long)STREF(fixnum,(base0[2]->c.c_car),28);
	V458= STREF(object,(base0[2]->c.c_car),44);
	if(type_of(V452)==t_structure){
	goto T1949;}
	goto T1947;
	goto T1949;
T1949:;
	if(!(((V452)->str.str_def)==(VV[114]))){
	goto T1947;}
	V459= STREF(object,(V452),0);
	goto T1945;
	goto T1947;
T1947:;{object V462;
	V462= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V452);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V463= vs_base[0];
	if(!((V462)==(CMPcar(V463)))){
	goto T1952;}}
	V459= CMPcar(((V452))->cc.cc_turbo[13]);
	goto T1945;
	goto T1952;
T1952:;
	if(!(type_of((V452))==t_structure)){
	goto T1958;}
	V459= (*(LnkLI256))((V452));
	goto T1945;
	goto T1958;
T1958:;
	if(!(type_of((V452))==t_symbol)){
	goto T1961;}
	if(((V452))==Cnil){
	goto T1964;}
	V459= (VV[44]->s.s_dbind);
	goto T1945;
	goto T1964;
T1964:;
	V459= (VV[45]->s.s_dbind);
	goto T1945;
	goto T1961;
T1961:;
	V459= (*(LnkLI257))((V452));
	goto T1945;
T1945:;
	if(type_of(V453)==t_structure){
	goto T1970;}
	goto T1968;
	goto T1970;
T1970:;
	if(!(((V453)->str.str_def)==(VV[115]))){
	goto T1968;}
	V460= STREF(object,(V453),0);
	goto T1966;
	goto T1968;
T1968:;{object V465;
	V465= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V453);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V466= vs_base[0];
	if(!((V465)==(CMPcar(V466)))){
	goto T1973;}}
	V460= CMPcar(((V453))->cc.cc_turbo[13]);
	goto T1966;
	goto T1973;
T1973:;
	if(!(type_of((V453))==t_structure)){
	goto T1979;}
	V460= (*(LnkLI256))((V453));
	goto T1966;
	goto T1979;
T1979:;
	if(!(type_of((V453))==t_symbol)){
	goto T1982;}
	if(((V453))==Cnil){
	goto T1985;}
	V460= (VV[44]->s.s_dbind);
	goto T1966;
	goto T1985;
T1985:;
	V460= (VV[45]->s.s_dbind);
	goto T1966;
	goto T1982;
T1982:;
	V460= (*(LnkLI257))((V453));
	goto T1966;
T1966:;
	{long V467;
	long V468;
	V467= 0;
	V468= (long)(V457)-(1);
	{long V469;
	V469= fix(((V459))->v.v_self[V454]);
	if(!((V469)==0)){
	goto T1993;}
	goto T1939;
	goto T1993;
T1993:;
	V467= (long)(V467)+(V469);}
	{long V470;
	V470= fix(((V460))->v.v_self[V454]);
	if(!((V470)==0)){
	goto T1998;}
	goto T1939;
	goto T1998;
T1998:;
	V467= (long)(V467)+(V470);
	V467= (long)((V467) & (V456));}
	{long V471;
	{object V472;
	V472= ((V455))->v.v_self[0];
	if(type_of((V472))==t_fixnum){
	goto T2006;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T2006;
T2006:;
	V471= fix((V472));}
	{register long V473;
	long V474;
	V473= V467;
	V474= 0;
	goto T2014;
T2014:;
	V474= (long)(V473)+(2);
	V473= (long)(V473)+(1);
	if(!(((V459))==(((V455))->v.v_self[V473]))){
	goto T2018;}
	V473= (long)(V473)+(1);
	if(!(((V460))==(((V455))->v.v_self[V473]))){
	goto T2018;}
	goto T2012;
	goto T2018;
T2018:;
	V473= V474;
	if(!((V473)==(V468))){
	goto T2027;}
	V473= 0;
	goto T2027;
T2027:;
	if(!((V473)==(V467))){
	goto T2015;}
	{register object V475;
	register object V476;
	V475= (V458);
	V476= CMPcar((V475));
	goto T2037;
T2037:;
	if(!(((V475))==Cnil)){
	goto T2038;}
	goto T2033;
	goto T2038;
T2038:;
	{register object V477;
	V477= CMPcar((V476));
	{register object V479;
	V479= CMPcar((V477));
	V477= CMPcdr((V477));
	V478= (V479);}
	if(!(((V459))==(V478))){
	goto T2042;}
	{register object V481;
	V481= CMPcar((V477));
	V477= CMPcdr((V477));
	V480= (V481);}
	if(!(((V460))==(V480))){
	goto T2042;}
	goto T2012;}
	goto T2042;
T2042:;
	V475= CMPcdr((V475));
	V476= CMPcar((V475));
	goto T2037;}
	goto T2033;
T2033:;
	goto T1939;
	goto T2015;
T2015:;
	goto T2014;
	goto T2012;
T2012:;
	{object V483;
	V483= ((V455))->v.v_self[0];
	if(type_of((V483))==t_fixnum){
	goto T2066;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T2066;
T2066:;
	V482= fix((V483));}
	if((V471)==(V482)){
	goto T1987;}
	goto T1939;}}}
	goto T1987;
T1987:;
	base[2]= (base0[1]->c.c_car);
	base[3]= VV[2];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2072;}
	base[2]= STREF(object,(base0[1]->c.c_car),0);
	base[3]= STREF(object,(base0[1]->c.c_car),4);
	base[4]= STREF(object,(base0[1]->c.c_car),8);
	base[5]= (V452);
	base[6]= (V453);
	vs_top=(vs_base=base+3)+4;
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2072;
T2072:;
	if(!(type_of((base0[1]->c.c_car))==t_fixnum)){
	goto T2082;}
	{object V485;
	if(type_of(V452)==t_structure){
	goto T2088;}
	goto T2086;
	goto T2088;
T2088:;
	if(!(((V452)->str.str_def)==(VV[116]))){
	goto T2086;}
	V485= STREF(object,(V452),4);
	goto T2084;
	goto T2086;
T2086:;{object V487;
	V487= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V452);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V488= vs_base[0];
	if(!((V487)==(CMPcar(V488)))){
	goto T2091;}}
	V485= CMPcar(((V452))->cc.cc_turbo[12]);
	goto T2084;
	goto T2091;
T2091:;
	V485= Cnil;
	goto T2084;
T2084:;
	if(((V485))==Cnil){
	goto T2097;}
	base[2]= ((V485))->v.v_self[fix((base0[1]->c.c_car))]= (V452);
	vs_top=(vs_base=base+2)+1;
	return;
	goto T2097;
T2097:;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	goto T2082;
T2082:;
	{object V489;
	V489= (base0[1]->c.c_car);
	base[2]= (V489);
	base[3]= VV[10];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2100;}
	{object V490;
	object V491;
	object V492;
	V490= STREF(object,(base0[1]->c.c_car),0);
	V491= list(2,(V452),(V453));
	V492= STREF(object,(base0[1]->c.c_car),4);
	if(((V492))==Cnil){
	goto T2108;}
	if((CMPcdr((V492)))!=Cnil){
	goto T2108;}
	base[2]= (V491);
	base[3]= CMPcar((V492));
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V490);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2108;
T2108:;
	base[2]= (V490);
	base[3]= (V491);
	{object V493;
	V493= (V492);
	 vs_top=base+4;
	 while(V493!=Cnil)
	 {vs_push((V493)->c.c_car);V493=(V493)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T2100;
T2100:;
	base[2]= (V489);
	vs_top=(vs_base=base+2)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2118;}
	base[2]= (V452);
	base[3]= (V453);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (base0[1]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2118;
T2118:;
	base[3]= VV[11];
	base[4]= (V489);
	base[5]= VV[117];
	vs_top=(vs_base=base+3)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	return;}}
	goto T1939;
T1939:;
	base[2]= (V452);
	base[3]= (V453);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC79(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM103; VC103
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC130,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC130(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM104; VC104
	vs_check;
	{register object V494;
	register object V495;
	register object V496;
	check_arg(3);
	V494=(base[0]);
	V495=(base[1]);
	V496=(base[2]);
	vs_top=sup;
	{long V497;
	object V498;
	long V499;
	long V500;
	object V501;
	register object V502;
	V497= (long)STREF(unsigned char,(base0[2]->c.c_car),16);
	V498= STREF(object,(base0[2]->c.c_car),40);
	V499= (long)STREF(fixnum,(base0[2]->c.c_car),24);
	V500= (long)STREF(fixnum,(base0[2]->c.c_car),28);
	V501= STREF(object,(base0[2]->c.c_car),44);
	if(type_of(V495)==t_structure){
	goto T2141;}
	goto T2139;
	goto T2141;
T2141:;
	if(!(((V495)->str.str_def)==(VV[111]))){
	goto T2139;}
	V502= STREF(object,(V495),0);
	goto T2137;
	goto T2139;
T2139:;{object V504;
	V504= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V495);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V505= vs_base[0];
	if(!((V504)==(CMPcar(V505)))){
	goto T2144;}}
	V502= CMPcar(((V495))->cc.cc_turbo[13]);
	goto T2137;
	goto T2144;
T2144:;
	if(!(type_of((V495))==t_structure)){
	goto T2150;}
	V502= (*(LnkLI256))((V495));
	goto T2137;
	goto T2150;
T2150:;
	if(!(type_of((V495))==t_symbol)){
	goto T2153;}
	if(((V495))==Cnil){
	goto T2156;}
	V502= (VV[44]->s.s_dbind);
	goto T2137;
	goto T2156;
T2156:;
	V502= (VV[45]->s.s_dbind);
	goto T2137;
	goto T2153;
T2153:;
	V502= (*(LnkLI257))((V495));
	goto T2137;
T2137:;
	{long V506;
	register long V507;
	{long V508;
	V508= fix(((V502))->v.v_self[V497]);
	if(!((V508)==0)){
	goto T2161;}
	goto T2131;
	goto T2161;
T2161:;
	V506= (long)((V499) & (V508));}
	V507= V506;
	goto T2166;
T2166:;
	if(!(((V502))==(((V498))->v.v_self[V507]))){
	goto T2168;}
	goto T2158;
	goto T2168;
T2168:;
	V507= (long)(V507)+(1);
	if(!((V507)==(V500))){
	goto T2173;}
	V507= 0;
	goto T2173;
T2173:;
	if(!((V507)==(V506))){
	goto T2167;}
	{register object V509;
	register object V510;
	V509= (V501);
	V510= CMPcar((V509));
	goto T2183;
T2183:;
	if(!(((V509))==Cnil)){
	goto T2184;}
	goto T2179;
	goto T2184;
T2184:;
	if(!((CMPcar((V510)))==((V502)))){
	goto T2188;}
	goto T2158;
	goto T2188;
T2188:;
	V509= CMPcdr((V509));
	V510= CMPcar((V509));
	goto T2183;}
	goto T2179;
T2179:;
	goto T2131;
	goto T2167;
T2167:;
	goto T2166;}
	goto T2158;
T2158:;
	base[3]= (base0[1]->c.c_car);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2199;}
	base[3]= STREF(object,(base0[1]->c.c_car),0);
	base[4]= STREF(object,(base0[1]->c.c_car),4);
	base[5]= STREF(object,(base0[1]->c.c_car),8);
	base[6]= (V494);
	base[7]= (V495);
	base[8]= (V496);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2199;
T2199:;
	{object V511;
	V511= (base0[1]->c.c_car);
	base[3]= (V511);
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2210;}
	{object V512;
	object V513;
	object V514;
	V512= STREF(object,(base0[1]->c.c_car),0);
	V513= list(3,(V494),(V495),(V496));
	V514= STREF(object,(base0[1]->c.c_car),4);
	if(((V514))==Cnil){
	goto T2218;}
	if((CMPcdr((V514)))!=Cnil){
	goto T2218;}
	base[3]= (V513);
	base[4]= CMPcar((V514));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V512);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2218;
T2218:;
	base[3]= (V512);
	base[4]= (V513);
	{object V515;
	V515= (V514);
	 vs_top=base+5;
	 while(V515!=Cnil)
	 {vs_push((V515)->c.c_car);V515=(V515)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T2210;
T2210:;
	base[3]= (V511);
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2228;}
	base[3]= (V494);
	base[4]= (V495);
	base[5]= (V496);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (base0[1]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2228;
T2228:;
	base[4]= VV[11];
	base[5]= (V511);
	base[6]= VV[112];
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}}
	goto T2131;
T2131:;
	base[3]= (V494);
	base[4]= (V495);
	base[5]= (V496);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[3]= Cnil;
	vs_top=(vs_base=base+3)+1;
	return;
	}
}
/*	local function CLOSURE	*/

static void LC78(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM105; VC105
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC131,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC131(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM106; VC106
	vs_check;
	{object V516;
	check_arg(1);
	V516=(base[0]);
	vs_top=sup;
	{register object V517;
	V517= Cnil;
	{long V518;
	register object V519;
	long V520;
	long V521;
	object V522;
	register object V523;
	V518= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V519= STREF(object,(base0[1]->c.c_car),40);
	V520= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V521= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V522= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V516)==t_structure){
	goto T2253;}
	goto T2251;
	goto T2253;
T2253:;
	if(!(((V516)->str.str_def)==(VV[108]))){
	goto T2251;}
	V523= STREF(object,(V516),0);
	goto T2249;
	goto T2251;
T2251:;{object V525;
	V525= (VV[30]->s.s_dbind);
	base[1]= small_fixnum(14);
	base[2]= (V516);
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V526= vs_base[0];
	if(!((V525)==(CMPcar(V526)))){
	goto T2256;}}
	V523= CMPcar(((V516))->cc.cc_turbo[13]);
	goto T2249;
	goto T2256;
T2256:;
	if(!(type_of((V516))==t_structure)){
	goto T2262;}
	V523= (*(LnkLI256))((V516));
	goto T2249;
	goto T2262;
T2262:;
	if(!(type_of((V516))==t_symbol)){
	goto T2265;}
	if(((V516))==Cnil){
	goto T2268;}
	V523= (VV[44]->s.s_dbind);
	goto T2249;
	goto T2268;
T2268:;
	V523= (VV[45]->s.s_dbind);
	goto T2249;
	goto T2265;
T2265:;
	V523= (*(LnkLI257))((V516));
	goto T2249;
T2249:;
	{long V527;
	long V528;
	{long V529;
	V529= fix(((V523))->v.v_self[V518]);
	if(!((V529)==0)){
	goto T2273;}
	goto T2243;
	goto T2273;
T2273:;
	V527= (long)((V520) & (V529));}
	{object V530;
	V530= ((V519))->v.v_self[0];
	if(type_of((V530))==t_fixnum){
	goto T2278;}
	base[1]= VV[46];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	vs_top=sup;
	goto T2278;
T2278:;
	V528= fix((V530));}
	{register long V531;
	V531= V527;
	goto T2285;
T2285:;
	if(!(((V523))==(((V519))->v.v_self[V531]))){
	goto T2287;}
	V517= ((V519))->v.v_self[(long)(V531)+1];
	goto T2283;
	goto T2287;
T2287:;
	V531= (long)(V531)+(2);
	if(!((V531)==(V521))){
	goto T2294;}
	V531= 0;
	goto T2294;
T2294:;
	if(!((V531)==(V527))){
	goto T2286;}
	{register object V532;
	register object V533;
	V532= (V522);
	V533= CMPcar((V532));
	goto T2304;
T2304:;
	if(!(((V532))==Cnil)){
	goto T2305;}
	goto T2300;
	goto T2305;
T2305:;
	if(!((CMPcar((V533)))==((V523)))){
	goto T2309;}
	V517= CMPcdr((V533));
	goto T2283;
	goto T2309;
T2309:;
	V532= CMPcdr((V532));
	V533= CMPcar((V532));
	goto T2304;}
	goto T2300;
T2300:;
	goto T2243;
	goto T2286;
T2286:;
	goto T2285;
	goto T2283;
T2283:;
	{object V535;
	V535= ((V519))->v.v_self[0];
	if(type_of((V535))==t_fixnum){
	goto T2324;}
	base[1]= VV[46];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	vs_top=sup;
	goto T2324;
T2324:;
	V534= fix((V535));}
	if((V528)==(V534)){
	goto T2270;}
	goto T2243;}}
	goto T2270;
T2270:;
	base[1]= (V517);
	vs_top=(vs_base=base+1)+1;
	return;}
	goto T2243;
T2243:;
	base[1]= (V516);
	vs_top=(vs_base=base+1)+1;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[1]= Cnil;
	vs_top=(vs_base=base+1)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC77(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM107; VC107
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC132,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC132(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM108; VC108
	vs_check;
	{object V536;
	object V537;
	check_arg(2);
	V536=(base[0]);
	V537=(base[1]);
	vs_top=sup;
	{register object V538;
	V538= Cnil;
	{long V539;
	register object V540;
	long V541;
	long V542;
	object V543;
	register object V544;
	V539= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V540= STREF(object,(base0[1]->c.c_car),40);
	V541= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V542= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V543= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V536)==t_structure){
	goto T2341;}
	goto T2339;
	goto T2341;
T2341:;
	if(!(((V536)->str.str_def)==(VV[106]))){
	goto T2339;}
	V544= STREF(object,(V536),0);
	goto T2337;
	goto T2339;
T2339:;{object V546;
	V546= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V536);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V547= vs_base[0];
	if(!((V546)==(CMPcar(V547)))){
	goto T2344;}}
	V544= CMPcar(((V536))->cc.cc_turbo[13]);
	goto T2337;
	goto T2344;
T2344:;
	if(!(type_of((V536))==t_structure)){
	goto T2350;}
	V544= (*(LnkLI256))((V536));
	goto T2337;
	goto T2350;
T2350:;
	if(!(type_of((V536))==t_symbol)){
	goto T2353;}
	if(((V536))==Cnil){
	goto T2356;}
	V544= (VV[44]->s.s_dbind);
	goto T2337;
	goto T2356;
T2356:;
	V544= (VV[45]->s.s_dbind);
	goto T2337;
	goto T2353;
T2353:;
	V544= (*(LnkLI257))((V536));
	goto T2337;
T2337:;
	{long V548;
	long V549;
	{long V550;
	V550= fix(((V544))->v.v_self[V539]);
	if(!((V550)==0)){
	goto T2361;}
	goto T2331;
	goto T2361;
T2361:;
	V548= (long)((V541) & (V550));}
	{object V551;
	V551= ((V540))->v.v_self[0];
	if(type_of((V551))==t_fixnum){
	goto T2366;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T2366;
T2366:;
	V549= fix((V551));}
	{register long V552;
	V552= V548;
	goto T2373;
T2373:;
	if(!(((V544))==(((V540))->v.v_self[V552]))){
	goto T2375;}
	V538= ((V540))->v.v_self[(long)(V552)+1];
	goto T2371;
	goto T2375;
T2375:;
	V552= (long)(V552)+(2);
	if(!((V552)==(V542))){
	goto T2382;}
	V552= 0;
	goto T2382;
T2382:;
	if(!((V552)==(V548))){
	goto T2374;}
	{register object V553;
	register object V554;
	V553= (V543);
	V554= CMPcar((V553));
	goto T2392;
T2392:;
	if(!(((V553))==Cnil)){
	goto T2393;}
	goto T2388;
	goto T2393;
T2393:;
	if(!((CMPcar((V554)))==((V544)))){
	goto T2397;}
	V538= CMPcdr((V554));
	goto T2371;
	goto T2397;
T2397:;
	V553= CMPcdr((V553));
	V554= CMPcar((V553));
	goto T2392;}
	goto T2388;
T2388:;
	goto T2331;
	goto T2374;
T2374:;
	goto T2373;
	goto T2371;
T2371:;
	{object V556;
	V556= ((V540))->v.v_self[0];
	if(type_of((V556))==t_fixnum){
	goto T2412;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T2412;
T2412:;
	V555= fix((V556));}
	if((V549)==(V555)){
	goto T2358;}
	goto T2331;}}
	goto T2358;
T2358:;
	base[2]= (V538);
	vs_top=(vs_base=base+2)+1;
	return;}
	goto T2331;
T2331:;
	base[2]= (V536);
	base[3]= (V537);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC76(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM109; VC109
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC133,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC133(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM110; VC110
	vs_check;
	{object V557;
	object V558;
	if(vs_top-vs_base<1) too_few_arguments();
	V557=(base[0]);
	vs_base=vs_base+1;
	vs_top[0]=Cnil;
	{object *p=vs_top;
	 for(;p>vs_base;p--)p[-1]=MMcons(p[-1],p[0]);}
	V558=(base[1]);
	vs_top=sup;
	{register object V559;
	V559= Cnil;
	{long V560;
	register object V561;
	long V562;
	long V563;
	object V564;
	register object V565;
	V560= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V561= STREF(object,(base0[1]->c.c_car),40);
	V562= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V563= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V564= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V557)==t_structure){
	goto T2430;}
	goto T2428;
	goto T2430;
T2430:;
	if(!(((V557)->str.str_def)==(VV[102]))){
	goto T2428;}
	V565= STREF(object,(V557),0);
	goto T2426;
	goto T2428;
T2428:;{object V567;
	V567= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V557);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V568= vs_base[0];
	if(!((V567)==(CMPcar(V568)))){
	goto T2433;}}
	V565= CMPcar(((V557))->cc.cc_turbo[13]);
	goto T2426;
	goto T2433;
T2433:;
	if(!(type_of((V557))==t_structure)){
	goto T2439;}
	V565= (*(LnkLI256))((V557));
	goto T2426;
	goto T2439;
T2439:;
	if(!(type_of((V557))==t_symbol)){
	goto T2442;}
	if(((V557))==Cnil){
	goto T2445;}
	V565= (VV[44]->s.s_dbind);
	goto T2426;
	goto T2445;
T2445:;
	V565= (VV[45]->s.s_dbind);
	goto T2426;
	goto T2442;
T2442:;
	V565= (*(LnkLI257))((V557));
	goto T2426;
T2426:;
	{long V569;
	long V570;
	{long V571;
	V571= fix(((V565))->v.v_self[V560]);
	if(!((V571)==0)){
	goto T2450;}
	goto T2420;
	goto T2450;
T2450:;
	V569= (long)((V562) & (V571));}
	{object V572;
	V572= ((V561))->v.v_self[0];
	if(type_of((V572))==t_fixnum){
	goto T2455;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T2455;
T2455:;
	V570= fix((V572));}
	{register long V573;
	V573= V569;
	goto T2462;
T2462:;
	if(!(((V565))==(((V561))->v.v_self[V573]))){
	goto T2464;}
	V559= ((V561))->v.v_self[(long)(V573)+1];
	goto T2460;
	goto T2464;
T2464:;
	V573= (long)(V573)+(2);
	if(!((V573)==(V563))){
	goto T2471;}
	V573= 0;
	goto T2471;
T2471:;
	if(!((V573)==(V569))){
	goto T2463;}
	{register object V574;
	register object V575;
	V574= (V564);
	V575= CMPcar((V574));
	goto T2481;
T2481:;
	if(!(((V574))==Cnil)){
	goto T2482;}
	goto T2477;
	goto T2482;
T2482:;
	if(!((CMPcar((V575)))==((V565)))){
	goto T2486;}
	V559= CMPcdr((V575));
	goto T2460;
	goto T2486;
T2486:;
	V574= CMPcdr((V574));
	V575= CMPcar((V574));
	goto T2481;}
	goto T2477;
T2477:;
	goto T2420;
	goto T2463;
T2463:;
	goto T2462;
	goto T2460;
T2460:;
	{object V577;
	V577= ((V561))->v.v_self[0];
	if(type_of((V577))==t_fixnum){
	goto T2501;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T2501;
T2501:;
	V576= fix((V577));}
	if((V570)==(V576)){
	goto T2447;}
	goto T2420;}}
	goto T2447;
T2447:;
	base[2]= (V559);
	base[3]= VV[2];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2507;}
	base[2]= STREF(object,(V559),0);
	base[3]= STREF(object,(V559),4);
	base[4]= STREF(object,(V559),8);
	base[5]= (V557);
	base[6]= (V558);
	vs_top=(vs_base=base+3)+4;
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2507;
T2507:;
	base[2]= V559;
	base[3]= VV[10];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2517;}
	{object V579;
	object V580;
	object V581;
	V579= STREF(object,(V559),0);
	V580= make_cons((V557),(V558));
	V581= STREF(object,(V559),4);
	if(((V581))==Cnil){
	goto T2525;}
	if((CMPcdr((V581)))!=Cnil){
	goto T2525;}
	base[2]= (V580);
	base[3]= CMPcar((V581));
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V579);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2525;
T2525:;
	base[2]= (V579);
	base[3]= (V580);
	{object V582;
	V582= (V581);
	 vs_top=base+4;
	 while(V582!=Cnil)
	 {vs_push((V582)->c.c_car);V582=(V582)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T2517;
T2517:;
	base[2]= V559;
	vs_top=(vs_base=base+2)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2535;}
	base[2]= (V559);
	base[3]= (V557);
	{object V583;
	V583= (V558);
	 vs_top=base+4;
	 while(V583!=Cnil)
	 {vs_push((V583)->c.c_car);V583=(V583)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2535;
T2535:;
	base[3]= VV[11];
	base[4]= V559;
	base[5]= VV[103];
	vs_top=(vs_base=base+3)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	return;}
	goto T2420;
T2420:;
	base[2]= (base0[0]->c.c_car);
	base[3]= (V557);
	{object V584;
	V584= (V558);
	 vs_top=base+4;
	 while(V584!=Cnil)
	 {vs_push((V584)->c.c_car);V584=(V584)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC75(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM111; VC111
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC134,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC134(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM112; VC112
	vs_check;
	{object V585;
	check_arg(1);
	V585=(base[0]);
	vs_top=sup;
	{register object V586;
	V586= Cnil;
	{long V587;
	register object V588;
	long V589;
	long V590;
	object V591;
	register object V592;
	V587= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V588= STREF(object,(base0[1]->c.c_car),40);
	V589= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V590= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V591= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V585)==t_structure){
	goto T2560;}
	goto T2558;
	goto T2560;
T2560:;
	if(!(((V585)->str.str_def)==(VV[98]))){
	goto T2558;}
	V592= STREF(object,(V585),0);
	goto T2556;
	goto T2558;
T2558:;{object V594;
	V594= (VV[30]->s.s_dbind);
	base[1]= small_fixnum(14);
	base[2]= (V585);
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V595= vs_base[0];
	if(!((V594)==(CMPcar(V595)))){
	goto T2563;}}
	V592= CMPcar(((V585))->cc.cc_turbo[13]);
	goto T2556;
	goto T2563;
T2563:;
	if(!(type_of((V585))==t_structure)){
	goto T2569;}
	V592= (*(LnkLI256))((V585));
	goto T2556;
	goto T2569;
T2569:;
	if(!(type_of((V585))==t_symbol)){
	goto T2572;}
	if(((V585))==Cnil){
	goto T2575;}
	V592= (VV[44]->s.s_dbind);
	goto T2556;
	goto T2575;
T2575:;
	V592= (VV[45]->s.s_dbind);
	goto T2556;
	goto T2572;
T2572:;
	V592= (*(LnkLI257))((V585));
	goto T2556;
T2556:;
	{long V596;
	long V597;
	{long V598;
	V598= fix(((V592))->v.v_self[V587]);
	if(!((V598)==0)){
	goto T2580;}
	goto T2550;
	goto T2580;
T2580:;
	V596= (long)((V589) & (V598));}
	{object V599;
	V599= ((V588))->v.v_self[0];
	if(type_of((V599))==t_fixnum){
	goto T2585;}
	base[1]= VV[46];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	vs_top=sup;
	goto T2585;
T2585:;
	V597= fix((V599));}
	{register long V600;
	V600= V596;
	goto T2592;
T2592:;
	if(!(((V592))==(((V588))->v.v_self[V600]))){
	goto T2594;}
	V586= ((V588))->v.v_self[(long)(V600)+1];
	goto T2590;
	goto T2594;
T2594:;
	V600= (long)(V600)+(2);
	if(!((V600)==(V590))){
	goto T2601;}
	V600= 0;
	goto T2601;
T2601:;
	if(!((V600)==(V596))){
	goto T2593;}
	{register object V601;
	register object V602;
	V601= (V591);
	V602= CMPcar((V601));
	goto T2611;
T2611:;
	if(!(((V601))==Cnil)){
	goto T2612;}
	goto T2607;
	goto T2612;
T2612:;
	if(!((CMPcar((V602)))==((V592)))){
	goto T2616;}
	V586= CMPcdr((V602));
	goto T2590;
	goto T2616;
T2616:;
	V601= CMPcdr((V601));
	V602= CMPcar((V601));
	goto T2611;}
	goto T2607;
T2607:;
	goto T2550;
	goto T2593;
T2593:;
	goto T2592;
	goto T2590;
T2590:;
	{object V604;
	V604= ((V588))->v.v_self[0];
	if(type_of((V604))==t_fixnum){
	goto T2631;}
	base[1]= VV[46];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	vs_top=sup;
	goto T2631;
T2631:;
	V603= fix((V604));}
	if((V597)==(V603)){
	goto T2577;}
	goto T2550;}}
	goto T2577;
T2577:;
	base[1]= (V586);
	base[2]= VV[2];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2637;}
	base[1]= STREF(object,(V586),0);
	base[2]= STREF(object,(V586),4);
	base[3]= STREF(object,(V586),8);
	base[4]= (V585);
	vs_top=(vs_base=base+2)+3;
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2637;
T2637:;
	if(!(type_of((V586))==t_fixnum)){
	goto T2646;}
	{object V605;
	object V606;
	if(type_of(V585)==t_structure){
	goto T2652;}
	goto T2650;
	goto T2652;
T2652:;
	if(!(((V585)->str.str_def)==(VV[99]))){
	goto T2650;}
	V605= STREF(object,(V585),4);
	goto T2648;
	goto T2650;
T2650:;{object V608;
	V608= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V585);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V609= vs_base[0];
	if(!((V608)==(CMPcar(V609)))){
	goto T2655;}}
	V605= CMPcar(((V585))->cc.cc_turbo[12]);
	goto T2648;
	goto T2655;
T2655:;
	V605= Cnil;
	goto T2648;
T2648:;
	if(((V605))==Cnil){
	goto T2662;}
	V606= ((V605))->v.v_self[fix((V586))];
	goto T2660;
	goto T2662;
T2662:;
	V606= Cnil;
	goto T2660;
T2660:;
	if(!(((V606))==(VV[31]))){
	goto T2665;}
	base[3]= (V585);
	base[4]= (V586);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk259)();
	return;
	goto T2665;
T2665:;
	base[3]= (V606);
	vs_top=(vs_base=base+3)+1;
	return;}
	goto T2646;
T2646:;
	base[1]= V586;
	base[2]= VV[10];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2670;}
	{object V611;
	object V612;
	object V613;
	V611= STREF(object,(V586),0);
	V612= make_cons((V585),Cnil);
	V613= STREF(object,(V586),4);
	if(((V613))==Cnil){
	goto T2678;}
	if((CMPcdr((V613)))!=Cnil){
	goto T2678;}
	base[1]= (V612);
	base[2]= CMPcar((V613));
	vs_top=(vs_base=base+1)+2;
	{object _funobj = (V611);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2678;
T2678:;
	base[1]= (V611);
	base[2]= (V612);
	{object V614;
	V614= (V613);
	 vs_top=base+3;
	 while(V614!=Cnil)
	 {vs_push((V614)->c.c_car);V614=(V614)->c.c_cdr;}
	vs_base=base+2;}
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T2670;
T2670:;
	base[1]= V586;
	vs_top=(vs_base=base+1)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2688;}
	base[1]= (V585);
	vs_top=(vs_base=base+1)+1;
	{object _funobj = (V586);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2688;
T2688:;
	base[2]= VV[11];
	base[3]= V586;
	base[4]= VV[100];
	vs_top=(vs_base=base+2)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[1]= vs_base[0];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	return;}
	goto T2550;
T2550:;
	base[1]= (V585);
	vs_top=(vs_base=base+1)+1;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[1]= Cnil;
	vs_top=(vs_base=base+1)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC74(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM113; VC113
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC135,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC135(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM114; VC114
	vs_check;
	{object V615;
	object V616;
	object V617;
	if(vs_top-vs_base<2) too_few_arguments();
	V615=(base[0]);
	V616=(base[1]);
	vs_base=vs_base+2;
	vs_top[0]=Cnil;
	{object *p=vs_top;
	 for(;p>vs_base;p--)p[-1]=MMcons(p[-1],p[0]);}
	V617=(base[2]);
	vs_top=sup;
	{register object V618;
	V618= Cnil;
	{long V619;
	register object V620;
	long V621;
	long V622;
	object V623;
	register object V624;
	V619= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V620= STREF(object,(base0[1]->c.c_car),40);
	V621= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V622= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V623= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V615)==t_structure){
	goto T2709;}
	goto T2707;
	goto T2709;
T2709:;
	if(!(((V615)->str.str_def)==(VV[95]))){
	goto T2707;}
	V624= STREF(object,(V615),0);
	goto T2705;
	goto T2707;
T2707:;{object V626;
	V626= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V615);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V627= vs_base[0];
	if(!((V626)==(CMPcar(V627)))){
	goto T2712;}}
	V624= CMPcar(((V615))->cc.cc_turbo[13]);
	goto T2705;
	goto T2712;
T2712:;
	if(!(type_of((V615))==t_structure)){
	goto T2718;}
	V624= (*(LnkLI256))((V615));
	goto T2705;
	goto T2718;
T2718:;
	if(!(type_of((V615))==t_symbol)){
	goto T2721;}
	if(((V615))==Cnil){
	goto T2724;}
	V624= (VV[44]->s.s_dbind);
	goto T2705;
	goto T2724;
T2724:;
	V624= (VV[45]->s.s_dbind);
	goto T2705;
	goto T2721;
T2721:;
	V624= (*(LnkLI257))((V615));
	goto T2705;
T2705:;
	{long V628;
	long V629;
	{long V630;
	V630= fix(((V624))->v.v_self[V619]);
	if(!((V630)==0)){
	goto T2729;}
	goto T2699;
	goto T2729;
T2729:;
	V628= (long)((V621) & (V630));}
	{object V631;
	V631= ((V620))->v.v_self[0];
	if(type_of((V631))==t_fixnum){
	goto T2734;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T2734;
T2734:;
	V629= fix((V631));}
	{register long V632;
	V632= V628;
	goto T2741;
T2741:;
	if(!(((V624))==(((V620))->v.v_self[V632]))){
	goto T2743;}
	V618= ((V620))->v.v_self[(long)(V632)+1];
	goto T2739;
	goto T2743;
T2743:;
	V632= (long)(V632)+(2);
	if(!((V632)==(V622))){
	goto T2750;}
	V632= 0;
	goto T2750;
T2750:;
	if(!((V632)==(V628))){
	goto T2742;}
	{register object V633;
	register object V634;
	V633= (V623);
	V634= CMPcar((V633));
	goto T2760;
T2760:;
	if(!(((V633))==Cnil)){
	goto T2761;}
	goto T2756;
	goto T2761;
T2761:;
	if(!((CMPcar((V634)))==((V624)))){
	goto T2765;}
	V618= CMPcdr((V634));
	goto T2739;
	goto T2765;
T2765:;
	V633= CMPcdr((V633));
	V634= CMPcar((V633));
	goto T2760;}
	goto T2756;
T2756:;
	goto T2699;
	goto T2742;
T2742:;
	goto T2741;
	goto T2739;
T2739:;
	{object V636;
	V636= ((V620))->v.v_self[0];
	if(type_of((V636))==t_fixnum){
	goto T2780;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T2780;
T2780:;
	V635= fix((V636));}
	if((V629)==(V635)){
	goto T2726;}
	goto T2699;}}
	goto T2726;
T2726:;
	base[3]= (V618);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2786;}
	base[3]= STREF(object,(V618),0);
	base[4]= STREF(object,(V618),4);
	base[5]= STREF(object,(V618),8);
	base[6]= (V615);
	base[7]= (V616);
	base[8]= (V617);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2786;
T2786:;
	base[3]= V618;
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2797;}
	{object V638;
	object V639;
	object V640;
	V638= STREF(object,(V618),0);
	V639= listA(3,(V615),(V616),(V617));
	V640= STREF(object,(V618),4);
	if(((V640))==Cnil){
	goto T2805;}
	if((CMPcdr((V640)))!=Cnil){
	goto T2805;}
	base[3]= (V639);
	base[4]= CMPcar((V640));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V638);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2805;
T2805:;
	base[3]= (V638);
	base[4]= (V639);
	{object V641;
	V641= (V640);
	 vs_top=base+5;
	 while(V641!=Cnil)
	 {vs_push((V641)->c.c_car);V641=(V641)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T2797;
T2797:;
	base[3]= V618;
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2815;}
	base[3]= (V618);
	base[4]= (V615);
	base[5]= (V616);
	{object V642;
	V642= (V617);
	 vs_top=base+6;
	 while(V642!=Cnil)
	 {vs_push((V642)->c.c_car);V642=(V642)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2815;
T2815:;
	base[4]= VV[11];
	base[5]= V618;
	base[6]= VV[96];
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}
	goto T2699;
T2699:;
	base[3]= (base0[0]->c.c_car);
	base[4]= (V615);
	base[5]= (V616);
	{object V643;
	V643= (V617);
	 vs_top=base+6;
	 while(V643!=Cnil)
	 {vs_push((V643)->c.c_car);V643=(V643)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[3]= Cnil;
	vs_top=(vs_base=base+3)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC73(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM115; VC115
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC136,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC136(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM116; VC116
	vs_check;
	{object V644;
	object V645;
	check_arg(2);
	V644=(base[0]);
	V645=(base[1]);
	vs_top=sup;
	{register object V646;
	V646= Cnil;
	{long V647;
	register object V648;
	long V649;
	long V650;
	object V651;
	register object V652;
	V647= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V648= STREF(object,(base0[1]->c.c_car),40);
	V649= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V650= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V651= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V644)==t_structure){
	goto T2842;}
	goto T2840;
	goto T2842;
T2842:;
	if(!(((V644)->str.str_def)==(VV[91]))){
	goto T2840;}
	V652= STREF(object,(V644),0);
	goto T2838;
	goto T2840;
T2840:;{object V654;
	V654= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V644);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V655= vs_base[0];
	if(!((V654)==(CMPcar(V655)))){
	goto T2845;}}
	V652= CMPcar(((V644))->cc.cc_turbo[13]);
	goto T2838;
	goto T2845;
T2845:;
	if(!(type_of((V644))==t_structure)){
	goto T2851;}
	V652= (*(LnkLI256))((V644));
	goto T2838;
	goto T2851;
T2851:;
	if(!(type_of((V644))==t_symbol)){
	goto T2854;}
	if(((V644))==Cnil){
	goto T2857;}
	V652= (VV[44]->s.s_dbind);
	goto T2838;
	goto T2857;
T2857:;
	V652= (VV[45]->s.s_dbind);
	goto T2838;
	goto T2854;
T2854:;
	V652= (*(LnkLI257))((V644));
	goto T2838;
T2838:;
	{long V656;
	long V657;
	{long V658;
	V658= fix(((V652))->v.v_self[V647]);
	if(!((V658)==0)){
	goto T2862;}
	goto T2832;
	goto T2862;
T2862:;
	V656= (long)((V649) & (V658));}
	{object V659;
	V659= ((V648))->v.v_self[0];
	if(type_of((V659))==t_fixnum){
	goto T2867;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T2867;
T2867:;
	V657= fix((V659));}
	{register long V660;
	V660= V656;
	goto T2874;
T2874:;
	if(!(((V652))==(((V648))->v.v_self[V660]))){
	goto T2876;}
	V646= ((V648))->v.v_self[(long)(V660)+1];
	goto T2872;
	goto T2876;
T2876:;
	V660= (long)(V660)+(2);
	if(!((V660)==(V650))){
	goto T2883;}
	V660= 0;
	goto T2883;
T2883:;
	if(!((V660)==(V656))){
	goto T2875;}
	{register object V661;
	register object V662;
	V661= (V651);
	V662= CMPcar((V661));
	goto T2893;
T2893:;
	if(!(((V661))==Cnil)){
	goto T2894;}
	goto T2889;
	goto T2894;
T2894:;
	if(!((CMPcar((V662)))==((V652)))){
	goto T2898;}
	V646= CMPcdr((V662));
	goto T2872;
	goto T2898;
T2898:;
	V661= CMPcdr((V661));
	V662= CMPcar((V661));
	goto T2893;}
	goto T2889;
T2889:;
	goto T2832;
	goto T2875;
T2875:;
	goto T2874;
	goto T2872;
T2872:;
	{object V664;
	V664= ((V648))->v.v_self[0];
	if(type_of((V664))==t_fixnum){
	goto T2913;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T2913;
T2913:;
	V663= fix((V664));}
	if((V657)==(V663)){
	goto T2859;}
	goto T2832;}}
	goto T2859;
T2859:;
	base[2]= (V646);
	base[3]= VV[2];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2919;}
	base[2]= STREF(object,(V646),0);
	base[3]= STREF(object,(V646),4);
	base[4]= STREF(object,(V646),8);
	base[5]= (V644);
	base[6]= (V645);
	vs_top=(vs_base=base+3)+4;
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2919;
T2919:;
	if(!(type_of((V646))==t_fixnum)){
	goto T2929;}
	{object V666;
	if(type_of(V644)==t_structure){
	goto T2935;}
	goto T2933;
	goto T2935;
T2935:;
	if(!(((V644)->str.str_def)==(VV[92]))){
	goto T2933;}
	V666= STREF(object,(V644),4);
	goto T2931;
	goto T2933;
T2933:;{object V668;
	V668= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V644);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V669= vs_base[0];
	if(!((V668)==(CMPcar(V669)))){
	goto T2938;}}
	V666= CMPcar(((V644))->cc.cc_turbo[12]);
	goto T2931;
	goto T2938;
T2938:;
	V666= Cnil;
	goto T2931;
T2931:;
	if(((V666))==Cnil){
	goto T2944;}
	base[2]= ((V666))->v.v_self[fix((V646))]= (V644);
	vs_top=(vs_base=base+2)+1;
	return;
	goto T2944;
T2944:;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	goto T2929;
T2929:;
	base[2]= V646;
	base[3]= VV[10];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2947;}
	{object V671;
	object V672;
	object V673;
	V671= STREF(object,(V646),0);
	V672= list(2,(V644),(V645));
	V673= STREF(object,(V646),4);
	if(((V673))==Cnil){
	goto T2955;}
	if((CMPcdr((V673)))!=Cnil){
	goto T2955;}
	base[2]= (V672);
	base[3]= CMPcar((V673));
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V671);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2955;
T2955:;
	base[2]= (V671);
	base[3]= (V672);
	{object V674;
	V674= (V673);
	 vs_top=base+4;
	 while(V674!=Cnil)
	 {vs_push((V674)->c.c_car);V674=(V674)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T2947;
T2947:;
	base[2]= V646;
	vs_top=(vs_base=base+2)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T2965;}
	base[2]= (V644);
	base[3]= (V645);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V646);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T2965;
T2965:;
	base[3]= VV[11];
	base[4]= V646;
	base[5]= VV[93];
	vs_top=(vs_base=base+3)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	return;}
	goto T2832;
T2832:;
	base[2]= (V644);
	base[3]= (V645);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC72(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM117; VC117
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC137,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC137(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM118; VC118
	vs_check;
	{object V675;
	object V676;
	check_arg(2);
	V675=(base[0]);
	V676=(base[1]);
	vs_top=sup;
	{object V677;
	V677= Cnil;
	{long V678;
	object V679;
	long V680;
	long V681;
	object V682;
	object V683;
	object V684;
	V678= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V679= STREF(object,(base0[1]->c.c_car),40);
	V680= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V681= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V682= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V675)==t_structure){
	goto T2988;}
	goto T2986;
	goto T2988;
T2988:;
	if(!(((V675)->str.str_def)==(VV[86]))){
	goto T2986;}
	V683= STREF(object,(V675),0);
	goto T2984;
	goto T2986;
T2986:;{object V686;
	V686= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V675);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V687= vs_base[0];
	if(!((V686)==(CMPcar(V687)))){
	goto T2991;}}
	V683= CMPcar(((V675))->cc.cc_turbo[13]);
	goto T2984;
	goto T2991;
T2991:;
	if(!(type_of((V675))==t_structure)){
	goto T2997;}
	V683= (*(LnkLI256))((V675));
	goto T2984;
	goto T2997;
T2997:;
	if(!(type_of((V675))==t_symbol)){
	goto T3000;}
	if(((V675))==Cnil){
	goto T3003;}
	V683= (VV[44]->s.s_dbind);
	goto T2984;
	goto T3003;
T3003:;
	V683= (VV[45]->s.s_dbind);
	goto T2984;
	goto T3000;
T3000:;
	V683= (*(LnkLI257))((V675));
	goto T2984;
T2984:;
	if(type_of(V676)==t_structure){
	goto T3009;}
	goto T3007;
	goto T3009;
T3009:;
	if(!(((V676)->str.str_def)==(VV[87]))){
	goto T3007;}
	V684= STREF(object,(V676),0);
	goto T3005;
	goto T3007;
T3007:;{object V689;
	V689= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V676);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V690= vs_base[0];
	if(!((V689)==(CMPcar(V690)))){
	goto T3012;}}
	V684= CMPcar(((V676))->cc.cc_turbo[13]);
	goto T3005;
	goto T3012;
T3012:;
	if(!(type_of((V676))==t_structure)){
	goto T3018;}
	V684= (*(LnkLI256))((V676));
	goto T3005;
	goto T3018;
T3018:;
	if(!(type_of((V676))==t_symbol)){
	goto T3021;}
	if(((V676))==Cnil){
	goto T3024;}
	V684= (VV[44]->s.s_dbind);
	goto T3005;
	goto T3024;
T3024:;
	V684= (VV[45]->s.s_dbind);
	goto T3005;
	goto T3021;
T3021:;
	V684= (*(LnkLI257))((V676));
	goto T3005;
T3005:;
	{long V691;
	long V692;
	V691= 0;
	V692= (long)(V681)-(1);
	{long V693;
	V693= fix(((V683))->v.v_self[V678]);
	if(!((V693)==0)){
	goto T3032;}
	goto T2978;
	goto T3032;
T3032:;
	V691= (long)(V691)+(V693);}
	{long V694;
	V694= fix(((V684))->v.v_self[V678]);
	if(!((V694)==0)){
	goto T3037;}
	goto T2978;
	goto T3037;
T3037:;
	V691= (long)(V691)+(V694);
	V691= (long)((V691) & (V680));}
	{long V695;
	{object V696;
	V696= ((V679))->v.v_self[0];
	if(type_of((V696))==t_fixnum){
	goto T3045;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T3045;
T3045:;
	V695= fix((V696));}
	{register long V697;
	long V698;
	V697= V691;
	V698= 0;
	goto T3053;
T3053:;
	V698= (long)(V697)+(4);
	V697= (long)(V697)+(1);
	if(!(((V683))==(((V679))->v.v_self[V697]))){
	goto T3057;}
	V697= (long)(V697)+(1);
	if(!(((V684))==(((V679))->v.v_self[V697]))){
	goto T3057;}
	V697= (long)(V697)+(1);
	V677= ((V679))->v.v_self[V697];
	goto T3051;
	goto T3057;
T3057:;
	V697= V698;
	if(!((V697)==(V692))){
	goto T3070;}
	V697= 0;
	goto T3070;
T3070:;
	if(!((V697)==(V691))){
	goto T3054;}
	{register object V699;
	register object V700;
	V699= (V682);
	V700= CMPcar((V699));
	goto T3080;
T3080:;
	if(!(((V699))==Cnil)){
	goto T3081;}
	goto T3076;
	goto T3081;
T3081:;
	{register object V701;
	V701= CMPcar((V700));
	{register object V703;
	V703= CMPcar((V701));
	V701= CMPcdr((V701));
	V702= (V703);}
	if(!(((V683))==(V702))){
	goto T3085;}
	{register object V705;
	V705= CMPcar((V701));
	V701= CMPcdr((V701));
	V704= (V705);}
	if(!(((V684))==(V704))){
	goto T3085;}
	V677= CMPcdr((V700));
	goto T3051;}
	goto T3085;
T3085:;
	V699= CMPcdr((V699));
	V700= CMPcar((V699));
	goto T3080;}
	goto T3076;
T3076:;
	goto T2978;
	goto T3054;
T3054:;
	goto T3053;
	goto T3051;
T3051:;
	{object V707;
	V707= ((V679))->v.v_self[0];
	if(type_of((V707))==t_fixnum){
	goto T3111;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T3111;
T3111:;
	V706= fix((V707));}
	if((V695)==(V706)){
	goto T3026;}
	goto T2978;}}}
	goto T3026;
T3026:;
	base[2]= (V677);
	base[3]= VV[2];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3117;}
	base[2]= STREF(object,(V677),0);
	base[3]= STREF(object,(V677),4);
	base[4]= STREF(object,(V677),8);
	base[5]= (V675);
	base[6]= (V676);
	vs_top=(vs_base=base+3)+4;
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3117;
T3117:;
	if(!(type_of((V677))==t_fixnum)){
	goto T3127;}
	{object V709;
	if(type_of(V675)==t_structure){
	goto T3133;}
	goto T3131;
	goto T3133;
T3133:;
	if(!(((V675)->str.str_def)==(VV[88]))){
	goto T3131;}
	V709= STREF(object,(V675),4);
	goto T3129;
	goto T3131;
T3131:;{object V711;
	V711= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V675);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V712= vs_base[0];
	if(!((V711)==(CMPcar(V712)))){
	goto T3136;}}
	V709= CMPcar(((V675))->cc.cc_turbo[12]);
	goto T3129;
	goto T3136;
T3136:;
	V709= Cnil;
	goto T3129;
T3129:;
	if(((V709))==Cnil){
	goto T3142;}
	base[2]= ((V709))->v.v_self[fix((V677))]= (V675);
	vs_top=(vs_base=base+2)+1;
	return;
	goto T3142;
T3142:;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	goto T3127;
T3127:;
	base[2]= V677;
	base[3]= VV[10];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3145;}
	{object V714;
	object V715;
	object V716;
	V714= STREF(object,(V677),0);
	V715= list(2,(V675),(V676));
	V716= STREF(object,(V677),4);
	if(((V716))==Cnil){
	goto T3153;}
	if((CMPcdr((V716)))!=Cnil){
	goto T3153;}
	base[2]= (V715);
	base[3]= CMPcar((V716));
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V714);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3153;
T3153:;
	base[2]= (V714);
	base[3]= (V715);
	{object V717;
	V717= (V716);
	 vs_top=base+4;
	 while(V717!=Cnil)
	 {vs_push((V717)->c.c_car);V717=(V717)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T3145;
T3145:;
	base[2]= V677;
	vs_top=(vs_base=base+2)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3163;}
	base[2]= (V675);
	base[3]= (V676);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V677);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3163;
T3163:;
	base[3]= VV[11];
	base[4]= V677;
	base[5]= VV[89];
	vs_top=(vs_base=base+3)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	return;}
	goto T2978;
T2978:;
	base[2]= (V675);
	base[3]= (V676);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC71(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM119; VC119
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC138,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC138(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM120; VC120
	vs_check;
	{object V718;
	object V719;
	object V720;
	check_arg(3);
	V718=(base[0]);
	V719=(base[1]);
	V720=(base[2]);
	vs_top=sup;
	{register object V721;
	V721= Cnil;
	{long V722;
	register object V723;
	long V724;
	long V725;
	object V726;
	register object V727;
	V722= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V723= STREF(object,(base0[1]->c.c_car),40);
	V724= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V725= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V726= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V718)==t_structure){
	goto T3186;}
	goto T3184;
	goto T3186;
T3186:;
	if(!(((V718)->str.str_def)==(VV[83]))){
	goto T3184;}
	V727= STREF(object,(V718),0);
	goto T3182;
	goto T3184;
T3184:;{object V729;
	V729= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V718);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V730= vs_base[0];
	if(!((V729)==(CMPcar(V730)))){
	goto T3189;}}
	V727= CMPcar(((V718))->cc.cc_turbo[13]);
	goto T3182;
	goto T3189;
T3189:;
	if(!(type_of((V718))==t_structure)){
	goto T3195;}
	V727= (*(LnkLI256))((V718));
	goto T3182;
	goto T3195;
T3195:;
	if(!(type_of((V718))==t_symbol)){
	goto T3198;}
	if(((V718))==Cnil){
	goto T3201;}
	V727= (VV[44]->s.s_dbind);
	goto T3182;
	goto T3201;
T3201:;
	V727= (VV[45]->s.s_dbind);
	goto T3182;
	goto T3198;
T3198:;
	V727= (*(LnkLI257))((V718));
	goto T3182;
T3182:;
	{long V731;
	long V732;
	{long V733;
	V733= fix(((V727))->v.v_self[V722]);
	if(!((V733)==0)){
	goto T3206;}
	goto T3176;
	goto T3206;
T3206:;
	V731= (long)((V724) & (V733));}
	{object V734;
	V734= ((V723))->v.v_self[0];
	if(type_of((V734))==t_fixnum){
	goto T3211;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3211;
T3211:;
	V732= fix((V734));}
	{register long V735;
	V735= V731;
	goto T3218;
T3218:;
	if(!(((V727))==(((V723))->v.v_self[V735]))){
	goto T3220;}
	V721= ((V723))->v.v_self[(long)(V735)+1];
	goto T3216;
	goto T3220;
T3220:;
	V735= (long)(V735)+(2);
	if(!((V735)==(V725))){
	goto T3227;}
	V735= 0;
	goto T3227;
T3227:;
	if(!((V735)==(V731))){
	goto T3219;}
	{register object V736;
	register object V737;
	V736= (V726);
	V737= CMPcar((V736));
	goto T3237;
T3237:;
	if(!(((V736))==Cnil)){
	goto T3238;}
	goto T3233;
	goto T3238;
T3238:;
	if(!((CMPcar((V737)))==((V727)))){
	goto T3242;}
	V721= CMPcdr((V737));
	goto T3216;
	goto T3242;
T3242:;
	V736= CMPcdr((V736));
	V737= CMPcar((V736));
	goto T3237;}
	goto T3233;
T3233:;
	goto T3176;
	goto T3219;
T3219:;
	goto T3218;
	goto T3216;
T3216:;
	{object V739;
	V739= ((V723))->v.v_self[0];
	if(type_of((V739))==t_fixnum){
	goto T3257;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3257;
T3257:;
	V738= fix((V739));}
	if((V732)==(V738)){
	goto T3203;}
	goto T3176;}}
	goto T3203;
T3203:;
	base[3]= (V721);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3263;}
	base[3]= STREF(object,(V721),0);
	base[4]= STREF(object,(V721),4);
	base[5]= STREF(object,(V721),8);
	base[6]= (V718);
	base[7]= (V719);
	base[8]= (V720);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3263;
T3263:;
	base[3]= V721;
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3274;}
	{object V741;
	object V742;
	object V743;
	V741= STREF(object,(V721),0);
	V742= list(3,(V718),(V719),(V720));
	V743= STREF(object,(V721),4);
	if(((V743))==Cnil){
	goto T3282;}
	if((CMPcdr((V743)))!=Cnil){
	goto T3282;}
	base[3]= (V742);
	base[4]= CMPcar((V743));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V741);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3282;
T3282:;
	base[3]= (V741);
	base[4]= (V742);
	{object V744;
	V744= (V743);
	 vs_top=base+5;
	 while(V744!=Cnil)
	 {vs_push((V744)->c.c_car);V744=(V744)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T3274;
T3274:;
	base[3]= V721;
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3292;}
	base[3]= (V718);
	base[4]= (V719);
	base[5]= (V720);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (V721);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3292;
T3292:;
	base[4]= VV[11];
	base[5]= V721;
	base[6]= VV[84];
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}
	goto T3176;
T3176:;
	base[3]= (V718);
	base[4]= (V719);
	base[5]= (V720);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[3]= Cnil;
	vs_top=(vs_base=base+3)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC70(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM121; VC121
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC139,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC139(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM122; VC122
	vs_check;
	{object V745;
	object V746;
	object V747;
	check_arg(3);
	V745=(base[0]);
	V746=(base[1]);
	V747=(base[2]);
	vs_top=sup;
	{register object V748;
	V748= Cnil;
	{long V749;
	register object V750;
	long V751;
	long V752;
	object V753;
	register object V754;
	V749= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V750= STREF(object,(base0[1]->c.c_car),40);
	V751= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V752= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V753= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V746)==t_structure){
	goto T3317;}
	goto T3315;
	goto T3317;
T3317:;
	if(!(((V746)->str.str_def)==(VV[80]))){
	goto T3315;}
	V754= STREF(object,(V746),0);
	goto T3313;
	goto T3315;
T3315:;{object V756;
	V756= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V746);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V757= vs_base[0];
	if(!((V756)==(CMPcar(V757)))){
	goto T3320;}}
	V754= CMPcar(((V746))->cc.cc_turbo[13]);
	goto T3313;
	goto T3320;
T3320:;
	if(!(type_of((V746))==t_structure)){
	goto T3326;}
	V754= (*(LnkLI256))((V746));
	goto T3313;
	goto T3326;
T3326:;
	if(!(type_of((V746))==t_symbol)){
	goto T3329;}
	if(((V746))==Cnil){
	goto T3332;}
	V754= (VV[44]->s.s_dbind);
	goto T3313;
	goto T3332;
T3332:;
	V754= (VV[45]->s.s_dbind);
	goto T3313;
	goto T3329;
T3329:;
	V754= (*(LnkLI257))((V746));
	goto T3313;
T3313:;
	{long V758;
	long V759;
	{long V760;
	V760= fix(((V754))->v.v_self[V749]);
	if(!((V760)==0)){
	goto T3337;}
	goto T3307;
	goto T3337;
T3337:;
	V758= (long)((V751) & (V760));}
	{object V761;
	V761= ((V750))->v.v_self[0];
	if(type_of((V761))==t_fixnum){
	goto T3342;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3342;
T3342:;
	V759= fix((V761));}
	{register long V762;
	V762= V758;
	goto T3349;
T3349:;
	if(!(((V754))==(((V750))->v.v_self[V762]))){
	goto T3351;}
	V748= ((V750))->v.v_self[(long)(V762)+1];
	goto T3347;
	goto T3351;
T3351:;
	V762= (long)(V762)+(2);
	if(!((V762)==(V752))){
	goto T3358;}
	V762= 0;
	goto T3358;
T3358:;
	if(!((V762)==(V758))){
	goto T3350;}
	{register object V763;
	register object V764;
	V763= (V753);
	V764= CMPcar((V763));
	goto T3368;
T3368:;
	if(!(((V763))==Cnil)){
	goto T3369;}
	goto T3364;
	goto T3369;
T3369:;
	if(!((CMPcar((V764)))==((V754)))){
	goto T3373;}
	V748= CMPcdr((V764));
	goto T3347;
	goto T3373;
T3373:;
	V763= CMPcdr((V763));
	V764= CMPcar((V763));
	goto T3368;}
	goto T3364;
T3364:;
	goto T3307;
	goto T3350;
T3350:;
	goto T3349;
	goto T3347;
T3347:;
	{object V766;
	V766= ((V750))->v.v_self[0];
	if(type_of((V766))==t_fixnum){
	goto T3388;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3388;
T3388:;
	V765= fix((V766));}
	if((V759)==(V765)){
	goto T3334;}
	goto T3307;}}
	goto T3334;
T3334:;
	base[3]= (V748);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3394;}
	base[3]= STREF(object,(V748),0);
	base[4]= STREF(object,(V748),4);
	base[5]= STREF(object,(V748),8);
	base[6]= (V745);
	base[7]= (V746);
	base[8]= (V747);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3394;
T3394:;
	base[3]= V748;
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3405;}
	{object V768;
	object V769;
	object V770;
	V768= STREF(object,(V748),0);
	V769= list(3,(V745),(V746),(V747));
	V770= STREF(object,(V748),4);
	if(((V770))==Cnil){
	goto T3413;}
	if((CMPcdr((V770)))!=Cnil){
	goto T3413;}
	base[3]= (V769);
	base[4]= CMPcar((V770));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V768);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3413;
T3413:;
	base[3]= (V768);
	base[4]= (V769);
	{object V771;
	V771= (V770);
	 vs_top=base+5;
	 while(V771!=Cnil)
	 {vs_push((V771)->c.c_car);V771=(V771)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T3405;
T3405:;
	base[3]= V748;
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3423;}
	base[3]= (V745);
	base[4]= (V746);
	base[5]= (V747);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (V748);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3423;
T3423:;
	base[4]= VV[11];
	base[5]= V748;
	base[6]= VV[81];
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}
	goto T3307;
T3307:;
	base[3]= (V745);
	base[4]= (V746);
	base[5]= (V747);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[3]= Cnil;
	vs_top=(vs_base=base+3)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC69(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM123; VC123
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC140,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC140(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM124; VC124
	vs_check;
	{object V772;
	object V773;
	object V774;
	object V775;
	object V776;
	if(vs_top-vs_base<4) too_few_arguments();
	V772=(base[0]);
	V773=(base[1]);
	V774=(base[2]);
	V775=(base[3]);
	vs_base=vs_base+4;
	vs_top[0]=Cnil;
	{object *p=vs_top;
	 for(;p>vs_base;p--)p[-1]=MMcons(p[-1],p[0]);}
	V776=(base[4]);
	vs_top=sup;
	{register object V777;
	V777= Cnil;
	{long V778;
	register object V779;
	long V780;
	long V781;
	object V782;
	register object V783;
	V778= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V779= STREF(object,(base0[1]->c.c_car),40);
	V780= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V781= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V782= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V772)==t_structure){
	goto T3448;}
	goto T3446;
	goto T3448;
T3448:;
	if(!(((V772)->str.str_def)==(VV[77]))){
	goto T3446;}
	V783= STREF(object,(V772),0);
	goto T3444;
	goto T3446;
T3446:;{object V785;
	V785= (VV[30]->s.s_dbind);
	base[5]= small_fixnum(14);
	base[6]= (V772);
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V786= vs_base[0];
	if(!((V785)==(CMPcar(V786)))){
	goto T3451;}}
	V783= CMPcar(((V772))->cc.cc_turbo[13]);
	goto T3444;
	goto T3451;
T3451:;
	if(!(type_of((V772))==t_structure)){
	goto T3457;}
	V783= (*(LnkLI256))((V772));
	goto T3444;
	goto T3457;
T3457:;
	if(!(type_of((V772))==t_symbol)){
	goto T3460;}
	if(((V772))==Cnil){
	goto T3463;}
	V783= (VV[44]->s.s_dbind);
	goto T3444;
	goto T3463;
T3463:;
	V783= (VV[45]->s.s_dbind);
	goto T3444;
	goto T3460;
T3460:;
	V783= (*(LnkLI257))((V772));
	goto T3444;
T3444:;
	{long V787;
	long V788;
	{long V789;
	V789= fix(((V783))->v.v_self[V778]);
	if(!((V789)==0)){
	goto T3468;}
	goto T3438;
	goto T3468;
T3468:;
	V787= (long)((V780) & (V789));}
	{object V790;
	V790= ((V779))->v.v_self[0];
	if(type_of((V790))==t_fixnum){
	goto T3473;}
	base[5]= VV[46];
	vs_top=(vs_base=base+5)+1;
	Lerror();
	vs_top=sup;
	goto T3473;
T3473:;
	V788= fix((V790));}
	{register long V791;
	V791= V787;
	goto T3480;
T3480:;
	if(!(((V783))==(((V779))->v.v_self[V791]))){
	goto T3482;}
	V777= ((V779))->v.v_self[(long)(V791)+1];
	goto T3478;
	goto T3482;
T3482:;
	V791= (long)(V791)+(2);
	if(!((V791)==(V781))){
	goto T3489;}
	V791= 0;
	goto T3489;
T3489:;
	if(!((V791)==(V787))){
	goto T3481;}
	{register object V792;
	register object V793;
	V792= (V782);
	V793= CMPcar((V792));
	goto T3499;
T3499:;
	if(!(((V792))==Cnil)){
	goto T3500;}
	goto T3495;
	goto T3500;
T3500:;
	if(!((CMPcar((V793)))==((V783)))){
	goto T3504;}
	V777= CMPcdr((V793));
	goto T3478;
	goto T3504;
T3504:;
	V792= CMPcdr((V792));
	V793= CMPcar((V792));
	goto T3499;}
	goto T3495;
T3495:;
	goto T3438;
	goto T3481;
T3481:;
	goto T3480;
	goto T3478;
T3478:;
	{object V795;
	V795= ((V779))->v.v_self[0];
	if(type_of((V795))==t_fixnum){
	goto T3519;}
	base[5]= VV[46];
	vs_top=(vs_base=base+5)+1;
	Lerror();
	vs_top=sup;
	goto T3519;
T3519:;
	V794= fix((V795));}
	if((V788)==(V794)){
	goto T3465;}
	goto T3438;}}
	goto T3465;
T3465:;
	base[5]= (V777);
	base[6]= VV[2];
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3525;}
	base[5]= STREF(object,(V777),0);
	base[6]= STREF(object,(V777),4);
	base[7]= STREF(object,(V777),8);
	base[8]= (V772);
	base[9]= (V773);
	base[10]= (V774);
	base[11]= (V775);
	base[12]= (V776);
	vs_top=(vs_base=base+6)+7;
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3525;
T3525:;
	base[5]= V777;
	base[6]= VV[10];
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3538;}
	{object V797;
	object V798;
	object V799;
	V797= STREF(object,(V777),0);
	V798= listA(5,(V772),(V773),(V774),(V775),(V776));
	V799= STREF(object,(V777),4);
	if(((V799))==Cnil){
	goto T3546;}
	if((CMPcdr((V799)))!=Cnil){
	goto T3546;}
	base[5]= (V798);
	base[6]= CMPcar((V799));
	vs_top=(vs_base=base+5)+2;
	{object _funobj = (V797);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3546;
T3546:;
	base[5]= (V797);
	base[6]= (V798);
	{object V800;
	V800= (V799);
	 vs_top=base+7;
	 while(V800!=Cnil)
	 {vs_push((V800)->c.c_car);V800=(V800)->c.c_cdr;}
	vs_base=base+6;}
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T3538;
T3538:;
	base[5]= V777;
	vs_top=(vs_base=base+5)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3556;}
	base[5]= (V777);
	base[6]= (V772);
	base[7]= (V773);
	base[8]= (V774);
	base[9]= (V775);
	{object V801;
	V801= (V776);
	 vs_top=base+10;
	 while(V801!=Cnil)
	 {vs_push((V801)->c.c_car);V801=(V801)->c.c_cdr;}
	vs_base=base+6;}
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3556;
T3556:;
	base[6]= VV[11];
	base[7]= V777;
	base[8]= VV[78];
	vs_top=(vs_base=base+6)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[5]= vs_base[0];
	vs_top=(vs_base=base+5)+1;
	Lerror();
	return;}
	goto T3438;
T3438:;
	base[5]= (base0[0]->c.c_car);
	base[6]= (V772);
	base[7]= (V773);
	base[8]= (V774);
	base[9]= (V775);
	{object V802;
	V802= (V776);
	 vs_top=base+10;
	 while(V802!=Cnil)
	 {vs_push((V802)->c.c_car);V802=(V802)->c.c_cdr;}
	vs_base=base+6;}
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[5]= Cnil;
	vs_top=(vs_base=base+5)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC68(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM125; VC125
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC141,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC141(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM126; VC126
	vs_check;
	{object V803;
	object V804;
	object V805;
	if(vs_top-vs_base<2) too_few_arguments();
	V803=(base[0]);
	V804=(base[1]);
	vs_base=vs_base+2;
	vs_top[0]=Cnil;
	{object *p=vs_top;
	 for(;p>vs_base;p--)p[-1]=MMcons(p[-1],p[0]);}
	V805=(base[2]);
	vs_top=sup;
	{object V806;
	V806= Cnil;
	{long V807;
	object V808;
	long V809;
	long V810;
	object V811;
	object V812;
	object V813;
	V807= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V808= STREF(object,(base0[1]->c.c_car),40);
	V809= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V810= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V811= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V803)==t_structure){
	goto T3587;}
	goto T3585;
	goto T3587;
T3587:;
	if(!(((V803)->str.str_def)==(VV[73]))){
	goto T3585;}
	V812= STREF(object,(V803),0);
	goto T3583;
	goto T3585;
T3585:;{object V815;
	V815= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V803);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V816= vs_base[0];
	if(!((V815)==(CMPcar(V816)))){
	goto T3590;}}
	V812= CMPcar(((V803))->cc.cc_turbo[13]);
	goto T3583;
	goto T3590;
T3590:;
	if(!(type_of((V803))==t_structure)){
	goto T3596;}
	V812= (*(LnkLI256))((V803));
	goto T3583;
	goto T3596;
T3596:;
	if(!(type_of((V803))==t_symbol)){
	goto T3599;}
	if(((V803))==Cnil){
	goto T3602;}
	V812= (VV[44]->s.s_dbind);
	goto T3583;
	goto T3602;
T3602:;
	V812= (VV[45]->s.s_dbind);
	goto T3583;
	goto T3599;
T3599:;
	V812= (*(LnkLI257))((V803));
	goto T3583;
T3583:;
	if(type_of(V804)==t_structure){
	goto T3608;}
	goto T3606;
	goto T3608;
T3608:;
	if(!(((V804)->str.str_def)==(VV[74]))){
	goto T3606;}
	V813= STREF(object,(V804),0);
	goto T3604;
	goto T3606;
T3606:;{object V818;
	V818= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V804);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V819= vs_base[0];
	if(!((V818)==(CMPcar(V819)))){
	goto T3611;}}
	V813= CMPcar(((V804))->cc.cc_turbo[13]);
	goto T3604;
	goto T3611;
T3611:;
	if(!(type_of((V804))==t_structure)){
	goto T3617;}
	V813= (*(LnkLI256))((V804));
	goto T3604;
	goto T3617;
T3617:;
	if(!(type_of((V804))==t_symbol)){
	goto T3620;}
	if(((V804))==Cnil){
	goto T3623;}
	V813= (VV[44]->s.s_dbind);
	goto T3604;
	goto T3623;
T3623:;
	V813= (VV[45]->s.s_dbind);
	goto T3604;
	goto T3620;
T3620:;
	V813= (*(LnkLI257))((V804));
	goto T3604;
T3604:;
	{long V820;
	long V821;
	V820= 0;
	V821= (long)(V810)-(1);
	{long V822;
	V822= fix(((V812))->v.v_self[V807]);
	if(!((V822)==0)){
	goto T3631;}
	goto T3577;
	goto T3631;
T3631:;
	V820= (long)(V820)+(V822);}
	{long V823;
	V823= fix(((V813))->v.v_self[V807]);
	if(!((V823)==0)){
	goto T3636;}
	goto T3577;
	goto T3636;
T3636:;
	V820= (long)(V820)+(V823);
	V820= (long)((V820) & (V809));}
	{long V824;
	{object V825;
	V825= ((V808))->v.v_self[0];
	if(type_of((V825))==t_fixnum){
	goto T3644;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3644;
T3644:;
	V824= fix((V825));}
	{register long V826;
	long V827;
	V826= V820;
	V827= 0;
	goto T3652;
T3652:;
	V827= (long)(V826)+(4);
	V826= (long)(V826)+(1);
	if(!(((V812))==(((V808))->v.v_self[V826]))){
	goto T3656;}
	V826= (long)(V826)+(1);
	if(!(((V813))==(((V808))->v.v_self[V826]))){
	goto T3656;}
	V826= (long)(V826)+(1);
	V806= ((V808))->v.v_self[V826];
	goto T3650;
	goto T3656;
T3656:;
	V826= V827;
	if(!((V826)==(V821))){
	goto T3669;}
	V826= 0;
	goto T3669;
T3669:;
	if(!((V826)==(V820))){
	goto T3653;}
	{register object V828;
	register object V829;
	V828= (V811);
	V829= CMPcar((V828));
	goto T3679;
T3679:;
	if(!(((V828))==Cnil)){
	goto T3680;}
	goto T3675;
	goto T3680;
T3680:;
	{register object V830;
	V830= CMPcar((V829));
	{register object V832;
	V832= CMPcar((V830));
	V830= CMPcdr((V830));
	V831= (V832);}
	if(!(((V812))==(V831))){
	goto T3684;}
	{register object V834;
	V834= CMPcar((V830));
	V830= CMPcdr((V830));
	V833= (V834);}
	if(!(((V813))==(V833))){
	goto T3684;}
	V806= CMPcdr((V829));
	goto T3650;}
	goto T3684;
T3684:;
	V828= CMPcdr((V828));
	V829= CMPcar((V828));
	goto T3679;}
	goto T3675;
T3675:;
	goto T3577;
	goto T3653;
T3653:;
	goto T3652;
	goto T3650;
T3650:;
	{object V836;
	V836= ((V808))->v.v_self[0];
	if(type_of((V836))==t_fixnum){
	goto T3710;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3710;
T3710:;
	V835= fix((V836));}
	if((V824)==(V835)){
	goto T3625;}
	goto T3577;}}}
	goto T3625;
T3625:;
	base[3]= (V806);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3716;}
	base[3]= STREF(object,(V806),0);
	base[4]= STREF(object,(V806),4);
	base[5]= STREF(object,(V806),8);
	base[6]= (V803);
	base[7]= (V804);
	base[8]= (V805);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3716;
T3716:;
	base[3]= V806;
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3727;}
	{object V838;
	object V839;
	object V840;
	V838= STREF(object,(V806),0);
	V839= listA(3,(V803),(V804),(V805));
	V840= STREF(object,(V806),4);
	if(((V840))==Cnil){
	goto T3735;}
	if((CMPcdr((V840)))!=Cnil){
	goto T3735;}
	base[3]= (V839);
	base[4]= CMPcar((V840));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V838);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3735;
T3735:;
	base[3]= (V838);
	base[4]= (V839);
	{object V841;
	V841= (V840);
	 vs_top=base+5;
	 while(V841!=Cnil)
	 {vs_push((V841)->c.c_car);V841=(V841)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T3727;
T3727:;
	base[3]= V806;
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3745;}
	base[3]= (V806);
	base[4]= (V803);
	base[5]= (V804);
	{object V842;
	V842= (V805);
	 vs_top=base+6;
	 while(V842!=Cnil)
	 {vs_push((V842)->c.c_car);V842=(V842)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3745;
T3745:;
	base[4]= VV[11];
	base[5]= V806;
	base[6]= VV[75];
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}
	goto T3577;
T3577:;
	base[3]= (base0[0]->c.c_car);
	base[4]= (V803);
	base[5]= (V804);
	{object V843;
	V843= (V805);
	 vs_top=base+6;
	 while(V843!=Cnil)
	 {vs_push((V843)->c.c_car);V843=(V843)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[3]= Cnil;
	vs_top=(vs_base=base+3)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC67(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM127; VC127
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC142,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC142(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM128; VC128
	vs_check;
	{object V844;
	object V845;
	object V846;
	if(vs_top-vs_base<2) too_few_arguments();
	V844=(base[0]);
	V845=(base[1]);
	vs_base=vs_base+2;
	vs_top[0]=Cnil;
	{object *p=vs_top;
	 for(;p>vs_base;p--)p[-1]=MMcons(p[-1],p[0]);}
	V846=(base[2]);
	vs_top=sup;
	{register object V847;
	V847= Cnil;
	{long V848;
	register object V849;
	long V850;
	long V851;
	object V852;
	register object V853;
	V848= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V849= STREF(object,(base0[1]->c.c_car),40);
	V850= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V851= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V852= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V845)==t_structure){
	goto T3772;}
	goto T3770;
	goto T3772;
T3772:;
	if(!(((V845)->str.str_def)==(VV[70]))){
	goto T3770;}
	V853= STREF(object,(V845),0);
	goto T3768;
	goto T3770;
T3770:;{object V855;
	V855= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V845);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V856= vs_base[0];
	if(!((V855)==(CMPcar(V856)))){
	goto T3775;}}
	V853= CMPcar(((V845))->cc.cc_turbo[13]);
	goto T3768;
	goto T3775;
T3775:;
	if(!(type_of((V845))==t_structure)){
	goto T3781;}
	V853= (*(LnkLI256))((V845));
	goto T3768;
	goto T3781;
T3781:;
	if(!(type_of((V845))==t_symbol)){
	goto T3784;}
	if(((V845))==Cnil){
	goto T3787;}
	V853= (VV[44]->s.s_dbind);
	goto T3768;
	goto T3787;
T3787:;
	V853= (VV[45]->s.s_dbind);
	goto T3768;
	goto T3784;
T3784:;
	V853= (*(LnkLI257))((V845));
	goto T3768;
T3768:;
	{long V857;
	long V858;
	{long V859;
	V859= fix(((V853))->v.v_self[V848]);
	if(!((V859)==0)){
	goto T3792;}
	goto T3762;
	goto T3792;
T3792:;
	V857= (long)((V850) & (V859));}
	{object V860;
	V860= ((V849))->v.v_self[0];
	if(type_of((V860))==t_fixnum){
	goto T3797;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3797;
T3797:;
	V858= fix((V860));}
	{register long V861;
	V861= V857;
	goto T3804;
T3804:;
	if(!(((V853))==(((V849))->v.v_self[V861]))){
	goto T3806;}
	V847= ((V849))->v.v_self[(long)(V861)+1];
	goto T3802;
	goto T3806;
T3806:;
	V861= (long)(V861)+(2);
	if(!((V861)==(V851))){
	goto T3813;}
	V861= 0;
	goto T3813;
T3813:;
	if(!((V861)==(V857))){
	goto T3805;}
	{register object V862;
	register object V863;
	V862= (V852);
	V863= CMPcar((V862));
	goto T3823;
T3823:;
	if(!(((V862))==Cnil)){
	goto T3824;}
	goto T3819;
	goto T3824;
T3824:;
	if(!((CMPcar((V863)))==((V853)))){
	goto T3828;}
	V847= CMPcdr((V863));
	goto T3802;
	goto T3828;
T3828:;
	V862= CMPcdr((V862));
	V863= CMPcar((V862));
	goto T3823;}
	goto T3819;
T3819:;
	goto T3762;
	goto T3805;
T3805:;
	goto T3804;
	goto T3802;
T3802:;
	{object V865;
	V865= ((V849))->v.v_self[0];
	if(type_of((V865))==t_fixnum){
	goto T3843;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3843;
T3843:;
	V864= fix((V865));}
	if((V858)==(V864)){
	goto T3789;}
	goto T3762;}}
	goto T3789;
T3789:;
	base[3]= (V847);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3849;}
	base[3]= STREF(object,(V847),0);
	base[4]= STREF(object,(V847),4);
	base[5]= STREF(object,(V847),8);
	base[6]= (V844);
	base[7]= (V845);
	base[8]= (V846);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3849;
T3849:;
	base[3]= V847;
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3860;}
	{object V867;
	object V868;
	object V869;
	V867= STREF(object,(V847),0);
	V868= listA(3,(V844),(V845),(V846));
	V869= STREF(object,(V847),4);
	if(((V869))==Cnil){
	goto T3868;}
	if((CMPcdr((V869)))!=Cnil){
	goto T3868;}
	base[3]= (V868);
	base[4]= CMPcar((V869));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V867);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3868;
T3868:;
	base[3]= (V867);
	base[4]= (V868);
	{object V870;
	V870= (V869);
	 vs_top=base+5;
	 while(V870!=Cnil)
	 {vs_push((V870)->c.c_car);V870=(V870)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T3860;
T3860:;
	base[3]= V847;
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T3878;}
	base[3]= (V847);
	base[4]= (V844);
	base[5]= (V845);
	{object V871;
	V871= (V846);
	 vs_top=base+6;
	 while(V871!=Cnil)
	 {vs_push((V871)->c.c_car);V871=(V871)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T3878;
T3878:;
	base[4]= VV[11];
	base[5]= V847;
	base[6]= VV[71];
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}
	goto T3762;
T3762:;
	base[3]= (base0[0]->c.c_car);
	base[4]= (V844);
	base[5]= (V845);
	{object V872;
	V872= (V846);
	 vs_top=base+6;
	 while(V872!=Cnil)
	 {vs_push((V872)->c.c_car);V872=(V872)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[3]= Cnil;
	vs_top=(vs_base=base+3)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC66(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM129; VC129
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC143,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC143(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM130; VC130
	vs_check;
	{object V873;
	object V874;
	object V875;
	check_arg(3);
	V873=(base[0]);
	V874=(base[1]);
	V875=(base[2]);
	vs_top=sup;
	{object V876;
	V876= Cnil;
	{long V877;
	register object V878;
	long V879;
	long V880;
	object V881;
	object V882;
	object V883;
	object V884;
	V877= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V878= STREF(object,(base0[1]->c.c_car),40);
	V879= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V880= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V881= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V873)==t_structure){
	goto T3905;}
	goto T3903;
	goto T3905;
T3905:;
	if(!(((V873)->str.str_def)==(VV[65]))){
	goto T3903;}
	V882= STREF(object,(V873),0);
	goto T3901;
	goto T3903;
T3903:;{object V886;
	V886= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V873);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V887= vs_base[0];
	if(!((V886)==(CMPcar(V887)))){
	goto T3908;}}
	V882= CMPcar(((V873))->cc.cc_turbo[13]);
	goto T3901;
	goto T3908;
T3908:;
	if(!(type_of((V873))==t_structure)){
	goto T3914;}
	V882= (*(LnkLI256))((V873));
	goto T3901;
	goto T3914;
T3914:;
	if(!(type_of((V873))==t_symbol)){
	goto T3917;}
	if(((V873))==Cnil){
	goto T3920;}
	V882= (VV[44]->s.s_dbind);
	goto T3901;
	goto T3920;
T3920:;
	V882= (VV[45]->s.s_dbind);
	goto T3901;
	goto T3917;
T3917:;
	V882= (*(LnkLI257))((V873));
	goto T3901;
T3901:;
	if(type_of(V874)==t_structure){
	goto T3926;}
	goto T3924;
	goto T3926;
T3926:;
	if(!(((V874)->str.str_def)==(VV[66]))){
	goto T3924;}
	V883= STREF(object,(V874),0);
	goto T3922;
	goto T3924;
T3924:;{object V889;
	V889= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V874);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V890= vs_base[0];
	if(!((V889)==(CMPcar(V890)))){
	goto T3929;}}
	V883= CMPcar(((V874))->cc.cc_turbo[13]);
	goto T3922;
	goto T3929;
T3929:;
	if(!(type_of((V874))==t_structure)){
	goto T3935;}
	V883= (*(LnkLI256))((V874));
	goto T3922;
	goto T3935;
T3935:;
	if(!(type_of((V874))==t_symbol)){
	goto T3938;}
	if(((V874))==Cnil){
	goto T3941;}
	V883= (VV[44]->s.s_dbind);
	goto T3922;
	goto T3941;
T3941:;
	V883= (VV[45]->s.s_dbind);
	goto T3922;
	goto T3938;
T3938:;
	V883= (*(LnkLI257))((V874));
	goto T3922;
T3922:;
	if(type_of(V875)==t_structure){
	goto T3947;}
	goto T3945;
	goto T3947;
T3947:;
	if(!(((V875)->str.str_def)==(VV[67]))){
	goto T3945;}
	V884= STREF(object,(V875),0);
	goto T3943;
	goto T3945;
T3945:;{object V892;
	V892= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V875);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V893= vs_base[0];
	if(!((V892)==(CMPcar(V893)))){
	goto T3950;}}
	V884= CMPcar(((V875))->cc.cc_turbo[13]);
	goto T3943;
	goto T3950;
T3950:;
	if(!(type_of((V875))==t_structure)){
	goto T3956;}
	V884= (*(LnkLI256))((V875));
	goto T3943;
	goto T3956;
T3956:;
	if(!(type_of((V875))==t_symbol)){
	goto T3959;}
	if(((V875))==Cnil){
	goto T3962;}
	V884= (VV[44]->s.s_dbind);
	goto T3943;
	goto T3962;
T3962:;
	V884= (VV[45]->s.s_dbind);
	goto T3943;
	goto T3959;
T3959:;
	V884= (*(LnkLI257))((V875));
	goto T3943;
T3943:;
	{long V894;
	long V895;
	V894= 0;
	V895= (long)(V880)-(1);
	{long V896;
	V896= fix(((V882))->v.v_self[V877]);
	if(!((V896)==0)){
	goto T3970;}
	goto T3895;
	goto T3970;
T3970:;
	V894= (long)(V894)+(V896);}
	{long V897;
	V897= fix(((V883))->v.v_self[V877]);
	if(!((V897)==0)){
	goto T3976;}
	goto T3895;
	goto T3976;
T3976:;
	V894= (long)(V894)+(V897);}
	{long V898;
	V898= fix(((V884))->v.v_self[V877]);
	if(!((V898)==0)){
	goto T3981;}
	goto T3895;
	goto T3981;
T3981:;
	V894= (long)(V894)+(V898);
	V894= (long)((V894) & (V879));}
	{long V899;
	{object V900;
	V900= ((V878))->v.v_self[0];
	if(type_of((V900))==t_fixnum){
	goto T3989;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T3989;
T3989:;
	V899= fix((V900));}
	{register long V901;
	long V902;
	V901= V894;
	V902= 0;
	goto T3997;
T3997:;
	V902= (long)(V901)+(4);
	V901= (long)(V901)+(1);
	if(!(((V882))==(((V878))->v.v_self[V901]))){
	goto T4001;}
	V901= (long)(V901)+(1);
	if(!(((V883))==(((V878))->v.v_self[V901]))){
	goto T4001;}
	V901= (long)(V901)+(1);
	if(!(((V884))==(((V878))->v.v_self[V901]))){
	goto T4001;}
	V901= (long)(V901)+(1);
	V876= ((V878))->v.v_self[V901];
	goto T3995;
	goto T4001;
T4001:;
	V901= V902;
	if(!((V901)==(V895))){
	goto T4017;}
	V901= 0;
	goto T4017;
T4017:;
	if(!((V901)==(V894))){
	goto T3998;}
	{register object V903;
	register object V904;
	V903= (V881);
	V904= CMPcar((V903));
	goto T4027;
T4027:;
	if(!(((V903))==Cnil)){
	goto T4028;}
	goto T4023;
	goto T4028;
T4028:;
	{register object V905;
	V905= CMPcar((V904));
	{register object V907;
	V907= CMPcar((V905));
	V905= CMPcdr((V905));
	V906= (V907);}
	if(!(((V882))==(V906))){
	goto T4032;}
	{register object V909;
	V909= CMPcar((V905));
	V905= CMPcdr((V905));
	V908= (V909);}
	if(!(((V883))==(V908))){
	goto T4032;}
	{register object V911;
	V911= CMPcar((V905));
	V905= CMPcdr((V905));
	V910= (V911);}
	if(!(((V884))==(V910))){
	goto T4032;}
	V876= CMPcdr((V904));
	goto T3995;}
	goto T4032;
T4032:;
	V903= CMPcdr((V903));
	V904= CMPcar((V903));
	goto T4027;}
	goto T4023;
T4023:;
	goto T3895;
	goto T3998;
T3998:;
	goto T3997;
	goto T3995;
T3995:;
	{object V913;
	V913= ((V878))->v.v_self[0];
	if(type_of((V913))==t_fixnum){
	goto T4064;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T4064;
T4064:;
	V912= fix((V913));}
	if((V899)==(V912)){
	goto T3964;}
	goto T3895;}}}
	goto T3964;
T3964:;
	base[3]= (V876);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4070;}
	base[3]= STREF(object,(V876),0);
	base[4]= STREF(object,(V876),4);
	base[5]= STREF(object,(V876),8);
	base[6]= (V873);
	base[7]= (V874);
	base[8]= (V875);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4070;
T4070:;
	base[3]= V876;
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4081;}
	{object V915;
	object V916;
	object V917;
	V915= STREF(object,(V876),0);
	V916= list(3,(V873),(V874),(V875));
	V917= STREF(object,(V876),4);
	if(((V917))==Cnil){
	goto T4089;}
	if((CMPcdr((V917)))!=Cnil){
	goto T4089;}
	base[3]= (V916);
	base[4]= CMPcar((V917));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V915);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4089;
T4089:;
	base[3]= (V915);
	base[4]= (V916);
	{object V918;
	V918= (V917);
	 vs_top=base+5;
	 while(V918!=Cnil)
	 {vs_push((V918)->c.c_car);V918=(V918)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T4081;
T4081:;
	base[3]= V876;
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4099;}
	base[3]= (V873);
	base[4]= (V874);
	base[5]= (V875);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (V876);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4099;
T4099:;
	base[4]= VV[11];
	base[5]= V876;
	base[6]= VV[68];
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}
	goto T3895;
T3895:;
	base[3]= (V873);
	base[4]= (V874);
	base[5]= (V875);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[3]= Cnil;
	vs_top=(vs_base=base+3)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC65(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM131; VC131
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC144,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC144(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM132; VC132
	vs_check;
	{object V919;
	object V920;
	object V921;
	object V922;
	if(vs_top-vs_base<3) too_few_arguments();
	V919=(base[0]);
	V920=(base[1]);
	V921=(base[2]);
	vs_base=vs_base+3;
	vs_top[0]=Cnil;
	{object *p=vs_top;
	 for(;p>vs_base;p--)p[-1]=MMcons(p[-1],p[0]);}
	V922=(base[3]);
	vs_top=sup;
	{register object V923;
	V923= Cnil;
	{long V924;
	register object V925;
	long V926;
	long V927;
	object V928;
	register object V929;
	V924= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V925= STREF(object,(base0[1]->c.c_car),40);
	V926= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V927= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V928= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V919)==t_structure){
	goto T4124;}
	goto T4122;
	goto T4124;
T4124:;
	if(!(((V919)->str.str_def)==(VV[62]))){
	goto T4122;}
	V929= STREF(object,(V919),0);
	goto T4120;
	goto T4122;
T4122:;{object V931;
	V931= (VV[30]->s.s_dbind);
	base[4]= small_fixnum(14);
	base[5]= (V919);
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V932= vs_base[0];
	if(!((V931)==(CMPcar(V932)))){
	goto T4127;}}
	V929= CMPcar(((V919))->cc.cc_turbo[13]);
	goto T4120;
	goto T4127;
T4127:;
	if(!(type_of((V919))==t_structure)){
	goto T4133;}
	V929= (*(LnkLI256))((V919));
	goto T4120;
	goto T4133;
T4133:;
	if(!(type_of((V919))==t_symbol)){
	goto T4136;}
	if(((V919))==Cnil){
	goto T4139;}
	V929= (VV[44]->s.s_dbind);
	goto T4120;
	goto T4139;
T4139:;
	V929= (VV[45]->s.s_dbind);
	goto T4120;
	goto T4136;
T4136:;
	V929= (*(LnkLI257))((V919));
	goto T4120;
T4120:;
	{long V933;
	long V934;
	{long V935;
	V935= fix(((V929))->v.v_self[V924]);
	if(!((V935)==0)){
	goto T4144;}
	goto T4114;
	goto T4144;
T4144:;
	V933= (long)((V926) & (V935));}
	{object V936;
	V936= ((V925))->v.v_self[0];
	if(type_of((V936))==t_fixnum){
	goto T4149;}
	base[4]= VV[46];
	vs_top=(vs_base=base+4)+1;
	Lerror();
	vs_top=sup;
	goto T4149;
T4149:;
	V934= fix((V936));}
	{register long V937;
	V937= V933;
	goto T4156;
T4156:;
	if(!(((V929))==(((V925))->v.v_self[V937]))){
	goto T4158;}
	V923= ((V925))->v.v_self[(long)(V937)+1];
	goto T4154;
	goto T4158;
T4158:;
	V937= (long)(V937)+(2);
	if(!((V937)==(V927))){
	goto T4165;}
	V937= 0;
	goto T4165;
T4165:;
	if(!((V937)==(V933))){
	goto T4157;}
	{register object V938;
	register object V939;
	V938= (V928);
	V939= CMPcar((V938));
	goto T4175;
T4175:;
	if(!(((V938))==Cnil)){
	goto T4176;}
	goto T4171;
	goto T4176;
T4176:;
	if(!((CMPcar((V939)))==((V929)))){
	goto T4180;}
	V923= CMPcdr((V939));
	goto T4154;
	goto T4180;
T4180:;
	V938= CMPcdr((V938));
	V939= CMPcar((V938));
	goto T4175;}
	goto T4171;
T4171:;
	goto T4114;
	goto T4157;
T4157:;
	goto T4156;
	goto T4154;
T4154:;
	{object V941;
	V941= ((V925))->v.v_self[0];
	if(type_of((V941))==t_fixnum){
	goto T4195;}
	base[4]= VV[46];
	vs_top=(vs_base=base+4)+1;
	Lerror();
	vs_top=sup;
	goto T4195;
T4195:;
	V940= fix((V941));}
	if((V934)==(V940)){
	goto T4141;}
	goto T4114;}}
	goto T4141;
T4141:;
	base[4]= (V923);
	base[5]= VV[2];
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4201;}
	base[4]= STREF(object,(V923),0);
	base[5]= STREF(object,(V923),4);
	base[6]= STREF(object,(V923),8);
	base[7]= (V919);
	base[8]= (V920);
	base[9]= (V921);
	base[10]= (V922);
	vs_top=(vs_base=base+5)+6;
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4201;
T4201:;
	base[4]= V923;
	base[5]= VV[10];
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4213;}
	{object V943;
	object V944;
	object V945;
	V943= STREF(object,(V923),0);
	V944= listA(4,(V919),(V920),(V921),(V922));
	V945= STREF(object,(V923),4);
	if(((V945))==Cnil){
	goto T4221;}
	if((CMPcdr((V945)))!=Cnil){
	goto T4221;}
	base[4]= (V944);
	base[5]= CMPcar((V945));
	vs_top=(vs_base=base+4)+2;
	{object _funobj = (V943);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4221;
T4221:;
	base[4]= (V943);
	base[5]= (V944);
	{object V946;
	V946= (V945);
	 vs_top=base+6;
	 while(V946!=Cnil)
	 {vs_push((V946)->c.c_car);V946=(V946)->c.c_cdr;}
	vs_base=base+5;}
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T4213;
T4213:;
	base[4]= V923;
	vs_top=(vs_base=base+4)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4231;}
	base[4]= (V923);
	base[5]= (V919);
	base[6]= (V920);
	base[7]= (V921);
	{object V947;
	V947= (V922);
	 vs_top=base+8;
	 while(V947!=Cnil)
	 {vs_push((V947)->c.c_car);V947=(V947)->c.c_cdr;}
	vs_base=base+5;}
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4231;
T4231:;
	base[5]= VV[11];
	base[6]= V923;
	base[7]= VV[63];
	vs_top=(vs_base=base+5)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[4]= vs_base[0];
	vs_top=(vs_base=base+4)+1;
	Lerror();
	return;}
	goto T4114;
T4114:;
	base[4]= (base0[0]->c.c_car);
	base[5]= (V919);
	base[6]= (V920);
	base[7]= (V921);
	{object V948;
	V948= (V922);
	 vs_top=base+8;
	 while(V948!=Cnil)
	 {vs_push((V948)->c.c_car);V948=(V948)->c.c_cdr;}
	vs_base=base+5;}
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[4]= Cnil;
	vs_top=(vs_base=base+4)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC64(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM133; VC133
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC145,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC145(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM134; VC134
	vs_check;
	{object V949;
	object V950;
	object V951;
	object V952;
	check_arg(4);
	V949=(base[0]);
	V950=(base[1]);
	V951=(base[2]);
	V952=(base[3]);
	vs_top=sup;
	{object V953;
	V953= Cnil;
	{long V954;
	object V955;
	long V956;
	long V957;
	object V958;
	object V959;
	object V960;
	V954= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V955= STREF(object,(base0[1]->c.c_car),40);
	V956= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V957= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V958= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V949)==t_structure){
	goto T4260;}
	goto T4258;
	goto T4260;
T4260:;
	if(!(((V949)->str.str_def)==(VV[58]))){
	goto T4258;}
	V959= STREF(object,(V949),0);
	goto T4256;
	goto T4258;
T4258:;{object V962;
	V962= (VV[30]->s.s_dbind);
	base[4]= small_fixnum(14);
	base[5]= (V949);
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V963= vs_base[0];
	if(!((V962)==(CMPcar(V963)))){
	goto T4263;}}
	V959= CMPcar(((V949))->cc.cc_turbo[13]);
	goto T4256;
	goto T4263;
T4263:;
	if(!(type_of((V949))==t_structure)){
	goto T4269;}
	V959= (*(LnkLI256))((V949));
	goto T4256;
	goto T4269;
T4269:;
	if(!(type_of((V949))==t_symbol)){
	goto T4272;}
	if(((V949))==Cnil){
	goto T4275;}
	V959= (VV[44]->s.s_dbind);
	goto T4256;
	goto T4275;
T4275:;
	V959= (VV[45]->s.s_dbind);
	goto T4256;
	goto T4272;
T4272:;
	V959= (*(LnkLI257))((V949));
	goto T4256;
T4256:;
	if(type_of(V950)==t_structure){
	goto T4281;}
	goto T4279;
	goto T4281;
T4281:;
	if(!(((V950)->str.str_def)==(VV[59]))){
	goto T4279;}
	V960= STREF(object,(V950),0);
	goto T4277;
	goto T4279;
T4279:;{object V965;
	V965= (VV[30]->s.s_dbind);
	base[4]= small_fixnum(14);
	base[5]= (V950);
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V966= vs_base[0];
	if(!((V965)==(CMPcar(V966)))){
	goto T4284;}}
	V960= CMPcar(((V950))->cc.cc_turbo[13]);
	goto T4277;
	goto T4284;
T4284:;
	if(!(type_of((V950))==t_structure)){
	goto T4290;}
	V960= (*(LnkLI256))((V950));
	goto T4277;
	goto T4290;
T4290:;
	if(!(type_of((V950))==t_symbol)){
	goto T4293;}
	if(((V950))==Cnil){
	goto T4296;}
	V960= (VV[44]->s.s_dbind);
	goto T4277;
	goto T4296;
T4296:;
	V960= (VV[45]->s.s_dbind);
	goto T4277;
	goto T4293;
T4293:;
	V960= (*(LnkLI257))((V950));
	goto T4277;
T4277:;
	{long V967;
	long V968;
	V967= 0;
	V968= (long)(V957)-(1);
	{long V969;
	V969= fix(((V959))->v.v_self[V954]);
	if(!((V969)==0)){
	goto T4304;}
	goto T4250;
	goto T4304;
T4304:;
	V967= (long)(V967)+(V969);}
	{long V970;
	V970= fix(((V960))->v.v_self[V954]);
	if(!((V970)==0)){
	goto T4309;}
	goto T4250;
	goto T4309;
T4309:;
	V967= (long)(V967)+(V970);
	V967= (long)((V967) & (V956));}
	{long V971;
	{object V972;
	V972= ((V955))->v.v_self[0];
	if(type_of((V972))==t_fixnum){
	goto T4317;}
	base[4]= VV[46];
	vs_top=(vs_base=base+4)+1;
	Lerror();
	vs_top=sup;
	goto T4317;
T4317:;
	V971= fix((V972));}
	{register long V973;
	long V974;
	V973= V967;
	V974= 0;
	goto T4325;
T4325:;
	V974= (long)(V973)+(4);
	V973= (long)(V973)+(1);
	if(!(((V959))==(((V955))->v.v_self[V973]))){
	goto T4329;}
	V973= (long)(V973)+(1);
	if(!(((V960))==(((V955))->v.v_self[V973]))){
	goto T4329;}
	V973= (long)(V973)+(1);
	V953= ((V955))->v.v_self[V973];
	goto T4323;
	goto T4329;
T4329:;
	V973= V974;
	if(!((V973)==(V968))){
	goto T4342;}
	V973= 0;
	goto T4342;
T4342:;
	if(!((V973)==(V967))){
	goto T4326;}
	{register object V975;
	register object V976;
	V975= (V958);
	V976= CMPcar((V975));
	goto T4352;
T4352:;
	if(!(((V975))==Cnil)){
	goto T4353;}
	goto T4348;
	goto T4353;
T4353:;
	{register object V977;
	V977= CMPcar((V976));
	{register object V979;
	V979= CMPcar((V977));
	V977= CMPcdr((V977));
	V978= (V979);}
	if(!(((V959))==(V978))){
	goto T4357;}
	{register object V981;
	V981= CMPcar((V977));
	V977= CMPcdr((V977));
	V980= (V981);}
	if(!(((V960))==(V980))){
	goto T4357;}
	V953= CMPcdr((V976));
	goto T4323;}
	goto T4357;
T4357:;
	V975= CMPcdr((V975));
	V976= CMPcar((V975));
	goto T4352;}
	goto T4348;
T4348:;
	goto T4250;
	goto T4326;
T4326:;
	goto T4325;
	goto T4323;
T4323:;
	{object V983;
	V983= ((V955))->v.v_self[0];
	if(type_of((V983))==t_fixnum){
	goto T4383;}
	base[4]= VV[46];
	vs_top=(vs_base=base+4)+1;
	Lerror();
	vs_top=sup;
	goto T4383;
T4383:;
	V982= fix((V983));}
	if((V971)==(V982)){
	goto T4298;}
	goto T4250;}}}
	goto T4298;
T4298:;
	base[4]= (V953);
	base[5]= VV[2];
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4389;}
	base[4]= STREF(object,(V953),0);
	base[5]= STREF(object,(V953),4);
	base[6]= STREF(object,(V953),8);
	base[7]= (V949);
	base[8]= (V950);
	base[9]= (V951);
	base[10]= (V952);
	vs_top=(vs_base=base+5)+6;
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4389;
T4389:;
	base[4]= V953;
	base[5]= VV[10];
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4401;}
	{object V985;
	object V986;
	object V987;
	V985= STREF(object,(V953),0);
	V986= list(4,(V949),(V950),(V951),(V952));
	V987= STREF(object,(V953),4);
	if(((V987))==Cnil){
	goto T4409;}
	if((CMPcdr((V987)))!=Cnil){
	goto T4409;}
	base[4]= (V986);
	base[5]= CMPcar((V987));
	vs_top=(vs_base=base+4)+2;
	{object _funobj = (V985);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4409;
T4409:;
	base[4]= (V985);
	base[5]= (V986);
	{object V988;
	V988= (V987);
	 vs_top=base+6;
	 while(V988!=Cnil)
	 {vs_push((V988)->c.c_car);V988=(V988)->c.c_cdr;}
	vs_base=base+5;}
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T4401;
T4401:;
	base[4]= V953;
	vs_top=(vs_base=base+4)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4419;}
	base[4]= (V949);
	base[5]= (V950);
	base[6]= (V951);
	base[7]= (V952);
	vs_top=(vs_base=base+4)+4;
	{object _funobj = (V953);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4419;
T4419:;
	base[5]= VV[11];
	base[6]= V953;
	base[7]= VV[60];
	vs_top=(vs_base=base+5)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[4]= vs_base[0];
	vs_top=(vs_base=base+4)+1;
	Lerror();
	return;}
	goto T4250;
T4250:;
	base[4]= (V949);
	base[5]= (V950);
	base[6]= (V951);
	base[7]= (V952);
	vs_top=(vs_base=base+4)+4;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[4]= Cnil;
	vs_top=(vs_base=base+4)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC63(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM135; VC135
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC146,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC146(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM136; VC136
	vs_check;
	{object V989;
	object V990;
	object V991;
	object V992;
	object V993;
	check_arg(5);
	V989=(base[0]);
	V990=(base[1]);
	V991=(base[2]);
	V992=(base[3]);
	V993=(base[4]);
	vs_top=sup;
	{object V994;
	V994= Cnil;
	{long V995;
	object V996;
	long V997;
	long V998;
	object V999;
	object V1000;
	object V1001;
	V995= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V996= STREF(object,(base0[1]->c.c_car),40);
	V997= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V998= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V999= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V989)==t_structure){
	goto T4446;}
	goto T4444;
	goto T4446;
T4446:;
	if(!(((V989)->str.str_def)==(VV[54]))){
	goto T4444;}
	V1000= STREF(object,(V989),0);
	goto T4442;
	goto T4444;
T4444:;{object V1003;
	V1003= (VV[30]->s.s_dbind);
	base[5]= small_fixnum(14);
	base[6]= (V989);
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V1004= vs_base[0];
	if(!((V1003)==(CMPcar(V1004)))){
	goto T4449;}}
	V1000= CMPcar(((V989))->cc.cc_turbo[13]);
	goto T4442;
	goto T4449;
T4449:;
	if(!(type_of((V989))==t_structure)){
	goto T4455;}
	V1000= (*(LnkLI256))((V989));
	goto T4442;
	goto T4455;
T4455:;
	if(!(type_of((V989))==t_symbol)){
	goto T4458;}
	if(((V989))==Cnil){
	goto T4461;}
	V1000= (VV[44]->s.s_dbind);
	goto T4442;
	goto T4461;
T4461:;
	V1000= (VV[45]->s.s_dbind);
	goto T4442;
	goto T4458;
T4458:;
	V1000= (*(LnkLI257))((V989));
	goto T4442;
T4442:;
	if(type_of(V990)==t_structure){
	goto T4467;}
	goto T4465;
	goto T4467;
T4467:;
	if(!(((V990)->str.str_def)==(VV[55]))){
	goto T4465;}
	V1001= STREF(object,(V990),0);
	goto T4463;
	goto T4465;
T4465:;{object V1006;
	V1006= (VV[30]->s.s_dbind);
	base[5]= small_fixnum(14);
	base[6]= (V990);
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V1007= vs_base[0];
	if(!((V1006)==(CMPcar(V1007)))){
	goto T4470;}}
	V1001= CMPcar(((V990))->cc.cc_turbo[13]);
	goto T4463;
	goto T4470;
T4470:;
	if(!(type_of((V990))==t_structure)){
	goto T4476;}
	V1001= (*(LnkLI256))((V990));
	goto T4463;
	goto T4476;
T4476:;
	if(!(type_of((V990))==t_symbol)){
	goto T4479;}
	if(((V990))==Cnil){
	goto T4482;}
	V1001= (VV[44]->s.s_dbind);
	goto T4463;
	goto T4482;
T4482:;
	V1001= (VV[45]->s.s_dbind);
	goto T4463;
	goto T4479;
T4479:;
	V1001= (*(LnkLI257))((V990));
	goto T4463;
T4463:;
	{long V1008;
	long V1009;
	V1008= 0;
	V1009= (long)(V998)-(1);
	{long V1010;
	V1010= fix(((V1000))->v.v_self[V995]);
	if(!((V1010)==0)){
	goto T4490;}
	goto T4436;
	goto T4490;
T4490:;
	V1008= (long)(V1008)+(V1010);}
	{long V1011;
	V1011= fix(((V1001))->v.v_self[V995]);
	if(!((V1011)==0)){
	goto T4495;}
	goto T4436;
	goto T4495;
T4495:;
	V1008= (long)(V1008)+(V1011);
	V1008= (long)((V1008) & (V997));}
	{long V1012;
	{object V1013;
	V1013= ((V996))->v.v_self[0];
	if(type_of((V1013))==t_fixnum){
	goto T4503;}
	base[5]= VV[46];
	vs_top=(vs_base=base+5)+1;
	Lerror();
	vs_top=sup;
	goto T4503;
T4503:;
	V1012= fix((V1013));}
	{register long V1014;
	long V1015;
	V1014= V1008;
	V1015= 0;
	goto T4511;
T4511:;
	V1015= (long)(V1014)+(4);
	V1014= (long)(V1014)+(1);
	if(!(((V1000))==(((V996))->v.v_self[V1014]))){
	goto T4515;}
	V1014= (long)(V1014)+(1);
	if(!(((V1001))==(((V996))->v.v_self[V1014]))){
	goto T4515;}
	V1014= (long)(V1014)+(1);
	V994= ((V996))->v.v_self[V1014];
	goto T4509;
	goto T4515;
T4515:;
	V1014= V1015;
	if(!((V1014)==(V1009))){
	goto T4528;}
	V1014= 0;
	goto T4528;
T4528:;
	if(!((V1014)==(V1008))){
	goto T4512;}
	{register object V1016;
	register object V1017;
	V1016= (V999);
	V1017= CMPcar((V1016));
	goto T4538;
T4538:;
	if(!(((V1016))==Cnil)){
	goto T4539;}
	goto T4534;
	goto T4539;
T4539:;
	{register object V1018;
	V1018= CMPcar((V1017));
	{register object V1020;
	V1020= CMPcar((V1018));
	V1018= CMPcdr((V1018));
	V1019= (V1020);}
	if(!(((V1000))==(V1019))){
	goto T4543;}
	{register object V1022;
	V1022= CMPcar((V1018));
	V1018= CMPcdr((V1018));
	V1021= (V1022);}
	if(!(((V1001))==(V1021))){
	goto T4543;}
	V994= CMPcdr((V1017));
	goto T4509;}
	goto T4543;
T4543:;
	V1016= CMPcdr((V1016));
	V1017= CMPcar((V1016));
	goto T4538;}
	goto T4534;
T4534:;
	goto T4436;
	goto T4512;
T4512:;
	goto T4511;
	goto T4509;
T4509:;
	{object V1024;
	V1024= ((V996))->v.v_self[0];
	if(type_of((V1024))==t_fixnum){
	goto T4569;}
	base[5]= VV[46];
	vs_top=(vs_base=base+5)+1;
	Lerror();
	vs_top=sup;
	goto T4569;
T4569:;
	V1023= fix((V1024));}
	if((V1012)==(V1023)){
	goto T4484;}
	goto T4436;}}}
	goto T4484;
T4484:;
	base[5]= (V994);
	base[6]= VV[2];
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4575;}
	base[5]= STREF(object,(V994),0);
	base[6]= STREF(object,(V994),4);
	base[7]= STREF(object,(V994),8);
	base[8]= (V989);
	base[9]= (V990);
	base[10]= (V991);
	base[11]= (V992);
	base[12]= (V993);
	vs_top=(vs_base=base+6)+7;
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4575;
T4575:;
	base[5]= V994;
	base[6]= VV[10];
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4588;}
	{object V1026;
	object V1027;
	object V1028;
	V1026= STREF(object,(V994),0);
	V1027= list(5,(V989),(V990),(V991),(V992),(V993));
	V1028= STREF(object,(V994),4);
	if(((V1028))==Cnil){
	goto T4596;}
	if((CMPcdr((V1028)))!=Cnil){
	goto T4596;}
	base[5]= (V1027);
	base[6]= CMPcar((V1028));
	vs_top=(vs_base=base+5)+2;
	{object _funobj = (V1026);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4596;
T4596:;
	base[5]= (V1026);
	base[6]= (V1027);
	{object V1029;
	V1029= (V1028);
	 vs_top=base+7;
	 while(V1029!=Cnil)
	 {vs_push((V1029)->c.c_car);V1029=(V1029)->c.c_cdr;}
	vs_base=base+6;}
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T4588;
T4588:;
	base[5]= V994;
	vs_top=(vs_base=base+5)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4606;}
	base[5]= (V989);
	base[6]= (V990);
	base[7]= (V991);
	base[8]= (V992);
	base[9]= (V993);
	vs_top=(vs_base=base+5)+5;
	{object _funobj = (V994);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4606;
T4606:;
	base[6]= VV[11];
	base[7]= V994;
	base[8]= VV[56];
	vs_top=(vs_base=base+6)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[5]= vs_base[0];
	vs_top=(vs_base=base+5)+1;
	Lerror();
	return;}
	goto T4436;
T4436:;
	base[5]= (V989);
	base[6]= (V990);
	base[7]= (V991);
	base[8]= (V992);
	base[9]= (V993);
	vs_top=(vs_base=base+5)+5;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[5]= Cnil;
	vs_top=(vs_base=base+5)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC62(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM137; VC137
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC147,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC147(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM138; VC138
	vs_check;
	{object V1030;
	object V1031;
	object V1032;
	check_arg(3);
	V1030=(base[0]);
	V1031=(base[1]);
	V1032=(base[2]);
	vs_top=sup;
	{object V1033;
	V1033= Cnil;
	{long V1034;
	object V1035;
	long V1036;
	long V1037;
	object V1038;
	object V1039;
	object V1040;
	V1034= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V1035= STREF(object,(base0[1]->c.c_car),40);
	V1036= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V1037= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V1038= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V1030)==t_structure){
	goto T4635;}
	goto T4633;
	goto T4635;
T4635:;
	if(!(((V1030)->str.str_def)==(VV[50]))){
	goto T4633;}
	V1039= STREF(object,(V1030),0);
	goto T4631;
	goto T4633;
T4633:;{object V1042;
	V1042= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V1030);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V1043= vs_base[0];
	if(!((V1042)==(CMPcar(V1043)))){
	goto T4638;}}
	V1039= CMPcar(((V1030))->cc.cc_turbo[13]);
	goto T4631;
	goto T4638;
T4638:;
	if(!(type_of((V1030))==t_structure)){
	goto T4644;}
	V1039= (*(LnkLI256))((V1030));
	goto T4631;
	goto T4644;
T4644:;
	if(!(type_of((V1030))==t_symbol)){
	goto T4647;}
	if(((V1030))==Cnil){
	goto T4650;}
	V1039= (VV[44]->s.s_dbind);
	goto T4631;
	goto T4650;
T4650:;
	V1039= (VV[45]->s.s_dbind);
	goto T4631;
	goto T4647;
T4647:;
	V1039= (*(LnkLI257))((V1030));
	goto T4631;
T4631:;
	if(type_of(V1031)==t_structure){
	goto T4656;}
	goto T4654;
	goto T4656;
T4656:;
	if(!(((V1031)->str.str_def)==(VV[51]))){
	goto T4654;}
	V1040= STREF(object,(V1031),0);
	goto T4652;
	goto T4654;
T4654:;{object V1045;
	V1045= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V1031);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V1046= vs_base[0];
	if(!((V1045)==(CMPcar(V1046)))){
	goto T4659;}}
	V1040= CMPcar(((V1031))->cc.cc_turbo[13]);
	goto T4652;
	goto T4659;
T4659:;
	if(!(type_of((V1031))==t_structure)){
	goto T4665;}
	V1040= (*(LnkLI256))((V1031));
	goto T4652;
	goto T4665;
T4665:;
	if(!(type_of((V1031))==t_symbol)){
	goto T4668;}
	if(((V1031))==Cnil){
	goto T4671;}
	V1040= (VV[44]->s.s_dbind);
	goto T4652;
	goto T4671;
T4671:;
	V1040= (VV[45]->s.s_dbind);
	goto T4652;
	goto T4668;
T4668:;
	V1040= (*(LnkLI257))((V1031));
	goto T4652;
T4652:;
	{long V1047;
	long V1048;
	V1047= 0;
	V1048= (long)(V1037)-(1);
	{long V1049;
	V1049= fix(((V1039))->v.v_self[V1034]);
	if(!((V1049)==0)){
	goto T4679;}
	goto T4625;
	goto T4679;
T4679:;
	V1047= (long)(V1047)+(V1049);}
	{long V1050;
	V1050= fix(((V1040))->v.v_self[V1034]);
	if(!((V1050)==0)){
	goto T4684;}
	goto T4625;
	goto T4684;
T4684:;
	V1047= (long)(V1047)+(V1050);
	V1047= (long)((V1047) & (V1036));}
	{long V1051;
	{object V1052;
	V1052= ((V1035))->v.v_self[0];
	if(type_of((V1052))==t_fixnum){
	goto T4692;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T4692;
T4692:;
	V1051= fix((V1052));}
	{register long V1053;
	long V1054;
	V1053= V1047;
	V1054= 0;
	goto T4700;
T4700:;
	V1054= (long)(V1053)+(4);
	V1053= (long)(V1053)+(1);
	if(!(((V1039))==(((V1035))->v.v_self[V1053]))){
	goto T4704;}
	V1053= (long)(V1053)+(1);
	if(!(((V1040))==(((V1035))->v.v_self[V1053]))){
	goto T4704;}
	V1053= (long)(V1053)+(1);
	V1033= ((V1035))->v.v_self[V1053];
	goto T4698;
	goto T4704;
T4704:;
	V1053= V1054;
	if(!((V1053)==(V1048))){
	goto T4717;}
	V1053= 0;
	goto T4717;
T4717:;
	if(!((V1053)==(V1047))){
	goto T4701;}
	{register object V1055;
	register object V1056;
	V1055= (V1038);
	V1056= CMPcar((V1055));
	goto T4727;
T4727:;
	if(!(((V1055))==Cnil)){
	goto T4728;}
	goto T4723;
	goto T4728;
T4728:;
	{register object V1057;
	V1057= CMPcar((V1056));
	{register object V1059;
	V1059= CMPcar((V1057));
	V1057= CMPcdr((V1057));
	V1058= (V1059);}
	if(!(((V1039))==(V1058))){
	goto T4732;}
	{register object V1061;
	V1061= CMPcar((V1057));
	V1057= CMPcdr((V1057));
	V1060= (V1061);}
	if(!(((V1040))==(V1060))){
	goto T4732;}
	V1033= CMPcdr((V1056));
	goto T4698;}
	goto T4732;
T4732:;
	V1055= CMPcdr((V1055));
	V1056= CMPcar((V1055));
	goto T4727;}
	goto T4723;
T4723:;
	goto T4625;
	goto T4701;
T4701:;
	goto T4700;
	goto T4698;
T4698:;
	{object V1063;
	V1063= ((V1035))->v.v_self[0];
	if(type_of((V1063))==t_fixnum){
	goto T4758;}
	base[3]= VV[46];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	vs_top=sup;
	goto T4758;
T4758:;
	V1062= fix((V1063));}
	if((V1051)==(V1062)){
	goto T4673;}
	goto T4625;}}}
	goto T4673;
T4673:;
	base[3]= (V1033);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4764;}
	base[3]= STREF(object,(V1033),0);
	base[4]= STREF(object,(V1033),4);
	base[5]= STREF(object,(V1033),8);
	base[6]= (V1030);
	base[7]= (V1031);
	base[8]= (V1032);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4764;
T4764:;
	base[3]= V1033;
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4775;}
	{object V1065;
	object V1066;
	object V1067;
	V1065= STREF(object,(V1033),0);
	V1066= list(3,(V1030),(V1031),(V1032));
	V1067= STREF(object,(V1033),4);
	if(((V1067))==Cnil){
	goto T4783;}
	if((CMPcdr((V1067)))!=Cnil){
	goto T4783;}
	base[3]= (V1066);
	base[4]= CMPcar((V1067));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V1065);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4783;
T4783:;
	base[3]= (V1065);
	base[4]= (V1066);
	{object V1068;
	V1068= (V1067);
	 vs_top=base+5;
	 while(V1068!=Cnil)
	 {vs_push((V1068)->c.c_car);V1068=(V1068)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T4775;
T4775:;
	base[3]= V1033;
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4793;}
	base[3]= (V1030);
	base[4]= (V1031);
	base[5]= (V1032);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (V1033);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4793;
T4793:;
	base[4]= VV[11];
	base[5]= V1033;
	base[6]= VV[52];
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}
	goto T4625;
T4625:;
	base[3]= (V1030);
	base[4]= (V1031);
	base[5]= (V1032);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[3]= Cnil;
	vs_top=(vs_base=base+3)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC61(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM139; VC139
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC148,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC148(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM140; VC140
	vs_check;
	{object V1069;
	object V1070;
	check_arg(2);
	V1069=(base[0]);
	V1070=(base[1]);
	vs_top=sup;
	{register object V1071;
	V1071= Cnil;
	{long V1072;
	register object V1073;
	long V1074;
	long V1075;
	object V1076;
	register object V1077;
	V1072= (long)STREF(unsigned char,(base0[1]->c.c_car),16);
	V1073= STREF(object,(base0[1]->c.c_car),40);
	V1074= (long)STREF(fixnum,(base0[1]->c.c_car),24);
	V1075= (long)STREF(fixnum,(base0[1]->c.c_car),28);
	V1076= STREF(object,(base0[1]->c.c_car),44);
	if(type_of(V1070)==t_structure){
	goto T4818;}
	goto T4816;
	goto T4818;
T4818:;
	if(!(((V1070)->str.str_def)==(VV[43]))){
	goto T4816;}
	V1077= STREF(object,(V1070),0);
	goto T4814;
	goto T4816;
T4816:;{object V1079;
	V1079= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V1070);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V1080= vs_base[0];
	if(!((V1079)==(CMPcar(V1080)))){
	goto T4821;}}
	V1077= CMPcar(((V1070))->cc.cc_turbo[13]);
	goto T4814;
	goto T4821;
T4821:;
	if(!(type_of((V1070))==t_structure)){
	goto T4827;}
	V1077= (*(LnkLI256))((V1070));
	goto T4814;
	goto T4827;
T4827:;
	if(!(type_of((V1070))==t_symbol)){
	goto T4830;}
	if(((V1070))==Cnil){
	goto T4833;}
	V1077= (VV[44]->s.s_dbind);
	goto T4814;
	goto T4833;
T4833:;
	V1077= (VV[45]->s.s_dbind);
	goto T4814;
	goto T4830;
T4830:;
	V1077= (*(LnkLI257))((V1070));
	goto T4814;
T4814:;
	{long V1081;
	long V1082;
	{long V1083;
	V1083= fix(((V1077))->v.v_self[V1072]);
	if(!((V1083)==0)){
	goto T4838;}
	goto T4808;
	goto T4838;
T4838:;
	V1081= (long)((V1074) & (V1083));}
	{object V1084;
	V1084= ((V1073))->v.v_self[0];
	if(type_of((V1084))==t_fixnum){
	goto T4843;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T4843;
T4843:;
	V1082= fix((V1084));}
	{register long V1085;
	V1085= V1081;
	goto T4850;
T4850:;
	if(!(((V1077))==(((V1073))->v.v_self[V1085]))){
	goto T4852;}
	V1071= ((V1073))->v.v_self[(long)(V1085)+1];
	goto T4848;
	goto T4852;
T4852:;
	V1085= (long)(V1085)+(2);
	if(!((V1085)==(V1075))){
	goto T4859;}
	V1085= 0;
	goto T4859;
T4859:;
	if(!((V1085)==(V1081))){
	goto T4851;}
	{register object V1086;
	register object V1087;
	V1086= (V1076);
	V1087= CMPcar((V1086));
	goto T4869;
T4869:;
	if(!(((V1086))==Cnil)){
	goto T4870;}
	goto T4865;
	goto T4870;
T4870:;
	if(!((CMPcar((V1087)))==((V1077)))){
	goto T4874;}
	V1071= CMPcdr((V1087));
	goto T4848;
	goto T4874;
T4874:;
	V1086= CMPcdr((V1086));
	V1087= CMPcar((V1086));
	goto T4869;}
	goto T4865;
T4865:;
	goto T4808;
	goto T4851;
T4851:;
	goto T4850;
	goto T4848;
T4848:;
	{object V1089;
	V1089= ((V1073))->v.v_self[0];
	if(type_of((V1089))==t_fixnum){
	goto T4889;}
	base[2]= VV[46];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	vs_top=sup;
	goto T4889;
T4889:;
	V1088= fix((V1089));}
	if((V1082)==(V1088)){
	goto T4835;}
	goto T4808;}}
	goto T4835;
T4835:;
	base[2]= (V1071);
	base[3]= VV[2];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4895;}
	base[2]= STREF(object,(V1071),0);
	base[3]= STREF(object,(V1071),4);
	base[4]= STREF(object,(V1071),8);
	base[5]= (V1069);
	base[6]= (V1070);
	vs_top=(vs_base=base+3)+4;
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4895;
T4895:;
	if(!(type_of((V1071))==t_fixnum)){
	goto T4905;}
	{object V1091;
	if(type_of(V1069)==t_structure){
	goto T4911;}
	goto T4909;
	goto T4911;
T4911:;
	if(!(((V1069)->str.str_def)==(VV[47]))){
	goto T4909;}
	V1091= STREF(object,(V1069),4);
	goto T4907;
	goto T4909;
T4909:;{object V1093;
	V1093= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V1069);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V1094= vs_base[0];
	if(!((V1093)==(CMPcar(V1094)))){
	goto T4914;}}
	V1091= CMPcar(((V1069))->cc.cc_turbo[12]);
	goto T4907;
	goto T4914;
T4914:;
	V1091= Cnil;
	goto T4907;
T4907:;
	if(((V1091))==Cnil){
	goto T4920;}
	base[2]= ((V1091))->v.v_self[fix((V1071))]= (V1069);
	vs_top=(vs_base=base+2)+1;
	return;
	goto T4920;
T4920:;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	goto T4905;
T4905:;
	base[2]= V1071;
	base[3]= VV[10];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4923;}
	{object V1096;
	object V1097;
	object V1098;
	V1096= STREF(object,(V1071),0);
	V1097= list(2,(V1069),(V1070));
	V1098= STREF(object,(V1071),4);
	if(((V1098))==Cnil){
	goto T4931;}
	if((CMPcdr((V1098)))!=Cnil){
	goto T4931;}
	base[2]= (V1097);
	base[3]= CMPcar((V1098));
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V1096);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4931;
T4931:;
	base[2]= (V1096);
	base[3]= (V1097);
	{object V1099;
	V1099= (V1098);
	 vs_top=base+4;
	 while(V1099!=Cnil)
	 {vs_push((V1099)->c.c_car);V1099=(V1099)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T4923;
T4923:;
	base[2]= V1071;
	vs_top=(vs_base=base+2)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4941;}
	base[2]= (V1069);
	base[3]= (V1070);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V1071);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4941;
T4941:;
	base[3]= VV[11];
	base[4]= V1071;
	base[5]= VV[48];
	vs_top=(vs_base=base+3)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	return;}
	goto T4808;
T4808:;
	base[2]= (V1069);
	base[3]= (V1070);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (base0[0]->c.c_car);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	}
}
/*	local function CLOSURE	*/

static void LC60(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM141; VC141
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC149,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC149(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM142; VC142
	vs_check;
	{register object V1100;
	object V1101;
	check_arg(2);
	V1100=(base[0]);
	V1101=(base[1]);
	vs_top=sup;
	{register object V1102;
	V1102= (base0[1]->c.c_car);
	base[2]= (V1102);
	base[3]= VV[2];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4955;}
	base[2]= STREF(object,(V1102),0);
	base[3]= STREF(object,(V1102),4);
	base[4]= STREF(object,(V1102),8);
	base[5]= (V1100);
	base[6]= (V1101);
	vs_top=(vs_base=base+3)+4;
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4955;
T4955:;
	if(!(type_of((V1102))==t_fixnum)){
	goto T4965;}
	{object V1104;
	if(type_of(V1100)==t_structure){
	goto T4971;}
	goto T4969;
	goto T4971;
T4971:;
	if(!(((V1100)->str.str_def)==(VV[38]))){
	goto T4969;}
	V1104= STREF(object,(V1100),4);
	goto T4967;
	goto T4969;
T4969:;{object V1106;
	V1106= (VV[30]->s.s_dbind);
	base[2]= small_fixnum(14);
	base[3]= (V1100);
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V1107= vs_base[0];
	if(!((V1106)==(CMPcar(V1107)))){
	goto T4974;}}
	V1104= CMPcar(((V1100))->cc.cc_turbo[12]);
	goto T4967;
	goto T4974;
T4974:;
	V1104= Cnil;
	goto T4967;
T4967:;
	if(((V1104))==Cnil){
	goto T4980;}
	base[2]= ((V1104))->v.v_self[fix((V1102))]= (V1100);
	vs_top=(vs_base=base+2)+1;
	return;
	goto T4980;
T4980:;
	base[2]= Cnil;
	vs_top=(vs_base=base+2)+1;
	return;}
	goto T4965;
T4965:;
	{register object V1108;
	V1108= (V1102);
	base[2]= (V1108);
	base[3]= VV[10];
	vs_top=(vs_base=base+2)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T4983;}
	{object V1109;
	object V1110;
	register object V1111;
	V1109= STREF(object,(V1102),0);
	V1110= list(2,(V1100),(V1101));
	V1111= STREF(object,(V1102),4);
	if(((V1111))==Cnil){
	goto T4994;}
	if(!((CMPcdr((V1111)))==Cnil)){
	goto T4991;}
	goto T4992;
	goto T4994;
T4994:;
	goto T4991;
	goto T4992;
T4992:;
	base[2]= (V1110);
	base[3]= CMPcar((V1111));
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V1109);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T4991;
T4991:;
	base[2]= (V1109);
	base[3]= (V1110);
	{object V1112;
	V1112= (V1111);
	 vs_top=base+4;
	 while(V1112!=Cnil)
	 {vs_push((V1112)->c.c_car);V1112=(V1112)->c.c_cdr;}
	vs_base=base+3;}
	{object _funobj = base[2];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T4983;
T4983:;
	base[2]= (V1108);
	vs_top=(vs_base=base+2)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5002;}
	base[2]= (V1100);
	base[3]= (V1101);
	vs_top=(vs_base=base+2)+2;
	{object _funobj = (V1102);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5002;
T5002:;
	base[3]= VV[11];
	base[4]= (V1108);
	base[5]= (base0[0]->c.c_car);
	vs_top=(vs_base=base+3)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[2]= vs_base[0];
	vs_top=(vs_base=base+2)+1;
	Lerror();
	return;}}
	}
}
/*	local function CLOSURE	*/

static void LC59(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM143; VC143
	vs_check;
	check_arg(4);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	base[3]=MMcons(base[3],base[2]);
	vs_top=sup;
	base[4]= 
	make_cclosure_new(LC150,Cnil,base[3],Cdata);
	vs_top=(vs_base=base+4)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC150(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM144; VC144
	vs_check;
	{register object V1113;
	register object V1114;
	object V1115;
	check_arg(3);
	V1113=(base[0]);
	V1114=(base[1]);
	V1115=(base[2]);
	vs_top=sup;
	{register object V1116;
	base[3]= (V1113);
	base[4]= VV[24];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk261)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5013;}
	{register object V1117;
	register object V1118;
	V1117= (base0[3]->c.c_car);
	V1118= CMPcar((V1117));
	goto T5020;
T5020:;
	if(!(((V1117))==Cnil)){
	goto T5021;}
	V1116= (base0[2]->c.c_car);
	goto T5011;
	goto T5021;
T5021:;
	if(!((CMPcar((V1118)))==((V1114)))){
	goto T5025;}
	V1116= CMPcdr((V1118));
	goto T5011;
	goto T5025;
T5025:;
	V1117= CMPcdr((V1117));
	V1118= CMPcar((V1117));
	goto T5020;}
	goto T5013;
T5013:;
	V1116= (base0[1]->c.c_car);
	goto T5011;
T5011:;
	base[3]= (V1116);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5035;}
	base[3]= STREF(object,(V1116),0);
	base[4]= STREF(object,(V1116),4);
	base[5]= STREF(object,(V1116),8);
	base[6]= (V1113);
	base[7]= (V1114);
	base[8]= (V1115);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5035;
T5035:;
	{register object V1119;
	V1119= (V1116);
	base[3]= (V1119);
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5046;}
	{object V1120;
	object V1121;
	object V1122;
	V1120= STREF(object,(V1116),0);
	V1121= list(3,(V1113),(V1114),(V1115));
	V1122= STREF(object,(V1116),4);
	if(((V1122))==Cnil){
	goto T5057;}
	if(!((CMPcdr((V1122)))==Cnil)){
	goto T5054;}
	goto T5055;
	goto T5057;
T5057:;
	goto T5054;
	goto T5055;
T5055:;
	base[3]= (V1121);
	base[4]= CMPcar((V1122));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V1120);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5054;
T5054:;
	base[3]= (V1120);
	base[4]= (V1121);
	{object V1123;
	V1123= (V1122);
	 vs_top=base+5;
	 while(V1123!=Cnil)
	 {vs_push((V1123)->c.c_car);V1123=(V1123)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T5046;
T5046:;
	base[3]= (V1119);
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5065;}
	base[3]= (V1113);
	base[4]= (V1114);
	base[5]= (V1115);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (V1116);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5065;
T5065:;
	base[4]= VV[11];
	base[5]= (V1119);
	base[6]= (base0[0]->c.c_car);
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}}
	}
}
/*	local function CLOSURE	*/

static void LC58(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM145; VC145
	vs_check;
	check_arg(2);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	vs_top=sup;
	base[2]= 
	make_cclosure_new(LC151,Cnil,base[1],Cdata);
	vs_top=(vs_base=base+2)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC151(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM146; VC146
	vs_check;
	{register object V1124;
	check_arg(1);
	V1124=(base[0]);
	vs_top=sup;
	{register object V1125;
	V1125= (base0[1]->c.c_car);
	base[1]= (V1125);
	base[2]= VV[2];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5077;}
	base[1]= STREF(object,(V1125),0);
	base[2]= STREF(object,(V1125),4);
	base[3]= STREF(object,(V1125),8);
	base[4]= (V1124);
	vs_top=(vs_base=base+2)+3;
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5077;
T5077:;
	if(!(type_of((V1125))==t_fixnum)){
	goto T5086;}
	{object V1126;
	object V1127;
	if(type_of(V1124)==t_structure){
	goto T5092;}
	goto T5090;
	goto T5092;
T5092:;
	if(!(((V1124)->str.str_def)==(VV[28]))){
	goto T5090;}
	V1126= STREF(object,(V1124),4);
	goto T5088;
	goto T5090;
T5090:;{object V1129;
	V1129= (VV[30]->s.s_dbind);
	base[3]= small_fixnum(14);
	base[4]= (V1124);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk253)();
	vs_top=sup;
	V1130= vs_base[0];
	if(!((V1129)==(CMPcar(V1130)))){
	goto T5095;}}
	V1126= CMPcar(((V1124))->cc.cc_turbo[12]);
	goto T5088;
	goto T5095;
T5095:;
	V1126= Cnil;
	goto T5088;
T5088:;
	if(((V1126))==Cnil){
	goto T5102;}
	V1127= ((V1126))->v.v_self[fix((V1125))];
	goto T5100;
	goto T5102;
T5102:;
	V1127= Cnil;
	goto T5100;
T5100:;
	if(!(((V1127))==(VV[31]))){
	goto T5105;}
	base[3]= (V1124);
	base[4]= (V1125);
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk259)();
	return;
	goto T5105;
T5105:;
	base[3]= (V1127);
	vs_top=(vs_base=base+3)+1;
	return;}
	goto T5086;
T5086:;
	{register object V1131;
	V1131= (V1125);
	base[1]= (V1131);
	base[2]= VV[10];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5110;}
	{object V1132;
	object V1133;
	register object V1134;
	V1132= STREF(object,(V1125),0);
	V1133= make_cons((V1124),Cnil);
	V1134= STREF(object,(V1125),4);
	if(((V1134))==Cnil){
	goto T5121;}
	if(!((CMPcdr((V1134)))==Cnil)){
	goto T5118;}
	goto T5119;
	goto T5121;
T5121:;
	goto T5118;
	goto T5119;
T5119:;
	base[1]= (V1133);
	base[2]= CMPcar((V1134));
	vs_top=(vs_base=base+1)+2;
	{object _funobj = (V1132);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5118;
T5118:;
	base[1]= (V1132);
	base[2]= (V1133);
	{object V1135;
	V1135= (V1134);
	 vs_top=base+3;
	 while(V1135!=Cnil)
	 {vs_push((V1135)->c.c_car);V1135=(V1135)->c.c_cdr;}
	vs_base=base+2;}
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T5110;
T5110:;
	base[1]= (V1131);
	vs_top=(vs_base=base+1)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5129;}
	base[1]= (V1124);
	vs_top=(vs_base=base+1)+1;
	{object _funobj = (V1125);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5129;
T5129:;
	base[2]= VV[11];
	base[3]= (V1131);
	base[4]= (base0[0]->c.c_car);
	vs_top=(vs_base=base+2)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[1]= vs_base[0];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	return;}}
	}
}
/*	local function CLOSURE	*/

static void LC57(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM147; VC147
	vs_check;
	check_arg(4);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	base[3]=MMcons(base[3],base[2]);
	vs_top=sup;
	base[4]= 
	make_cclosure_new(LC152,Cnil,base[3],Cdata);
	vs_top=(vs_base=base+4)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC152(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM148; VC148
	vs_check;
	{register object V1136;
	register object V1137;
	object V1138;
	check_arg(3);
	V1136=(base[0]);
	V1137=(base[1]);
	V1138=(base[2]);
	vs_top=sup;
	{register object V1139;
	base[3]= (V1136);
	base[4]= VV[24];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk261)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5139;}
	if(!(((V1137))==(CMPcar((base0[3]->c.c_car))))){
	goto T5144;}
	V1139= CMPcdr((base0[3]->c.c_car));
	goto T5137;
	goto T5144;
T5144:;
	V1139= (base0[2]->c.c_car);
	goto T5137;
	goto T5139;
T5139:;
	V1139= (base0[1]->c.c_car);
	goto T5137;
T5137:;
	base[3]= (V1139);
	base[4]= VV[2];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5148;}
	base[3]= STREF(object,(V1139),0);
	base[4]= STREF(object,(V1139),4);
	base[5]= STREF(object,(V1139),8);
	base[6]= (V1136);
	base[7]= (V1137);
	base[8]= (V1138);
	vs_top=(vs_base=base+4)+5;
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5148;
T5148:;
	{register object V1140;
	V1140= (V1139);
	base[3]= (V1140);
	base[4]= VV[10];
	vs_top=(vs_base=base+3)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5159;}
	{object V1141;
	object V1142;
	register object V1143;
	V1141= STREF(object,(V1139),0);
	V1142= list(3,(V1136),(V1137),(V1138));
	V1143= STREF(object,(V1139),4);
	if(((V1143))==Cnil){
	goto T5170;}
	if(!((CMPcdr((V1143)))==Cnil)){
	goto T5167;}
	goto T5168;
	goto T5170;
T5170:;
	goto T5167;
	goto T5168;
T5168:;
	base[3]= (V1142);
	base[4]= CMPcar((V1143));
	vs_top=(vs_base=base+3)+2;
	{object _funobj = (V1141);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5167;
T5167:;
	base[3]= (V1141);
	base[4]= (V1142);
	{object V1144;
	V1144= (V1143);
	 vs_top=base+5;
	 while(V1144!=Cnil)
	 {vs_push((V1144)->c.c_car);V1144=(V1144)->c.c_cdr;}
	vs_base=base+4;}
	{object _funobj = base[3];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;}
	goto T5159;
T5159:;
	base[3]= (V1140);
	vs_top=(vs_base=base+3)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5178;}
	base[3]= (V1136);
	base[4]= (V1137);
	base[5]= (V1138);
	vs_top=(vs_base=base+3)+3;
	{object _funobj = (V1139);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	return;
	goto T5178;
T5178:;
	base[4]= VV[11];
	base[5]= (V1140);
	base[6]= (base0[0]->c.c_car);
	vs_top=(vs_base=base+4)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[3]= vs_base[0];
	vs_top=(vs_base=base+3)+1;
	Lerror();
	return;}}
	}
}
/*	local function CLOSURE	*/

static void LC56(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM149; VC149
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC153,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC153(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM150; VC150
	vs_check;
	{object V1145;
	object V1146;
	register object V1147;
	register object V1148;
	check_arg(4);
	V1145=(base[0]);
	V1146=(base[1]);
	V1147=(base[2]);
	V1148=(base[3]);
	vs_top=sup;
	{register object V1151;
	object V1152;
	V1151= (base0[2]->c.c_car);
	V1152= CMPcar((V1151));
	goto T5193;
T5193:;
	if(!(((V1151))==Cnil)){
	goto T5194;}
	goto T5189;
	goto T5194;
T5194:;
	(void)((
	V1153 = STREF(object,(V1152),0),
	(type_of(V1153) == t_sfun ?(*((V1153)->sfn.sfn_self)):
	(fcall.argd=4,type_of(V1153)==t_vfun) ?
	(*((V1153)->sfn.sfn_self)):
	(fcall.fun=(V1153),fcalln))(STREF(object,(V1152),4),STREF(object,(V1152),8),(V1147),(V1148))));
	V1151= CMPcdr((V1151));
	V1152= CMPcar((V1151));
	goto T5193;}
	goto T5189;
T5189:;
	base[4]= (base0[1]->c.c_car);
	base[5]= VV[2];
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5207;}
	base[4]= STREF(object,(base0[1]->c.c_car),0);
	base[5]= STREF(object,(base0[1]->c.c_car),4);
	base[6]= STREF(object,(base0[1]->c.c_car),8);
	base[7]= (V1147);
	base[8]= (V1148);
	vs_top=(vs_base=base+5)+4;
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	goto T5188;
	goto T5207;
T5207:;
	{object V1154;
	V1154= (base0[1]->c.c_car);
	base[4]= (V1154);
	base[5]= VV[10];
	vs_top=(vs_base=base+4)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5217;}
	{object V1155;
	object V1156;
	object V1157;
	V1155= STREF(object,(base0[1]->c.c_car),0);
	V1156= make_cons((V1147),(V1148));
	V1157= STREF(object,(base0[1]->c.c_car),4);
	if(((V1157))==Cnil){
	goto T5225;}
	if((CMPcdr((V1157)))!=Cnil){
	goto T5225;}
	base[4]= (V1156);
	base[5]= CMPcar((V1157));
	vs_top=(vs_base=base+4)+2;
	{object _funobj = (V1155);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	goto T5188;
	goto T5225;
T5225:;
	base[4]= (V1155);
	base[5]= (V1156);
	{object V1158;
	V1158= (V1157);
	 vs_top=base+6;
	 while(V1158!=Cnil)
	 {vs_push((V1158)->c.c_car);V1158=(V1158)->c.c_cdr;}
	vs_base=base+5;}
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	goto T5188;}
	goto T5217;
T5217:;
	base[4]= (V1154);
	vs_top=(vs_base=base+4)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5235;}
	base[4]= (base0[1]->c.c_car);
	base[5]= (V1147);
	{object V1159;
	V1159= (V1148);
	 vs_top=base+6;
	 while(V1159!=Cnil)
	 {vs_push((V1159)->c.c_car);V1159=(V1159)->c.c_cdr;}
	vs_base=base+5;}
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	goto T5188;
	goto T5235;
T5235:;
	base[5]= VV[13];
	base[6]= (V1154);
	base[7]= VV[19];
	vs_top=(vs_base=base+5)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[4]= vs_base[0];
	vs_top=(vs_base=base+4)+1;
	Lerror();}
	goto T5188;
T5188:;
	{object *V1150=vs_top;object *V1149=vs_base; vs_base=V1150;
	{register object *base1=base;
	{register object *base=V1150;
	register object *sup=vs_base+VM151;
	base1[0]=base1[0];
	base[0]=base[0];
	vs_check;
	vs_top=sup;
	{register object V1160;
	register object V1161;
	V1160= (base0[0]->c.c_car);
	V1161= CMPcar((V1160));
	goto T5249;
T5249:;
	if(!(((V1160))==Cnil)){
	goto T5250;}
	goto T5245;
	goto T5250;
T5250:;
	base[1]= (V1161);
	base[2]= VV[2];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5257;}
	(void)((
	V1162 = STREF(object,(V1161),0),
	(type_of(V1162) == t_sfun ?(*((V1162)->sfn.sfn_self)):
	(fcall.argd=4,type_of(V1162)==t_vfun) ?
	(*((V1162)->sfn.sfn_self)):
	(fcall.fun=(V1162),fcalln))(STREF(object,(V1161),4),STREF(object,(V1161),8),(V1147),(V1148))));
	goto T5254;
	goto T5257;
T5257:;
	{register object V1163;
	V1163= (V1161);
	base[1]= (V1163);
	base[2]= VV[10];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5262;}
	{object V1164;
	object V1165;
	register object V1166;
	V1164= STREF(object,(V1161),0);
	V1165= make_cons((V1147),(V1148));
	V1166= STREF(object,(V1161),4);
	if(((V1166))==Cnil){
	goto T5270;}
	if((CMPcdr((V1166)))!=Cnil){
	goto T5270;}
	(void)((
	(type_of((V1164)) == t_sfun ?(*(((V1164))->sfn.sfn_self)):
	(fcall.argd=2,type_of((V1164))==t_vfun) ?
	(*(((V1164))->sfn.sfn_self)):
	(fcall.fun=((V1164)),fcalln))((V1165),CMPcar((V1166)))));
	goto T5254;
	goto T5270;
T5270:;
	base[1]= (V1164);
	base[2]= (V1165);
	{object V1167;
	V1167= (V1166);
	 vs_top=base+3;
	 while(V1167!=Cnil)
	 {vs_push((V1167)->c.c_car);V1167=(V1167)->c.c_cdr;}
	vs_base=base+2;}
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	vs_top=sup;
	goto T5254;}
	goto T5262;
T5262:;
	base[1]= (V1163);
	vs_top=(vs_base=base+1)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5278;}
	base[1]= (V1161);
	base[2]= (V1147);
	{object V1168;
	V1168= (V1148);
	 vs_top=base+3;
	 while(V1168!=Cnil)
	 {vs_push((V1168)->c.c_car);V1168=(V1168)->c.c_cdr;}
	vs_base=base+2;}
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	vs_top=sup;
	goto T5254;
	goto T5278;
T5278:;
	base[2]= VV[11];
	base[3]= (V1163);
	base[4]= VV[20];
	vs_top=(vs_base=base+2)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[1]= vs_base[0];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	vs_top=sup;}
	goto T5254;
T5254:;
	V1160= CMPcdr((V1160));
	V1161= CMPcar((V1160));
	goto T5249;}
	}}
	goto T5245;
T5245:;
	vs_base=V1149;vs_top=V1150;}
	return;
	}
}
/*	local function CLOSURE	*/

static void LC55(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM152; VC152
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC154,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC154(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM153; VC153
	vs_check;
	{object V1169;
	object V1170;
	register object V1171;
	register object V1172;
	register object V1173;
	check_arg(5);
	V1169=(base[0]);
	V1170=(base[1]);
	V1171=(base[2]);
	V1172=(base[3]);
	V1173=(base[4]);
	vs_top=sup;
	{object V1176;
	register object V1177;
	V1176= (base0[2]->c.c_car);
	V1177= CMPcar((V1176));
	goto T5298;
T5298:;
	if(!(((V1176))==Cnil)){
	goto T5299;}
	goto T5294;
	goto T5299;
T5299:;
	base[6]= (V1177);
	base[7]= VV[2];
	vs_top=(vs_base=base+6)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5306;}
	(void)((
	V1178 = STREF(object,(V1177),0),
	(type_of(V1178) == t_sfun ?(*((V1178)->sfn.sfn_self)):
	(fcall.argd=5,type_of(V1178)==t_vfun) ?
	(*((V1178)->sfn.sfn_self)):
	(fcall.fun=(V1178),fcalln))(STREF(object,(V1177),4),STREF(object,(V1177),8),(V1171),(V1172),(V1173))));
	goto T5303;
	goto T5306;
T5306:;
	base[6]= V1177;
	base[7]= VV[10];
	vs_top=(vs_base=base+6)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5311;}
	{object V1180;
	object V1181;
	register object V1182;
	V1180= STREF(object,(V1177),0);
	V1181= listA(3,(V1171),(V1172),(V1173));
	V1182= STREF(object,(V1177),4);
	if(((V1182))==Cnil){
	goto T5319;}
	if((CMPcdr((V1182)))!=Cnil){
	goto T5319;}
	(void)((
	(type_of((V1180)) == t_sfun ?(*(((V1180))->sfn.sfn_self)):
	(fcall.argd=2,type_of((V1180))==t_vfun) ?
	(*(((V1180))->sfn.sfn_self)):
	(fcall.fun=((V1180)),fcalln))((V1181),CMPcar((V1182)))));
	goto T5303;
	goto T5319;
T5319:;
	base[6]= (V1180);
	base[7]= (V1181);
	{object V1183;
	V1183= (V1182);
	 vs_top=base+8;
	 while(V1183!=Cnil)
	 {vs_push((V1183)->c.c_car);V1183=(V1183)->c.c_cdr;}
	vs_base=base+7;}
	{object _funobj = base[6];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	vs_top=sup;
	goto T5303;}
	goto T5311;
T5311:;
	base[6]= V1177;
	vs_top=(vs_base=base+6)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5327;}
	base[6]= (V1177);
	base[7]= (V1171);
	base[8]= (V1172);
	{object V1184;
	V1184= (V1173);
	 vs_top=base+9;
	 while(V1184!=Cnil)
	 {vs_push((V1184)->c.c_car);V1184=(V1184)->c.c_cdr;}
	vs_base=base+7;}
	{object _funobj = base[6];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	vs_top=sup;
	goto T5303;
	goto T5327;
T5327:;
	base[7]= VV[11];
	base[8]= V1177;
	base[9]= VV[12];
	vs_top=(vs_base=base+7)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[6]= vs_base[0];
	vs_top=(vs_base=base+6)+1;
	Lerror();
	vs_top=sup;
	goto T5303;
T5303:;
	V1176= CMPcdr((V1176));
	V1177= CMPcar((V1176));
	goto T5298;}
	goto T5294;
T5294:;
	base[5]= (base0[1]->c.c_car);
	base[6]= VV[2];
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5345;}
	base[5]= STREF(object,(base0[1]->c.c_car),0);
	base[6]= STREF(object,(base0[1]->c.c_car),4);
	base[7]= STREF(object,(base0[1]->c.c_car),8);
	base[8]= (V1171);
	base[9]= (V1172);
	base[10]= (V1173);
	vs_top=(vs_base=base+6)+5;
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	goto T5293;
	goto T5345;
T5345:;
	{object V1185;
	V1185= (base0[1]->c.c_car);
	base[5]= (V1185);
	base[6]= VV[10];
	vs_top=(vs_base=base+5)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5356;}
	{object V1186;
	object V1187;
	object V1188;
	V1186= STREF(object,(base0[1]->c.c_car),0);
	V1187= listA(3,(V1171),(V1172),(V1173));
	V1188= STREF(object,(base0[1]->c.c_car),4);
	if(((V1188))==Cnil){
	goto T5364;}
	if((CMPcdr((V1188)))!=Cnil){
	goto T5364;}
	base[5]= (V1187);
	base[6]= CMPcar((V1188));
	vs_top=(vs_base=base+5)+2;
	{object _funobj = (V1186);if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	goto T5293;
	goto T5364;
T5364:;
	base[5]= (V1186);
	base[6]= (V1187);
	{object V1189;
	V1189= (V1188);
	 vs_top=base+7;
	 while(V1189!=Cnil)
	 {vs_push((V1189)->c.c_car);V1189=(V1189)->c.c_cdr;}
	vs_base=base+6;}
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	goto T5293;}
	goto T5356;
T5356:;
	base[5]= (V1185);
	vs_top=(vs_base=base+5)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5374;}
	base[5]= (base0[1]->c.c_car);
	base[6]= (V1171);
	base[7]= (V1172);
	{object V1190;
	V1190= (V1173);
	 vs_top=base+8;
	 while(V1190!=Cnil)
	 {vs_push((V1190)->c.c_car);V1190=(V1190)->c.c_cdr;}
	vs_base=base+6;}
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	goto T5293;
	goto T5374;
T5374:;
	base[6]= VV[13];
	base[7]= (V1185);
	base[8]= VV[14];
	vs_top=(vs_base=base+6)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[5]= vs_base[0];
	vs_top=(vs_base=base+5)+1;
	Lerror();}
	goto T5293;
T5293:;
	{object *V1175=vs_top;object *V1174=vs_base; vs_base=V1175;
	{register object *base1=base;
	{register object *base=V1175;
	register object *sup=vs_base+VM154;
	base1[0]=base1[0];
	base[0]=base[0];
	vs_check;
	vs_top=sup;
	{object V1191;
	register object V1192;
	V1191= (base0[0]->c.c_car);
	V1192= CMPcar((V1191));
	goto T5389;
T5389:;
	if(!(((V1191))==Cnil)){
	goto T5390;}
	goto T5385;
	goto T5390;
T5390:;
	base[1]= (V1192);
	base[2]= VV[2];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5397;}
	(void)((
	V1193 = STREF(object,(V1192),0),
	(type_of(V1193) == t_sfun ?(*((V1193)->sfn.sfn_self)):
	(fcall.argd=5,type_of(V1193)==t_vfun) ?
	(*((V1193)->sfn.sfn_self)):
	(fcall.fun=(V1193),fcalln))(STREF(object,(V1192),4),STREF(object,(V1192),8),(V1171),(V1172),(V1173))));
	goto T5394;
	goto T5397;
T5397:;
	base[1]= V1192;
	base[2]= VV[10];
	vs_top=(vs_base=base+1)+2;
	(void) (*Lnk258)();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5402;}
	{object V1195;
	object V1196;
	register object V1197;
	V1195= STREF(object,(V1192),0);
	V1196= listA(3,(V1171),(V1172),(V1173));
	V1197= STREF(object,(V1192),4);
	if(((V1197))==Cnil){
	goto T5410;}
	if((CMPcdr((V1197)))!=Cnil){
	goto T5410;}
	(void)((
	(type_of((V1195)) == t_sfun ?(*(((V1195))->sfn.sfn_self)):
	(fcall.argd=2,type_of((V1195))==t_vfun) ?
	(*(((V1195))->sfn.sfn_self)):
	(fcall.fun=((V1195)),fcalln))((V1196),CMPcar((V1197)))));
	goto T5394;
	goto T5410;
T5410:;
	base[1]= (V1195);
	base[2]= (V1196);
	{object V1198;
	V1198= (V1197);
	 vs_top=base+3;
	 while(V1198!=Cnil)
	 {vs_push((V1198)->c.c_car);V1198=(V1198)->c.c_cdr;}
	vs_base=base+2;}
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	vs_top=sup;
	goto T5394;}
	goto T5402;
T5402:;
	base[1]= V1192;
	vs_top=(vs_base=base+1)+1;
	Lfunctionp();
	vs_top=sup;
	if((vs_base[0])==Cnil){
	goto T5418;}
	base[1]= (V1192);
	base[2]= (V1171);
	base[3]= (V1172);
	{object V1199;
	V1199= (V1173);
	 vs_top=base+4;
	 while(V1199!=Cnil)
	 {vs_push((V1199)->c.c_car);V1199=(V1199)->c.c_cdr;}
	vs_base=base+2;}
	{object _funobj = base[1];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	vs_top=sup;
	goto T5394;
	goto T5418;
T5418:;
	base[2]= VV[11];
	base[3]= V1192;
	base[4]= VV[15];
	vs_top=(vs_base=base+2)+3;
	(void) (*Lnk260)();
	vs_top=sup;
	base[1]= vs_base[0];
	vs_top=(vs_base=base+1)+1;
	Lerror();
	vs_top=sup;
	goto T5394;
T5394:;
	V1191= CMPcdr((V1191));
	V1192= CMPcar((V1191));
	goto T5389;}
	}}
	goto T5385;
T5385:;
	vs_base=V1174;vs_top=V1175;}
	return;
	}
}
/*	local function CLOSURE	*/

static void LC54(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM155; VC155
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC155,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC155(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM156; VC156
	vs_check;
	{object V1200;
	object V1201;
	register object V1202;
	register object V1203;
	check_arg(4);
	V1200=(base[0]);
	V1201=(base[1]);
	V1202=(base[2]);
	V1203=(base[3]);
	vs_top=sup;
	{register object V1206;
	register object V1207;
	V1206= (base0[2]->c.c_car);
	V1207= CMPcar((V1206));
	goto T5439;
T5439:;
	if(!(((V1206))==Cnil)){
	goto T5440;}
	goto T5435;
	goto T5440;
T5440:;
	(void)((
	V1208 = STREF(object,(V1207),0),
	(type_of(V1208) == t_sfun ?(*((V1208)->sfn.sfn_self)):
	(fcall.argd=4,type_of(V1208)==t_vfun) ?
	(*((V1208)->sfn.sfn_self)):
	(fcall.fun=(V1208),fcalln))(STREF(object,(V1207),4),STREF(object,(V1207),8),(V1202),(V1203))));
	V1206= CMPcdr((V1206));
	V1207= CMPcar((V1206));
	goto T5439;}
	goto T5435;
T5435:;
	base[4]= STREF(object,(base0[1]->c.c_car),0);
	base[5]= STREF(object,(base0[1]->c.c_car),4);
	base[6]= STREF(object,(base0[1]->c.c_car),8);
	base[7]= (V1202);
	base[8]= (V1203);
	vs_top=(vs_base=base+5)+4;
	{object _funobj = base[4];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	{object *V1205=vs_top;object *V1204=vs_base; vs_base=V1205;
	{register object *base1=base;
	{register object *base=V1205;
	register object *sup=vs_base+VM157;
	base1[0]=base1[0];
	base[0]=base[0];
	vs_check;
	vs_top=sup;
	{register object V1209;
	register object V1210;
	V1209= (base0[0]->c.c_car);
	V1210= CMPcar((V1209));
	goto T5461;
T5461:;
	if(!(((V1209))==Cnil)){
	goto T5462;}
	goto T5457;
	goto T5462;
T5462:;
	(void)((
	V1211 = STREF(object,(V1210),0),
	(type_of(V1211) == t_sfun ?(*((V1211)->sfn.sfn_self)):
	(fcall.argd=4,type_of(V1211)==t_vfun) ?
	(*((V1211)->sfn.sfn_self)):
	(fcall.fun=(V1211),fcalln))(STREF(object,(V1210),4),STREF(object,(V1210),8),(V1202),(V1203))));
	V1209= CMPcdr((V1209));
	V1210= CMPcar((V1209));
	goto T5461;}
	}}
	goto T5457;
T5457:;
	vs_base=V1204;vs_top=V1205;}
	return;
	}
}
/*	local function CLOSURE	*/

static void LC53(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM158; VC158
	vs_check;
	check_arg(3);
	base[0]=MMcons(base[0],Cnil);
	base[1]=MMcons(base[1],base[0]);
	base[2]=MMcons(base[2],base[1]);
	vs_top=sup;
	base[3]= 
	make_cclosure_new(LC156,Cnil,base[2],Cdata);
	vs_top=(vs_base=base+3)+1;
	return;
}
/*	local function CLOSURE	*/

static void LC156(base0)
register object *base0;
{	register object *base=vs_base;
	register object *sup=base+VM159; VC159
	vs_check;
	{object V1212;
	object V1213;
	register object V1214;
	register object V1215;
	register object V1216;
	check_arg(5);
	V1212=(base[0]);
	V1213=(base[1]);
	V1214=(base[2]);
	V1215=(base[3]);
	V1216=(base[4]);
	vs_top=sup;
	{register object V1219;
	register object V1220;
	V1219= (base0[2]->c.c_car);
	V1220= CMPcar((V1219));
	goto T5478;
T5478:;
	if(!(((V1219))==Cnil)){
	goto T5479;}
	goto T5474;
	goto T5479;
T5479:;
	(void)((
	V1221 = STREF(object,(V1220),0),
	(type_of(V1221) == t_sfun ?(*((V1221)->sfn.sfn_self)):
	(fcall.argd=5,type_of(V1221)==t_vfun) ?
	(*((V1221)->sfn.sfn_self)):
	(fcall.fun=(V1221),fcalln))(STREF(object,(V1220),4),STREF(object,(V1220),8),(V1214),(V1215),(V1216))));
	V1219= CMPcdr((V1219));
	V1220= CMPcar((V1219));
	goto T5478;}
	goto T5474;
T5474:;
	base[5]= STREF(object,(base0[1]->c.c_car),0);
	base[6]= STREF(object,(base0[1]->c.c_car),4);
	base[7]= STREF(object,(base0[1]->c.c_car),8);
	base[8]= (V1214);
	base[9]= (V1215);
	base[10]= (V1216);
	vs_top=(vs_base=base+6)+5;
	{object _funobj = base[5];if(type_of(_funobj)==t_cclosure && (_funobj->cc.cc_turbo))
                   (*(_funobj->cc.cc_self))(_funobj->cc.cc_turbo);
               else if (type_of(_funobj)==t_cfun) (*(_funobj->cc.cc_self))();
               else super_funcall_no_event(_funobj);}
	{object *V1218=vs_top;object *V1217=vs_base; vs_base=V1218;
	{register object *base1=base;
	{register object *base=V1218;
	register object *sup=vs_base+VM160;
	base1[0]=base1[0];
	base[0]=base[0];
	vs_check;
	vs_top=sup;
	{register object V1222;
	register object V1223;
	V1222= (base0[0]->c.c_car);
	V1223= CMPcar((V1222));
	goto T5501;
T5501:;
	if(!(((V1222))==Cnil)){
	goto T5502;}
	goto T5497;
	goto T5502;
T5502:;
	(void)((
	V1224 = STREF(object,(V1223),0),
	(type_of(V1224) == t_sfun ?(*((V1224)->sfn.sfn_self)):
	(fcall.argd=5,type_of(V1224)==t_vfun) ?
	(*((V1224)->sfn.sfn_self)):
	(fcall.fun=(V1224),fcalln))(STREF(object,(V1223),4),STREF(object,(V1223),8),(V1214),(V1215),(V1216))));
	V1222= CMPcdr((V1222));
	V1223= CMPcar((V1222));
	goto T5501;}
	}}
	goto T5497;
T5497:;
	vs_base=V1217;vs_top=V1218;}
	return;
	}
}
static void LnkT261(){ call_or_link(VV[261],(void **)(void *)&Lnk261);} /* TYPEP */
static void LnkT260(){ call_or_link(VV[260],(void **)(void *)&Lnk260);} /* TYPECASE-ERROR-STRING */
static void LnkT259(){ call_or_link(VV[259],(void **)(void *)&Lnk259);} /* SLOT-UNBOUND-INTERNAL */
static void LnkT258(){ call_or_link(VV[258],(void **)(void *)&Lnk258);} /* STRUCTURE-SUBTYPE-P */
static object  LnkTLI257(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_proc_new(VV[257],(void **)(void *)&LnkLI257,1,first,ap);va_end(ap);return V1;} /* BUILT-IN-WRAPPER-OF */
static object  LnkTLI256(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_proc_new(VV[256],(void **)(void *)&LnkLI256,1,first,ap);va_end(ap);return V1;} /* WRAPPER-FOR-STRUCTURE */
static object  LnkTLI255(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_proc_new(VV[255],(void **)(void *)&LnkLI255,1,first,ap);va_end(ap);return V1;} /* WRAPPER-OF */
static object  LnkTLI254(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_proc_new(VV[254],(void **)(void *)&LnkLI254,4098,first,ap);va_end(ap);return V1;} /* %CCLOSURE-ENV-NTHCDR */
static void LnkT253(){ call_or_link(VV[253],(void **)(void *)&Lnk253);} /* CCLOSURE-ENV-NTHCDR */
static object  LnkTLI231(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_proc_new(VV[231],(void **)(void *)&LnkLI231,4,first,ap);va_end(ap);return V1;} /* LOAD-PRECOMPILED-IIS-ENTRY */
static object  LnkTLI207(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_proc_new(VV[207],(void **)(void *)&LnkLI207,4,first,ap);va_end(ap);return V1;} /* LOAD-PRECOMPILED-DFUN-CONSTRUCTOR */
static object  LnkTLI198(object first,...){object V1;va_list ap;va_start(ap,first);V1=call_proc_new(VV[198],(void **)(void *)&LnkLI198,5,first,ap);va_end(ap);return V1;} /* LOAD-FUNCTION-GENERATOR */

#ifdef SYSTEM_SPECIAL_INIT
SYSTEM_SPECIAL_INIT
#endif

